.btn-toggle{background:#bdc1c8;color:#6b7381}.btn-toggle.active{background-color:#2a9fd8}.btn-toggle.disabled{cursor:not-allowed;opacity:.5}.btn-toggle.btn-lg{position:relative;min-width:5.6rem;height:2.8rem;padding:0;border:none;border-radius:2.8rem;float:right}.btn-toggle.btn-lg:focus,.btn-toggle.btn-lg:focus.active,.btn-toggle.btn-lg.focus,.btn-toggle.btn-lg.focus.active{outline:none}.btn-toggle.btn-lg>.handle{position:absolute;top:.4rem;left:.4rem;width:2rem;height:2rem;background:#fff;border-radius:1rem;transition:left .25s}.btn-toggle.btn-lg.active{transition:background-color .25s}.btn-toggle.btn-lg.active>.handle{right:.4rem;left:inherit;transition:left .25s}.btn-toggle.btn-sm{position:relative;min-width:3rem;height:1.5rem;padding:0;border:none;border-radius:1.5rem;float:right}.btn-toggle.btn-sm:focus,.btn-toggle.btn-sm:focus.active,.btn-toggle.btn-sm.focus,.btn-toggle.btn-sm.focus.active{outline:none}.btn-toggle.btn-sm>.handle{position:absolute;top:.4rem;left:.4rem;width:2rem;height:2rem;background:#fff;border-radius:1rem;transition:left .25s}.btn-toggle.btn-sm.active{transition:background-color .25s}.btn-toggle.btn-sm.active>.handle{right:.4rem;left:inherit;transition:left .25s}.btn-toggle.btn-xs{position:relative;min-width:2rem;height:1rem;padding:0;border:none;border-radius:1rem;float:right}.btn-toggle.btn-xs:focus,.btn-toggle.btn-xs:focus.active,.btn-toggle.btn-xs.focus,.btn-toggle.btn-xs.focus.active{outline:none}.btn-toggle.btn-xs>.handle{position:absolute;top:.4rem;left:.4rem;width:2rem;height:2rem;background:#fff;border-radius:1rem;transition:left .25s}.btn-toggle.btn-xs.active{transition:background-color .25s}.btn-toggle.btn-xs.active>.handle{right:.4rem;left:inherit;transition:left .25s}.btn-toggle .bg-text{color:#fff;font-size:1.4rem;font-weight:600}.btn-toggle .bg-text.off{padding:0 1.6rem 0 3.4rem}.btn-toggle .bg-text.on{padding:0 3.4rem 0 1.6rem}.InviteAs__label{color:var(--center-channel-color)}.InviteAs__label--parenthetical{color:rgba(var(--center-channel-color-rgb), 0.8)}.InviteAs .radio:first-child{margin-top:0}.InviteAs .radio:last-child{margin-bottom:0}
.InviteResultTable{width:100%;max-height:400px;overflow-y:auto}.InviteResultTable .table-header{display:flex;height:40px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color);font-size:14px}.InviteResultTable .table-header .people-header,.InviteResultTable .table-header .details-header{display:flex;width:50%;align-items:center;margin:12px;font-weight:bold}.InviteResultTable .table-header span{display:flex}.InviteResultRow{display:flex}.InviteResultRow .username-or-icon{display:flex;width:50%;align-items:center}.InviteResultRow .username-or-icon .email{margin:0 4px 0 8px;overflow-wrap:anywhere;word-break:break-word}.InviteResultRow .username-or-icon .name{margin:0 4px 0 8px}.InviteResultRow .username-or-icon .mail-icon{display:inline-block;width:36px;height:36px;padding:3px;margin:12px 0 12px 12px;background:var(--button-bg);border-radius:18px}.InviteResultRow .username-or-icon .mail-icon svg{width:24px;height:24px;margin:3px;fill:var(--button-color)}.InviteResultRow .username-or-icon .alert-icon{display:inline-block;width:36px;height:36px;padding:3px;margin:12px 0 12px 12px;background:var(--dnd-indicator);border-radius:18px}.InviteResultRow .username-or-icon .alert-icon svg{width:28.8px;height:28.8px;margin:.6px;fill:var(--button-color)}.InviteResultRow .username-or-icon .Avatar{margin:12px 0 12px 12px}.InviteResultRow .username-or-icon .Badge{display:inline-block;margin-top:2px;vertical-align:top}.InviteResultRow .reason{display:flex;width:50%;align-items:center;padding:12px}.invitation-modal-confirm h2{margin-bottom:13px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:14px;font-weight:600}.invitation-modal-confirm--not-sent .InviteResultTable .table-header{background:rgba(238,179,0,.2)}.invitation-modal-confirm--sent .InviteResultTable .table-header{background:rgba(0,131,89,.2)}.invitation-modal-confirm--sent .InviteResultTable .table-header svg{width:18px;height:18px;fill:var(--center-channel-color)}
.ResultView__inviteMore{border:1px solid var(--button-bg);background:transparent}
.ChannelsInput.empty .channels-input__control .channels-input__input{border-bottom:0}.ChannelsInput .channels-input__control{min-height:48px;padding:3px;border-color:rgba(var(--center-channel-color-rgb), 0.2);background:var(--center-channel-bg);box-shadow:none;color:rgba(var(--center-channel-color-rgb), 0.64);transition:none}.ChannelsInput .channels-input__control:hover{border-color:rgba(var(--center-channel-color-rgb), 0.2);cursor:text}.ChannelsInput .channels-input__control--is-focused,.ChannelsInput .channels-input__control--menu-is-open{padding:2px;border-width:2px;border-color:var(--button-bg);transition:none}.ChannelsInput .channels-input__control--is-focused:hover,.ChannelsInput .channels-input__control--menu-is-open:hover{border-color:var(--button-bg)}.ChannelsInput .channels-input__control--is-focused .channels-input__value-container .channels-input__input,.ChannelsInput .channels-input__control--menu-is-open .channels-input__value-container .channels-input__input{border-bottom:0}.ChannelsInput .channels-input__control .channels-input__input{border-bottom:1px dotted red}.ChannelsInput .channels-input__control .channels-input__input>div{width:1px}.ChannelsInput .channels-input__value-container{padding:0;margin-left:0}.ChannelsInput .channels-input__placeholder{margin-left:8px;color:rgba(var(--center-channel-color-rgb), 0.64)}.ChannelsInput .channels-input__input{margin-left:6px;color:var(--center-channel-color)}.ChannelsInput .channels-input__input .a11y--focused{box-shadow:none}.ChannelsInput input{height:inherit}.ChannelsInput .channels-input__menu{margin-top:0;background:var(--center-channel-bg);box-shadow:0 0 0 0 rgba(0,0,0,.1),0 4px 11px rgba(0,0,0,.1);color:var(--center-channel-color)}.ChannelsInput .channels-input__menu-list{padding:0}.ChannelsInput .channels-input__menu-notice{display:flex;height:44px;align-items:center;justify-content:center;padding:12px;border-radius:4px 4px 0 0}.ChannelsInput .channels-input__option{display:flex;height:44px;align-items:center;padding:12px;cursor:pointer;font-size:16px}.ChannelsInput .channels-input__option--no-matches{color:rgba(var(--center-channel-color-rgb), 0.56);text-align:center}.ChannelsInput .channels-input__option--no-matches span{width:100%}.ChannelsInput .channels-input__option--no-matches strong{font-weight:600}.ChannelsInput .channels-input__option:first-child{border-radius:4px 4px 0 0}.ChannelsInput .channels-input__option:last-child{border-radius:0 0 4px 4px}.ChannelsInput .channels-input__option--is-focused{background:rgba(var(--button-bg-rgb), 0.08)}.ChannelsInput .channels-input__option--no-matches:hover{background:none;cursor:default}.ChannelsInput .channels-input__option .public-channel-icon,.ChannelsInput .channels-input__option .private-channel-icon{display:flex;width:18px;height:18px;align-items:center;margin-right:8px}.ChannelsInput .channels-input__option .public-channel-icon svg,.ChannelsInput .channels-input__option .private-channel-icon svg{width:18px;height:18px;fill:rgba(var(--center-channel-color-rgb), 0.56)}.ChannelsInput .channels-input__option .channel-name{opacity:.5}.ChannelsInput .channels-input__option .channel-name::before{padding-left:5px;content:"(";opacity:.5}.ChannelsInput .channels-input__option .channel-name::after{content:")";opacity:.5}.ChannelsInput .show{display:block}.ChannelsInput .channels-input__multi-value{align-items:center;padding:4px;margin:4px;background:rgba(var(--center-channel-color-rgb), 0.08);border-radius:16px;color:var(--center-channel-color)}.ChannelsInput .channels-input__multi-value:nth-last-child(2){margin:4px 0 4px 4px}.ChannelsInput .channels-input__multi-value__label{display:flex;align-items:center;padding:0;color:var(--center-channel-color);font-size:1.6rem}.ChannelsInput .channels-input__multi-value__label .public-channel-icon,.ChannelsInput .channels-input__multi-value__label .private-channel-icon{display:flex;width:24px;height:24px;padding:4px;margin-right:4px;background:rgba(var(--center-channel-color-rgb), 0.56);border-radius:16px}.ChannelsInput .channels-input__multi-value__label .public-channel-icon svg{width:16px;height:16px;fill:rgba(var(--button-color-rgb), 0.8)}.ChannelsInput .channels-input__multi-value__label .private-channel-icon svg{width:14px;height:14px;margin:0 1px;fill:rgba(var(--button-color-rgb), 0.8)}.ChannelsInput .channels-input__multi-value__label .channel-name{display:none}.ChannelsInput .channels-input__multi-value__remove{padding:0 4px 0 8px;cursor:pointer}.ChannelsInput .channels-input__multi-value__remove span{display:flex;width:16px;height:16px}.ChannelsInput .channels-input__multi-value__remove:hover{background:none}.ChannelsInput .channels-input__multi-value__remove svg{width:16px;height:16px;fill:rgba(var(--center-channel-color-rgb), 0.64);opacity:.6}.ChannelsInput .channels-input__multi-value__remove svg:hover{fill:rgba(var(--center-channel-color-rgb), 0.8)}
.AddToChannels__messageInput{width:100%;height:90px;padding:12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.64);margin-bottom:8px;background:var(--center-channel-bg);border-radius:4px;resize:vertical}.AddToChannels__messageInput:focus{padding:11px;border:2px solid var(--button-bg)}.AddToChannels .help-text{margin:0;color:rgba(var(--center-channel-color-rgb), 0.64)}.AddToChannels__customMessage{position:relative;width:100%;max-width:720px}.AddToChannels__customMessageTitle{display:flex;align-items:center;justify-content:space-between}.AddToChannels__customMessage a{color:rgba(var(--button-bg-rgb), 0.88);font-weight:600}.AddToChannels__customMessage svg{position:relative;top:3px;width:24px;height:24px;cursor:pointer;fill:rgba(var(--center-channel-color-rgb), 0.64)}.AddToChannels__customMessage svg:hover{fill:rgba(var(--center-channel-color-rgb), 0.56)}.AddToChannels__customMessage .help-text span{font-weight:normal}
@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}button.InviteView__copyLink.tertiary-button:focus{outline:none}.InviteView__sectionTitle{padding-top:16px;padding-bottom:8px;font-weight:600}.InviteView__sectionTitle--first{padding-top:0}.InviteView__copyLink{display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px;display:flex;align-items:center}.InviteView__copyLink:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.InviteView__copyLink:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.InviteView__copyLink:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.InviteView__copyLink i{display:flex;font-size:18px}.InviteView__copyLink i::before{margin:0 7px 0 0}.InviteView__copyLink:active{box-shadow:none}.InviteView__copyLink:focus{outline:none}.InviteView__copyLink.btn.btn-cancel{padding-left:0}.InviteView__copyLink .icon-check{color:var(--online-indicator)}.InviteView__footer{display:flex;justify-content:space-between}.InviteView__footer::before,.InviteView__footer::after{display:none}.InviteView__footer .btn{font-weight:600}.InviteView__sectionTitleParenthetical{color:rgba(var(--center-channel-color-rgb), 0.6);font-weight:normal}.modal-body .UsersEmailsInput.no-selections .users-emails-input__value-container{margin-top:6px}.modal-body .UsersEmailsInput .users-emails-input__control{overflow:auto;min-height:84px;max-height:227px;align-items:flex-start}
.NoPermissionsView__body{display:flex;flex-direction:column;align-items:center;justify-content:center}.NoPermissionsView__body .icon-close{position:absolute;top:20px;right:15px;padding:0;border:none;-moz-appearance:none;-webkit-appearance:none;appearance:none;background:none;color:inherit;color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;font:inherit;font-size:24px;outline:inherit}.NoPermissionsView__title{margin:10px 0 22px;font-size:22px;font-weight:600;text-align:center}.NoPermissionsView__description{font-size:14px;text-align:left}
.InvitationModal .modal-dialog{position:absolute;top:50%;left:50%;margin:auto;transform:translate(-50%, -50%) !important}.InvitationModal .modal-header,.InvitationModal .modal-footer{padding:24px}.InvitationModal .modal-body{overflow:visible;max-height:none;padding:0 24px}.InvitationModal .InvitationModal__header{display:flex;align-items:center;justify-content:space-between;border:none;font-size:22px;font-weight:600}.InvitationModal .InvitationModal__header h1{margin:0;font-size:22px;font-weight:600}.InvitationModal .InvitationModal__header::before,.InvitationModal .InvitationModal__header::after{display:none}.InvitationModal .InvitationModal__header.modal-header{background-color:var(--center-channel-bg);color:var(--center-channel-color)}.InvitationModal .InvitationModal__header .icon-close{padding:0;border:none;-moz-appearance:none;-webkit-appearance:none;appearance:none;background:none;color:rgb(var(--center-channel-color-rgb), 0.56);cursor:pointer;font:inherit;outline:inherit}.InvitationModal .InvitationModal__header .icon-close:hover,.InvitationModal .InvitationModal__header .icon-close:active,.InvitationModal .InvitationModal__header .icon-close:focus{color:rgb(var(--center-channel-color-rgb), 0.56)}.InvitationModal__footer{border-top:none}.InvitationModal__footer .btn{border-radius:4px}.InvitationModal .btn.btn-primary:disabled{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.InvitationModal .btn.btn-primary:disabled:hover{border-color:rgba(var(--center-channel-color-rgb), 0.08);background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}

/*# sourceMappingURL=919.6a97a735d643d64a2a45.css.map*/