.gfycat-search{position:relative;width:100%;box-sizing:border-box;padding:8px 7px 1px 7px}.gfycat-search .search-input{position:relative;z-index:1;display:block;width:100%;height:29px;box-sizing:border-box;padding:0 27px;border-width:1px;border-style:solid;background-color:transparent;border-radius:30px;box-shadow:none;font-size:1.3rem;outline:none}.gfycat-search .search-input::-ms-clear{display:none}.gfycat-search .search-input-bg{position:absolute;width:calc(100% - 2.4rem);height:3.3rem;border-radius:.6rem}.gfycat-search .placeholder{position:absolute;top:14px;left:34px;font-size:13px}.gfycat-search .ic{position:absolute;top:calc(50% - 0.3rem)}.gfycat-search .ic-clear-search,.gfycat-search .ic-search{position:absolute;z-index:1;background-position:center;background-repeat:no-repeat;cursor:pointer}.gfycat-search .ic-clear-search{top:12px;right:12px;width:2rem;height:2rem}.gfycat-search .ic-search{top:11px;left:11px;width:2.4rem;height:2.4rem}.gfycat-search .submit-button{display:none}
.header-container{z-index:1;width:100%}.header-container .nav-bar{position:relative;display:flex;height:3.5rem;align-items:center;justify-content:space-around;border-bottom-width:1px;border-bottom-style:solid}.header-container .nav-bar .ic{cursor:pointer;vertical-align:middle}.header-container .nav-bar a{display:flex;height:100%;flex-grow:1;align-items:center;justify-content:space-around}.header-container .nav-bar a .header-text{padding-left:1rem;font-family:SFUIDisplay,sans-serif;font-size:1.6rem;font-weight:500;vertical-align:middle}
.categories-container{position:relative;height:292px;box-sizing:border-box;padding:0 .2rem;font-size:0;overflow-x:hidden}.categories-container .category-container{display:inline-block;width:33.33%;box-sizing:border-box;padding:.2rem}.categories-container .category{position:relative;display:inline-block;overflow:hidden;width:100%;padding-bottom:75%;background-position:center;background-repeat:no-repeat;background-size:cover;border-radius:.6rem;cursor:pointer}.categories-container .category-name{position:absolute;display:flex;width:100%;height:100%;align-items:center;justify-content:center;background-color:rgba(0,0,0,.2);color:#fff;font-size:1.2rem;font-weight:bold;text-align:center;text-transform:uppercase}
.search-item-wrapper{position:absolute;overflow:hidden;width:50%;box-sizing:border-box;border-radius:.6rem}.search-item{display:inline-block;width:100%;background-size:cover;border-radius:.6rem;cursor:pointer}
.search-grid-container{position:relative;width:100%;height:336px;margin:0 auto;overflow-x:hidden}.empty-search{margin:2rem auto;color:#a0a0a0;font-size:1.6rem;text-align:center}.empty-search a{text-decoration:none}.empty-search .empty-search-button{display:inline-block;padding:.6rem 1.6rem;background-color:#1b70ff;border-radius:.6rem;color:#fff;font-size:1.2rem;line-height:1.5}.empty-search-image{width:100%;height:9rem;margin-bottom:2rem;background-image:url(/static/files/d392bf61b3c06ca6ec8a8443ffb57b18.png);background-position:center;background-repeat:no-repeat;background-size:contain}

/*# sourceMappingURL=789.bb6b9733dcccfee57d1a.css.map*/