"use strict";(self.webpackChunk_mattermost_webapp=self.webpackChunk_mattermost_webapp||[]).push([[962],{2962:(e,r,t)=>{t.r(r),t.d(r,{default:()=>s});var a=t(67294),o=t(86896),l=t(14494),n=t(22742);const s=()=>{const{formatMessage:e}=(0,o.Z)(),{AboutLink:r,PrivacyPolicyLink:t,TermsOfServiceLink:s,HelpLink:f}=(0,l.useSelector)(n.iE);return a.createElement("div",{className:"hfroute-footer"},a.createElement("span",{key:"footer-copyright",className:"footer-copyright"},"© ".concat((new Date).getFullYear()," Mattermost Inc.")),r&&a.createElement("a",{key:"footer-link-about",className:"footer-link",href:r,target:"_blank",rel:"noopener noreferrer"},e({id:"web.footer.about",defaultMessage:"About"})),t&&a.createElement("a",{key:"footer-link-privacy",className:"footer-link",href:t,target:"_blank",rel:"noopener noreferrer"},e({id:"web.footer.privacy",defaultMessage:"Privacy Policy"})),s&&a.createElement("a",{key:"footer-link-terms",className:"footer-link",href:s,target:"_blank",rel:"noopener noreferrer"},e({id:"web.footer.terms",defaultMessage:"Terms"})),f&&a.createElement("a",{key:"footer-link-help",className:"footer-link",href:f,target:"_blank",rel:"noopener noreferrer"},e({id:"web.footer.help",defaultMessage:"Help"})))}}}]);
//# sourceMappingURL=962.7511b61aa92b409bb854.js.map