"use strict";(self.webpackChunk_mattermost_webapp=self.webpackChunk_mattermost_webapp||[]).push([[182],{96512:(e,a,t)=>{t.d(a,{Z:()=>u});var n=t(45697),s=t.n(n),l=t(67294),r=t(86896),c=t(44012),i=t(73727),o=t(94184),m=t.n(o);const k=e=>{let{url:a,className:t,onClick:n}=e;const{formatMessage:s}=(0,r.Z)();return l.createElement("div",{id:"back_button",className:m()("signup-header",t)},l.createElement(i.Link,{onClick:n,to:a},l.createElement("span",{id:"back_button_icon",className:"fa fa-1x fa-angle-left",title:s({id:"generic_icons.back",defaultMessage:"Back Icon"})}),l.createElement(c.Z,{id:"web.header.back",defaultMessage:"Back"})))};k.propTypes={url:s().string,className:s().string,onClick:s().func},k.defaultProps={url:"/"};const u=k},98182:(e,a,t)=>{t.r(a),t.d(a,{default:()=>u});var n=t(45697),s=t.n(n),l=(t(74916),t(64765),t(67294)),r=t(73727),c=t(14494),i=t(96512),o=t(35961),m=t(22742);const k=e=>{let{alternateMessage:a,alternateLinkPath:t,alternateLinkLabel:n,backButtonURL:s,onBackButtonClick:k}=e;const{EnableCustomBrand:u,SiteName:d}=(0,c.useSelector)(m.iE);return l.createElement("div",{className:"hfroute-header"},l.createElement("div",{className:"header-main"},l.createElement(r.Link,{className:"header-logo-link",to:"/"},"true"===u||"Mattermost"!==d?d:l.createElement(o.Z,null)),l.createElement("div",{className:"header-alternate-container"},a&&l.createElement("span",{className:"header-alternate-message"},a),t&&n&&l.createElement(r.Link,{className:"header-alternate-link",to:{pathname:t,search:location.search}},n))),k&&l.createElement(i.Z,{className:"header-back-button",url:s,onClick:k}))};k.propTypes={alternateMessage:s().string,alternateLinkPath:s().string,alternateLinkLabel:s().string,backButtonURL:s().string,onBackButtonClick:s().func};const u=k}}]);
//# sourceMappingURL=182.ca2448d2b10d895722aa.js.map