"use strict";(self.webpackChunk_mattermost_webapp=self.webpackChunk_mattermost_webapp||[]).push([[6],{76006:(e,t,r)=>{r.r(t),r.d(t,{default:()=>d});var n,o,a,i=r(14494),s=r(22742),c=r(45697),l=r.n(c),p=r(67294),m=r(44012);class f extends p.PureComponent{componentDidMount(){document.body.classList.add("sticky");const e=document.getElementById("root");e&&e.classList.add("container-fluid")}componentWillUnmount(){document.body.classList.remove("sticky");const e=document.getElementById("root");e&&e.classList.remove("container-fluid")}render(){const e=[];return this.props.config?(this.props.config.AboutLink&&e.push(p.createElement("a",{key:"about_link",id:"about_link",className:"footer-link",target:"_blank",rel:"noopener noreferrer",href:this.props.config.AboutLink},p.createElement(m.Z,{id:"web.footer.about"}))),this.props.config.PrivacyPolicyLink&&e.push(p.createElement("a",{key:"privacy_link",id:"privacy_link",className:"footer-link",target:"_blank",rel:"noopener noreferrer",href:this.props.config.PrivacyPolicyLink},p.createElement(m.Z,{id:"web.footer.privacy"}))),this.props.config.TermsOfServiceLink&&e.push(p.createElement("a",{key:"terms_link",id:"terms_link",className:"footer-link",target:"_blank",rel:"noopener noreferrer",href:this.props.config.TermsOfServiceLink},p.createElement(m.Z,{id:"web.footer.terms"}))),this.props.config.HelpLink&&e.push(p.createElement("a",{key:"help_link",id:"help_link",className:"footer-link",target:"_blank",rel:"noopener noreferrer",href:this.props.config.HelpLink},p.createElement(m.Z,{id:"web.footer.help"}))),p.createElement("div",{className:"inner-wrap"},p.createElement("div",{className:"row content"},this.props.children),p.createElement("div",{className:"row footer"},p.createElement("div",{id:"footer_section",className:"footer-pane col-xs-12"},p.createElement("div",{className:"col-xs-12"},p.createElement("span",{id:"company_name",className:"pull-right footer-site-name"},"Mattermost")),p.createElement("div",{className:"col-xs-12"},p.createElement("span",{id:"copyright",className:"pull-right footer-link copyright"},"© 2015-".concat((new Date).getFullYear()," Mattermost, Inc.")),p.createElement("span",{className:"pull-right"},e)))))):null}}n=f,o="propTypes",a={children:l().object,config:l().object},o in n?Object.defineProperty(n,o,{value:a,enumerable:!0,configurable:!0,writable:!0}):n[o]=a;const d=(0,i.connect)((function(e){return{config:(0,s.iE)(e)}}))(f)}}]);
//# sourceMappingURL=6.f81a083e206f828fd4f3.js.map