.modal-marketplace{display:flex;width:100%;height:100%;flex-direction:column;align-items:center;padding-top:50px;color:var(--center-channel-color);font-size:16px}@media(max-width: 768px){.modal-marketplace{padding-right:15px;padding-left:15px}}.modal-marketplace div.navigation-row{margin-top:10px}.modal-marketplace div.navigation-row div{font-size:14px;text-align:center}.modal-marketplace div.navigation-row div button{font-size:14px;font-weight:bold}.modal-marketplace div.navigation-row div.count{padding-top:8px}.modal-marketplace .input-clear{top:32px;right:36px;display:flex;width:32px;height:32px;align-items:center;justify-content:center;font-size:16px}.modal-marketplace .nav-tabs{font-size:14px}.modal-marketplace .nav-tabs>li>a{padding:10px 16px;background:transparent;transition:all .15s ease}.modal-marketplace .nav-tabs>li>a:hover,.modal-marketplace .nav-tabs>li>a:active,.modal-marketplace .nav-tabs>li>a:focus{background:transparent;color:var(--center-channel-color)}.modal-marketplace .nav-tabs>li.active>a{color:var(--center-channel-color)}.modal-marketplace h1{margin:8px 0 24px;font-size:28px}.modal-marketplace h2{font-weight:300}.modal-marketplace h2 strong{font-weight:400}.modal-marketplace .more-modal__list{padding-bottom:80px}.modal-marketplace .more-modal__list .more-modal__row{align-items:normal}.modal-marketplace .more-modal__list .more-modal__row .tag{padding:3px 5px;margin-left:10px;background-color:rgba(0,0,0,.3);border-radius:4px;color:#fff;cursor:help;font-size:.8em;font-weight:bold}.modal-marketplace .more-modal__list .more-modal__row .update{padding:10px 10px 0 0;border-top:1px solid rgba(0,0,0,.1);margin:10px 10px 0 0;font-size:.9em}.modal-marketplace .more-modal__list .more-modal__description{margin:2px 0 0;font-size:.9em}.modal-marketplace .search_input{width:720px;height:40px;flex:1;margin-top:28px;margin-right:16px;margin-bottom:20px;margin-left:16px;box-shadow:none}.modal-marketplace .btn{min-width:8rem;padding:8px 16px;border-radius:4px;font-size:13px;font-weight:600}.modal-marketplace .btn-outline{border:1px solid var(--button-bg);background:transparent}.modal-marketplace .tabs{display:flex;width:720px;flex-direction:column}.modal-marketplace .subtitle{margin-left:5px}.modal-marketplace .plugin__list{display:flex;flex-direction:column}.modal-marketplace .plugin__list .plugin__row{display:flex;align-items:center;padding:10px 15px;border-bottom:1px solid rgba(0,0,0,.15)}.modal-marketplace .plugin__list .plugin__row.clickable{cursor:pointer}.modal-marketplace .plugin__list .plugin__row:hover .plugin__actions--round{opacity:.5}.modal-marketplace .icon__plugin{display:flex;height:42px;flex:0 0 42px;align-items:center;justify-content:center;margin-right:4px;border-radius:50%}.modal-marketplace .icon__plugin svg{width:32px;height:32px;fill:var(--button-bg)}.modal-marketplace .icon__plugin--background{padding:6px;background-color:#fff}.modal-marketplace .icon__plugin--background svg{width:24px;height:24px}.modal-marketplace .no_plugins_div{text-align:center}.modal-marketplace .item_error{background-color:rgba(var(--error-text-rgb), 0.08)}.modal-marketplace .error_text{color:var(--error-text);opacity:1}.error-bar{position:fixed;z-index:8;top:0;overflow:hidden;width:100%;min-height:40px;max-height:40px;padding:5px 30px;background-color:var(--center-channel-bg);color:var(--error-text)}.error-bar .error-bar__content{position:absolute;top:0;left:0;display:flex;width:100%;height:100%;align-items:center;justify-content:center;background-color:rgba(var(--error-text-rgb), 0.12)}

/*# sourceMappingURL=404.240cef8f44de6ec075a7.css.map*/