.CardImage {
    width: auto;
    max-width: 30px;
    height: auto;
    max-height: 30px;
    margin-top: -1px;
    margin-right: 9px;
}

.StripeElement {
    position: relative;
    width: 100%;
    height: 100%;
    padding-top: 8px;
    padding-bottom: 2px !important;
    padding-left: 12px;
    background-color: var(--center-channel-bg);
    background-image: none;
    border-radius: 4px;
    box-shadow: none;
    color: var(--center-channel-color);
    font-family: 'Open Sans';
    font-size: 14px;
    line-height: 23px;
    outline: none;
}

.StripeElement--invalid {
    color: var(--error-text);
}

.StripeElement::placeholder {
    color: rgba(var(--center-channel-color-rgb), 0.72);
    font-size: 14px;
    opacity: 0.5;
}

.StripeElement:focus::placeholder {
    color: 'transparent';
}

.StripeElement:focus {
    border-color: transparent;
    box-shadow: 0 0 0 2px var(--button-bg);
}

.PaymentForm{padding-right:96px;padding-left:96px;margin:0 auto}.PaymentForm .form-row{display:flex;width:100%;margin-bottom:24px}.PaymentForm .form-row-third-1{width:66%;max-width:288px;margin-right:16px}.PaymentForm .form-row-third-1 .DropdownInput{z-index:99999;margin-top:0}.PaymentForm .form-row-third-2{width:34%;max-width:144px}.PaymentForm .section-title{margin-bottom:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:16px;font-weight:600;text-align:left}.PaymentForm .DropdownInput{position:relative;z-index:999999;height:36px;margin-bottom:24px}.PaymentForm .DropdownInput .DropDown__control{min-height:0;background-color:var(--center-channel-bg) !important}.PaymentForm .DropdownInput .DropDown__control .DropDown__value-container>div{color:var(--center-channel-color) !important}.PaymentForm .DropdownInput .DropDown__menu{background-color:var(--center-channel-bg) !important;box-shadow:0 0 0 1px var(--center-channel-color),0 4px 11px var(--center-channel-color) !important}.PaymentForm .full-width{width:100%}.PaymentForm input{font-size:14px}.PaymentForm input:-webkit-autofill,.PaymentForm input:-webkit-autofill:hover,.PaymentForm input:-webkit-autofill:focus,.PaymentForm input:-webkit-autofill:active{-webkit-box-shadow:0 0 0 30px var(--center-channel-bg) inset !important;-webkit-text-fill-color:var(--center-channel-color) !important}.PaymentForm .Input_fieldset{height:40px;padding:2px 1px;background:var(--center-channel-bg)}.PaymentForm .Input_fieldset .Input_wrapper{margin:0}.PaymentForm .Input_fieldset.Input_fieldset___legend>legend{margin-left:11px}.PaymentForm .Input_fieldset.Input_fieldset:focus-within{padding-top:2px;box-shadow:inset 0 0 0 2px var(--button-bg);color:var(--button-bg)}.PaymentForm .Input_fieldset.Input_fieldset___error{padding-top:1px;padding-bottom:1px;box-shadow:inset 0 0 0 1px var(--error-text);color:var(--error-text)}.PaymentForm .Input_fieldset.Input_fieldset___error:focus-within{box-shadow:inset 0 0 0 2px var(--error-text);color:var(--error-text)}.PaymentForm .Input_fieldset .Input{height:32px;background:inherit}.PaymentForm .Input_fieldset .Input::placeholder{color:var(--center-channel-color);opacity:.64}.PaymentForm .PaymentForm-saved{width:442px;height:fit-content;box-sizing:border-box;padding:24px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin-bottom:16px;background:#fff;border-radius:4px}.PaymentForm .PaymentForm-saved-title{margin-bottom:16px;color:var(--secondary-blue);font-family:Metropolis;font-size:14px;font-weight:600;letter-spacing:1.5px;line-height:18px;opacity:.4;text-transform:uppercase}.PaymentForm .PaymentForm-saved-card{padding-bottom:16px;border-bottom:1px solid rgba(0,0,0,.12);color:var(--secondary-blue);font-family:Source Sans Pro;font-size:16px;line-height:24px}.PaymentForm .PaymentForm-saved-address{margin-top:16px;margin-bottom:16px;color:var(--secondary-blue);font-family:Source Sans Pro;font-size:16px;line-height:24px}.PaymentForm .PaymentForm-change{color:#0058cc;font-family:Source Sans Pro;font-size:16px;font-weight:600;line-height:20px}
.ProcessPayment-progress {
    width: 387px;
    height: 4px;
    margin: 0 auto;
    margin-top: 60px;
    background: rgb(34, 64, 109, 0.12);
    border-radius: 4px;
}

.ProcessPayment-progress-fill {
    height: 100%;
    background: #0058cc;
    border-radius: 4px;
}

.ProcessPayment-body {
    overflow-x: hidden;
    overflow-y: hidden;
}

.PurchaseModal{overflow:hidden;height:100%}.PurchaseModal>div{display:flex;overflow:hidden;width:100%;height:100%;flex-direction:row;flex-grow:1;flex-wrap:wrap;align-content:center;justify-content:center;padding:77px 107px;color:var(--center-channel-color);font-family:"Open Sans";font-size:16px;font-weight:600}.PurchaseModal>div.processing{display:none}.PurchaseModal>div .footer-text .normal-payment-text{color:rgba(var(--center-channel-color-rgb), 0.72);font-size:14px}.PurchaseModal>div .footer-text .prorrated-payment-text div{display:inline-block;margin-right:4px;font-family:"compass-icons";font-size:16px}.PurchaseModal>div .footer-text a{color:var(--button-bg) !important}.PurchaseModal>div .fineprint-text{margin-top:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;line-height:16px}.PurchaseModal>div .bold-text{font-weight:600}.PurchaseModal>div .normal-text{font-weight:normal}.PurchaseModal>div .LHS{width:25%}.PurchaseModal>div .LHS .title{font-weight:600}.PurchaseModal>div .LHS .image{padding:32px 0}.PurchaseModal>div .central-panel{width:50%}.PurchaseModal>div .central-panel .PaymentDetails{padding:10px 0 0 10%;font-size:14px;font-style:normal;font-weight:normal;line-height:20px}.PurchaseModal>div .central-panel .PaymentDetails .PaymentInfoDisplay__paymentInfo-text{width:416px;height:318px;box-sizing:border-box;padding:32px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin:24px 0;background-color:#fff;border-radius:4px;box-shadow:0 2px 3px rgba(0,0,0,.08)}.PurchaseModal>div .central-panel .PaymentDetails .PaymentInfoDisplay__paymentInfo-text .CardImage{max-width:55px !important;max-height:37px !important}.PurchaseModal>div .central-panel .PaymentDetails .PaymentInfoDisplay__paymentInfo-text .PaymentInfoDisplay__paymentInfo-cardInfo{margin:10px 0}.PurchaseModal>div .central-panel .PaymentDetails .title{font-size:16px;font-style:normal;font-weight:600;line-height:24px}.PurchaseModal>div .central-panel .PaymentDetails .editPaymentButton{padding-left:20px !important;border:none;background:none;color:var(--button-bg);font-size:14px;font-weight:600;line-height:24px}.PurchaseModal>div .full-width{border-color:rgba(var(--center-channel-color-rgb), 0.16)}.PurchaseModal>div .RHS{position:sticky;display:flex;width:25%;flex-direction:column;align-items:center}.PurchaseModal>div .RHS .price-text{display:flex;align-items:baseline;padding:8px 0;font-size:32px;font-weight:600;line-height:1}.PurchaseModal>div .RHS .price-text .price-decimals{align-self:end;padding-bottom:2px;font-size:16px}.PurchaseModal>div .RHS .price-text .price-decimals::before{content:"."}.PurchaseModal>div .RHS .monthly-text{align-self:center;margin-left:5px;font-size:14px;font-weight:normal}.PurchaseModal>div .RHS .plan_comparison{text-align:center}.PurchaseModal>div .RHS .plan_comparison button,.PurchaseModal>div .RHS .plan_comparison a{width:100%;height:40px;padding:10px 24px;border:none;background:none;color:var(--denim-button-bg);font-size:14px;font-weight:600;line-height:20px}.PurchaseModal>div .RHS .PlanCard{position:relative;width:280px;height:428px}.PurchaseModal>div .RHS .PlanCard .planLabel{position:absolute;top:-44px;left:52px;display:flex;width:184px;align-items:center;justify-content:center;padding:14px;border-radius:13px 13px 0 0;font-family:"Open Sans";font-size:12px;font-style:normal;font-weight:600;gap:5px;line-height:16px}.PurchaseModal>div .RHS .PlanCard .top{height:18px;border-radius:4px 4px 0 0}.PurchaseModal>div .RHS .PlanCard .bottom{height:363px;padding-right:24px;padding-left:24px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg);border-radius:0 0 4px 4px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_action_btn{width:100%;height:40px;padding:10px 24px;border:none;background:none;border-radius:4px;color:var(--denim-button-bg);font-size:14px;font-weight:700;line-height:14px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_action_btn.grayed{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.PurchaseModal>div .RHS .PlanCard .bottom .plan_action_btn.active{border:1px solid var(--denim-button-bg)}.PurchaseModal>div .RHS .PlanCard .bottom .plan_action_btn.special{background:var(--denim-button-bg);color:var(--button-color)}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section{width:100%;height:150px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.16);font-weight:400;letter-spacing:-0.02em;text-align:center}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section h4{color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Metropolis";font-size:20px;font-style:normal;line-height:30px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section h1{color:var(--center-channel-color);font-family:"Metropolis";font-size:52px;font-style:normal;font-weight:700;line-height:60px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section .enterprise_price{font-size:32px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_price_rate_section p{color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Metropolis";font-size:18px;font-style:normal;line-height:20px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_payment_commencement{margin-top:16px;margin-bottom:24px;color:var(--center-channel-color-rgb);font-size:14px;font-style:normal;font-weight:400;line-height:20px}.PurchaseModal>div .RHS .PlanCard .bottom .plan_billing_cycle{margin-top:24px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:12px;font-style:normal;font-weight:400;line-height:16px}.PurchaseModal>div .logo{position:absolute;right:0;bottom:0}.PurchaseModal>div button{width:fit-content;height:40px;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-size:14px;font-weight:600}.PurchaseModal>div button:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.background-svg{position:absolute;z-index:-1;top:0}.background-svg>div{position:absolute;top:0;left:0}.FullScreenModal .close-x{top:12px;right:12px}.tooltipTitle{font-weight:700}.tooltipText{color:#9a9a9a !important;text-align:left}.proratedTooltip>.tooltip-inner{min-width:300px}

/*# sourceMappingURL=649.7f8826107d3a4bfc52ed.css.map*/