"use strict";(self.webpackChunk_mattermost_webapp=self.webpackChunk_mattermost_webapp||[]).push([[821],{76821:(e,t,a)=>{a.r(t),a.d(t,{default:()=>c});var n=a(45697),i=a.n(n),s=(a(33948),a(67294)),r=a(47470);function l(e,t,a){return t in e?Object.defineProperty(e,t,{value:a,enumerable:!0,configurable:!0,writable:!0}):e[t]=a,e}class c extends s.PureComponent{constructor(){super(...arguments),l(this,"handleClick",((e,t)=>{var a;t.preventDefault(),this.props.updateTab(e.name),null===(a=t.target.closest(".settings-modal"))||void 0===a||a.classList.add("display--content")}))}componentDidMount(){var e;r.vU()&&(null===(e=document.querySelector(".settings-modal .settings-table .nav"))||void 0===e||e.classList.add("position--top"))}render(){const e=this.props.tabs.map((e=>{const t="".concat(e.name,"_li");let a="";return this.props.activeTab===e.name&&(a="active"),s.createElement("li",{id:"".concat(e.name,"Li"),key:t,className:a},s.createElement("button",{id:"".concat(e.name,"Button"),className:"cursor--pointer style--none",onClick:this.handleClick.bind(null,e),"aria-label":e.uiName.toLowerCase()},s.createElement("i",{className:e.icon,title:e.iconTitle}),e.uiName))}));return s.createElement("div",null,s.createElement("ul",{id:"tabList",className:"nav nav-pills nav-stacked"},e))}}l(c,"propTypes",{activeTab:i().string,tabs:i().arrayOf(i().shape({icon:i().string.isRequired,iconTitle:i().string.isRequired,name:i().string.isRequired,uiName:i().string.isRequired})).isRequired,updateTab:i().func.isRequired})}}]);
//# sourceMappingURL=821.0d2e3dd080bcb53aed6b.js.map