/*!
 * Bootstrap v3.4.1 (https://getbootstrap.com/)
 * Copyright 2011-2019 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 */
/*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */
html {
  font-family: sans-serif;
  -ms-text-size-adjust: 100%;
  -webkit-text-size-adjust: 100%;
}
body {
  margin: 0;
}
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
  display: block;
}
audio,
canvas,
progress,
video {
  display: inline-block;
  vertical-align: baseline;
}
audio:not([controls]) {
  display: none;
  height: 0;
}
[hidden],
template {
  display: none;
}
a {
  background-color: transparent;
}
a:active,
a:hover {
  outline: 0;
}
abbr[title] {
  border-bottom: none;
  text-decoration: underline;
  -webkit-text-decoration: underline dotted;
  -moz-text-decoration: underline dotted;
  text-decoration: underline dotted;
}
b,
strong {
  font-weight: bold;
}
dfn {
  font-style: italic;
}
h1 {
  font-size: 2em;
  margin: 0.67em 0;
}
mark {
  background: #ff0;
  color: #000;
}
small {
  font-size: 80%;
}
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}
sup {
  top: -0.5em;
}
sub {
  bottom: -0.25em;
}
img {
  border: 0;
}
svg:not(:root) {
  overflow: hidden;
}
figure {
  margin: 1em 40px;
}
hr {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  height: 0;
}
pre {
  overflow: auto;
}
code,
kbd,
pre,
samp {
  font-family: monospace, monospace;
  font-size: 1em;
}
button,
input,
optgroup,
select,
textarea {
  color: inherit;
  font: inherit;
  margin: 0;
}
button {
  overflow: visible;
}
button,
select {
  text-transform: none;
}
button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
  -webkit-appearance: button;
  cursor: pointer;
}
button[disabled],
html input[disabled] {
  cursor: default;
}
button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0;
}
input {
  line-height: normal;
}
input[type="checkbox"],
input[type="radio"] {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  padding: 0;
}
input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
  height: auto;
}
input[type="search"] {
  -webkit-appearance: textfield;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}
input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
}
fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em;
}
legend {
  border: 0;
  padding: 0;
}
textarea {
  overflow: auto;
}
optgroup {
  font-weight: bold;
}
table {
  border-collapse: collapse;
  border-spacing: 0;
}
td,
th {
  padding: 0;
}
/*! Source: https://github.com/h5bp/html5-boilerplate/blob/master/src/css/main.css */
@media print {
  *,
  *:before,
  *:after {
    color: #000 !important;
    text-shadow: none !important;
    background: transparent !important;
    -webkit-box-shadow: none !important;
    box-shadow: none !important;
  }
  a,
  a:visited {
    text-decoration: underline;
  }
  a[href]:after {
    content: " (" attr(href) ")";
  }
  abbr[title]:after {
    content: " (" attr(title) ")";
  }
  a[href^="#"]:after,
  a[href^="javascript:"]:after {
    content: "";
  }
  pre,
  blockquote {
    border: 1px solid #999;
    page-break-inside: avoid;
  }
  thead {
    display: table-header-group;
  }
  tr,
  img {
    page-break-inside: avoid;
  }
  img {
    max-width: 100% !important;
  }
  p,
  h2,
  h3 {
    orphans: 3;
    widows: 3;
  }
  h2,
  h3 {
    page-break-after: avoid;
  }
  .navbar {
    display: none;
  }
  .btn > .caret,
  .dropup > .btn > .caret {
    border-top-color: #000 !important;
  }
  .label {
    border: 1px solid #000;
  }
  .table {
    border-collapse: collapse !important;
  }
  .table td,
  .table th {
    background-color: #fff !important;
  }
  .table-bordered th,
  .table-bordered td {
    border: 1px solid #ddd !important;
  }
}
@font-face {
  font-family: "Glyphicons Halflings";
  src: url(/static/files/5be1347c682810f199c7f486f40c5974.eot);
  src: url(/static/files/5be1347c682810f199c7f486f40c5974.eot?#iefix) format("embedded-opentype"), url(/static/files/be810be3a3e14c682a257d6eff341fe4.woff2) format("woff2"), url(/static/files/82b1212e45a2bc35dd731913b27ad813.woff) format("woff"), url(/static/files/4692b9ec53fd5972caa2f2372ae20d16.ttf) format("truetype"), url(/static/files/372ee7bbea28f5a75e2af6ceaf56bc10.svg#glyphicons_halflingsregular) format("svg");
}
.glyphicon {
  position: relative;
  top: 1px;
  display: inline-block;
  font-family: "Glyphicons Halflings";
  font-style: normal;
  font-weight: 400;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.glyphicon-asterisk:before {
  content: "\002a";
}
.glyphicon-plus:before {
  content: "\002b";
}
.glyphicon-euro:before,
.glyphicon-eur:before {
  content: "\20ac";
}
.glyphicon-minus:before {
  content: "\2212";
}
.glyphicon-cloud:before {
  content: "\2601";
}
.glyphicon-envelope:before {
  content: "\2709";
}
.glyphicon-pencil:before {
  content: "\270f";
}
.glyphicon-glass:before {
  content: "\e001";
}
.glyphicon-music:before {
  content: "\e002";
}
.glyphicon-search:before {
  content: "\e003";
}
.glyphicon-heart:before {
  content: "\e005";
}
.glyphicon-star:before {
  content: "\e006";
}
.glyphicon-star-empty:before {
  content: "\e007";
}
.glyphicon-user:before {
  content: "\e008";
}
.glyphicon-film:before {
  content: "\e009";
}
.glyphicon-th-large:before {
  content: "\e010";
}
.glyphicon-th:before {
  content: "\e011";
}
.glyphicon-th-list:before {
  content: "\e012";
}
.glyphicon-ok:before {
  content: "\e013";
}
.glyphicon-remove:before {
  content: "\e014";
}
.glyphicon-zoom-in:before {
  content: "\e015";
}
.glyphicon-zoom-out:before {
  content: "\e016";
}
.glyphicon-off:before {
  content: "\e017";
}
.glyphicon-signal:before {
  content: "\e018";
}
.glyphicon-cog:before {
  content: "\e019";
}
.glyphicon-trash:before {
  content: "\e020";
}
.glyphicon-home:before {
  content: "\e021";
}
.glyphicon-file:before {
  content: "\e022";
}
.glyphicon-time:before {
  content: "\e023";
}
.glyphicon-road:before {
  content: "\e024";
}
.glyphicon-download-alt:before {
  content: "\e025";
}
.glyphicon-download:before {
  content: "\e026";
}
.glyphicon-upload:before {
  content: "\e027";
}
.glyphicon-inbox:before {
  content: "\e028";
}
.glyphicon-play-circle:before {
  content: "\e029";
}
.glyphicon-repeat:before {
  content: "\e030";
}
.glyphicon-refresh:before {
  content: "\e031";
}
.glyphicon-list-alt:before {
  content: "\e032";
}
.glyphicon-lock:before {
  content: "\e033";
}
.glyphicon-flag:before {
  content: "\e034";
}
.glyphicon-headphones:before {
  content: "\e035";
}
.glyphicon-volume-off:before {
  content: "\e036";
}
.glyphicon-volume-down:before {
  content: "\e037";
}
.glyphicon-volume-up:before {
  content: "\e038";
}
.glyphicon-qrcode:before {
  content: "\e039";
}
.glyphicon-barcode:before {
  content: "\e040";
}
.glyphicon-tag:before {
  content: "\e041";
}
.glyphicon-tags:before {
  content: "\e042";
}
.glyphicon-book:before {
  content: "\e043";
}
.glyphicon-bookmark:before {
  content: "\e044";
}
.glyphicon-print:before {
  content: "\e045";
}
.glyphicon-camera:before {
  content: "\e046";
}
.glyphicon-font:before {
  content: "\e047";
}
.glyphicon-bold:before {
  content: "\e048";
}
.glyphicon-italic:before {
  content: "\e049";
}
.glyphicon-text-height:before {
  content: "\e050";
}
.glyphicon-text-width:before {
  content: "\e051";
}
.glyphicon-align-left:before {
  content: "\e052";
}
.glyphicon-align-center:before {
  content: "\e053";
}
.glyphicon-align-right:before {
  content: "\e054";
}
.glyphicon-align-justify:before {
  content: "\e055";
}
.glyphicon-list:before {
  content: "\e056";
}
.glyphicon-indent-left:before {
  content: "\e057";
}
.glyphicon-indent-right:before {
  content: "\e058";
}
.glyphicon-facetime-video:before {
  content: "\e059";
}
.glyphicon-picture:before {
  content: "\e060";
}
.glyphicon-map-marker:before {
  content: "\e062";
}
.glyphicon-adjust:before {
  content: "\e063";
}
.glyphicon-tint:before {
  content: "\e064";
}
.glyphicon-edit:before {
  content: "\e065";
}
.glyphicon-share:before {
  content: "\e066";
}
.glyphicon-check:before {
  content: "\e067";
}
.glyphicon-move:before {
  content: "\e068";
}
.glyphicon-step-backward:before {
  content: "\e069";
}
.glyphicon-fast-backward:before {
  content: "\e070";
}
.glyphicon-backward:before {
  content: "\e071";
}
.glyphicon-play:before {
  content: "\e072";
}
.glyphicon-pause:before {
  content: "\e073";
}
.glyphicon-stop:before {
  content: "\e074";
}
.glyphicon-forward:before {
  content: "\e075";
}
.glyphicon-fast-forward:before {
  content: "\e076";
}
.glyphicon-step-forward:before {
  content: "\e077";
}
.glyphicon-eject:before {
  content: "\e078";
}
.glyphicon-chevron-left:before {
  content: "\e079";
}
.glyphicon-chevron-right:before {
  content: "\e080";
}
.glyphicon-plus-sign:before {
  content: "\e081";
}
.glyphicon-minus-sign:before {
  content: "\e082";
}
.glyphicon-remove-sign:before {
  content: "\e083";
}
.glyphicon-ok-sign:before {
  content: "\e084";
}
.glyphicon-question-sign:before {
  content: "\e085";
}
.glyphicon-info-sign:before {
  content: "\e086";
}
.glyphicon-screenshot:before {
  content: "\e087";
}
.glyphicon-remove-circle:before {
  content: "\e088";
}
.glyphicon-ok-circle:before {
  content: "\e089";
}
.glyphicon-ban-circle:before {
  content: "\e090";
}
.glyphicon-arrow-left:before {
  content: "\e091";
}
.glyphicon-arrow-right:before {
  content: "\e092";
}
.glyphicon-arrow-up:before {
  content: "\e093";
}
.glyphicon-arrow-down:before {
  content: "\e094";
}
.glyphicon-share-alt:before {
  content: "\e095";
}
.glyphicon-resize-full:before {
  content: "\e096";
}
.glyphicon-resize-small:before {
  content: "\e097";
}
.glyphicon-exclamation-sign:before {
  content: "\e101";
}
.glyphicon-gift:before {
  content: "\e102";
}
.glyphicon-leaf:before {
  content: "\e103";
}
.glyphicon-fire:before {
  content: "\e104";
}
.glyphicon-eye-open:before {
  content: "\e105";
}
.glyphicon-eye-close:before {
  content: "\e106";
}
.glyphicon-warning-sign:before {
  content: "\e107";
}
.glyphicon-plane:before {
  content: "\e108";
}
.glyphicon-calendar:before {
  content: "\e109";
}
.glyphicon-random:before {
  content: "\e110";
}
.glyphicon-comment:before {
  content: "\e111";
}
.glyphicon-magnet:before {
  content: "\e112";
}
.glyphicon-chevron-up:before {
  content: "\e113";
}
.glyphicon-chevron-down:before {
  content: "\e114";
}
.glyphicon-retweet:before {
  content: "\e115";
}
.glyphicon-shopping-cart:before {
  content: "\e116";
}
.glyphicon-folder-close:before {
  content: "\e117";
}
.glyphicon-folder-open:before {
  content: "\e118";
}
.glyphicon-resize-vertical:before {
  content: "\e119";
}
.glyphicon-resize-horizontal:before {
  content: "\e120";
}
.glyphicon-hdd:before {
  content: "\e121";
}
.glyphicon-bullhorn:before {
  content: "\e122";
}
.glyphicon-bell:before {
  content: "\e123";
}
.glyphicon-certificate:before {
  content: "\e124";
}
.glyphicon-thumbs-up:before {
  content: "\e125";
}
.glyphicon-thumbs-down:before {
  content: "\e126";
}
.glyphicon-hand-right:before {
  content: "\e127";
}
.glyphicon-hand-left:before {
  content: "\e128";
}
.glyphicon-hand-up:before {
  content: "\e129";
}
.glyphicon-hand-down:before {
  content: "\e130";
}
.glyphicon-circle-arrow-right:before {
  content: "\e131";
}
.glyphicon-circle-arrow-left:before {
  content: "\e132";
}
.glyphicon-circle-arrow-up:before {
  content: "\e133";
}
.glyphicon-circle-arrow-down:before {
  content: "\e134";
}
.glyphicon-globe:before {
  content: "\e135";
}
.glyphicon-wrench:before {
  content: "\e136";
}
.glyphicon-tasks:before {
  content: "\e137";
}
.glyphicon-filter:before {
  content: "\e138";
}
.glyphicon-briefcase:before {
  content: "\e139";
}
.glyphicon-fullscreen:before {
  content: "\e140";
}
.glyphicon-dashboard:before {
  content: "\e141";
}
.glyphicon-paperclip:before {
  content: "\e142";
}
.glyphicon-heart-empty:before {
  content: "\e143";
}
.glyphicon-link:before {
  content: "\e144";
}
.glyphicon-phone:before {
  content: "\e145";
}
.glyphicon-pushpin:before {
  content: "\e146";
}
.glyphicon-usd:before {
  content: "\e148";
}
.glyphicon-gbp:before {
  content: "\e149";
}
.glyphicon-sort:before {
  content: "\e150";
}
.glyphicon-sort-by-alphabet:before {
  content: "\e151";
}
.glyphicon-sort-by-alphabet-alt:before {
  content: "\e152";
}
.glyphicon-sort-by-order:before {
  content: "\e153";
}
.glyphicon-sort-by-order-alt:before {
  content: "\e154";
}
.glyphicon-sort-by-attributes:before {
  content: "\e155";
}
.glyphicon-sort-by-attributes-alt:before {
  content: "\e156";
}
.glyphicon-unchecked:before {
  content: "\e157";
}
.glyphicon-expand:before {
  content: "\e158";
}
.glyphicon-collapse-down:before {
  content: "\e159";
}
.glyphicon-collapse-up:before {
  content: "\e160";
}
.glyphicon-log-in:before {
  content: "\e161";
}
.glyphicon-flash:before {
  content: "\e162";
}
.glyphicon-log-out:before {
  content: "\e163";
}
.glyphicon-new-window:before {
  content: "\e164";
}
.glyphicon-record:before {
  content: "\e165";
}
.glyphicon-save:before {
  content: "\e166";
}
.glyphicon-open:before {
  content: "\e167";
}
.glyphicon-saved:before {
  content: "\e168";
}
.glyphicon-import:before {
  content: "\e169";
}
.glyphicon-export:before {
  content: "\e170";
}
.glyphicon-send:before {
  content: "\e171";
}
.glyphicon-floppy-disk:before {
  content: "\e172";
}
.glyphicon-floppy-saved:before {
  content: "\e173";
}
.glyphicon-floppy-remove:before {
  content: "\e174";
}
.glyphicon-floppy-save:before {
  content: "\e175";
}
.glyphicon-floppy-open:before {
  content: "\e176";
}
.glyphicon-credit-card:before {
  content: "\e177";
}
.glyphicon-transfer:before {
  content: "\e178";
}
.glyphicon-cutlery:before {
  content: "\e179";
}
.glyphicon-header:before {
  content: "\e180";
}
.glyphicon-compressed:before {
  content: "\e181";
}
.glyphicon-earphone:before {
  content: "\e182";
}
.glyphicon-phone-alt:before {
  content: "\e183";
}
.glyphicon-tower:before {
  content: "\e184";
}
.glyphicon-stats:before {
  content: "\e185";
}
.glyphicon-sd-video:before {
  content: "\e186";
}
.glyphicon-hd-video:before {
  content: "\e187";
}
.glyphicon-subtitles:before {
  content: "\e188";
}
.glyphicon-sound-stereo:before {
  content: "\e189";
}
.glyphicon-sound-dolby:before {
  content: "\e190";
}
.glyphicon-sound-5-1:before {
  content: "\e191";
}
.glyphicon-sound-6-1:before {
  content: "\e192";
}
.glyphicon-sound-7-1:before {
  content: "\e193";
}
.glyphicon-copyright-mark:before {
  content: "\e194";
}
.glyphicon-registration-mark:before {
  content: "\e195";
}
.glyphicon-cloud-download:before {
  content: "\e197";
}
.glyphicon-cloud-upload:before {
  content: "\e198";
}
.glyphicon-tree-conifer:before {
  content: "\e199";
}
.glyphicon-tree-deciduous:before {
  content: "\e200";
}
.glyphicon-cd:before {
  content: "\e201";
}
.glyphicon-save-file:before {
  content: "\e202";
}
.glyphicon-open-file:before {
  content: "\e203";
}
.glyphicon-level-up:before {
  content: "\e204";
}
.glyphicon-copy:before {
  content: "\e205";
}
.glyphicon-paste:before {
  content: "\e206";
}
.glyphicon-alert:before {
  content: "\e209";
}
.glyphicon-equalizer:before {
  content: "\e210";
}
.glyphicon-king:before {
  content: "\e211";
}
.glyphicon-queen:before {
  content: "\e212";
}
.glyphicon-pawn:before {
  content: "\e213";
}
.glyphicon-bishop:before {
  content: "\e214";
}
.glyphicon-knight:before {
  content: "\e215";
}
.glyphicon-baby-formula:before {
  content: "\e216";
}
.glyphicon-tent:before {
  content: "\26fa";
}
.glyphicon-blackboard:before {
  content: "\e218";
}
.glyphicon-bed:before {
  content: "\e219";
}
.glyphicon-apple:before {
  content: "\f8ff";
}
.glyphicon-erase:before {
  content: "\e221";
}
.glyphicon-hourglass:before {
  content: "\231b";
}
.glyphicon-lamp:before {
  content: "\e223";
}
.glyphicon-duplicate:before {
  content: "\e224";
}
.glyphicon-piggy-bank:before {
  content: "\e225";
}
.glyphicon-scissors:before {
  content: "\e226";
}
.glyphicon-bitcoin:before {
  content: "\e227";
}
.glyphicon-btc:before {
  content: "\e227";
}
.glyphicon-xbt:before {
  content: "\e227";
}
.glyphicon-yen:before {
  content: "\00a5";
}
.glyphicon-jpy:before {
  content: "\00a5";
}
.glyphicon-ruble:before {
  content: "\20bd";
}
.glyphicon-rub:before {
  content: "\20bd";
}
.glyphicon-scale:before {
  content: "\e230";
}
.glyphicon-ice-lolly:before {
  content: "\e231";
}
.glyphicon-ice-lolly-tasted:before {
  content: "\e232";
}
.glyphicon-education:before {
  content: "\e233";
}
.glyphicon-option-horizontal:before {
  content: "\e234";
}
.glyphicon-option-vertical:before {
  content: "\e235";
}
.glyphicon-menu-hamburger:before {
  content: "\e236";
}
.glyphicon-modal-window:before {
  content: "\e237";
}
.glyphicon-oil:before {
  content: "\e238";
}
.glyphicon-grain:before {
  content: "\e239";
}
.glyphicon-sunglasses:before {
  content: "\e240";
}
.glyphicon-text-size:before {
  content: "\e241";
}
.glyphicon-text-color:before {
  content: "\e242";
}
.glyphicon-text-background:before {
  content: "\e243";
}
.glyphicon-object-align-top:before {
  content: "\e244";
}
.glyphicon-object-align-bottom:before {
  content: "\e245";
}
.glyphicon-object-align-horizontal:before {
  content: "\e246";
}
.glyphicon-object-align-left:before {
  content: "\e247";
}
.glyphicon-object-align-vertical:before {
  content: "\e248";
}
.glyphicon-object-align-right:before {
  content: "\e249";
}
.glyphicon-triangle-right:before {
  content: "\e250";
}
.glyphicon-triangle-left:before {
  content: "\e251";
}
.glyphicon-triangle-bottom:before {
  content: "\e252";
}
.glyphicon-triangle-top:before {
  content: "\e253";
}
.glyphicon-console:before {
  content: "\e254";
}
.glyphicon-superscript:before {
  content: "\e255";
}
.glyphicon-subscript:before {
  content: "\e256";
}
.glyphicon-menu-left:before {
  content: "\e257";
}
.glyphicon-menu-right:before {
  content: "\e258";
}
.glyphicon-menu-down:before {
  content: "\e259";
}
.glyphicon-menu-up:before {
  content: "\e260";
}
* {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
*:before,
*:after {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
html {
  font-size: 10px;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
}
body {
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 14px;
  line-height: 1.42857143;
  color: #333333;
  background-color: #fff;
}
input,
button,
select,
textarea {
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
}
a {
  color: #337ab7;
  text-decoration: none;
}
a:hover,
a:focus {
  color: #23527c;
  text-decoration: underline;
}
a:focus {
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
figure {
  margin: 0;
}
img {
  vertical-align: middle;
}
.img-responsive,
.thumbnail > img,
.thumbnail a > img,
.carousel-inner > .item > img,
.carousel-inner > .item > a > img {
  display: block;
  max-width: 100%;
  height: auto;
}
.img-rounded {
  border-radius: 6px;
}
.img-thumbnail {
  padding: 4px;
  line-height: 1.42857143;
  background-color: #fff;
  border: 1px solid #ddd;
  border-radius: 4px;
  -webkit-transition: all 0.2s ease-in-out;
  -o-transition: all 0.2s ease-in-out;
  transition: all 0.2s ease-in-out;
  display: inline-block;
  max-width: 100%;
  height: auto;
}
.img-circle {
  border-radius: 50%;
}
hr {
  margin-top: 20px;
  margin-bottom: 20px;
  border: 0;
  border-top: 1px solid #eeeeee;
}
.sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}
.sr-only-focusable:active,
.sr-only-focusable:focus {
  position: static;
  width: auto;
  height: auto;
  margin: 0;
  overflow: visible;
  clip: auto;
}
[role="button"] {
  cursor: pointer;
}
h1,
h2,
h3,
h4,
h5,
h6,
.h1,
.h2,
.h3,
.h4,
.h5,
.h6 {
  font-family: inherit;
  font-weight: 500;
  line-height: 1.1;
  color: inherit;
}
h1 small,
h2 small,
h3 small,
h4 small,
h5 small,
h6 small,
.h1 small,
.h2 small,
.h3 small,
.h4 small,
.h5 small,
.h6 small,
h1 .small,
h2 .small,
h3 .small,
h4 .small,
h5 .small,
h6 .small,
.h1 .small,
.h2 .small,
.h3 .small,
.h4 .small,
.h5 .small,
.h6 .small {
  font-weight: 400;
  line-height: 1;
  color: #777777;
}
h1,
.h1,
h2,
.h2,
h3,
.h3 {
  margin-top: 20px;
  margin-bottom: 10px;
}
h1 small,
.h1 small,
h2 small,
.h2 small,
h3 small,
.h3 small,
h1 .small,
.h1 .small,
h2 .small,
.h2 .small,
h3 .small,
.h3 .small {
  font-size: 65%;
}
h4,
.h4,
h5,
.h5,
h6,
.h6 {
  margin-top: 10px;
  margin-bottom: 10px;
}
h4 small,
.h4 small,
h5 small,
.h5 small,
h6 small,
.h6 small,
h4 .small,
.h4 .small,
h5 .small,
.h5 .small,
h6 .small,
.h6 .small {
  font-size: 75%;
}
h1,
.h1 {
  font-size: 36px;
}
h2,
.h2 {
  font-size: 30px;
}
h3,
.h3 {
  font-size: 24px;
}
h4,
.h4 {
  font-size: 18px;
}
h5,
.h5 {
  font-size: 14px;
}
h6,
.h6 {
  font-size: 12px;
}
p {
  margin: 0 0 10px;
}
.lead {
  margin-bottom: 20px;
  font-size: 16px;
  font-weight: 300;
  line-height: 1.4;
}
@media (min-width: 768px) {
  .lead {
    font-size: 21px;
  }
}
small,
.small {
  font-size: 85%;
}
mark,
.mark {
  padding: 0.2em;
  background-color: #fcf8e3;
}
.text-left {
  text-align: left;
}
.text-right {
  text-align: right;
}
.text-center {
  text-align: center;
}
.text-justify {
  text-align: justify;
}
.text-nowrap {
  white-space: nowrap;
}
.text-lowercase {
  text-transform: lowercase;
}
.text-uppercase {
  text-transform: uppercase;
}
.text-capitalize {
  text-transform: capitalize;
}
.text-muted {
  color: #777777;
}
.text-primary {
  color: #337ab7;
}
a.text-primary:hover,
a.text-primary:focus {
  color: #286090;
}
.text-success {
  color: #3c763d;
}
a.text-success:hover,
a.text-success:focus {
  color: #2b542c;
}
.text-info {
  color: #31708f;
}
a.text-info:hover,
a.text-info:focus {
  color: #245269;
}
.text-warning {
  color: #8a6d3b;
}
a.text-warning:hover,
a.text-warning:focus {
  color: #66512c;
}
.text-danger {
  color: #a94442;
}
a.text-danger:hover,
a.text-danger:focus {
  color: #843534;
}
.bg-primary {
  color: #fff;
  background-color: #337ab7;
}
a.bg-primary:hover,
a.bg-primary:focus {
  background-color: #286090;
}
.bg-success {
  background-color: #dff0d8;
}
a.bg-success:hover,
a.bg-success:focus {
  background-color: #c1e2b3;
}
.bg-info {
  background-color: #d9edf7;
}
a.bg-info:hover,
a.bg-info:focus {
  background-color: #afd9ee;
}
.bg-warning {
  background-color: #fcf8e3;
}
a.bg-warning:hover,
a.bg-warning:focus {
  background-color: #f7ecb5;
}
.bg-danger {
  background-color: #f2dede;
}
a.bg-danger:hover,
a.bg-danger:focus {
  background-color: #e4b9b9;
}
.page-header {
  padding-bottom: 9px;
  margin: 40px 0 20px;
  border-bottom: 1px solid #eeeeee;
}
ul,
ol {
  margin-top: 0;
  margin-bottom: 10px;
}
ul ul,
ol ul,
ul ol,
ol ol {
  margin-bottom: 0;
}
.list-unstyled {
  padding-left: 0;
  list-style: none;
}
.list-inline {
  padding-left: 0;
  list-style: none;
  margin-left: -5px;
}
.list-inline > li {
  display: inline-block;
  padding-right: 5px;
  padding-left: 5px;
}
dl {
  margin-top: 0;
  margin-bottom: 20px;
}
dt,
dd {
  line-height: 1.42857143;
}
dt {
  font-weight: 700;
}
dd {
  margin-left: 0;
}
@media (min-width: 768px) {
  .dl-horizontal dt {
    float: left;
    width: 160px;
    clear: left;
    text-align: right;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
  }
  .dl-horizontal dd {
    margin-left: 180px;
  }
}
abbr[title],
abbr[data-original-title] {
  cursor: help;
}
.initialism {
  font-size: 90%;
  text-transform: uppercase;
}
blockquote {
  padding: 10px 20px;
  margin: 0 0 20px;
  font-size: 17.5px;
  border-left: 5px solid #eeeeee;
}
blockquote p:last-child,
blockquote ul:last-child,
blockquote ol:last-child {
  margin-bottom: 0;
}
blockquote footer,
blockquote small,
blockquote .small {
  display: block;
  font-size: 80%;
  line-height: 1.42857143;
  color: #777777;
}
blockquote footer:before,
blockquote small:before,
blockquote .small:before {
  content: "\2014 \00A0";
}
.blockquote-reverse,
blockquote.pull-right {
  padding-right: 15px;
  padding-left: 0;
  text-align: right;
  border-right: 5px solid #eeeeee;
  border-left: 0;
}
.blockquote-reverse footer:before,
blockquote.pull-right footer:before,
.blockquote-reverse small:before,
blockquote.pull-right small:before,
.blockquote-reverse .small:before,
blockquote.pull-right .small:before {
  content: "";
}
.blockquote-reverse footer:after,
blockquote.pull-right footer:after,
.blockquote-reverse small:after,
blockquote.pull-right small:after,
.blockquote-reverse .small:after,
blockquote.pull-right .small:after {
  content: "\00A0 \2014";
}
address {
  margin-bottom: 20px;
  font-style: normal;
  line-height: 1.42857143;
}
code,
kbd,
pre,
samp {
  font-family: Menlo, Monaco, Consolas, "Courier New", monospace;
}
code {
  padding: 2px 4px;
  font-size: 90%;
  color: #c7254e;
  background-color: #f9f2f4;
  border-radius: 4px;
}
kbd {
  padding: 2px 4px;
  font-size: 90%;
  color: #fff;
  background-color: #333;
  border-radius: 3px;
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25);
}
kbd kbd {
  padding: 0;
  font-size: 100%;
  font-weight: 700;
  -webkit-box-shadow: none;
  box-shadow: none;
}
pre {
  display: block;
  padding: 9.5px;
  margin: 0 0 10px;
  font-size: 13px;
  line-height: 1.42857143;
  color: #333333;
  word-break: break-all;
  word-wrap: break-word;
  background-color: #f5f5f5;
  border: 1px solid #ccc;
  border-radius: 4px;
}
pre code {
  padding: 0;
  font-size: inherit;
  color: inherit;
  white-space: pre-wrap;
  background-color: transparent;
  border-radius: 0;
}
.pre-scrollable {
  max-height: 340px;
  overflow-y: scroll;
}
.container {
  padding-right: 15px;
  padding-left: 15px;
  margin-right: auto;
  margin-left: auto;
}
@media (min-width: 768px) {
  .container {
    width: 750px;
  }
}
@media (min-width: 992px) {
  .container {
    width: 970px;
  }
}
@media (min-width: 1200px) {
  .container {
    width: 1170px;
  }
}
.container-fluid {
  padding-right: 15px;
  padding-left: 15px;
  margin-right: auto;
  margin-left: auto;
}
.row {
  margin-right: -15px;
  margin-left: -15px;
}
.row-no-gutters {
  margin-right: 0;
  margin-left: 0;
}
.row-no-gutters [class*="col-"] {
  padding-right: 0;
  padding-left: 0;
}
.col-xs-1,
.col-sm-1,
.col-md-1,
.col-lg-1,
.col-xs-2,
.col-sm-2,
.col-md-2,
.col-lg-2,
.col-xs-3,
.col-sm-3,
.col-md-3,
.col-lg-3,
.col-xs-4,
.col-sm-4,
.col-md-4,
.col-lg-4,
.col-xs-5,
.col-sm-5,
.col-md-5,
.col-lg-5,
.col-xs-6,
.col-sm-6,
.col-md-6,
.col-lg-6,
.col-xs-7,
.col-sm-7,
.col-md-7,
.col-lg-7,
.col-xs-8,
.col-sm-8,
.col-md-8,
.col-lg-8,
.col-xs-9,
.col-sm-9,
.col-md-9,
.col-lg-9,
.col-xs-10,
.col-sm-10,
.col-md-10,
.col-lg-10,
.col-xs-11,
.col-sm-11,
.col-md-11,
.col-lg-11,
.col-xs-12,
.col-sm-12,
.col-md-12,
.col-lg-12 {
  position: relative;
  min-height: 1px;
  padding-right: 15px;
  padding-left: 15px;
}
.col-xs-1,
.col-xs-2,
.col-xs-3,
.col-xs-4,
.col-xs-5,
.col-xs-6,
.col-xs-7,
.col-xs-8,
.col-xs-9,
.col-xs-10,
.col-xs-11,
.col-xs-12 {
  float: left;
}
.col-xs-12 {
  width: 100%;
}
.col-xs-11 {
  width: 91.66666667%;
}
.col-xs-10 {
  width: 83.33333333%;
}
.col-xs-9 {
  width: 75%;
}
.col-xs-8 {
  width: 66.66666667%;
}
.col-xs-7 {
  width: 58.33333333%;
}
.col-xs-6 {
  width: 50%;
}
.col-xs-5 {
  width: 41.66666667%;
}
.col-xs-4 {
  width: 33.33333333%;
}
.col-xs-3 {
  width: 25%;
}
.col-xs-2 {
  width: 16.66666667%;
}
.col-xs-1 {
  width: 8.33333333%;
}
.col-xs-pull-12 {
  right: 100%;
}
.col-xs-pull-11 {
  right: 91.66666667%;
}
.col-xs-pull-10 {
  right: 83.33333333%;
}
.col-xs-pull-9 {
  right: 75%;
}
.col-xs-pull-8 {
  right: 66.66666667%;
}
.col-xs-pull-7 {
  right: 58.33333333%;
}
.col-xs-pull-6 {
  right: 50%;
}
.col-xs-pull-5 {
  right: 41.66666667%;
}
.col-xs-pull-4 {
  right: 33.33333333%;
}
.col-xs-pull-3 {
  right: 25%;
}
.col-xs-pull-2 {
  right: 16.66666667%;
}
.col-xs-pull-1 {
  right: 8.33333333%;
}
.col-xs-pull-0 {
  right: auto;
}
.col-xs-push-12 {
  left: 100%;
}
.col-xs-push-11 {
  left: 91.66666667%;
}
.col-xs-push-10 {
  left: 83.33333333%;
}
.col-xs-push-9 {
  left: 75%;
}
.col-xs-push-8 {
  left: 66.66666667%;
}
.col-xs-push-7 {
  left: 58.33333333%;
}
.col-xs-push-6 {
  left: 50%;
}
.col-xs-push-5 {
  left: 41.66666667%;
}
.col-xs-push-4 {
  left: 33.33333333%;
}
.col-xs-push-3 {
  left: 25%;
}
.col-xs-push-2 {
  left: 16.66666667%;
}
.col-xs-push-1 {
  left: 8.33333333%;
}
.col-xs-push-0 {
  left: auto;
}
.col-xs-offset-12 {
  margin-left: 100%;
}
.col-xs-offset-11 {
  margin-left: 91.66666667%;
}
.col-xs-offset-10 {
  margin-left: 83.33333333%;
}
.col-xs-offset-9 {
  margin-left: 75%;
}
.col-xs-offset-8 {
  margin-left: 66.66666667%;
}
.col-xs-offset-7 {
  margin-left: 58.33333333%;
}
.col-xs-offset-6 {
  margin-left: 50%;
}
.col-xs-offset-5 {
  margin-left: 41.66666667%;
}
.col-xs-offset-4 {
  margin-left: 33.33333333%;
}
.col-xs-offset-3 {
  margin-left: 25%;
}
.col-xs-offset-2 {
  margin-left: 16.66666667%;
}
.col-xs-offset-1 {
  margin-left: 8.33333333%;
}
.col-xs-offset-0 {
  margin-left: 0%;
}
@media (min-width: 768px) {
  .col-sm-1,
  .col-sm-2,
  .col-sm-3,
  .col-sm-4,
  .col-sm-5,
  .col-sm-6,
  .col-sm-7,
  .col-sm-8,
  .col-sm-9,
  .col-sm-10,
  .col-sm-11,
  .col-sm-12 {
    float: left;
  }
  .col-sm-12 {
    width: 100%;
  }
  .col-sm-11 {
    width: 91.66666667%;
  }
  .col-sm-10 {
    width: 83.33333333%;
  }
  .col-sm-9 {
    width: 75%;
  }
  .col-sm-8 {
    width: 66.66666667%;
  }
  .col-sm-7 {
    width: 58.33333333%;
  }
  .col-sm-6 {
    width: 50%;
  }
  .col-sm-5 {
    width: 41.66666667%;
  }
  .col-sm-4 {
    width: 33.33333333%;
  }
  .col-sm-3 {
    width: 25%;
  }
  .col-sm-2 {
    width: 16.66666667%;
  }
  .col-sm-1 {
    width: 8.33333333%;
  }
  .col-sm-pull-12 {
    right: 100%;
  }
  .col-sm-pull-11 {
    right: 91.66666667%;
  }
  .col-sm-pull-10 {
    right: 83.33333333%;
  }
  .col-sm-pull-9 {
    right: 75%;
  }
  .col-sm-pull-8 {
    right: 66.66666667%;
  }
  .col-sm-pull-7 {
    right: 58.33333333%;
  }
  .col-sm-pull-6 {
    right: 50%;
  }
  .col-sm-pull-5 {
    right: 41.66666667%;
  }
  .col-sm-pull-4 {
    right: 33.33333333%;
  }
  .col-sm-pull-3 {
    right: 25%;
  }
  .col-sm-pull-2 {
    right: 16.66666667%;
  }
  .col-sm-pull-1 {
    right: 8.33333333%;
  }
  .col-sm-pull-0 {
    right: auto;
  }
  .col-sm-push-12 {
    left: 100%;
  }
  .col-sm-push-11 {
    left: 91.66666667%;
  }
  .col-sm-push-10 {
    left: 83.33333333%;
  }
  .col-sm-push-9 {
    left: 75%;
  }
  .col-sm-push-8 {
    left: 66.66666667%;
  }
  .col-sm-push-7 {
    left: 58.33333333%;
  }
  .col-sm-push-6 {
    left: 50%;
  }
  .col-sm-push-5 {
    left: 41.66666667%;
  }
  .col-sm-push-4 {
    left: 33.33333333%;
  }
  .col-sm-push-3 {
    left: 25%;
  }
  .col-sm-push-2 {
    left: 16.66666667%;
  }
  .col-sm-push-1 {
    left: 8.33333333%;
  }
  .col-sm-push-0 {
    left: auto;
  }
  .col-sm-offset-12 {
    margin-left: 100%;
  }
  .col-sm-offset-11 {
    margin-left: 91.66666667%;
  }
  .col-sm-offset-10 {
    margin-left: 83.33333333%;
  }
  .col-sm-offset-9 {
    margin-left: 75%;
  }
  .col-sm-offset-8 {
    margin-left: 66.66666667%;
  }
  .col-sm-offset-7 {
    margin-left: 58.33333333%;
  }
  .col-sm-offset-6 {
    margin-left: 50%;
  }
  .col-sm-offset-5 {
    margin-left: 41.66666667%;
  }
  .col-sm-offset-4 {
    margin-left: 33.33333333%;
  }
  .col-sm-offset-3 {
    margin-left: 25%;
  }
  .col-sm-offset-2 {
    margin-left: 16.66666667%;
  }
  .col-sm-offset-1 {
    margin-left: 8.33333333%;
  }
  .col-sm-offset-0 {
    margin-left: 0%;
  }
}
@media (min-width: 992px) {
  .col-md-1,
  .col-md-2,
  .col-md-3,
  .col-md-4,
  .col-md-5,
  .col-md-6,
  .col-md-7,
  .col-md-8,
  .col-md-9,
  .col-md-10,
  .col-md-11,
  .col-md-12 {
    float: left;
  }
  .col-md-12 {
    width: 100%;
  }
  .col-md-11 {
    width: 91.66666667%;
  }
  .col-md-10 {
    width: 83.33333333%;
  }
  .col-md-9 {
    width: 75%;
  }
  .col-md-8 {
    width: 66.66666667%;
  }
  .col-md-7 {
    width: 58.33333333%;
  }
  .col-md-6 {
    width: 50%;
  }
  .col-md-5 {
    width: 41.66666667%;
  }
  .col-md-4 {
    width: 33.33333333%;
  }
  .col-md-3 {
    width: 25%;
  }
  .col-md-2 {
    width: 16.66666667%;
  }
  .col-md-1 {
    width: 8.33333333%;
  }
  .col-md-pull-12 {
    right: 100%;
  }
  .col-md-pull-11 {
    right: 91.66666667%;
  }
  .col-md-pull-10 {
    right: 83.33333333%;
  }
  .col-md-pull-9 {
    right: 75%;
  }
  .col-md-pull-8 {
    right: 66.66666667%;
  }
  .col-md-pull-7 {
    right: 58.33333333%;
  }
  .col-md-pull-6 {
    right: 50%;
  }
  .col-md-pull-5 {
    right: 41.66666667%;
  }
  .col-md-pull-4 {
    right: 33.33333333%;
  }
  .col-md-pull-3 {
    right: 25%;
  }
  .col-md-pull-2 {
    right: 16.66666667%;
  }
  .col-md-pull-1 {
    right: 8.33333333%;
  }
  .col-md-pull-0 {
    right: auto;
  }
  .col-md-push-12 {
    left: 100%;
  }
  .col-md-push-11 {
    left: 91.66666667%;
  }
  .col-md-push-10 {
    left: 83.33333333%;
  }
  .col-md-push-9 {
    left: 75%;
  }
  .col-md-push-8 {
    left: 66.66666667%;
  }
  .col-md-push-7 {
    left: 58.33333333%;
  }
  .col-md-push-6 {
    left: 50%;
  }
  .col-md-push-5 {
    left: 41.66666667%;
  }
  .col-md-push-4 {
    left: 33.33333333%;
  }
  .col-md-push-3 {
    left: 25%;
  }
  .col-md-push-2 {
    left: 16.66666667%;
  }
  .col-md-push-1 {
    left: 8.33333333%;
  }
  .col-md-push-0 {
    left: auto;
  }
  .col-md-offset-12 {
    margin-left: 100%;
  }
  .col-md-offset-11 {
    margin-left: 91.66666667%;
  }
  .col-md-offset-10 {
    margin-left: 83.33333333%;
  }
  .col-md-offset-9 {
    margin-left: 75%;
  }
  .col-md-offset-8 {
    margin-left: 66.66666667%;
  }
  .col-md-offset-7 {
    margin-left: 58.33333333%;
  }
  .col-md-offset-6 {
    margin-left: 50%;
  }
  .col-md-offset-5 {
    margin-left: 41.66666667%;
  }
  .col-md-offset-4 {
    margin-left: 33.33333333%;
  }
  .col-md-offset-3 {
    margin-left: 25%;
  }
  .col-md-offset-2 {
    margin-left: 16.66666667%;
  }
  .col-md-offset-1 {
    margin-left: 8.33333333%;
  }
  .col-md-offset-0 {
    margin-left: 0%;
  }
}
@media (min-width: 1200px) {
  .col-lg-1,
  .col-lg-2,
  .col-lg-3,
  .col-lg-4,
  .col-lg-5,
  .col-lg-6,
  .col-lg-7,
  .col-lg-8,
  .col-lg-9,
  .col-lg-10,
  .col-lg-11,
  .col-lg-12 {
    float: left;
  }
  .col-lg-12 {
    width: 100%;
  }
  .col-lg-11 {
    width: 91.66666667%;
  }
  .col-lg-10 {
    width: 83.33333333%;
  }
  .col-lg-9 {
    width: 75%;
  }
  .col-lg-8 {
    width: 66.66666667%;
  }
  .col-lg-7 {
    width: 58.33333333%;
  }
  .col-lg-6 {
    width: 50%;
  }
  .col-lg-5 {
    width: 41.66666667%;
  }
  .col-lg-4 {
    width: 33.33333333%;
  }
  .col-lg-3 {
    width: 25%;
  }
  .col-lg-2 {
    width: 16.66666667%;
  }
  .col-lg-1 {
    width: 8.33333333%;
  }
  .col-lg-pull-12 {
    right: 100%;
  }
  .col-lg-pull-11 {
    right: 91.66666667%;
  }
  .col-lg-pull-10 {
    right: 83.33333333%;
  }
  .col-lg-pull-9 {
    right: 75%;
  }
  .col-lg-pull-8 {
    right: 66.66666667%;
  }
  .col-lg-pull-7 {
    right: 58.33333333%;
  }
  .col-lg-pull-6 {
    right: 50%;
  }
  .col-lg-pull-5 {
    right: 41.66666667%;
  }
  .col-lg-pull-4 {
    right: 33.33333333%;
  }
  .col-lg-pull-3 {
    right: 25%;
  }
  .col-lg-pull-2 {
    right: 16.66666667%;
  }
  .col-lg-pull-1 {
    right: 8.33333333%;
  }
  .col-lg-pull-0 {
    right: auto;
  }
  .col-lg-push-12 {
    left: 100%;
  }
  .col-lg-push-11 {
    left: 91.66666667%;
  }
  .col-lg-push-10 {
    left: 83.33333333%;
  }
  .col-lg-push-9 {
    left: 75%;
  }
  .col-lg-push-8 {
    left: 66.66666667%;
  }
  .col-lg-push-7 {
    left: 58.33333333%;
  }
  .col-lg-push-6 {
    left: 50%;
  }
  .col-lg-push-5 {
    left: 41.66666667%;
  }
  .col-lg-push-4 {
    left: 33.33333333%;
  }
  .col-lg-push-3 {
    left: 25%;
  }
  .col-lg-push-2 {
    left: 16.66666667%;
  }
  .col-lg-push-1 {
    left: 8.33333333%;
  }
  .col-lg-push-0 {
    left: auto;
  }
  .col-lg-offset-12 {
    margin-left: 100%;
  }
  .col-lg-offset-11 {
    margin-left: 91.66666667%;
  }
  .col-lg-offset-10 {
    margin-left: 83.33333333%;
  }
  .col-lg-offset-9 {
    margin-left: 75%;
  }
  .col-lg-offset-8 {
    margin-left: 66.66666667%;
  }
  .col-lg-offset-7 {
    margin-left: 58.33333333%;
  }
  .col-lg-offset-6 {
    margin-left: 50%;
  }
  .col-lg-offset-5 {
    margin-left: 41.66666667%;
  }
  .col-lg-offset-4 {
    margin-left: 33.33333333%;
  }
  .col-lg-offset-3 {
    margin-left: 25%;
  }
  .col-lg-offset-2 {
    margin-left: 16.66666667%;
  }
  .col-lg-offset-1 {
    margin-left: 8.33333333%;
  }
  .col-lg-offset-0 {
    margin-left: 0%;
  }
}
table {
  background-color: transparent;
}
table col[class*="col-"] {
  position: static;
  display: table-column;
  float: none;
}
table td[class*="col-"],
table th[class*="col-"] {
  position: static;
  display: table-cell;
  float: none;
}
caption {
  padding-top: 8px;
  padding-bottom: 8px;
  color: #777777;
  text-align: left;
}
th {
  text-align: left;
}
.table {
  width: 100%;
  max-width: 100%;
  margin-bottom: 20px;
}
.table > thead > tr > th,
.table > tbody > tr > th,
.table > tfoot > tr > th,
.table > thead > tr > td,
.table > tbody > tr > td,
.table > tfoot > tr > td {
  padding: 8px;
  line-height: 1.42857143;
  vertical-align: top;
  border-top: 1px solid #ddd;
}
.table > thead > tr > th {
  vertical-align: bottom;
  border-bottom: 2px solid #ddd;
}
.table > caption + thead > tr:first-child > th,
.table > colgroup + thead > tr:first-child > th,
.table > thead:first-child > tr:first-child > th,
.table > caption + thead > tr:first-child > td,
.table > colgroup + thead > tr:first-child > td,
.table > thead:first-child > tr:first-child > td {
  border-top: 0;
}
.table > tbody + tbody {
  border-top: 2px solid #ddd;
}
.table .table {
  background-color: #fff;
}
.table-condensed > thead > tr > th,
.table-condensed > tbody > tr > th,
.table-condensed > tfoot > tr > th,
.table-condensed > thead > tr > td,
.table-condensed > tbody > tr > td,
.table-condensed > tfoot > tr > td {
  padding: 5px;
}
.table-bordered {
  border: 1px solid #ddd;
}
.table-bordered > thead > tr > th,
.table-bordered > tbody > tr > th,
.table-bordered > tfoot > tr > th,
.table-bordered > thead > tr > td,
.table-bordered > tbody > tr > td,
.table-bordered > tfoot > tr > td {
  border: 1px solid #ddd;
}
.table-bordered > thead > tr > th,
.table-bordered > thead > tr > td {
  border-bottom-width: 2px;
}
.table-striped > tbody > tr:nth-of-type(odd) {
  background-color: #f9f9f9;
}
.table-hover > tbody > tr:hover {
  background-color: #f5f5f5;
}
.table > thead > tr > td.active,
.table > tbody > tr > td.active,
.table > tfoot > tr > td.active,
.table > thead > tr > th.active,
.table > tbody > tr > th.active,
.table > tfoot > tr > th.active,
.table > thead > tr.active > td,
.table > tbody > tr.active > td,
.table > tfoot > tr.active > td,
.table > thead > tr.active > th,
.table > tbody > tr.active > th,
.table > tfoot > tr.active > th {
  background-color: #f5f5f5;
}
.table-hover > tbody > tr > td.active:hover,
.table-hover > tbody > tr > th.active:hover,
.table-hover > tbody > tr.active:hover > td,
.table-hover > tbody > tr:hover > .active,
.table-hover > tbody > tr.active:hover > th {
  background-color: #e8e8e8;
}
.table > thead > tr > td.success,
.table > tbody > tr > td.success,
.table > tfoot > tr > td.success,
.table > thead > tr > th.success,
.table > tbody > tr > th.success,
.table > tfoot > tr > th.success,
.table > thead > tr.success > td,
.table > tbody > tr.success > td,
.table > tfoot > tr.success > td,
.table > thead > tr.success > th,
.table > tbody > tr.success > th,
.table > tfoot > tr.success > th {
  background-color: #dff0d8;
}
.table-hover > tbody > tr > td.success:hover,
.table-hover > tbody > tr > th.success:hover,
.table-hover > tbody > tr.success:hover > td,
.table-hover > tbody > tr:hover > .success,
.table-hover > tbody > tr.success:hover > th {
  background-color: #d0e9c6;
}
.table > thead > tr > td.info,
.table > tbody > tr > td.info,
.table > tfoot > tr > td.info,
.table > thead > tr > th.info,
.table > tbody > tr > th.info,
.table > tfoot > tr > th.info,
.table > thead > tr.info > td,
.table > tbody > tr.info > td,
.table > tfoot > tr.info > td,
.table > thead > tr.info > th,
.table > tbody > tr.info > th,
.table > tfoot > tr.info > th {
  background-color: #d9edf7;
}
.table-hover > tbody > tr > td.info:hover,
.table-hover > tbody > tr > th.info:hover,
.table-hover > tbody > tr.info:hover > td,
.table-hover > tbody > tr:hover > .info,
.table-hover > tbody > tr.info:hover > th {
  background-color: #c4e3f3;
}
.table > thead > tr > td.warning,
.table > tbody > tr > td.warning,
.table > tfoot > tr > td.warning,
.table > thead > tr > th.warning,
.table > tbody > tr > th.warning,
.table > tfoot > tr > th.warning,
.table > thead > tr.warning > td,
.table > tbody > tr.warning > td,
.table > tfoot > tr.warning > td,
.table > thead > tr.warning > th,
.table > tbody > tr.warning > th,
.table > tfoot > tr.warning > th {
  background-color: #fcf8e3;
}
.table-hover > tbody > tr > td.warning:hover,
.table-hover > tbody > tr > th.warning:hover,
.table-hover > tbody > tr.warning:hover > td,
.table-hover > tbody > tr:hover > .warning,
.table-hover > tbody > tr.warning:hover > th {
  background-color: #faf2cc;
}
.table > thead > tr > td.danger,
.table > tbody > tr > td.danger,
.table > tfoot > tr > td.danger,
.table > thead > tr > th.danger,
.table > tbody > tr > th.danger,
.table > tfoot > tr > th.danger,
.table > thead > tr.danger > td,
.table > tbody > tr.danger > td,
.table > tfoot > tr.danger > td,
.table > thead > tr.danger > th,
.table > tbody > tr.danger > th,
.table > tfoot > tr.danger > th {
  background-color: #f2dede;
}
.table-hover > tbody > tr > td.danger:hover,
.table-hover > tbody > tr > th.danger:hover,
.table-hover > tbody > tr.danger:hover > td,
.table-hover > tbody > tr:hover > .danger,
.table-hover > tbody > tr.danger:hover > th {
  background-color: #ebcccc;
}
.table-responsive {
  min-height: 0.01%;
  overflow-x: auto;
}
@media screen and (max-width: 767px) {
  .table-responsive {
    width: 100%;
    margin-bottom: 15px;
    overflow-y: hidden;
    -ms-overflow-style: -ms-autohiding-scrollbar;
    border: 1px solid #ddd;
  }
  .table-responsive > .table {
    margin-bottom: 0;
  }
  .table-responsive > .table > thead > tr > th,
  .table-responsive > .table > tbody > tr > th,
  .table-responsive > .table > tfoot > tr > th,
  .table-responsive > .table > thead > tr > td,
  .table-responsive > .table > tbody > tr > td,
  .table-responsive > .table > tfoot > tr > td {
    white-space: nowrap;
  }
  .table-responsive > .table-bordered {
    border: 0;
  }
  .table-responsive > .table-bordered > thead > tr > th:first-child,
  .table-responsive > .table-bordered > tbody > tr > th:first-child,
  .table-responsive > .table-bordered > tfoot > tr > th:first-child,
  .table-responsive > .table-bordered > thead > tr > td:first-child,
  .table-responsive > .table-bordered > tbody > tr > td:first-child,
  .table-responsive > .table-bordered > tfoot > tr > td:first-child {
    border-left: 0;
  }
  .table-responsive > .table-bordered > thead > tr > th:last-child,
  .table-responsive > .table-bordered > tbody > tr > th:last-child,
  .table-responsive > .table-bordered > tfoot > tr > th:last-child,
  .table-responsive > .table-bordered > thead > tr > td:last-child,
  .table-responsive > .table-bordered > tbody > tr > td:last-child,
  .table-responsive > .table-bordered > tfoot > tr > td:last-child {
    border-right: 0;
  }
  .table-responsive > .table-bordered > tbody > tr:last-child > th,
  .table-responsive > .table-bordered > tfoot > tr:last-child > th,
  .table-responsive > .table-bordered > tbody > tr:last-child > td,
  .table-responsive > .table-bordered > tfoot > tr:last-child > td {
    border-bottom: 0;
  }
}
fieldset {
  min-width: 0;
  padding: 0;
  margin: 0;
  border: 0;
}
legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 20px;
  font-size: 21px;
  line-height: inherit;
  color: #333333;
  border: 0;
  border-bottom: 1px solid #e5e5e5;
}
label {
  display: inline-block;
  max-width: 100%;
  margin-bottom: 5px;
  font-weight: 700;
}
input[type="search"] {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
}
input[type="radio"],
input[type="checkbox"] {
  margin: 4px 0 0;
  margin-top: 1px \9;
  line-height: normal;
}
input[type="radio"][disabled],
input[type="checkbox"][disabled],
input[type="radio"].disabled,
input[type="checkbox"].disabled,
fieldset[disabled] input[type="radio"],
fieldset[disabled] input[type="checkbox"] {
  cursor: not-allowed;
}
input[type="file"] {
  display: block;
}
input[type="range"] {
  display: block;
  width: 100%;
}
select[multiple],
select[size] {
  height: auto;
}
input[type="file"]:focus,
input[type="radio"]:focus,
input[type="checkbox"]:focus {
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
output {
  display: block;
  padding-top: 7px;
  font-size: 14px;
  line-height: 1.42857143;
  color: #555555;
}
.form-control {
  display: block;
  width: 100%;
  height: 34px;
  padding: 6px 12px;
  font-size: 14px;
  line-height: 1.42857143;
  color: #555555;
  background-color: #fff;
  background-image: none;
  border: 1px solid #ccc;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -webkit-transition: border-color ease-in-out .15s, box-shadow ease-in-out .15s;
  -o-transition: border-color ease-in-out .15s, box-shadow ease-in-out .15s;
  -webkit-transition: border-color ease-in-out .15s, -webkit-box-shadow ease-in-out .15s;
  transition: border-color ease-in-out .15s, -webkit-box-shadow ease-in-out .15s;
  transition: border-color ease-in-out .15s, box-shadow ease-in-out .15s;
  transition: border-color ease-in-out .15s, box-shadow ease-in-out .15s, -webkit-box-shadow ease-in-out .15s;
}
.form-control:focus {
  border-color: #66afe9;
  outline: 0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 8px rgba(102, 175, 233, 0.6);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 8px rgba(102, 175, 233, 0.6);
}
.form-control::-moz-placeholder {
  color: #999;
  opacity: 1;
}
.form-control:-ms-input-placeholder {
  color: #999;
}
.form-control::-webkit-input-placeholder {
  color: #999;
}
.form-control::-ms-expand {
  background-color: transparent;
  border: 0;
}
.form-control[disabled],
.form-control[readonly],
fieldset[disabled] .form-control {
  background-color: #eeeeee;
  opacity: 1;
}
.form-control[disabled],
fieldset[disabled] .form-control {
  cursor: not-allowed;
}
textarea.form-control {
  height: auto;
}
@media screen and (-webkit-min-device-pixel-ratio: 0) {
  input[type="date"].form-control,
  input[type="time"].form-control,
  input[type="datetime-local"].form-control,
  input[type="month"].form-control {
    line-height: 34px;
  }
  input[type="date"].input-sm,
  input[type="time"].input-sm,
  input[type="datetime-local"].input-sm,
  input[type="month"].input-sm,
  .input-group-sm input[type="date"],
  .input-group-sm input[type="time"],
  .input-group-sm input[type="datetime-local"],
  .input-group-sm input[type="month"] {
    line-height: 30px;
  }
  input[type="date"].input-lg,
  input[type="time"].input-lg,
  input[type="datetime-local"].input-lg,
  input[type="month"].input-lg,
  .input-group-lg input[type="date"],
  .input-group-lg input[type="time"],
  .input-group-lg input[type="datetime-local"],
  .input-group-lg input[type="month"] {
    line-height: 46px;
  }
}
.form-group {
  margin-bottom: 15px;
}
.radio,
.checkbox {
  position: relative;
  display: block;
  margin-top: 10px;
  margin-bottom: 10px;
}
.radio.disabled label,
.checkbox.disabled label,
fieldset[disabled] .radio label,
fieldset[disabled] .checkbox label {
  cursor: not-allowed;
}
.radio label,
.checkbox label {
  min-height: 20px;
  padding-left: 20px;
  margin-bottom: 0;
  font-weight: 400;
  cursor: pointer;
}
.radio input[type="radio"],
.radio-inline input[type="radio"],
.checkbox input[type="checkbox"],
.checkbox-inline input[type="checkbox"] {
  position: absolute;
  margin-top: 4px \9;
  margin-left: -20px;
}
.radio + .radio,
.checkbox + .checkbox {
  margin-top: -5px;
}
.radio-inline,
.checkbox-inline {
  position: relative;
  display: inline-block;
  padding-left: 20px;
  margin-bottom: 0;
  font-weight: 400;
  vertical-align: middle;
  cursor: pointer;
}
.radio-inline.disabled,
.checkbox-inline.disabled,
fieldset[disabled] .radio-inline,
fieldset[disabled] .checkbox-inline {
  cursor: not-allowed;
}
.radio-inline + .radio-inline,
.checkbox-inline + .checkbox-inline {
  margin-top: 0;
  margin-left: 10px;
}
.form-control-static {
  min-height: 34px;
  padding-top: 7px;
  padding-bottom: 7px;
  margin-bottom: 0;
}
.form-control-static.input-lg,
.form-control-static.input-sm {
  padding-right: 0;
  padding-left: 0;
}
.input-sm {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
select.input-sm {
  height: 30px;
  line-height: 30px;
}
textarea.input-sm,
select[multiple].input-sm {
  height: auto;
}
.form-group-sm .form-control {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
.form-group-sm select.form-control {
  height: 30px;
  line-height: 30px;
}
.form-group-sm textarea.form-control,
.form-group-sm select[multiple].form-control {
  height: auto;
}
.form-group-sm .form-control-static {
  height: 30px;
  min-height: 32px;
  padding: 6px 10px;
  font-size: 12px;
  line-height: 1.5;
}
.input-lg {
  height: 46px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
  border-radius: 6px;
}
select.input-lg {
  height: 46px;
  line-height: 46px;
}
textarea.input-lg,
select[multiple].input-lg {
  height: auto;
}
.form-group-lg .form-control {
  height: 46px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
  border-radius: 6px;
}
.form-group-lg select.form-control {
  height: 46px;
  line-height: 46px;
}
.form-group-lg textarea.form-control,
.form-group-lg select[multiple].form-control {
  height: auto;
}
.form-group-lg .form-control-static {
  height: 46px;
  min-height: 38px;
  padding: 11px 16px;
  font-size: 18px;
  line-height: 1.3333333;
}
.has-feedback {
  position: relative;
}
.has-feedback .form-control {
  padding-right: 42.5px;
}
.form-control-feedback {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 2;
  display: block;
  width: 34px;
  height: 34px;
  line-height: 34px;
  text-align: center;
  pointer-events: none;
}
.input-lg + .form-control-feedback,
.input-group-lg + .form-control-feedback,
.form-group-lg .form-control + .form-control-feedback {
  width: 46px;
  height: 46px;
  line-height: 46px;
}
.input-sm + .form-control-feedback,
.input-group-sm + .form-control-feedback,
.form-group-sm .form-control + .form-control-feedback {
  width: 30px;
  height: 30px;
  line-height: 30px;
}
.has-success .help-block,
.has-success .control-label,
.has-success .radio,
.has-success .checkbox,
.has-success .radio-inline,
.has-success .checkbox-inline,
.has-success.radio label,
.has-success.checkbox label,
.has-success.radio-inline label,
.has-success.checkbox-inline label {
  color: #3c763d;
}
.has-success .form-control {
  border-color: #3c763d;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.has-success .form-control:focus {
  border-color: #2b542c;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
}
.has-success .input-group-addon {
  color: #3c763d;
  background-color: #dff0d8;
  border-color: #3c763d;
}
.has-success .form-control-feedback {
  color: #3c763d;
}
.has-warning .help-block,
.has-warning .control-label,
.has-warning .radio,
.has-warning .checkbox,
.has-warning .radio-inline,
.has-warning .checkbox-inline,
.has-warning.radio label,
.has-warning.checkbox label,
.has-warning.radio-inline label,
.has-warning.checkbox-inline label {
  color: #8a6d3b;
}
.has-warning .form-control {
  border-color: #8a6d3b;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.has-warning .form-control:focus {
  border-color: #66512c;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
}
.has-warning .input-group-addon {
  color: #8a6d3b;
  background-color: #fcf8e3;
  border-color: #8a6d3b;
}
.has-warning .form-control-feedback {
  color: #8a6d3b;
}
.has-error .help-block,
.has-error .control-label,
.has-error .radio,
.has-error .checkbox,
.has-error .radio-inline,
.has-error .checkbox-inline,
.has-error.radio label,
.has-error.checkbox label,
.has-error.radio-inline label,
.has-error.checkbox-inline label {
  color: #a94442;
}
.has-error .form-control {
  border-color: #a94442;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.has-error .form-control:focus {
  border-color: #843534;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
}
.has-error .input-group-addon {
  color: #a94442;
  background-color: #f2dede;
  border-color: #a94442;
}
.has-error .form-control-feedback {
  color: #a94442;
}
.has-feedback label ~ .form-control-feedback {
  top: 25px;
}
.has-feedback label.sr-only ~ .form-control-feedback {
  top: 0;
}
.help-block {
  display: block;
  margin-top: 5px;
  margin-bottom: 10px;
  color: #737373;
}
@media (min-width: 768px) {
  .form-inline .form-group {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle;
  }
  .form-inline .form-control {
    display: inline-block;
    width: auto;
    vertical-align: middle;
  }
  .form-inline .form-control-static {
    display: inline-block;
  }
  .form-inline .input-group {
    display: inline-table;
    vertical-align: middle;
  }
  .form-inline .input-group .input-group-addon,
  .form-inline .input-group .input-group-btn,
  .form-inline .input-group .form-control {
    width: auto;
  }
  .form-inline .input-group > .form-control {
    width: 100%;
  }
  .form-inline .control-label {
    margin-bottom: 0;
    vertical-align: middle;
  }
  .form-inline .radio,
  .form-inline .checkbox {
    display: inline-block;
    margin-top: 0;
    margin-bottom: 0;
    vertical-align: middle;
  }
  .form-inline .radio label,
  .form-inline .checkbox label {
    padding-left: 0;
  }
  .form-inline .radio input[type="radio"],
  .form-inline .checkbox input[type="checkbox"] {
    position: relative;
    margin-left: 0;
  }
  .form-inline .has-feedback .form-control-feedback {
    top: 0;
  }
}
.form-horizontal .radio,
.form-horizontal .checkbox,
.form-horizontal .radio-inline,
.form-horizontal .checkbox-inline {
  padding-top: 7px;
  margin-top: 0;
  margin-bottom: 0;
}
.form-horizontal .radio,
.form-horizontal .checkbox {
  min-height: 27px;
}
.form-horizontal .form-group {
  margin-right: -15px;
  margin-left: -15px;
}
@media (min-width: 768px) {
  .form-horizontal .control-label {
    padding-top: 7px;
    margin-bottom: 0;
    text-align: right;
  }
}
.form-horizontal .has-feedback .form-control-feedback {
  right: 15px;
}
@media (min-width: 768px) {
  .form-horizontal .form-group-lg .control-label {
    padding-top: 11px;
    font-size: 18px;
  }
}
@media (min-width: 768px) {
  .form-horizontal .form-group-sm .control-label {
    padding-top: 6px;
    font-size: 12px;
  }
}
.btn {
  display: inline-block;
  margin-bottom: 0;
  font-weight: normal;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  -ms-touch-action: manipulation;
  touch-action: manipulation;
  cursor: pointer;
  background-image: none;
  border: 1px solid transparent;
  padding: 6px 12px;
  font-size: 14px;
  line-height: 1.42857143;
  border-radius: 4px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.btn:focus,
.btn:active:focus,
.btn.active:focus,
.btn.focus,
.btn:active.focus,
.btn.active.focus {
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.btn:hover,
.btn:focus,
.btn.focus {
  color: #333;
  text-decoration: none;
}
.btn:active,
.btn.active {
  background-image: none;
  outline: 0;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
.btn.disabled,
.btn[disabled],
fieldset[disabled] .btn {
  cursor: not-allowed;
  filter: alpha(opacity=65);
  opacity: 0.65;
  -webkit-box-shadow: none;
  box-shadow: none;
}
a.btn.disabled,
fieldset[disabled] a.btn {
  pointer-events: none;
}
.btn-default {
  color: #333;
  background-color: #fff;
  border-color: #ccc;
}
.btn-default:focus,
.btn-default.focus {
  color: #333;
  background-color: #e6e6e6;
  border-color: #8c8c8c;
}
.btn-default:hover {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}
.btn-default:active,
.btn-default.active,
.open > .dropdown-toggle.btn-default {
  color: #333;
  background-color: #e6e6e6;
  background-image: none;
  border-color: #adadad;
}
.btn-default:active:hover,
.btn-default.active:hover,
.open > .dropdown-toggle.btn-default:hover,
.btn-default:active:focus,
.btn-default.active:focus,
.open > .dropdown-toggle.btn-default:focus,
.btn-default:active.focus,
.btn-default.active.focus,
.open > .dropdown-toggle.btn-default.focus {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}
.btn-default.disabled:hover,
.btn-default[disabled]:hover,
fieldset[disabled] .btn-default:hover,
.btn-default.disabled:focus,
.btn-default[disabled]:focus,
fieldset[disabled] .btn-default:focus,
.btn-default.disabled.focus,
.btn-default[disabled].focus,
fieldset[disabled] .btn-default.focus {
  background-color: #fff;
  border-color: #ccc;
}
.btn-default .badge {
  color: #fff;
  background-color: #333;
}
.btn-primary {
  color: #fff;
  background-color: #337ab7;
  border-color: #2e6da4;
}
.btn-primary:focus,
.btn-primary.focus {
  color: #fff;
  background-color: #286090;
  border-color: #122b40;
}
.btn-primary:hover {
  color: #fff;
  background-color: #286090;
  border-color: #204d74;
}
.btn-primary:active,
.btn-primary.active,
.open > .dropdown-toggle.btn-primary {
  color: #fff;
  background-color: #286090;
  background-image: none;
  border-color: #204d74;
}
.btn-primary:active:hover,
.btn-primary.active:hover,
.open > .dropdown-toggle.btn-primary:hover,
.btn-primary:active:focus,
.btn-primary.active:focus,
.open > .dropdown-toggle.btn-primary:focus,
.btn-primary:active.focus,
.btn-primary.active.focus,
.open > .dropdown-toggle.btn-primary.focus {
  color: #fff;
  background-color: #204d74;
  border-color: #122b40;
}
.btn-primary.disabled:hover,
.btn-primary[disabled]:hover,
fieldset[disabled] .btn-primary:hover,
.btn-primary.disabled:focus,
.btn-primary[disabled]:focus,
fieldset[disabled] .btn-primary:focus,
.btn-primary.disabled.focus,
.btn-primary[disabled].focus,
fieldset[disabled] .btn-primary.focus {
  background-color: #337ab7;
  border-color: #2e6da4;
}
.btn-primary .badge {
  color: #337ab7;
  background-color: #fff;
}
.btn-success {
  color: #fff;
  background-color: #5cb85c;
  border-color: #4cae4c;
}
.btn-success:focus,
.btn-success.focus {
  color: #fff;
  background-color: #449d44;
  border-color: #255625;
}
.btn-success:hover {
  color: #fff;
  background-color: #449d44;
  border-color: #398439;
}
.btn-success:active,
.btn-success.active,
.open > .dropdown-toggle.btn-success {
  color: #fff;
  background-color: #449d44;
  background-image: none;
  border-color: #398439;
}
.btn-success:active:hover,
.btn-success.active:hover,
.open > .dropdown-toggle.btn-success:hover,
.btn-success:active:focus,
.btn-success.active:focus,
.open > .dropdown-toggle.btn-success:focus,
.btn-success:active.focus,
.btn-success.active.focus,
.open > .dropdown-toggle.btn-success.focus {
  color: #fff;
  background-color: #398439;
  border-color: #255625;
}
.btn-success.disabled:hover,
.btn-success[disabled]:hover,
fieldset[disabled] .btn-success:hover,
.btn-success.disabled:focus,
.btn-success[disabled]:focus,
fieldset[disabled] .btn-success:focus,
.btn-success.disabled.focus,
.btn-success[disabled].focus,
fieldset[disabled] .btn-success.focus {
  background-color: #5cb85c;
  border-color: #4cae4c;
}
.btn-success .badge {
  color: #5cb85c;
  background-color: #fff;
}
.btn-info {
  color: #fff;
  background-color: #5bc0de;
  border-color: #46b8da;
}
.btn-info:focus,
.btn-info.focus {
  color: #fff;
  background-color: #31b0d5;
  border-color: #1b6d85;
}
.btn-info:hover {
  color: #fff;
  background-color: #31b0d5;
  border-color: #269abc;
}
.btn-info:active,
.btn-info.active,
.open > .dropdown-toggle.btn-info {
  color: #fff;
  background-color: #31b0d5;
  background-image: none;
  border-color: #269abc;
}
.btn-info:active:hover,
.btn-info.active:hover,
.open > .dropdown-toggle.btn-info:hover,
.btn-info:active:focus,
.btn-info.active:focus,
.open > .dropdown-toggle.btn-info:focus,
.btn-info:active.focus,
.btn-info.active.focus,
.open > .dropdown-toggle.btn-info.focus {
  color: #fff;
  background-color: #269abc;
  border-color: #1b6d85;
}
.btn-info.disabled:hover,
.btn-info[disabled]:hover,
fieldset[disabled] .btn-info:hover,
.btn-info.disabled:focus,
.btn-info[disabled]:focus,
fieldset[disabled] .btn-info:focus,
.btn-info.disabled.focus,
.btn-info[disabled].focus,
fieldset[disabled] .btn-info.focus {
  background-color: #5bc0de;
  border-color: #46b8da;
}
.btn-info .badge {
  color: #5bc0de;
  background-color: #fff;
}
.btn-warning {
  color: #fff;
  background-color: #f0ad4e;
  border-color: #eea236;
}
.btn-warning:focus,
.btn-warning.focus {
  color: #fff;
  background-color: #ec971f;
  border-color: #985f0d;
}
.btn-warning:hover {
  color: #fff;
  background-color: #ec971f;
  border-color: #d58512;
}
.btn-warning:active,
.btn-warning.active,
.open > .dropdown-toggle.btn-warning {
  color: #fff;
  background-color: #ec971f;
  background-image: none;
  border-color: #d58512;
}
.btn-warning:active:hover,
.btn-warning.active:hover,
.open > .dropdown-toggle.btn-warning:hover,
.btn-warning:active:focus,
.btn-warning.active:focus,
.open > .dropdown-toggle.btn-warning:focus,
.btn-warning:active.focus,
.btn-warning.active.focus,
.open > .dropdown-toggle.btn-warning.focus {
  color: #fff;
  background-color: #d58512;
  border-color: #985f0d;
}
.btn-warning.disabled:hover,
.btn-warning[disabled]:hover,
fieldset[disabled] .btn-warning:hover,
.btn-warning.disabled:focus,
.btn-warning[disabled]:focus,
fieldset[disabled] .btn-warning:focus,
.btn-warning.disabled.focus,
.btn-warning[disabled].focus,
fieldset[disabled] .btn-warning.focus {
  background-color: #f0ad4e;
  border-color: #eea236;
}
.btn-warning .badge {
  color: #f0ad4e;
  background-color: #fff;
}
.btn-danger {
  color: #fff;
  background-color: #d9534f;
  border-color: #d43f3a;
}
.btn-danger:focus,
.btn-danger.focus {
  color: #fff;
  background-color: #c9302c;
  border-color: #761c19;
}
.btn-danger:hover {
  color: #fff;
  background-color: #c9302c;
  border-color: #ac2925;
}
.btn-danger:active,
.btn-danger.active,
.open > .dropdown-toggle.btn-danger {
  color: #fff;
  background-color: #c9302c;
  background-image: none;
  border-color: #ac2925;
}
.btn-danger:active:hover,
.btn-danger.active:hover,
.open > .dropdown-toggle.btn-danger:hover,
.btn-danger:active:focus,
.btn-danger.active:focus,
.open > .dropdown-toggle.btn-danger:focus,
.btn-danger:active.focus,
.btn-danger.active.focus,
.open > .dropdown-toggle.btn-danger.focus {
  color: #fff;
  background-color: #ac2925;
  border-color: #761c19;
}
.btn-danger.disabled:hover,
.btn-danger[disabled]:hover,
fieldset[disabled] .btn-danger:hover,
.btn-danger.disabled:focus,
.btn-danger[disabled]:focus,
fieldset[disabled] .btn-danger:focus,
.btn-danger.disabled.focus,
.btn-danger[disabled].focus,
fieldset[disabled] .btn-danger.focus {
  background-color: #d9534f;
  border-color: #d43f3a;
}
.btn-danger .badge {
  color: #d9534f;
  background-color: #fff;
}
.btn-link {
  font-weight: 400;
  color: #337ab7;
  border-radius: 0;
}
.btn-link,
.btn-link:active,
.btn-link.active,
.btn-link[disabled],
fieldset[disabled] .btn-link {
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.btn-link,
.btn-link:hover,
.btn-link:focus,
.btn-link:active {
  border-color: transparent;
}
.btn-link:hover,
.btn-link:focus {
  color: #23527c;
  text-decoration: underline;
  background-color: transparent;
}
.btn-link[disabled]:hover,
fieldset[disabled] .btn-link:hover,
.btn-link[disabled]:focus,
fieldset[disabled] .btn-link:focus {
  color: #777777;
  text-decoration: none;
}
.btn-lg,
.btn-group-lg > .btn {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
  border-radius: 6px;
}
.btn-sm,
.btn-group-sm > .btn {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
.btn-xs,
.btn-group-xs > .btn {
  padding: 1px 5px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
.btn-block {
  display: block;
  width: 100%;
}
.btn-block + .btn-block {
  margin-top: 5px;
}
input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
  width: 100%;
}
.fade {
  opacity: 0;
  -webkit-transition: opacity 0.15s linear;
  -o-transition: opacity 0.15s linear;
  transition: opacity 0.15s linear;
}
.fade.in {
  opacity: 1;
}
.collapse {
  display: none;
}
.collapse.in {
  display: block;
}
tr.collapse.in {
  display: table-row;
}
tbody.collapse.in {
  display: table-row-group;
}
.collapsing {
  position: relative;
  height: 0;
  overflow: hidden;
  -webkit-transition-property: height, visibility;
  -o-transition-property: height, visibility;
  transition-property: height, visibility;
  -webkit-transition-duration: 0.35s;
  -o-transition-duration: 0.35s;
  transition-duration: 0.35s;
  -webkit-transition-timing-function: ease;
  -o-transition-timing-function: ease;
  transition-timing-function: ease;
}
.caret {
  display: inline-block;
  width: 0;
  height: 0;
  margin-left: 2px;
  vertical-align: middle;
  border-top: 4px dashed;
  border-top: 4px solid \9;
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
}
.dropup,
.dropdown {
  position: relative;
}
.dropdown-toggle:focus {
  outline: 0;
}
.dropdown-menu {
  position: absolute;
  top: 100%;
  left: 0;
  z-index: 1000;
  display: none;
  float: left;
  min-width: 160px;
  padding: 5px 0;
  margin: 2px 0 0;
  font-size: 14px;
  text-align: left;
  list-style: none;
  background-color: #fff;
  background-clip: padding-box;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 4px;
  -webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
  box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
}
.dropdown-menu.pull-right {
  right: 0;
  left: auto;
}
.dropdown-menu .divider {
  height: 1px;
  margin: 9px 0;
  overflow: hidden;
  background-color: #e5e5e5;
}
.dropdown-menu > li > a {
  display: block;
  padding: 3px 20px;
  clear: both;
  font-weight: 400;
  line-height: 1.42857143;
  color: #333333;
  white-space: nowrap;
}
.dropdown-menu > li > a:hover,
.dropdown-menu > li > a:focus {
  color: #262626;
  text-decoration: none;
  background-color: #f5f5f5;
}
.dropdown-menu > .active > a,
.dropdown-menu > .active > a:hover,
.dropdown-menu > .active > a:focus {
  color: #fff;
  text-decoration: none;
  background-color: #337ab7;
  outline: 0;
}
.dropdown-menu > .disabled > a,
.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  color: #777777;
}
.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  text-decoration: none;
  cursor: not-allowed;
  background-color: transparent;
  background-image: none;
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}
.open > .dropdown-menu {
  display: block;
}
.open > a {
  outline: 0;
}
.dropdown-menu-right {
  right: 0;
  left: auto;
}
.dropdown-menu-left {
  right: auto;
  left: 0;
}
.dropdown-header {
  display: block;
  padding: 3px 20px;
  font-size: 12px;
  line-height: 1.42857143;
  color: #777777;
  white-space: nowrap;
}
.dropdown-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 990;
}
.pull-right > .dropdown-menu {
  right: 0;
  left: auto;
}
.dropup .caret,
.navbar-fixed-bottom .dropdown .caret {
  content: "";
  border-top: 0;
  border-bottom: 4px dashed;
  border-bottom: 4px solid \9;
}
.dropup .dropdown-menu,
.navbar-fixed-bottom .dropdown .dropdown-menu {
  top: auto;
  bottom: 100%;
  margin-bottom: 2px;
}
@media (min-width: 768px) {
  .navbar-right .dropdown-menu {
    right: 0;
    left: auto;
  }
  .navbar-right .dropdown-menu-left {
    right: auto;
    left: 0;
  }
}
.btn-group,
.btn-group-vertical {
  position: relative;
  display: inline-block;
  vertical-align: middle;
}
.btn-group > .btn,
.btn-group-vertical > .btn {
  position: relative;
  float: left;
}
.btn-group > .btn:hover,
.btn-group-vertical > .btn:hover,
.btn-group > .btn:focus,
.btn-group-vertical > .btn:focus,
.btn-group > .btn:active,
.btn-group-vertical > .btn:active,
.btn-group > .btn.active,
.btn-group-vertical > .btn.active {
  z-index: 2;
}
.btn-group .btn + .btn,
.btn-group .btn + .btn-group,
.btn-group .btn-group + .btn,
.btn-group .btn-group + .btn-group {
  margin-left: -1px;
}
.btn-toolbar {
  margin-left: -5px;
}
.btn-toolbar .btn,
.btn-toolbar .btn-group,
.btn-toolbar .input-group {
  float: left;
}
.btn-toolbar > .btn,
.btn-toolbar > .btn-group,
.btn-toolbar > .input-group {
  margin-left: 5px;
}
.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0;
}
.btn-group > .btn:first-child {
  margin-left: 0;
}
.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.btn-group > .btn:last-child:not(:first-child),
.btn-group > .dropdown-toggle:not(:first-child) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.btn-group > .btn-group {
  float: left;
}
.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0;
}
.btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
  outline: 0;
}
.btn-group > .btn + .dropdown-toggle {
  padding-right: 8px;
  padding-left: 8px;
}
.btn-group > .btn-lg + .dropdown-toggle {
  padding-right: 12px;
  padding-left: 12px;
}
.btn-group.open .dropdown-toggle {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
.btn-group.open .dropdown-toggle.btn-link {
  -webkit-box-shadow: none;
  box-shadow: none;
}
.btn .caret {
  margin-left: 0;
}
.btn-lg .caret {
  border-width: 5px 5px 0;
  border-bottom-width: 0;
}
.dropup .btn-lg .caret {
  border-width: 0 5px 5px;
}
.btn-group-vertical > .btn,
.btn-group-vertical > .btn-group,
.btn-group-vertical > .btn-group > .btn {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%;
}
.btn-group-vertical > .btn-group > .btn {
  float: none;
}
.btn-group-vertical > .btn + .btn,
.btn-group-vertical > .btn + .btn-group,
.btn-group-vertical > .btn-group + .btn,
.btn-group-vertical > .btn-group + .btn-group {
  margin-top: -1px;
  margin-left: 0;
}
.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
  border-radius: 0;
}
.btn-group-vertical > .btn:first-child:not(:last-child) {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
.btn-group-vertical > .btn:last-child:not(:first-child) {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
}
.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0;
}
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.btn-group-justified {
  display: table;
  width: 100%;
  table-layout: fixed;
  border-collapse: separate;
}
.btn-group-justified > .btn,
.btn-group-justified > .btn-group {
  display: table-cell;
  float: none;
  width: 1%;
}
.btn-group-justified > .btn-group .btn {
  width: 100%;
}
.btn-group-justified > .btn-group .dropdown-menu {
  left: auto;
}
[data-toggle="buttons"] > .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .btn input[type="radio"],
[data-toggle="buttons"] > .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none;
}
.input-group {
  position: relative;
  display: table;
  border-collapse: separate;
}
.input-group[class*="col-"] {
  float: none;
  padding-right: 0;
  padding-left: 0;
}
.input-group .form-control {
  position: relative;
  z-index: 2;
  float: left;
  width: 100%;
  margin-bottom: 0;
}
.input-group .form-control:focus {
  z-index: 3;
}
.input-group-lg > .form-control,
.input-group-lg > .input-group-addon,
.input-group-lg > .input-group-btn > .btn {
  height: 46px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
  border-radius: 6px;
}
select.input-group-lg > .form-control,
select.input-group-lg > .input-group-addon,
select.input-group-lg > .input-group-btn > .btn {
  height: 46px;
  line-height: 46px;
}
textarea.input-group-lg > .form-control,
textarea.input-group-lg > .input-group-addon,
textarea.input-group-lg > .input-group-btn > .btn,
select[multiple].input-group-lg > .form-control,
select[multiple].input-group-lg > .input-group-addon,
select[multiple].input-group-lg > .input-group-btn > .btn {
  height: auto;
}
.input-group-sm > .form-control,
.input-group-sm > .input-group-addon,
.input-group-sm > .input-group-btn > .btn {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}
select.input-group-sm > .form-control,
select.input-group-sm > .input-group-addon,
select.input-group-sm > .input-group-btn > .btn {
  height: 30px;
  line-height: 30px;
}
textarea.input-group-sm > .form-control,
textarea.input-group-sm > .input-group-addon,
textarea.input-group-sm > .input-group-btn > .btn,
select[multiple].input-group-sm > .form-control,
select[multiple].input-group-sm > .input-group-addon,
select[multiple].input-group-sm > .input-group-btn > .btn {
  height: auto;
}
.input-group-addon,
.input-group-btn,
.input-group .form-control {
  display: table-cell;
}
.input-group-addon:not(:first-child):not(:last-child),
.input-group-btn:not(:first-child):not(:last-child),
.input-group .form-control:not(:first-child):not(:last-child) {
  border-radius: 0;
}
.input-group-addon,
.input-group-btn {
  width: 1%;
  white-space: nowrap;
  vertical-align: middle;
}
.input-group-addon {
  padding: 6px 12px;
  font-size: 14px;
  font-weight: 400;
  line-height: 1;
  color: #555555;
  text-align: center;
  background-color: #eeeeee;
  border: 1px solid #ccc;
  border-radius: 4px;
}
.input-group-addon.input-sm {
  padding: 5px 10px;
  font-size: 12px;
  border-radius: 3px;
}
.input-group-addon.input-lg {
  padding: 10px 16px;
  font-size: 18px;
  border-radius: 6px;
}
.input-group-addon input[type="radio"],
.input-group-addon input[type="checkbox"] {
  margin-top: 0;
}
.input-group .form-control:first-child,
.input-group-addon:first-child,
.input-group-btn:first-child > .btn,
.input-group-btn:first-child > .btn-group > .btn,
.input-group-btn:first-child > .dropdown-toggle,
.input-group-btn:last-child > .btn:not(:last-child):not(.dropdown-toggle),
.input-group-btn:last-child > .btn-group:not(:last-child) > .btn {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.input-group-addon:first-child {
  border-right: 0;
}
.input-group .form-control:last-child,
.input-group-addon:last-child,
.input-group-btn:last-child > .btn,
.input-group-btn:last-child > .btn-group > .btn,
.input-group-btn:last-child > .dropdown-toggle,
.input-group-btn:first-child > .btn:not(:first-child),
.input-group-btn:first-child > .btn-group:not(:first-child) > .btn {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.input-group-addon:last-child {
  border-left: 0;
}
.input-group-btn {
  position: relative;
  font-size: 0;
  white-space: nowrap;
}
.input-group-btn > .btn {
  position: relative;
}
.input-group-btn > .btn + .btn {
  margin-left: -1px;
}
.input-group-btn > .btn:hover,
.input-group-btn > .btn:focus,
.input-group-btn > .btn:active {
  z-index: 2;
}
.input-group-btn:first-child > .btn,
.input-group-btn:first-child > .btn-group {
  margin-right: -1px;
}
.input-group-btn:last-child > .btn,
.input-group-btn:last-child > .btn-group {
  z-index: 2;
  margin-left: -1px;
}
.nav {
  padding-left: 0;
  margin-bottom: 0;
  list-style: none;
}
.nav > li {
  position: relative;
  display: block;
}
.nav > li > a {
  position: relative;
  display: block;
  padding: 10px 15px;
}
.nav > li > a:hover,
.nav > li > a:focus {
  text-decoration: none;
  background-color: #eeeeee;
}
.nav > li.disabled > a {
  color: #777777;
}
.nav > li.disabled > a:hover,
.nav > li.disabled > a:focus {
  color: #777777;
  text-decoration: none;
  cursor: not-allowed;
  background-color: transparent;
}
.nav .open > a,
.nav .open > a:hover,
.nav .open > a:focus {
  background-color: #eeeeee;
  border-color: #337ab7;
}
.nav .nav-divider {
  height: 1px;
  margin: 9px 0;
  overflow: hidden;
  background-color: #e5e5e5;
}
.nav > li > a > img {
  max-width: none;
}
.nav-tabs {
  border-bottom: 1px solid #ddd;
}
.nav-tabs > li {
  float: left;
  margin-bottom: -1px;
}
.nav-tabs > li > a {
  margin-right: 2px;
  line-height: 1.42857143;
  border: 1px solid transparent;
  border-radius: 4px 4px 0 0;
}
.nav-tabs > li > a:hover {
  border-color: #eeeeee #eeeeee #ddd;
}
.nav-tabs > li.active > a,
.nav-tabs > li.active > a:hover,
.nav-tabs > li.active > a:focus {
  color: #555555;
  cursor: default;
  background-color: #fff;
  border: 1px solid #ddd;
  border-bottom-color: transparent;
}
.nav-tabs.nav-justified {
  width: 100%;
  border-bottom: 0;
}
.nav-tabs.nav-justified > li {
  float: none;
}
.nav-tabs.nav-justified > li > a {
  margin-bottom: 5px;
  text-align: center;
}
.nav-tabs.nav-justified > .dropdown .dropdown-menu {
  top: auto;
  left: auto;
}
@media (min-width: 768px) {
  .nav-tabs.nav-justified > li {
    display: table-cell;
    width: 1%;
  }
  .nav-tabs.nav-justified > li > a {
    margin-bottom: 0;
  }
}
.nav-tabs.nav-justified > li > a {
  margin-right: 0;
  border-radius: 4px;
}
.nav-tabs.nav-justified > .active > a,
.nav-tabs.nav-justified > .active > a:hover,
.nav-tabs.nav-justified > .active > a:focus {
  border: 1px solid #ddd;
}
@media (min-width: 768px) {
  .nav-tabs.nav-justified > li > a {
    border-bottom: 1px solid #ddd;
    border-radius: 4px 4px 0 0;
  }
  .nav-tabs.nav-justified > .active > a,
  .nav-tabs.nav-justified > .active > a:hover,
  .nav-tabs.nav-justified > .active > a:focus {
    border-bottom-color: #fff;
  }
}
.nav-pills > li {
  float: left;
}
.nav-pills > li > a {
  border-radius: 4px;
}
.nav-pills > li + li {
  margin-left: 2px;
}
.nav-pills > li.active > a,
.nav-pills > li.active > a:hover,
.nav-pills > li.active > a:focus {
  color: #fff;
  background-color: #337ab7;
}
.nav-stacked > li {
  float: none;
}
.nav-stacked > li + li {
  margin-top: 2px;
  margin-left: 0;
}
.nav-justified {
  width: 100%;
}
.nav-justified > li {
  float: none;
}
.nav-justified > li > a {
  margin-bottom: 5px;
  text-align: center;
}
.nav-justified > .dropdown .dropdown-menu {
  top: auto;
  left: auto;
}
@media (min-width: 768px) {
  .nav-justified > li {
    display: table-cell;
    width: 1%;
  }
  .nav-justified > li > a {
    margin-bottom: 0;
  }
}
.nav-tabs-justified {
  border-bottom: 0;
}
.nav-tabs-justified > li > a {
  margin-right: 0;
  border-radius: 4px;
}
.nav-tabs-justified > .active > a,
.nav-tabs-justified > .active > a:hover,
.nav-tabs-justified > .active > a:focus {
  border: 1px solid #ddd;
}
@media (min-width: 768px) {
  .nav-tabs-justified > li > a {
    border-bottom: 1px solid #ddd;
    border-radius: 4px 4px 0 0;
  }
  .nav-tabs-justified > .active > a,
  .nav-tabs-justified > .active > a:hover,
  .nav-tabs-justified > .active > a:focus {
    border-bottom-color: #fff;
  }
}
.tab-content > .tab-pane {
  display: none;
}
.tab-content > .active {
  display: block;
}
.nav-tabs .dropdown-menu {
  margin-top: -1px;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.navbar {
  position: relative;
  min-height: 50px;
  margin-bottom: 20px;
  border: 1px solid transparent;
}
@media (min-width: 768px) {
  .navbar {
    border-radius: 4px;
  }
}
@media (min-width: 768px) {
  .navbar-header {
    float: left;
  }
}
.navbar-collapse {
  padding-right: 15px;
  padding-left: 15px;
  overflow-x: visible;
  border-top: 1px solid transparent;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
  -webkit-overflow-scrolling: touch;
}
.navbar-collapse.in {
  overflow-y: auto;
}
@media (min-width: 768px) {
  .navbar-collapse {
    width: auto;
    border-top: 0;
    -webkit-box-shadow: none;
    box-shadow: none;
  }
  .navbar-collapse.collapse {
    display: block !important;
    height: auto !important;
    padding-bottom: 0;
    overflow: visible !important;
  }
  .navbar-collapse.in {
    overflow-y: visible;
  }
  .navbar-fixed-top .navbar-collapse,
  .navbar-static-top .navbar-collapse,
  .navbar-fixed-bottom .navbar-collapse {
    padding-right: 0;
    padding-left: 0;
  }
}
.navbar-fixed-top,
.navbar-fixed-bottom {
  position: fixed;
  right: 0;
  left: 0;
  z-index: 1030;
}
.navbar-fixed-top .navbar-collapse,
.navbar-fixed-bottom .navbar-collapse {
  max-height: 340px;
}
@media (max-device-width: 480px) and (orientation: landscape) {
  .navbar-fixed-top .navbar-collapse,
  .navbar-fixed-bottom .navbar-collapse {
    max-height: 200px;
  }
}
@media (min-width: 768px) {
  .navbar-fixed-top,
  .navbar-fixed-bottom {
    border-radius: 0;
  }
}
.navbar-fixed-top {
  top: 0;
  border-width: 0 0 1px;
}
.navbar-fixed-bottom {
  bottom: 0;
  margin-bottom: 0;
  border-width: 1px 0 0;
}
.container > .navbar-header,
.container-fluid > .navbar-header,
.container > .navbar-collapse,
.container-fluid > .navbar-collapse {
  margin-right: -15px;
  margin-left: -15px;
}
@media (min-width: 768px) {
  .container > .navbar-header,
  .container-fluid > .navbar-header,
  .container > .navbar-collapse,
  .container-fluid > .navbar-collapse {
    margin-right: 0;
    margin-left: 0;
  }
}
.navbar-static-top {
  z-index: 1000;
  border-width: 0 0 1px;
}
@media (min-width: 768px) {
  .navbar-static-top {
    border-radius: 0;
  }
}
.navbar-brand {
  float: left;
  height: 50px;
  padding: 15px 15px;
  font-size: 18px;
  line-height: 20px;
}
.navbar-brand:hover,
.navbar-brand:focus {
  text-decoration: none;
}
.navbar-brand > img {
  display: block;
}
@media (min-width: 768px) {
  .navbar > .container .navbar-brand,
  .navbar > .container-fluid .navbar-brand {
    margin-left: -15px;
  }
}
.navbar-toggle {
  position: relative;
  float: right;
  padding: 9px 10px;
  margin-right: 15px;
  margin-top: 8px;
  margin-bottom: 8px;
  background-color: transparent;
  background-image: none;
  border: 1px solid transparent;
  border-radius: 4px;
}
.navbar-toggle:focus {
  outline: 0;
}
.navbar-toggle .icon-bar {
  display: block;
  width: 22px;
  height: 2px;
  border-radius: 1px;
}
.navbar-toggle .icon-bar + .icon-bar {
  margin-top: 4px;
}
@media (min-width: 768px) {
  .navbar-toggle {
    display: none;
  }
}
.navbar-nav {
  margin: 7.5px -15px;
}
.navbar-nav > li > a {
  padding-top: 10px;
  padding-bottom: 10px;
  line-height: 20px;
}
@media (max-width: 767px) {
  .navbar-nav .open .dropdown-menu {
    position: static;
    float: none;
    width: auto;
    margin-top: 0;
    background-color: transparent;
    border: 0;
    -webkit-box-shadow: none;
    box-shadow: none;
  }
  .navbar-nav .open .dropdown-menu > li > a,
  .navbar-nav .open .dropdown-menu .dropdown-header {
    padding: 5px 15px 5px 25px;
  }
  .navbar-nav .open .dropdown-menu > li > a {
    line-height: 20px;
  }
  .navbar-nav .open .dropdown-menu > li > a:hover,
  .navbar-nav .open .dropdown-menu > li > a:focus {
    background-image: none;
  }
}
@media (min-width: 768px) {
  .navbar-nav {
    float: left;
    margin: 0;
  }
  .navbar-nav > li {
    float: left;
  }
  .navbar-nav > li > a {
    padding-top: 15px;
    padding-bottom: 15px;
  }
}
.navbar-form {
  padding: 10px 15px;
  margin-right: -15px;
  margin-left: -15px;
  border-top: 1px solid transparent;
  border-bottom: 1px solid transparent;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
  margin-top: 8px;
  margin-bottom: 8px;
}
@media (min-width: 768px) {
  .navbar-form .form-group {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle;
  }
  .navbar-form .form-control {
    display: inline-block;
    width: auto;
    vertical-align: middle;
  }
  .navbar-form .form-control-static {
    display: inline-block;
  }
  .navbar-form .input-group {
    display: inline-table;
    vertical-align: middle;
  }
  .navbar-form .input-group .input-group-addon,
  .navbar-form .input-group .input-group-btn,
  .navbar-form .input-group .form-control {
    width: auto;
  }
  .navbar-form .input-group > .form-control {
    width: 100%;
  }
  .navbar-form .control-label {
    margin-bottom: 0;
    vertical-align: middle;
  }
  .navbar-form .radio,
  .navbar-form .checkbox {
    display: inline-block;
    margin-top: 0;
    margin-bottom: 0;
    vertical-align: middle;
  }
  .navbar-form .radio label,
  .navbar-form .checkbox label {
    padding-left: 0;
  }
  .navbar-form .radio input[type="radio"],
  .navbar-form .checkbox input[type="checkbox"] {
    position: relative;
    margin-left: 0;
  }
  .navbar-form .has-feedback .form-control-feedback {
    top: 0;
  }
}
@media (max-width: 767px) {
  .navbar-form .form-group {
    margin-bottom: 5px;
  }
  .navbar-form .form-group:last-child {
    margin-bottom: 0;
  }
}
@media (min-width: 768px) {
  .navbar-form {
    width: auto;
    padding-top: 0;
    padding-bottom: 0;
    margin-right: 0;
    margin-left: 0;
    border: 0;
    -webkit-box-shadow: none;
    box-shadow: none;
  }
}
.navbar-nav > li > .dropdown-menu {
  margin-top: 0;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.navbar-fixed-bottom .navbar-nav > li > .dropdown-menu {
  margin-bottom: 0;
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
.navbar-btn {
  margin-top: 8px;
  margin-bottom: 8px;
}
.navbar-btn.btn-sm {
  margin-top: 10px;
  margin-bottom: 10px;
}
.navbar-btn.btn-xs {
  margin-top: 14px;
  margin-bottom: 14px;
}
.navbar-text {
  margin-top: 15px;
  margin-bottom: 15px;
}
@media (min-width: 768px) {
  .navbar-text {
    float: left;
    margin-right: 15px;
    margin-left: 15px;
  }
}
@media (min-width: 768px) {
  .navbar-left {
    float: left !important;
  }
  .navbar-right {
    float: right !important;
    margin-right: -15px;
  }
  .navbar-right ~ .navbar-right {
    margin-right: 0;
  }
}
.navbar-default {
  background-color: #f8f8f8;
  border-color: #e7e7e7;
}
.navbar-default .navbar-brand {
  color: #777;
}
.navbar-default .navbar-brand:hover,
.navbar-default .navbar-brand:focus {
  color: #5e5e5e;
  background-color: transparent;
}
.navbar-default .navbar-text {
  color: #777;
}
.navbar-default .navbar-nav > li > a {
  color: #777;
}
.navbar-default .navbar-nav > li > a:hover,
.navbar-default .navbar-nav > li > a:focus {
  color: #333;
  background-color: transparent;
}
.navbar-default .navbar-nav > .active > a,
.navbar-default .navbar-nav > .active > a:hover,
.navbar-default .navbar-nav > .active > a:focus {
  color: #555;
  background-color: #e7e7e7;
}
.navbar-default .navbar-nav > .disabled > a,
.navbar-default .navbar-nav > .disabled > a:hover,
.navbar-default .navbar-nav > .disabled > a:focus {
  color: #ccc;
  background-color: transparent;
}
.navbar-default .navbar-nav > .open > a,
.navbar-default .navbar-nav > .open > a:hover,
.navbar-default .navbar-nav > .open > a:focus {
  color: #555;
  background-color: #e7e7e7;
}
@media (max-width: 767px) {
  .navbar-default .navbar-nav .open .dropdown-menu > li > a {
    color: #777;
  }
  .navbar-default .navbar-nav .open .dropdown-menu > li > a:hover,
  .navbar-default .navbar-nav .open .dropdown-menu > li > a:focus {
    color: #333;
    background-color: transparent;
  }
  .navbar-default .navbar-nav .open .dropdown-menu > .active > a,
  .navbar-default .navbar-nav .open .dropdown-menu > .active > a:hover,
  .navbar-default .navbar-nav .open .dropdown-menu > .active > a:focus {
    color: #555;
    background-color: #e7e7e7;
  }
  .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a,
  .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:hover,
  .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:focus {
    color: #ccc;
    background-color: transparent;
  }
}
.navbar-default .navbar-toggle {
  border-color: #ddd;
}
.navbar-default .navbar-toggle:hover,
.navbar-default .navbar-toggle:focus {
  background-color: #ddd;
}
.navbar-default .navbar-toggle .icon-bar {
  background-color: #888;
}
.navbar-default .navbar-collapse,
.navbar-default .navbar-form {
  border-color: #e7e7e7;
}
.navbar-default .navbar-link {
  color: #777;
}
.navbar-default .navbar-link:hover {
  color: #333;
}
.navbar-default .btn-link {
  color: #777;
}
.navbar-default .btn-link:hover,
.navbar-default .btn-link:focus {
  color: #333;
}
.navbar-default .btn-link[disabled]:hover,
fieldset[disabled] .navbar-default .btn-link:hover,
.navbar-default .btn-link[disabled]:focus,
fieldset[disabled] .navbar-default .btn-link:focus {
  color: #ccc;
}
.navbar-inverse {
  background-color: #222;
  border-color: #080808;
}
.navbar-inverse .navbar-brand {
  color: #9d9d9d;
}
.navbar-inverse .navbar-brand:hover,
.navbar-inverse .navbar-brand:focus {
  color: #fff;
  background-color: transparent;
}
.navbar-inverse .navbar-text {
  color: #9d9d9d;
}
.navbar-inverse .navbar-nav > li > a {
  color: #9d9d9d;
}
.navbar-inverse .navbar-nav > li > a:hover,
.navbar-inverse .navbar-nav > li > a:focus {
  color: #fff;
  background-color: transparent;
}
.navbar-inverse .navbar-nav > .active > a,
.navbar-inverse .navbar-nav > .active > a:hover,
.navbar-inverse .navbar-nav > .active > a:focus {
  color: #fff;
  background-color: #080808;
}
.navbar-inverse .navbar-nav > .disabled > a,
.navbar-inverse .navbar-nav > .disabled > a:hover,
.navbar-inverse .navbar-nav > .disabled > a:focus {
  color: #444;
  background-color: transparent;
}
.navbar-inverse .navbar-nav > .open > a,
.navbar-inverse .navbar-nav > .open > a:hover,
.navbar-inverse .navbar-nav > .open > a:focus {
  color: #fff;
  background-color: #080808;
}
@media (max-width: 767px) {
  .navbar-inverse .navbar-nav .open .dropdown-menu > .dropdown-header {
    border-color: #080808;
  }
  .navbar-inverse .navbar-nav .open .dropdown-menu .divider {
    background-color: #080808;
  }
  .navbar-inverse .navbar-nav .open .dropdown-menu > li > a {
    color: #9d9d9d;
  }
  .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:hover,
  .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:focus {
    color: #fff;
    background-color: transparent;
  }
  .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:hover,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:focus {
    color: #fff;
    background-color: #080808;
  }
  .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:hover,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:focus {
    color: #444;
    background-color: transparent;
  }
}
.navbar-inverse .navbar-toggle {
  border-color: #333;
}
.navbar-inverse .navbar-toggle:hover,
.navbar-inverse .navbar-toggle:focus {
  background-color: #333;
}
.navbar-inverse .navbar-toggle .icon-bar {
  background-color: #fff;
}
.navbar-inverse .navbar-collapse,
.navbar-inverse .navbar-form {
  border-color: #101010;
}
.navbar-inverse .navbar-link {
  color: #9d9d9d;
}
.navbar-inverse .navbar-link:hover {
  color: #fff;
}
.navbar-inverse .btn-link {
  color: #9d9d9d;
}
.navbar-inverse .btn-link:hover,
.navbar-inverse .btn-link:focus {
  color: #fff;
}
.navbar-inverse .btn-link[disabled]:hover,
fieldset[disabled] .navbar-inverse .btn-link:hover,
.navbar-inverse .btn-link[disabled]:focus,
fieldset[disabled] .navbar-inverse .btn-link:focus {
  color: #444;
}
.breadcrumb {
  padding: 8px 15px;
  margin-bottom: 20px;
  list-style: none;
  background-color: #f5f5f5;
  border-radius: 4px;
}
.breadcrumb > li {
  display: inline-block;
}
.breadcrumb > li + li:before {
  padding: 0 5px;
  color: #ccc;
  content: "/\00a0";
}
.breadcrumb > .active {
  color: #777777;
}
.pagination {
  display: inline-block;
  padding-left: 0;
  margin: 20px 0;
  border-radius: 4px;
}
.pagination > li {
  display: inline;
}
.pagination > li > a,
.pagination > li > span {
  position: relative;
  float: left;
  padding: 6px 12px;
  margin-left: -1px;
  line-height: 1.42857143;
  color: #337ab7;
  text-decoration: none;
  background-color: #fff;
  border: 1px solid #ddd;
}
.pagination > li > a:hover,
.pagination > li > span:hover,
.pagination > li > a:focus,
.pagination > li > span:focus {
  z-index: 2;
  color: #23527c;
  background-color: #eeeeee;
  border-color: #ddd;
}
.pagination > li:first-child > a,
.pagination > li:first-child > span {
  margin-left: 0;
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}
.pagination > li:last-child > a,
.pagination > li:last-child > span {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
}
.pagination > .active > a,
.pagination > .active > span,
.pagination > .active > a:hover,
.pagination > .active > span:hover,
.pagination > .active > a:focus,
.pagination > .active > span:focus {
  z-index: 3;
  color: #fff;
  cursor: default;
  background-color: #337ab7;
  border-color: #337ab7;
}
.pagination > .disabled > span,
.pagination > .disabled > span:hover,
.pagination > .disabled > span:focus,
.pagination > .disabled > a,
.pagination > .disabled > a:hover,
.pagination > .disabled > a:focus {
  color: #777777;
  cursor: not-allowed;
  background-color: #fff;
  border-color: #ddd;
}
.pagination-lg > li > a,
.pagination-lg > li > span {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
}
.pagination-lg > li:first-child > a,
.pagination-lg > li:first-child > span {
  border-top-left-radius: 6px;
  border-bottom-left-radius: 6px;
}
.pagination-lg > li:last-child > a,
.pagination-lg > li:last-child > span {
  border-top-right-radius: 6px;
  border-bottom-right-radius: 6px;
}
.pagination-sm > li > a,
.pagination-sm > li > span {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
}
.pagination-sm > li:first-child > a,
.pagination-sm > li:first-child > span {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
}
.pagination-sm > li:last-child > a,
.pagination-sm > li:last-child > span {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
}
.pager {
  padding-left: 0;
  margin: 20px 0;
  text-align: center;
  list-style: none;
}
.pager li {
  display: inline;
}
.pager li > a,
.pager li > span {
  display: inline-block;
  padding: 5px 14px;
  background-color: #fff;
  border: 1px solid #ddd;
  border-radius: 15px;
}
.pager li > a:hover,
.pager li > a:focus {
  text-decoration: none;
  background-color: #eeeeee;
}
.pager .next > a,
.pager .next > span {
  float: right;
}
.pager .previous > a,
.pager .previous > span {
  float: left;
}
.pager .disabled > a,
.pager .disabled > a:hover,
.pager .disabled > a:focus,
.pager .disabled > span {
  color: #777777;
  cursor: not-allowed;
  background-color: #fff;
}
.label {
  display: inline;
  padding: 0.2em 0.6em 0.3em;
  font-size: 75%;
  font-weight: 700;
  line-height: 1;
  color: #fff;
  text-align: center;
  white-space: nowrap;
  vertical-align: baseline;
  border-radius: 0.25em;
}
a.label:hover,
a.label:focus {
  color: #fff;
  text-decoration: none;
  cursor: pointer;
}
.label:empty {
  display: none;
}
.btn .label {
  position: relative;
  top: -1px;
}
.label-default {
  background-color: #777777;
}
.label-default[href]:hover,
.label-default[href]:focus {
  background-color: #5e5e5e;
}
.label-primary {
  background-color: #337ab7;
}
.label-primary[href]:hover,
.label-primary[href]:focus {
  background-color: #286090;
}
.label-success {
  background-color: #5cb85c;
}
.label-success[href]:hover,
.label-success[href]:focus {
  background-color: #449d44;
}
.label-info {
  background-color: #5bc0de;
}
.label-info[href]:hover,
.label-info[href]:focus {
  background-color: #31b0d5;
}
.label-warning {
  background-color: #f0ad4e;
}
.label-warning[href]:hover,
.label-warning[href]:focus {
  background-color: #ec971f;
}
.label-danger {
  background-color: #d9534f;
}
.label-danger[href]:hover,
.label-danger[href]:focus {
  background-color: #c9302c;
}
.badge {
  display: inline-block;
  min-width: 10px;
  padding: 3px 7px;
  font-size: 12px;
  font-weight: bold;
  line-height: 1;
  color: #fff;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  background-color: #777777;
  border-radius: 10px;
}
.badge:empty {
  display: none;
}
.btn .badge {
  position: relative;
  top: -1px;
}
.btn-xs .badge,
.btn-group-xs > .btn .badge {
  top: 0;
  padding: 1px 5px;
}
a.badge:hover,
a.badge:focus {
  color: #fff;
  text-decoration: none;
  cursor: pointer;
}
.list-group-item.active > .badge,
.nav-pills > .active > a > .badge {
  color: #337ab7;
  background-color: #fff;
}
.list-group-item > .badge {
  float: right;
}
.list-group-item > .badge + .badge {
  margin-right: 5px;
}
.nav-pills > li > a > .badge {
  margin-left: 3px;
}
.jumbotron {
  padding-top: 30px;
  padding-bottom: 30px;
  margin-bottom: 30px;
  color: inherit;
  background-color: #eeeeee;
}
.jumbotron h1,
.jumbotron .h1 {
  color: inherit;
}
.jumbotron p {
  margin-bottom: 15px;
  font-size: 21px;
  font-weight: 200;
}
.jumbotron > hr {
  border-top-color: #d5d5d5;
}
.container .jumbotron,
.container-fluid .jumbotron {
  padding-right: 15px;
  padding-left: 15px;
  border-radius: 6px;
}
.jumbotron .container {
  max-width: 100%;
}
@media screen and (min-width: 768px) {
  .jumbotron {
    padding-top: 48px;
    padding-bottom: 48px;
  }
  .container .jumbotron,
  .container-fluid .jumbotron {
    padding-right: 60px;
    padding-left: 60px;
  }
  .jumbotron h1,
  .jumbotron .h1 {
    font-size: 63px;
  }
}
.thumbnail {
  display: block;
  padding: 4px;
  margin-bottom: 20px;
  line-height: 1.42857143;
  background-color: #fff;
  border: 1px solid #ddd;
  border-radius: 4px;
  -webkit-transition: border 0.2s ease-in-out;
  -o-transition: border 0.2s ease-in-out;
  transition: border 0.2s ease-in-out;
}
.thumbnail > img,
.thumbnail a > img {
  margin-right: auto;
  margin-left: auto;
}
a.thumbnail:hover,
a.thumbnail:focus,
a.thumbnail.active {
  border-color: #337ab7;
}
.thumbnail .caption {
  padding: 9px;
  color: #333333;
}
.alert {
  padding: 15px;
  margin-bottom: 20px;
  border: 1px solid transparent;
  border-radius: 4px;
}
.alert h4 {
  margin-top: 0;
  color: inherit;
}
.alert .alert-link {
  font-weight: bold;
}
.alert > p,
.alert > ul {
  margin-bottom: 0;
}
.alert > p + p {
  margin-top: 5px;
}
.alert-dismissable,
.alert-dismissible {
  padding-right: 35px;
}
.alert-dismissable .close,
.alert-dismissible .close {
  position: relative;
  top: -2px;
  right: -21px;
  color: inherit;
}
.alert-success {
  color: #3c763d;
  background-color: #dff0d8;
  border-color: #d6e9c6;
}
.alert-success hr {
  border-top-color: #c9e2b3;
}
.alert-success .alert-link {
  color: #2b542c;
}
.alert-info {
  color: #31708f;
  background-color: #d9edf7;
  border-color: #bce8f1;
}
.alert-info hr {
  border-top-color: #a6e1ec;
}
.alert-info .alert-link {
  color: #245269;
}
.alert-warning {
  color: #8a6d3b;
  background-color: #fcf8e3;
  border-color: #faebcc;
}
.alert-warning hr {
  border-top-color: #f7e1b5;
}
.alert-warning .alert-link {
  color: #66512c;
}
.alert-danger {
  color: #a94442;
  background-color: #f2dede;
  border-color: #ebccd1;
}
.alert-danger hr {
  border-top-color: #e4b9c0;
}
.alert-danger .alert-link {
  color: #843534;
}
@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@-o-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
.progress {
  height: 20px;
  margin-bottom: 20px;
  overflow: hidden;
  background-color: #f5f5f5;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
}
.progress-bar {
  float: left;
  width: 0%;
  height: 100%;
  font-size: 12px;
  line-height: 20px;
  color: #fff;
  text-align: center;
  background-color: #337ab7;
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  -webkit-transition: width 0.6s ease;
  -o-transition: width 0.6s ease;
  transition: width 0.6s ease;
}
.progress-striped .progress-bar,
.progress-bar-striped {
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  -webkit-background-size: 40px 40px;
  background-size: 40px 40px;
}
.progress.active .progress-bar,
.progress-bar.active {
  -webkit-animation: progress-bar-stripes 2s linear infinite;
  -o-animation: progress-bar-stripes 2s linear infinite;
  animation: progress-bar-stripes 2s linear infinite;
}
.progress-bar-success {
  background-color: #5cb85c;
}
.progress-striped .progress-bar-success {
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-info {
  background-color: #5bc0de;
}
.progress-striped .progress-bar-info {
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-warning {
  background-color: #f0ad4e;
}
.progress-striped .progress-bar-warning {
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-danger {
  background-color: #d9534f;
}
.progress-striped .progress-bar-danger {
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.media {
  margin-top: 15px;
}
.media:first-child {
  margin-top: 0;
}
.media,
.media-body {
  overflow: hidden;
  zoom: 1;
}
.media-body {
  width: 10000px;
}
.media-object {
  display: block;
}
.media-object.img-thumbnail {
  max-width: none;
}
.media-right,
.media > .pull-right {
  padding-left: 10px;
}
.media-left,
.media > .pull-left {
  padding-right: 10px;
}
.media-left,
.media-right,
.media-body {
  display: table-cell;
  vertical-align: top;
}
.media-middle {
  vertical-align: middle;
}
.media-bottom {
  vertical-align: bottom;
}
.media-heading {
  margin-top: 0;
  margin-bottom: 5px;
}
.media-list {
  padding-left: 0;
  list-style: none;
}
.list-group {
  padding-left: 0;
  margin-bottom: 20px;
}
.list-group-item {
  position: relative;
  display: block;
  padding: 10px 15px;
  margin-bottom: -1px;
  background-color: #fff;
  border: 1px solid #ddd;
}
.list-group-item:first-child {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}
.list-group-item:last-child {
  margin-bottom: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
}
.list-group-item.disabled,
.list-group-item.disabled:hover,
.list-group-item.disabled:focus {
  color: #777777;
  cursor: not-allowed;
  background-color: #eeeeee;
}
.list-group-item.disabled .list-group-item-heading,
.list-group-item.disabled:hover .list-group-item-heading,
.list-group-item.disabled:focus .list-group-item-heading {
  color: inherit;
}
.list-group-item.disabled .list-group-item-text,
.list-group-item.disabled:hover .list-group-item-text,
.list-group-item.disabled:focus .list-group-item-text {
  color: #777777;
}
.list-group-item.active,
.list-group-item.active:hover,
.list-group-item.active:focus {
  z-index: 2;
  color: #fff;
  background-color: #337ab7;
  border-color: #337ab7;
}
.list-group-item.active .list-group-item-heading,
.list-group-item.active:hover .list-group-item-heading,
.list-group-item.active:focus .list-group-item-heading,
.list-group-item.active .list-group-item-heading > small,
.list-group-item.active:hover .list-group-item-heading > small,
.list-group-item.active:focus .list-group-item-heading > small,
.list-group-item.active .list-group-item-heading > .small,
.list-group-item.active:hover .list-group-item-heading > .small,
.list-group-item.active:focus .list-group-item-heading > .small {
  color: inherit;
}
.list-group-item.active .list-group-item-text,
.list-group-item.active:hover .list-group-item-text,
.list-group-item.active:focus .list-group-item-text {
  color: #c7ddef;
}
a.list-group-item,
button.list-group-item {
  color: #555;
}
a.list-group-item .list-group-item-heading,
button.list-group-item .list-group-item-heading {
  color: #333;
}
a.list-group-item:hover,
button.list-group-item:hover,
a.list-group-item:focus,
button.list-group-item:focus {
  color: #555;
  text-decoration: none;
  background-color: #f5f5f5;
}
button.list-group-item {
  width: 100%;
  text-align: left;
}
.list-group-item-success {
  color: #3c763d;
  background-color: #dff0d8;
}
a.list-group-item-success,
button.list-group-item-success {
  color: #3c763d;
}
a.list-group-item-success .list-group-item-heading,
button.list-group-item-success .list-group-item-heading {
  color: inherit;
}
a.list-group-item-success:hover,
button.list-group-item-success:hover,
a.list-group-item-success:focus,
button.list-group-item-success:focus {
  color: #3c763d;
  background-color: #d0e9c6;
}
a.list-group-item-success.active,
button.list-group-item-success.active,
a.list-group-item-success.active:hover,
button.list-group-item-success.active:hover,
a.list-group-item-success.active:focus,
button.list-group-item-success.active:focus {
  color: #fff;
  background-color: #3c763d;
  border-color: #3c763d;
}
.list-group-item-info {
  color: #31708f;
  background-color: #d9edf7;
}
a.list-group-item-info,
button.list-group-item-info {
  color: #31708f;
}
a.list-group-item-info .list-group-item-heading,
button.list-group-item-info .list-group-item-heading {
  color: inherit;
}
a.list-group-item-info:hover,
button.list-group-item-info:hover,
a.list-group-item-info:focus,
button.list-group-item-info:focus {
  color: #31708f;
  background-color: #c4e3f3;
}
a.list-group-item-info.active,
button.list-group-item-info.active,
a.list-group-item-info.active:hover,
button.list-group-item-info.active:hover,
a.list-group-item-info.active:focus,
button.list-group-item-info.active:focus {
  color: #fff;
  background-color: #31708f;
  border-color: #31708f;
}
.list-group-item-warning {
  color: #8a6d3b;
  background-color: #fcf8e3;
}
a.list-group-item-warning,
button.list-group-item-warning {
  color: #8a6d3b;
}
a.list-group-item-warning .list-group-item-heading,
button.list-group-item-warning .list-group-item-heading {
  color: inherit;
}
a.list-group-item-warning:hover,
button.list-group-item-warning:hover,
a.list-group-item-warning:focus,
button.list-group-item-warning:focus {
  color: #8a6d3b;
  background-color: #faf2cc;
}
a.list-group-item-warning.active,
button.list-group-item-warning.active,
a.list-group-item-warning.active:hover,
button.list-group-item-warning.active:hover,
a.list-group-item-warning.active:focus,
button.list-group-item-warning.active:focus {
  color: #fff;
  background-color: #8a6d3b;
  border-color: #8a6d3b;
}
.list-group-item-danger {
  color: #a94442;
  background-color: #f2dede;
}
a.list-group-item-danger,
button.list-group-item-danger {
  color: #a94442;
}
a.list-group-item-danger .list-group-item-heading,
button.list-group-item-danger .list-group-item-heading {
  color: inherit;
}
a.list-group-item-danger:hover,
button.list-group-item-danger:hover,
a.list-group-item-danger:focus,
button.list-group-item-danger:focus {
  color: #a94442;
  background-color: #ebcccc;
}
a.list-group-item-danger.active,
button.list-group-item-danger.active,
a.list-group-item-danger.active:hover,
button.list-group-item-danger.active:hover,
a.list-group-item-danger.active:focus,
button.list-group-item-danger.active:focus {
  color: #fff;
  background-color: #a94442;
  border-color: #a94442;
}
.list-group-item-heading {
  margin-top: 0;
  margin-bottom: 5px;
}
.list-group-item-text {
  margin-bottom: 0;
  line-height: 1.3;
}
.panel {
  margin-bottom: 20px;
  background-color: #fff;
  border: 1px solid transparent;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
}
.panel-body {
  padding: 15px;
}
.panel-heading {
  padding: 10px 15px;
  border-bottom: 1px solid transparent;
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}
.panel-heading > .dropdown .dropdown-toggle {
  color: inherit;
}
.panel-title {
  margin-top: 0;
  margin-bottom: 0;
  font-size: 16px;
  color: inherit;
}
.panel-title > a,
.panel-title > small,
.panel-title > .small,
.panel-title > small > a,
.panel-title > .small > a {
  color: inherit;
}
.panel-footer {
  padding: 10px 15px;
  background-color: #f5f5f5;
  border-top: 1px solid #ddd;
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px;
}
.panel > .list-group,
.panel > .panel-collapse > .list-group {
  margin-bottom: 0;
}
.panel > .list-group .list-group-item,
.panel > .panel-collapse > .list-group .list-group-item {
  border-width: 1px 0;
  border-radius: 0;
}
.panel > .list-group:first-child .list-group-item:first-child,
.panel > .panel-collapse > .list-group:first-child .list-group-item:first-child {
  border-top: 0;
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}
.panel > .list-group:last-child .list-group-item:last-child,
.panel > .panel-collapse > .list-group:last-child .list-group-item:last-child {
  border-bottom: 0;
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px;
}
.panel > .panel-heading + .panel-collapse > .list-group .list-group-item:first-child {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.panel-heading + .list-group .list-group-item:first-child {
  border-top-width: 0;
}
.list-group + .panel-footer {
  border-top-width: 0;
}
.panel > .table,
.panel > .table-responsive > .table,
.panel > .panel-collapse > .table {
  margin-bottom: 0;
}
.panel > .table caption,
.panel > .table-responsive > .table caption,
.panel > .panel-collapse > .table caption {
  padding-right: 15px;
  padding-left: 15px;
}
.panel > .table:first-child,
.panel > .table-responsive:first-child > .table:first-child {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}
.panel > .table:first-child > thead:first-child > tr:first-child,
.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child,
.panel > .table:first-child > tbody:first-child > tr:first-child,
.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}
.panel > .table:first-child > thead:first-child > tr:first-child td:first-child,
.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:first-child,
.panel > .table:first-child > tbody:first-child > tr:first-child td:first-child,
.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:first-child,
.panel > .table:first-child > thead:first-child > tr:first-child th:first-child,
.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:first-child,
.panel > .table:first-child > tbody:first-child > tr:first-child th:first-child,
.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:first-child {
  border-top-left-radius: 3px;
}
.panel > .table:first-child > thead:first-child > tr:first-child td:last-child,
.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:last-child,
.panel > .table:first-child > tbody:first-child > tr:first-child td:last-child,
.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:last-child,
.panel > .table:first-child > thead:first-child > tr:first-child th:last-child,
.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:last-child,
.panel > .table:first-child > tbody:first-child > tr:first-child th:last-child,
.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:last-child {
  border-top-right-radius: 3px;
}
.panel > .table:last-child,
.panel > .table-responsive:last-child > .table:last-child {
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px;
}
.panel > .table:last-child > tbody:last-child > tr:last-child,
.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child,
.panel > .table:last-child > tfoot:last-child > tr:last-child,
.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child {
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px;
}
.panel > .table:last-child > tbody:last-child > tr:last-child td:first-child,
.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:first-child,
.panel > .table:last-child > tfoot:last-child > tr:last-child td:first-child,
.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:first-child,
.panel > .table:last-child > tbody:last-child > tr:last-child th:first-child,
.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:first-child,
.panel > .table:last-child > tfoot:last-child > tr:last-child th:first-child,
.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:first-child {
  border-bottom-left-radius: 3px;
}
.panel > .table:last-child > tbody:last-child > tr:last-child td:last-child,
.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:last-child,
.panel > .table:last-child > tfoot:last-child > tr:last-child td:last-child,
.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:last-child,
.panel > .table:last-child > tbody:last-child > tr:last-child th:last-child,
.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:last-child,
.panel > .table:last-child > tfoot:last-child > tr:last-child th:last-child,
.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:last-child {
  border-bottom-right-radius: 3px;
}
.panel > .panel-body + .table,
.panel > .panel-body + .table-responsive,
.panel > .table + .panel-body,
.panel > .table-responsive + .panel-body {
  border-top: 1px solid #ddd;
}
.panel > .table > tbody:first-child > tr:first-child th,
.panel > .table > tbody:first-child > tr:first-child td {
  border-top: 0;
}
.panel > .table-bordered,
.panel > .table-responsive > .table-bordered {
  border: 0;
}
.panel > .table-bordered > thead > tr > th:first-child,
.panel > .table-responsive > .table-bordered > thead > tr > th:first-child,
.panel > .table-bordered > tbody > tr > th:first-child,
.panel > .table-responsive > .table-bordered > tbody > tr > th:first-child,
.panel > .table-bordered > tfoot > tr > th:first-child,
.panel > .table-responsive > .table-bordered > tfoot > tr > th:first-child,
.panel > .table-bordered > thead > tr > td:first-child,
.panel > .table-responsive > .table-bordered > thead > tr > td:first-child,
.panel > .table-bordered > tbody > tr > td:first-child,
.panel > .table-responsive > .table-bordered > tbody > tr > td:first-child,
.panel > .table-bordered > tfoot > tr > td:first-child,
.panel > .table-responsive > .table-bordered > tfoot > tr > td:first-child {
  border-left: 0;
}
.panel > .table-bordered > thead > tr > th:last-child,
.panel > .table-responsive > .table-bordered > thead > tr > th:last-child,
.panel > .table-bordered > tbody > tr > th:last-child,
.panel > .table-responsive > .table-bordered > tbody > tr > th:last-child,
.panel > .table-bordered > tfoot > tr > th:last-child,
.panel > .table-responsive > .table-bordered > tfoot > tr > th:last-child,
.panel > .table-bordered > thead > tr > td:last-child,
.panel > .table-responsive > .table-bordered > thead > tr > td:last-child,
.panel > .table-bordered > tbody > tr > td:last-child,
.panel > .table-responsive > .table-bordered > tbody > tr > td:last-child,
.panel > .table-bordered > tfoot > tr > td:last-child,
.panel > .table-responsive > .table-bordered > tfoot > tr > td:last-child {
  border-right: 0;
}
.panel > .table-bordered > thead > tr:first-child > td,
.panel > .table-responsive > .table-bordered > thead > tr:first-child > td,
.panel > .table-bordered > tbody > tr:first-child > td,
.panel > .table-responsive > .table-bordered > tbody > tr:first-child > td,
.panel > .table-bordered > thead > tr:first-child > th,
.panel > .table-responsive > .table-bordered > thead > tr:first-child > th,
.panel > .table-bordered > tbody > tr:first-child > th,
.panel > .table-responsive > .table-bordered > tbody > tr:first-child > th {
  border-bottom: 0;
}
.panel > .table-bordered > tbody > tr:last-child > td,
.panel > .table-responsive > .table-bordered > tbody > tr:last-child > td,
.panel > .table-bordered > tfoot > tr:last-child > td,
.panel > .table-responsive > .table-bordered > tfoot > tr:last-child > td,
.panel > .table-bordered > tbody > tr:last-child > th,
.panel > .table-responsive > .table-bordered > tbody > tr:last-child > th,
.panel > .table-bordered > tfoot > tr:last-child > th,
.panel > .table-responsive > .table-bordered > tfoot > tr:last-child > th {
  border-bottom: 0;
}
.panel > .table-responsive {
  margin-bottom: 0;
  border: 0;
}
.panel-group {
  margin-bottom: 20px;
}
.panel-group .panel {
  margin-bottom: 0;
  border-radius: 4px;
}
.panel-group .panel + .panel {
  margin-top: 5px;
}
.panel-group .panel-heading {
  border-bottom: 0;
}
.panel-group .panel-heading + .panel-collapse > .panel-body,
.panel-group .panel-heading + .panel-collapse > .list-group {
  border-top: 1px solid #ddd;
}
.panel-group .panel-footer {
  border-top: 0;
}
.panel-group .panel-footer + .panel-collapse .panel-body {
  border-bottom: 1px solid #ddd;
}
.panel-default {
  border-color: #ddd;
}
.panel-default > .panel-heading {
  color: #333333;
  background-color: #f5f5f5;
  border-color: #ddd;
}
.panel-default > .panel-heading + .panel-collapse > .panel-body {
  border-top-color: #ddd;
}
.panel-default > .panel-heading .badge {
  color: #f5f5f5;
  background-color: #333333;
}
.panel-default > .panel-footer + .panel-collapse > .panel-body {
  border-bottom-color: #ddd;
}
.panel-primary {
  border-color: #337ab7;
}
.panel-primary > .panel-heading {
  color: #fff;
  background-color: #337ab7;
  border-color: #337ab7;
}
.panel-primary > .panel-heading + .panel-collapse > .panel-body {
  border-top-color: #337ab7;
}
.panel-primary > .panel-heading .badge {
  color: #337ab7;
  background-color: #fff;
}
.panel-primary > .panel-footer + .panel-collapse > .panel-body {
  border-bottom-color: #337ab7;
}
.panel-success {
  border-color: #d6e9c6;
}
.panel-success > .panel-heading {
  color: #3c763d;
  background-color: #dff0d8;
  border-color: #d6e9c6;
}
.panel-success > .panel-heading + .panel-collapse > .panel-body {
  border-top-color: #d6e9c6;
}
.panel-success > .panel-heading .badge {
  color: #dff0d8;
  background-color: #3c763d;
}
.panel-success > .panel-footer + .panel-collapse > .panel-body {
  border-bottom-color: #d6e9c6;
}
.panel-info {
  border-color: #bce8f1;
}
.panel-info > .panel-heading {
  color: #31708f;
  background-color: #d9edf7;
  border-color: #bce8f1;
}
.panel-info > .panel-heading + .panel-collapse > .panel-body {
  border-top-color: #bce8f1;
}
.panel-info > .panel-heading .badge {
  color: #d9edf7;
  background-color: #31708f;
}
.panel-info > .panel-footer + .panel-collapse > .panel-body {
  border-bottom-color: #bce8f1;
}
.panel-warning {
  border-color: #faebcc;
}
.panel-warning > .panel-heading {
  color: #8a6d3b;
  background-color: #fcf8e3;
  border-color: #faebcc;
}
.panel-warning > .panel-heading + .panel-collapse > .panel-body {
  border-top-color: #faebcc;
}
.panel-warning > .panel-heading .badge {
  color: #fcf8e3;
  background-color: #8a6d3b;
}
.panel-warning > .panel-footer + .panel-collapse > .panel-body {
  border-bottom-color: #faebcc;
}
.panel-danger {
  border-color: #ebccd1;
}
.panel-danger > .panel-heading {
  color: #a94442;
  background-color: #f2dede;
  border-color: #ebccd1;
}
.panel-danger > .panel-heading + .panel-collapse > .panel-body {
  border-top-color: #ebccd1;
}
.panel-danger > .panel-heading .badge {
  color: #f2dede;
  background-color: #a94442;
}
.panel-danger > .panel-footer + .panel-collapse > .panel-body {
  border-bottom-color: #ebccd1;
}
.embed-responsive {
  position: relative;
  display: block;
  height: 0;
  padding: 0;
  overflow: hidden;
}
.embed-responsive .embed-responsive-item,
.embed-responsive iframe,
.embed-responsive embed,
.embed-responsive object,
.embed-responsive video {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 100%;
  border: 0;
}
.embed-responsive-16by9 {
  padding-bottom: 56.25%;
}
.embed-responsive-4by3 {
  padding-bottom: 75%;
}
.well {
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid #e3e3e3;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
}
.well blockquote {
  border-color: #ddd;
  border-color: rgba(0, 0, 0, 0.15);
}
.well-lg {
  padding: 24px;
  border-radius: 6px;
}
.well-sm {
  padding: 9px;
  border-radius: 3px;
}
.close {
  float: right;
  font-size: 21px;
  font-weight: bold;
  line-height: 1;
  color: #000;
  text-shadow: 0 1px 0 #fff;
  filter: alpha(opacity=20);
  opacity: 0.2;
}
.close:hover,
.close:focus {
  color: #000;
  text-decoration: none;
  cursor: pointer;
  filter: alpha(opacity=50);
  opacity: 0.5;
}
button.close {
  padding: 0;
  cursor: pointer;
  background: transparent;
  border: 0;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
}
.modal-open {
  overflow: hidden;
}
.modal {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1050;
  display: none;
  overflow: hidden;
  -webkit-overflow-scrolling: touch;
  outline: 0;
}
.modal.fade .modal-dialog {
  -webkit-transform: translate(0, -25%);
  -ms-transform: translate(0, -25%);
  -o-transform: translate(0, -25%);
  transform: translate(0, -25%);
  -webkit-transition: -webkit-transform 0.3s ease-out;
  -o-transition: -o-transform 0.3s ease-out;
  transition: -webkit-transform 0.3s ease-out;
  transition: transform 0.3s ease-out;
  transition: transform 0.3s ease-out, -webkit-transform 0.3s ease-out, -o-transform 0.3s ease-out;
}
.modal.in .modal-dialog {
  -webkit-transform: translate(0, 0);
  -ms-transform: translate(0, 0);
  -o-transform: translate(0, 0);
  transform: translate(0, 0);
}
.modal-open .modal {
  overflow-x: hidden;
  overflow-y: auto;
}
.modal-dialog {
  position: relative;
  width: auto;
  margin: 10px;
}
.modal-content {
  position: relative;
  background-color: #fff;
  background-clip: padding-box;
  border: 1px solid #999;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 6px;
  -webkit-box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
  box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
  outline: 0;
}
.modal-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1040;
  background-color: #000;
}
.modal-backdrop.fade {
  filter: alpha(opacity=0);
  opacity: 0;
}
.modal-backdrop.in {
  filter: alpha(opacity=50);
  opacity: 0.5;
}
.modal-header {
  padding: 15px;
  border-bottom: 1px solid #e5e5e5;
}
.modal-header .close {
  margin-top: -2px;
}
.modal-title {
  margin: 0;
  line-height: 1.42857143;
}
.modal-body {
  position: relative;
  padding: 15px;
}
.modal-footer {
  padding: 15px;
  text-align: right;
  border-top: 1px solid #e5e5e5;
}
.modal-footer .btn + .btn {
  margin-bottom: 0;
  margin-left: 5px;
}
.modal-footer .btn-group .btn + .btn {
  margin-left: -1px;
}
.modal-footer .btn-block + .btn-block {
  margin-left: 0;
}
.modal-scrollbar-measure {
  position: absolute;
  top: -9999px;
  width: 50px;
  height: 50px;
  overflow: scroll;
}
@media (min-width: 768px) {
  .modal-dialog {
    width: 600px;
    margin: 30px auto;
  }
  .modal-content {
    -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
    box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
  }
  .modal-sm {
    width: 300px;
  }
}
@media (min-width: 992px) {
  .modal-lg {
    width: 900px;
  }
}
.tooltip {
  position: absolute;
  z-index: 1070;
  display: block;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-style: normal;
  font-weight: 400;
  line-height: 1.42857143;
  line-break: auto;
  text-align: left;
  text-align: start;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  letter-spacing: normal;
  word-break: normal;
  word-spacing: normal;
  word-wrap: normal;
  white-space: normal;
  font-size: 12px;
  filter: alpha(opacity=0);
  opacity: 0;
}
.tooltip.in {
  filter: alpha(opacity=90);
  opacity: 0.9;
}
.tooltip.top {
  padding: 5px 0;
  margin-top: -3px;
}
.tooltip.right {
  padding: 0 5px;
  margin-left: 3px;
}
.tooltip.bottom {
  padding: 5px 0;
  margin-top: 3px;
}
.tooltip.left {
  padding: 0 5px;
  margin-left: -3px;
}
.tooltip.top .tooltip-arrow {
  bottom: 0;
  left: 50%;
  margin-left: -5px;
  border-width: 5px 5px 0;
  border-top-color: #000;
}
.tooltip.top-left .tooltip-arrow {
  right: 5px;
  bottom: 0;
  margin-bottom: -5px;
  border-width: 5px 5px 0;
  border-top-color: #000;
}
.tooltip.top-right .tooltip-arrow {
  bottom: 0;
  left: 5px;
  margin-bottom: -5px;
  border-width: 5px 5px 0;
  border-top-color: #000;
}
.tooltip.right .tooltip-arrow {
  top: 50%;
  left: 0;
  margin-top: -5px;
  border-width: 5px 5px 5px 0;
  border-right-color: #000;
}
.tooltip.left .tooltip-arrow {
  top: 50%;
  right: 0;
  margin-top: -5px;
  border-width: 5px 0 5px 5px;
  border-left-color: #000;
}
.tooltip.bottom .tooltip-arrow {
  top: 0;
  left: 50%;
  margin-left: -5px;
  border-width: 0 5px 5px;
  border-bottom-color: #000;
}
.tooltip.bottom-left .tooltip-arrow {
  top: 0;
  right: 5px;
  margin-top: -5px;
  border-width: 0 5px 5px;
  border-bottom-color: #000;
}
.tooltip.bottom-right .tooltip-arrow {
  top: 0;
  left: 5px;
  margin-top: -5px;
  border-width: 0 5px 5px;
  border-bottom-color: #000;
}
.tooltip-inner {
  max-width: 200px;
  padding: 3px 8px;
  color: #fff;
  text-align: center;
  background-color: #000;
  border-radius: 4px;
}
.tooltip-arrow {
  position: absolute;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
}
.popover {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1060;
  display: none;
  max-width: 276px;
  padding: 1px;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-style: normal;
  font-weight: 400;
  line-height: 1.42857143;
  line-break: auto;
  text-align: left;
  text-align: start;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  letter-spacing: normal;
  word-break: normal;
  word-spacing: normal;
  word-wrap: normal;
  white-space: normal;
  font-size: 14px;
  background-color: #fff;
  background-clip: padding-box;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 6px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
}
.popover.top {
  margin-top: -10px;
}
.popover.right {
  margin-left: 10px;
}
.popover.bottom {
  margin-top: 10px;
}
.popover.left {
  margin-left: -10px;
}
.popover > .arrow {
  border-width: 11px;
}
.popover > .arrow,
.popover > .arrow:after {
  position: absolute;
  display: block;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
}
.popover > .arrow:after {
  content: "";
  border-width: 10px;
}
.popover.top > .arrow {
  bottom: -11px;
  left: 50%;
  margin-left: -11px;
  border-top-color: #999999;
  border-top-color: rgba(0, 0, 0, 0.25);
  border-bottom-width: 0;
}
.popover.top > .arrow:after {
  bottom: 1px;
  margin-left: -10px;
  content: " ";
  border-top-color: #fff;
  border-bottom-width: 0;
}
.popover.right > .arrow {
  top: 50%;
  left: -11px;
  margin-top: -11px;
  border-right-color: #999999;
  border-right-color: rgba(0, 0, 0, 0.25);
  border-left-width: 0;
}
.popover.right > .arrow:after {
  bottom: -10px;
  left: 1px;
  content: " ";
  border-right-color: #fff;
  border-left-width: 0;
}
.popover.bottom > .arrow {
  top: -11px;
  left: 50%;
  margin-left: -11px;
  border-top-width: 0;
  border-bottom-color: #999999;
  border-bottom-color: rgba(0, 0, 0, 0.25);
}
.popover.bottom > .arrow:after {
  top: 1px;
  margin-left: -10px;
  content: " ";
  border-top-width: 0;
  border-bottom-color: #fff;
}
.popover.left > .arrow {
  top: 50%;
  right: -11px;
  margin-top: -11px;
  border-right-width: 0;
  border-left-color: #999999;
  border-left-color: rgba(0, 0, 0, 0.25);
}
.popover.left > .arrow:after {
  right: 1px;
  bottom: -10px;
  content: " ";
  border-right-width: 0;
  border-left-color: #fff;
}
.popover-title {
  padding: 8px 14px;
  margin: 0;
  font-size: 14px;
  background-color: #f7f7f7;
  border-bottom: 1px solid #ebebeb;
  border-radius: 5px 5px 0 0;
}
.popover-content {
  padding: 9px 14px;
}
.carousel {
  position: relative;
}
.carousel-inner {
  position: relative;
  width: 100%;
  overflow: hidden;
}
.carousel-inner > .item {
  position: relative;
  display: none;
  -webkit-transition: 0.6s ease-in-out left;
  -o-transition: 0.6s ease-in-out left;
  transition: 0.6s ease-in-out left;
}
.carousel-inner > .item > img,
.carousel-inner > .item > a > img {
  line-height: 1;
}
@media all and (transform-3d), (-webkit-transform-3d) {
  .carousel-inner > .item {
    -webkit-transition: -webkit-transform 0.6s ease-in-out;
    -o-transition: -o-transform 0.6s ease-in-out;
    transition: -webkit-transform 0.6s ease-in-out;
    transition: transform 0.6s ease-in-out;
    transition: transform 0.6s ease-in-out, -webkit-transform 0.6s ease-in-out, -o-transform 0.6s ease-in-out;
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden;
    -webkit-perspective: 1000px;
    perspective: 1000px;
  }
  .carousel-inner > .item.next,
  .carousel-inner > .item.active.right {
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
    left: 0;
  }
  .carousel-inner > .item.prev,
  .carousel-inner > .item.active.left {
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
    left: 0;
  }
  .carousel-inner > .item.next.left,
  .carousel-inner > .item.prev.right,
  .carousel-inner > .item.active {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
    left: 0;
  }
}
.carousel-inner > .active,
.carousel-inner > .next,
.carousel-inner > .prev {
  display: block;
}
.carousel-inner > .active {
  left: 0;
}
.carousel-inner > .next,
.carousel-inner > .prev {
  position: absolute;
  top: 0;
  width: 100%;
}
.carousel-inner > .next {
  left: 100%;
}
.carousel-inner > .prev {
  left: -100%;
}
.carousel-inner > .next.left,
.carousel-inner > .prev.right {
  left: 0;
}
.carousel-inner > .active.left {
  left: -100%;
}
.carousel-inner > .active.right {
  left: 100%;
}
.carousel-control {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 15%;
  font-size: 20px;
  color: #fff;
  text-align: center;
  text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
  background-color: rgba(0, 0, 0, 0);
  filter: alpha(opacity=50);
  opacity: 0.5;
}
.carousel-control.left {
  background-image: -webkit-linear-gradient(left, rgba(0, 0, 0, 0.5) 0%, rgba(0, 0, 0, 0.0001) 100%);
  background-image: -o-linear-gradient(left, rgba(0, 0, 0, 0.5) 0%, rgba(0, 0, 0, 0.0001) 100%);
  background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, 0.5)), to(rgba(0, 0, 0, 0.0001)));
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.5) 0%, rgba(0, 0, 0, 0.0001) 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#80000000', endColorstr='#00000000', GradientType=1);
  background-repeat: repeat-x;
}
.carousel-control.right {
  right: 0;
  left: auto;
  background-image: -webkit-linear-gradient(left, rgba(0, 0, 0, 0.0001) 0%, rgba(0, 0, 0, 0.5) 100%);
  background-image: -o-linear-gradient(left, rgba(0, 0, 0, 0.0001) 0%, rgba(0, 0, 0, 0.5) 100%);
  background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, 0.0001)), to(rgba(0, 0, 0, 0.5)));
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.0001) 0%, rgba(0, 0, 0, 0.5) 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#80000000', GradientType=1);
  background-repeat: repeat-x;
}
.carousel-control:hover,
.carousel-control:focus {
  color: #fff;
  text-decoration: none;
  outline: 0;
  filter: alpha(opacity=90);
  opacity: 0.9;
}
.carousel-control .icon-prev,
.carousel-control .icon-next,
.carousel-control .glyphicon-chevron-left,
.carousel-control .glyphicon-chevron-right {
  position: absolute;
  top: 50%;
  z-index: 5;
  display: inline-block;
  margin-top: -10px;
}
.carousel-control .icon-prev,
.carousel-control .glyphicon-chevron-left {
  left: 50%;
  margin-left: -10px;
}
.carousel-control .icon-next,
.carousel-control .glyphicon-chevron-right {
  right: 50%;
  margin-right: -10px;
}
.carousel-control .icon-prev,
.carousel-control .icon-next {
  width: 20px;
  height: 20px;
  font-family: serif;
  line-height: 1;
}
.carousel-control .icon-prev:before {
  content: "\2039";
}
.carousel-control .icon-next:before {
  content: "\203a";
}
.carousel-indicators {
  position: absolute;
  bottom: 10px;
  left: 50%;
  z-index: 15;
  width: 60%;
  padding-left: 0;
  margin-left: -30%;
  text-align: center;
  list-style: none;
}
.carousel-indicators li {
  display: inline-block;
  width: 10px;
  height: 10px;
  margin: 1px;
  text-indent: -999px;
  cursor: pointer;
  background-color: #000 \9;
  background-color: rgba(0, 0, 0, 0);
  border: 1px solid #fff;
  border-radius: 10px;
}
.carousel-indicators .active {
  width: 12px;
  height: 12px;
  margin: 0;
  background-color: #fff;
}
.carousel-caption {
  position: absolute;
  right: 15%;
  bottom: 20px;
  left: 15%;
  z-index: 10;
  padding-top: 20px;
  padding-bottom: 20px;
  color: #fff;
  text-align: center;
  text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
}
.carousel-caption .btn {
  text-shadow: none;
}
@media screen and (min-width: 768px) {
  .carousel-control .glyphicon-chevron-left,
  .carousel-control .glyphicon-chevron-right,
  .carousel-control .icon-prev,
  .carousel-control .icon-next {
    width: 30px;
    height: 30px;
    margin-top: -10px;
    font-size: 30px;
  }
  .carousel-control .glyphicon-chevron-left,
  .carousel-control .icon-prev {
    margin-left: -10px;
  }
  .carousel-control .glyphicon-chevron-right,
  .carousel-control .icon-next {
    margin-right: -10px;
  }
  .carousel-caption {
    right: 20%;
    left: 20%;
    padding-bottom: 30px;
  }
  .carousel-indicators {
    bottom: 20px;
  }
}
.clearfix:before,
.clearfix:after,
.dl-horizontal dd:before,
.dl-horizontal dd:after,
.container:before,
.container:after,
.container-fluid:before,
.container-fluid:after,
.row:before,
.row:after,
.form-horizontal .form-group:before,
.form-horizontal .form-group:after,
.btn-toolbar:before,
.btn-toolbar:after,
.btn-group-vertical > .btn-group:before,
.btn-group-vertical > .btn-group:after,
.nav:before,
.nav:after,
.navbar:before,
.navbar:after,
.navbar-header:before,
.navbar-header:after,
.navbar-collapse:before,
.navbar-collapse:after,
.pager:before,
.pager:after,
.panel-body:before,
.panel-body:after,
.modal-header:before,
.modal-header:after,
.modal-footer:before,
.modal-footer:after {
  display: table;
  content: " ";
}
.clearfix:after,
.dl-horizontal dd:after,
.container:after,
.container-fluid:after,
.row:after,
.form-horizontal .form-group:after,
.btn-toolbar:after,
.btn-group-vertical > .btn-group:after,
.nav:after,
.navbar:after,
.navbar-header:after,
.navbar-collapse:after,
.pager:after,
.panel-body:after,
.modal-header:after,
.modal-footer:after {
  clear: both;
}
.center-block {
  display: block;
  margin-right: auto;
  margin-left: auto;
}
.pull-right {
  float: right !important;
}
.pull-left {
  float: left !important;
}
.hide {
  display: none !important;
}
.show {
  display: block !important;
}
.invisible {
  visibility: hidden;
}
.text-hide {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0;
}
.hidden {
  display: none !important;
}
.affix {
  position: fixed;
}
@-ms-viewport {
  width: device-width;
}
.visible-xs,
.visible-sm,
.visible-md,
.visible-lg {
  display: none !important;
}
.visible-xs-block,
.visible-xs-inline,
.visible-xs-inline-block,
.visible-sm-block,
.visible-sm-inline,
.visible-sm-inline-block,
.visible-md-block,
.visible-md-inline,
.visible-md-inline-block,
.visible-lg-block,
.visible-lg-inline,
.visible-lg-inline-block {
  display: none !important;
}
@media (max-width: 767px) {
  .visible-xs {
    display: block !important;
  }
  table.visible-xs {
    display: table !important;
  }
  tr.visible-xs {
    display: table-row !important;
  }
  th.visible-xs,
  td.visible-xs {
    display: table-cell !important;
  }
}
@media (max-width: 767px) {
  .visible-xs-block {
    display: block !important;
  }
}
@media (max-width: 767px) {
  .visible-xs-inline {
    display: inline !important;
  }
}
@media (max-width: 767px) {
  .visible-xs-inline-block {
    display: inline-block !important;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .visible-sm {
    display: block !important;
  }
  table.visible-sm {
    display: table !important;
  }
  tr.visible-sm {
    display: table-row !important;
  }
  th.visible-sm,
  td.visible-sm {
    display: table-cell !important;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .visible-sm-block {
    display: block !important;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .visible-sm-inline {
    display: inline !important;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .visible-sm-inline-block {
    display: inline-block !important;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-md {
    display: block !important;
  }
  table.visible-md {
    display: table !important;
  }
  tr.visible-md {
    display: table-row !important;
  }
  th.visible-md,
  td.visible-md {
    display: table-cell !important;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-md-block {
    display: block !important;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-md-inline {
    display: inline !important;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-md-inline-block {
    display: inline-block !important;
  }
}
@media (min-width: 1200px) {
  .visible-lg {
    display: block !important;
  }
  table.visible-lg {
    display: table !important;
  }
  tr.visible-lg {
    display: table-row !important;
  }
  th.visible-lg,
  td.visible-lg {
    display: table-cell !important;
  }
}
@media (min-width: 1200px) {
  .visible-lg-block {
    display: block !important;
  }
}
@media (min-width: 1200px) {
  .visible-lg-inline {
    display: inline !important;
  }
}
@media (min-width: 1200px) {
  .visible-lg-inline-block {
    display: inline-block !important;
  }
}
@media (max-width: 767px) {
  .hidden-xs {
    display: none !important;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .hidden-sm {
    display: none !important;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  .hidden-md {
    display: none !important;
  }
}
@media (min-width: 1200px) {
  .hidden-lg {
    display: none !important;
  }
}
.visible-print {
  display: none !important;
}
@media print {
  .visible-print {
    display: block !important;
  }
  table.visible-print {
    display: table !important;
  }
  tr.visible-print {
    display: table-row !important;
  }
  th.visible-print,
  td.visible-print {
    display: table-cell !important;
  }
}
.visible-print-block {
  display: none !important;
}
@media print {
  .visible-print-block {
    display: block !important;
  }
}
.visible-print-inline {
  display: none !important;
}
@media print {
  .visible-print-inline {
    display: inline !important;
  }
}
.visible-print-inline-block {
  display: none !important;
}
@media print {
  .visible-print-inline-block {
    display: inline-block !important;
  }
}
@media print {
  .hidden-print {
    display: none !important;
  }
}
/*# sourceMappingURL=bootstrap.css.map */
/*!
 *  Font Awesome 4.7.0 by @davegandy - http://fontawesome.io - @fontawesome
 *  License - http://fontawesome.io/license (Font: SIL OFL 1.1, CSS: MIT License)
 */
/* FONT PATH
 * -------------------------- */
@font-face {
  font-family: 'FontAwesome';
  src: url(/static/files/8b43027f47b20503057dfbbaa9401fef.eot);
  src: url(/static/files/8b43027f47b20503057dfbbaa9401fef.eot?#iefix&v=4.7.0) format('embedded-opentype'), url(/static/files/20fd1704ea223900efa9fd4e869efb08.woff2) format('woff2'), url(/static/files/f691f37e57f04c152e2315ab7dbad881.woff) format('woff'), url(/static/files/1e59d2330b4c6deb84b340635ed36249.ttf) format('truetype'), url(/static/files/0e266bf6f9d07469ad718c96058f9fbb.svg#fontawesomeregular) format('svg');
  font-weight: normal;
  font-style: normal;
}
.fa {
  display: inline-block;
  font: normal normal normal 14px/1 FontAwesome;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
/* makes the font 33% larger relative to the icon container */
.fa-lg {
  font-size: 1.33333333em;
  line-height: 0.75em;
  vertical-align: -15%;
}
.fa-2x {
  font-size: 2em;
}
.fa-3x {
  font-size: 3em;
}
.fa-4x {
  font-size: 4em;
}
.fa-5x {
  font-size: 5em;
}
.fa-fw {
  width: 1.28571429em;
  text-align: center;
}
.fa-ul {
  padding-left: 0;
  margin-left: 2.14285714em;
  list-style-type: none;
}
.fa-ul > li {
  position: relative;
}
.fa-li {
  position: absolute;
  left: -2.14285714em;
  width: 2.14285714em;
  top: 0.14285714em;
  text-align: center;
}
.fa-li.fa-lg {
  left: -1.85714286em;
}
.fa-border {
  padding: .2em .25em .15em;
  border: solid 0.08em #eeeeee;
  border-radius: .1em;
}
.fa-pull-left {
  float: left;
}
.fa-pull-right {
  float: right;
}
.fa.fa-pull-left {
  margin-right: .3em;
}
.fa.fa-pull-right {
  margin-left: .3em;
}
/* Deprecated as of 4.4.0 */
.pull-right {
  float: right;
}
.pull-left {
  float: left;
}
.fa.pull-left {
  margin-right: .3em;
}
.fa.pull-right {
  margin-left: .3em;
}
.fa-spin {
  -webkit-animation: fa-spin 2s infinite linear;
  animation: fa-spin 2s infinite linear;
}
.fa-pulse {
  -webkit-animation: fa-spin 1s infinite steps(8);
  animation: fa-spin 1s infinite steps(8);
}
@-webkit-keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
@keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
.fa-rotate-90 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
  -webkit-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  transform: rotate(90deg);
}
.fa-rotate-180 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2)";
  -webkit-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}
.fa-rotate-270 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
  -webkit-transform: rotate(270deg);
  -ms-transform: rotate(270deg);
  transform: rotate(270deg);
}
.fa-flip-horizontal {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)";
  -webkit-transform: scale(-1, 1);
  -ms-transform: scale(-1, 1);
  transform: scale(-1, 1);
}
.fa-flip-vertical {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";
  -webkit-transform: scale(1, -1);
  -ms-transform: scale(1, -1);
  transform: scale(1, -1);
}
:root .fa-rotate-90,
:root .fa-rotate-180,
:root .fa-rotate-270,
:root .fa-flip-horizontal,
:root .fa-flip-vertical {
  filter: none;
}
.fa-stack {
  position: relative;
  display: inline-block;
  width: 2em;
  height: 2em;
  line-height: 2em;
  vertical-align: middle;
}
.fa-stack-1x,
.fa-stack-2x {
  position: absolute;
  left: 0;
  width: 100%;
  text-align: center;
}
.fa-stack-1x {
  line-height: inherit;
}
.fa-stack-2x {
  font-size: 2em;
}
.fa-inverse {
  color: #ffffff;
}
/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
   readers do not read off random characters that represent icons */
.fa-glass:before {
  content: "\f000";
}
.fa-music:before {
  content: "\f001";
}
.fa-search:before {
  content: "\f002";
}
.fa-envelope-o:before {
  content: "\f003";
}
.fa-heart:before {
  content: "\f004";
}
.fa-star:before {
  content: "\f005";
}
.fa-star-o:before {
  content: "\f006";
}
.fa-user:before {
  content: "\f007";
}
.fa-film:before {
  content: "\f008";
}
.fa-th-large:before {
  content: "\f009";
}
.fa-th:before {
  content: "\f00a";
}
.fa-th-list:before {
  content: "\f00b";
}
.fa-check:before {
  content: "\f00c";
}
.fa-remove:before,
.fa-close:before,
.fa-times:before {
  content: "\f00d";
}
.fa-search-plus:before {
  content: "\f00e";
}
.fa-search-minus:before {
  content: "\f010";
}
.fa-power-off:before {
  content: "\f011";
}
.fa-signal:before {
  content: "\f012";
}
.fa-gear:before,
.fa-cog:before {
  content: "\f013";
}
.fa-trash-o:before {
  content: "\f014";
}
.fa-home:before {
  content: "\f015";
}
.fa-file-o:before {
  content: "\f016";
}
.fa-clock-o:before {
  content: "\f017";
}
.fa-road:before {
  content: "\f018";
}
.fa-download:before {
  content: "\f019";
}
.fa-arrow-circle-o-down:before {
  content: "\f01a";
}
.fa-arrow-circle-o-up:before {
  content: "\f01b";
}
.fa-inbox:before {
  content: "\f01c";
}
.fa-play-circle-o:before {
  content: "\f01d";
}
.fa-rotate-right:before,
.fa-repeat:before {
  content: "\f01e";
}
.fa-refresh:before {
  content: "\f021";
}
.fa-list-alt:before {
  content: "\f022";
}
.fa-lock:before {
  content: "\f023";
}
.fa-flag:before {
  content: "\f024";
}
.fa-headphones:before {
  content: "\f025";
}
.fa-volume-off:before {
  content: "\f026";
}
.fa-volume-down:before {
  content: "\f027";
}
.fa-volume-up:before {
  content: "\f028";
}
.fa-qrcode:before {
  content: "\f029";
}
.fa-barcode:before {
  content: "\f02a";
}
.fa-tag:before {
  content: "\f02b";
}
.fa-tags:before {
  content: "\f02c";
}
.fa-book:before {
  content: "\f02d";
}
.fa-bookmark:before {
  content: "\f02e";
}
.fa-print:before {
  content: "\f02f";
}
.fa-camera:before {
  content: "\f030";
}
.fa-font:before {
  content: "\f031";
}
.fa-bold:before {
  content: "\f032";
}
.fa-italic:before {
  content: "\f033";
}
.fa-text-height:before {
  content: "\f034";
}
.fa-text-width:before {
  content: "\f035";
}
.fa-align-left:before {
  content: "\f036";
}
.fa-align-center:before {
  content: "\f037";
}
.fa-align-right:before {
  content: "\f038";
}
.fa-align-justify:before {
  content: "\f039";
}
.fa-list:before {
  content: "\f03a";
}
.fa-dedent:before,
.fa-outdent:before {
  content: "\f03b";
}
.fa-indent:before {
  content: "\f03c";
}
.fa-video-camera:before {
  content: "\f03d";
}
.fa-photo:before,
.fa-image:before,
.fa-picture-o:before {
  content: "\f03e";
}
.fa-pencil:before {
  content: "\f040";
}
.fa-map-marker:before {
  content: "\f041";
}
.fa-adjust:before {
  content: "\f042";
}
.fa-tint:before {
  content: "\f043";
}
.fa-edit:before,
.fa-pencil-square-o:before {
  content: "\f044";
}
.fa-share-square-o:before {
  content: "\f045";
}
.fa-check-square-o:before {
  content: "\f046";
}
.fa-arrows:before {
  content: "\f047";
}
.fa-step-backward:before {
  content: "\f048";
}
.fa-fast-backward:before {
  content: "\f049";
}
.fa-backward:before {
  content: "\f04a";
}
.fa-play:before {
  content: "\f04b";
}
.fa-pause:before {
  content: "\f04c";
}
.fa-stop:before {
  content: "\f04d";
}
.fa-forward:before {
  content: "\f04e";
}
.fa-fast-forward:before {
  content: "\f050";
}
.fa-step-forward:before {
  content: "\f051";
}
.fa-eject:before {
  content: "\f052";
}
.fa-chevron-left:before {
  content: "\f053";
}
.fa-chevron-right:before {
  content: "\f054";
}
.fa-plus-circle:before {
  content: "\f055";
}
.fa-minus-circle:before {
  content: "\f056";
}
.fa-times-circle:before {
  content: "\f057";
}
.fa-check-circle:before {
  content: "\f058";
}
.fa-question-circle:before {
  content: "\f059";
}
.fa-info-circle:before {
  content: "\f05a";
}
.fa-crosshairs:before {
  content: "\f05b";
}
.fa-times-circle-o:before {
  content: "\f05c";
}
.fa-check-circle-o:before {
  content: "\f05d";
}
.fa-ban:before {
  content: "\f05e";
}
.fa-arrow-left:before {
  content: "\f060";
}
.fa-arrow-right:before {
  content: "\f061";
}
.fa-arrow-up:before {
  content: "\f062";
}
.fa-arrow-down:before {
  content: "\f063";
}
.fa-mail-forward:before,
.fa-share:before {
  content: "\f064";
}
.fa-expand:before {
  content: "\f065";
}
.fa-compress:before {
  content: "\f066";
}
.fa-plus:before {
  content: "\f067";
}
.fa-minus:before {
  content: "\f068";
}
.fa-asterisk:before {
  content: "\f069";
}
.fa-exclamation-circle:before {
  content: "\f06a";
}
.fa-gift:before {
  content: "\f06b";
}
.fa-leaf:before {
  content: "\f06c";
}
.fa-fire:before {
  content: "\f06d";
}
.fa-eye:before {
  content: "\f06e";
}
.fa-eye-slash:before {
  content: "\f070";
}
.fa-warning:before,
.fa-exclamation-triangle:before {
  content: "\f071";
}
.fa-plane:before {
  content: "\f072";
}
.fa-calendar:before {
  content: "\f073";
}
.fa-random:before {
  content: "\f074";
}
.fa-comment:before {
  content: "\f075";
}
.fa-magnet:before {
  content: "\f076";
}
.fa-chevron-up:before {
  content: "\f077";
}
.fa-chevron-down:before {
  content: "\f078";
}
.fa-retweet:before {
  content: "\f079";
}
.fa-shopping-cart:before {
  content: "\f07a";
}
.fa-folder:before {
  content: "\f07b";
}
.fa-folder-open:before {
  content: "\f07c";
}
.fa-arrows-v:before {
  content: "\f07d";
}
.fa-arrows-h:before {
  content: "\f07e";
}
.fa-bar-chart-o:before,
.fa-bar-chart:before {
  content: "\f080";
}
.fa-twitter-square:before {
  content: "\f081";
}
.fa-facebook-square:before {
  content: "\f082";
}
.fa-camera-retro:before {
  content: "\f083";
}
.fa-key:before {
  content: "\f084";
}
.fa-gears:before,
.fa-cogs:before {
  content: "\f085";
}
.fa-comments:before {
  content: "\f086";
}
.fa-thumbs-o-up:before {
  content: "\f087";
}
.fa-thumbs-o-down:before {
  content: "\f088";
}
.fa-star-half:before {
  content: "\f089";
}
.fa-heart-o:before {
  content: "\f08a";
}
.fa-sign-out:before {
  content: "\f08b";
}
.fa-linkedin-square:before {
  content: "\f08c";
}
.fa-thumb-tack:before {
  content: "\f08d";
}
.fa-external-link:before {
  content: "\f08e";
}
.fa-sign-in:before {
  content: "\f090";
}
.fa-trophy:before {
  content: "\f091";
}
.fa-github-square:before {
  content: "\f092";
}
.fa-upload:before {
  content: "\f093";
}
.fa-lemon-o:before {
  content: "\f094";
}
.fa-phone:before {
  content: "\f095";
}
.fa-square-o:before {
  content: "\f096";
}
.fa-bookmark-o:before {
  content: "\f097";
}
.fa-phone-square:before {
  content: "\f098";
}
.fa-twitter:before {
  content: "\f099";
}
.fa-facebook-f:before,
.fa-facebook:before {
  content: "\f09a";
}
.fa-github:before {
  content: "\f09b";
}
.fa-unlock:before {
  content: "\f09c";
}
.fa-credit-card:before {
  content: "\f09d";
}
.fa-feed:before,
.fa-rss:before {
  content: "\f09e";
}
.fa-hdd-o:before {
  content: "\f0a0";
}
.fa-bullhorn:before {
  content: "\f0a1";
}
.fa-bell:before {
  content: "\f0f3";
}
.fa-certificate:before {
  content: "\f0a3";
}
.fa-hand-o-right:before {
  content: "\f0a4";
}
.fa-hand-o-left:before {
  content: "\f0a5";
}
.fa-hand-o-up:before {
  content: "\f0a6";
}
.fa-hand-o-down:before {
  content: "\f0a7";
}
.fa-arrow-circle-left:before {
  content: "\f0a8";
}
.fa-arrow-circle-right:before {
  content: "\f0a9";
}
.fa-arrow-circle-up:before {
  content: "\f0aa";
}
.fa-arrow-circle-down:before {
  content: "\f0ab";
}
.fa-globe:before {
  content: "\f0ac";
}
.fa-wrench:before {
  content: "\f0ad";
}
.fa-tasks:before {
  content: "\f0ae";
}
.fa-filter:before {
  content: "\f0b0";
}
.fa-briefcase:before {
  content: "\f0b1";
}
.fa-arrows-alt:before {
  content: "\f0b2";
}
.fa-group:before,
.fa-users:before {
  content: "\f0c0";
}
.fa-chain:before,
.fa-link:before {
  content: "\f0c1";
}
.fa-cloud:before {
  content: "\f0c2";
}
.fa-flask:before {
  content: "\f0c3";
}
.fa-cut:before,
.fa-scissors:before {
  content: "\f0c4";
}
.fa-copy:before,
.fa-files-o:before {
  content: "\f0c5";
}
.fa-paperclip:before {
  content: "\f0c6";
}
.fa-save:before,
.fa-floppy-o:before {
  content: "\f0c7";
}
.fa-square:before {
  content: "\f0c8";
}
.fa-navicon:before,
.fa-reorder:before,
.fa-bars:before {
  content: "\f0c9";
}
.fa-list-ul:before {
  content: "\f0ca";
}
.fa-list-ol:before {
  content: "\f0cb";
}
.fa-strikethrough:before {
  content: "\f0cc";
}
.fa-underline:before {
  content: "\f0cd";
}
.fa-table:before {
  content: "\f0ce";
}
.fa-magic:before {
  content: "\f0d0";
}
.fa-truck:before {
  content: "\f0d1";
}
.fa-pinterest:before {
  content: "\f0d2";
}
.fa-pinterest-square:before {
  content: "\f0d3";
}
.fa-google-plus-square:before {
  content: "\f0d4";
}
.fa-google-plus:before {
  content: "\f0d5";
}
.fa-money:before {
  content: "\f0d6";
}
.fa-caret-down:before {
  content: "\f0d7";
}
.fa-caret-up:before {
  content: "\f0d8";
}
.fa-caret-left:before {
  content: "\f0d9";
}
.fa-caret-right:before {
  content: "\f0da";
}
.fa-columns:before {
  content: "\f0db";
}
.fa-unsorted:before,
.fa-sort:before {
  content: "\f0dc";
}
.fa-sort-down:before,
.fa-sort-desc:before {
  content: "\f0dd";
}
.fa-sort-up:before,
.fa-sort-asc:before {
  content: "\f0de";
}
.fa-envelope:before {
  content: "\f0e0";
}
.fa-linkedin:before {
  content: "\f0e1";
}
.fa-rotate-left:before,
.fa-undo:before {
  content: "\f0e2";
}
.fa-legal:before,
.fa-gavel:before {
  content: "\f0e3";
}
.fa-dashboard:before,
.fa-tachometer:before {
  content: "\f0e4";
}
.fa-comment-o:before {
  content: "\f0e5";
}
.fa-comments-o:before {
  content: "\f0e6";
}
.fa-flash:before,
.fa-bolt:before {
  content: "\f0e7";
}
.fa-sitemap:before {
  content: "\f0e8";
}
.fa-umbrella:before {
  content: "\f0e9";
}
.fa-paste:before,
.fa-clipboard:before {
  content: "\f0ea";
}
.fa-lightbulb-o:before {
  content: "\f0eb";
}
.fa-exchange:before {
  content: "\f0ec";
}
.fa-cloud-download:before {
  content: "\f0ed";
}
.fa-cloud-upload:before {
  content: "\f0ee";
}
.fa-user-md:before {
  content: "\f0f0";
}
.fa-stethoscope:before {
  content: "\f0f1";
}
.fa-suitcase:before {
  content: "\f0f2";
}
.fa-bell-o:before {
  content: "\f0a2";
}
.fa-coffee:before {
  content: "\f0f4";
}
.fa-cutlery:before {
  content: "\f0f5";
}
.fa-file-text-o:before {
  content: "\f0f6";
}
.fa-building-o:before {
  content: "\f0f7";
}
.fa-hospital-o:before {
  content: "\f0f8";
}
.fa-ambulance:before {
  content: "\f0f9";
}
.fa-medkit:before {
  content: "\f0fa";
}
.fa-fighter-jet:before {
  content: "\f0fb";
}
.fa-beer:before {
  content: "\f0fc";
}
.fa-h-square:before {
  content: "\f0fd";
}
.fa-plus-square:before {
  content: "\f0fe";
}
.fa-angle-double-left:before {
  content: "\f100";
}
.fa-angle-double-right:before {
  content: "\f101";
}
.fa-angle-double-up:before {
  content: "\f102";
}
.fa-angle-double-down:before {
  content: "\f103";
}
.fa-angle-left:before {
  content: "\f104";
}
.fa-angle-right:before {
  content: "\f105";
}
.fa-angle-up:before {
  content: "\f106";
}
.fa-angle-down:before {
  content: "\f107";
}
.fa-desktop:before {
  content: "\f108";
}
.fa-laptop:before {
  content: "\f109";
}
.fa-tablet:before {
  content: "\f10a";
}
.fa-mobile-phone:before,
.fa-mobile:before {
  content: "\f10b";
}
.fa-circle-o:before {
  content: "\f10c";
}
.fa-quote-left:before {
  content: "\f10d";
}
.fa-quote-right:before {
  content: "\f10e";
}
.fa-spinner:before {
  content: "\f110";
}
.fa-circle:before {
  content: "\f111";
}
.fa-mail-reply:before,
.fa-reply:before {
  content: "\f112";
}
.fa-github-alt:before {
  content: "\f113";
}
.fa-folder-o:before {
  content: "\f114";
}
.fa-folder-open-o:before {
  content: "\f115";
}
.fa-smile-o:before {
  content: "\f118";
}
.fa-frown-o:before {
  content: "\f119";
}
.fa-meh-o:before {
  content: "\f11a";
}
.fa-gamepad:before {
  content: "\f11b";
}
.fa-keyboard-o:before {
  content: "\f11c";
}
.fa-flag-o:before {
  content: "\f11d";
}
.fa-flag-checkered:before {
  content: "\f11e";
}
.fa-terminal:before {
  content: "\f120";
}
.fa-code:before {
  content: "\f121";
}
.fa-mail-reply-all:before,
.fa-reply-all:before {
  content: "\f122";
}
.fa-star-half-empty:before,
.fa-star-half-full:before,
.fa-star-half-o:before {
  content: "\f123";
}
.fa-location-arrow:before {
  content: "\f124";
}
.fa-crop:before {
  content: "\f125";
}
.fa-code-fork:before {
  content: "\f126";
}
.fa-unlink:before,
.fa-chain-broken:before {
  content: "\f127";
}
.fa-question:before {
  content: "\f128";
}
.fa-info:before {
  content: "\f129";
}
.fa-exclamation:before {
  content: "\f12a";
}
.fa-superscript:before {
  content: "\f12b";
}
.fa-subscript:before {
  content: "\f12c";
}
.fa-eraser:before {
  content: "\f12d";
}
.fa-puzzle-piece:before {
  content: "\f12e";
}
.fa-microphone:before {
  content: "\f130";
}
.fa-microphone-slash:before {
  content: "\f131";
}
.fa-shield:before {
  content: "\f132";
}
.fa-calendar-o:before {
  content: "\f133";
}
.fa-fire-extinguisher:before {
  content: "\f134";
}
.fa-rocket:before {
  content: "\f135";
}
.fa-maxcdn:before {
  content: "\f136";
}
.fa-chevron-circle-left:before {
  content: "\f137";
}
.fa-chevron-circle-right:before {
  content: "\f138";
}
.fa-chevron-circle-up:before {
  content: "\f139";
}
.fa-chevron-circle-down:before {
  content: "\f13a";
}
.fa-html5:before {
  content: "\f13b";
}
.fa-css3:before {
  content: "\f13c";
}
.fa-anchor:before {
  content: "\f13d";
}
.fa-unlock-alt:before {
  content: "\f13e";
}
.fa-bullseye:before {
  content: "\f140";
}
.fa-ellipsis-h:before {
  content: "\f141";
}
.fa-ellipsis-v:before {
  content: "\f142";
}
.fa-rss-square:before {
  content: "\f143";
}
.fa-play-circle:before {
  content: "\f144";
}
.fa-ticket:before {
  content: "\f145";
}
.fa-minus-square:before {
  content: "\f146";
}
.fa-minus-square-o:before {
  content: "\f147";
}
.fa-level-up:before {
  content: "\f148";
}
.fa-level-down:before {
  content: "\f149";
}
.fa-check-square:before {
  content: "\f14a";
}
.fa-pencil-square:before {
  content: "\f14b";
}
.fa-external-link-square:before {
  content: "\f14c";
}
.fa-share-square:before {
  content: "\f14d";
}
.fa-compass:before {
  content: "\f14e";
}
.fa-toggle-down:before,
.fa-caret-square-o-down:before {
  content: "\f150";
}
.fa-toggle-up:before,
.fa-caret-square-o-up:before {
  content: "\f151";
}
.fa-toggle-right:before,
.fa-caret-square-o-right:before {
  content: "\f152";
}
.fa-euro:before,
.fa-eur:before {
  content: "\f153";
}
.fa-gbp:before {
  content: "\f154";
}
.fa-dollar:before,
.fa-usd:before {
  content: "\f155";
}
.fa-rupee:before,
.fa-inr:before {
  content: "\f156";
}
.fa-cny:before,
.fa-rmb:before,
.fa-yen:before,
.fa-jpy:before {
  content: "\f157";
}
.fa-ruble:before,
.fa-rouble:before,
.fa-rub:before {
  content: "\f158";
}
.fa-won:before,
.fa-krw:before {
  content: "\f159";
}
.fa-bitcoin:before,
.fa-btc:before {
  content: "\f15a";
}
.fa-file:before {
  content: "\f15b";
}
.fa-file-text:before {
  content: "\f15c";
}
.fa-sort-alpha-asc:before {
  content: "\f15d";
}
.fa-sort-alpha-desc:before {
  content: "\f15e";
}
.fa-sort-amount-asc:before {
  content: "\f160";
}
.fa-sort-amount-desc:before {
  content: "\f161";
}
.fa-sort-numeric-asc:before {
  content: "\f162";
}
.fa-sort-numeric-desc:before {
  content: "\f163";
}
.fa-thumbs-up:before {
  content: "\f164";
}
.fa-thumbs-down:before {
  content: "\f165";
}
.fa-youtube-square:before {
  content: "\f166";
}
.fa-youtube:before {
  content: "\f167";
}
.fa-xing:before {
  content: "\f168";
}
.fa-xing-square:before {
  content: "\f169";
}
.fa-youtube-play:before {
  content: "\f16a";
}
.fa-dropbox:before {
  content: "\f16b";
}
.fa-stack-overflow:before {
  content: "\f16c";
}
.fa-instagram:before {
  content: "\f16d";
}
.fa-flickr:before {
  content: "\f16e";
}
.fa-adn:before {
  content: "\f170";
}
.fa-bitbucket:before {
  content: "\f171";
}
.fa-bitbucket-square:before {
  content: "\f172";
}
.fa-tumblr:before {
  content: "\f173";
}
.fa-tumblr-square:before {
  content: "\f174";
}
.fa-long-arrow-down:before {
  content: "\f175";
}
.fa-long-arrow-up:before {
  content: "\f176";
}
.fa-long-arrow-left:before {
  content: "\f177";
}
.fa-long-arrow-right:before {
  content: "\f178";
}
.fa-apple:before {
  content: "\f179";
}
.fa-windows:before {
  content: "\f17a";
}
.fa-android:before {
  content: "\f17b";
}
.fa-linux:before {
  content: "\f17c";
}
.fa-dribbble:before {
  content: "\f17d";
}
.fa-skype:before {
  content: "\f17e";
}
.fa-foursquare:before {
  content: "\f180";
}
.fa-trello:before {
  content: "\f181";
}
.fa-female:before {
  content: "\f182";
}
.fa-male:before {
  content: "\f183";
}
.fa-gittip:before,
.fa-gratipay:before {
  content: "\f184";
}
.fa-sun-o:before {
  content: "\f185";
}
.fa-moon-o:before {
  content: "\f186";
}
.fa-archive:before {
  content: "\f187";
}
.fa-bug:before {
  content: "\f188";
}
.fa-vk:before {
  content: "\f189";
}
.fa-weibo:before {
  content: "\f18a";
}
.fa-renren:before {
  content: "\f18b";
}
.fa-pagelines:before {
  content: "\f18c";
}
.fa-stack-exchange:before {
  content: "\f18d";
}
.fa-arrow-circle-o-right:before {
  content: "\f18e";
}
.fa-arrow-circle-o-left:before {
  content: "\f190";
}
.fa-toggle-left:before,
.fa-caret-square-o-left:before {
  content: "\f191";
}
.fa-dot-circle-o:before {
  content: "\f192";
}
.fa-wheelchair:before {
  content: "\f193";
}
.fa-vimeo-square:before {
  content: "\f194";
}
.fa-turkish-lira:before,
.fa-try:before {
  content: "\f195";
}
.fa-plus-square-o:before {
  content: "\f196";
}
.fa-space-shuttle:before {
  content: "\f197";
}
.fa-slack:before {
  content: "\f198";
}
.fa-envelope-square:before {
  content: "\f199";
}
.fa-wordpress:before {
  content: "\f19a";
}
.fa-openid:before {
  content: "\f19b";
}
.fa-institution:before,
.fa-bank:before,
.fa-university:before {
  content: "\f19c";
}
.fa-mortar-board:before,
.fa-graduation-cap:before {
  content: "\f19d";
}
.fa-yahoo:before {
  content: "\f19e";
}
.fa-google:before {
  content: "\f1a0";
}
.fa-reddit:before {
  content: "\f1a1";
}
.fa-reddit-square:before {
  content: "\f1a2";
}
.fa-stumbleupon-circle:before {
  content: "\f1a3";
}
.fa-stumbleupon:before {
  content: "\f1a4";
}
.fa-delicious:before {
  content: "\f1a5";
}
.fa-digg:before {
  content: "\f1a6";
}
.fa-pied-piper-pp:before {
  content: "\f1a7";
}
.fa-pied-piper-alt:before {
  content: "\f1a8";
}
.fa-drupal:before {
  content: "\f1a9";
}
.fa-joomla:before {
  content: "\f1aa";
}
.fa-language:before {
  content: "\f1ab";
}
.fa-fax:before {
  content: "\f1ac";
}
.fa-building:before {
  content: "\f1ad";
}
.fa-child:before {
  content: "\f1ae";
}
.fa-paw:before {
  content: "\f1b0";
}
.fa-spoon:before {
  content: "\f1b1";
}
.fa-cube:before {
  content: "\f1b2";
}
.fa-cubes:before {
  content: "\f1b3";
}
.fa-behance:before {
  content: "\f1b4";
}
.fa-behance-square:before {
  content: "\f1b5";
}
.fa-steam:before {
  content: "\f1b6";
}
.fa-steam-square:before {
  content: "\f1b7";
}
.fa-recycle:before {
  content: "\f1b8";
}
.fa-automobile:before,
.fa-car:before {
  content: "\f1b9";
}
.fa-cab:before,
.fa-taxi:before {
  content: "\f1ba";
}
.fa-tree:before {
  content: "\f1bb";
}
.fa-spotify:before {
  content: "\f1bc";
}
.fa-deviantart:before {
  content: "\f1bd";
}
.fa-soundcloud:before {
  content: "\f1be";
}
.fa-database:before {
  content: "\f1c0";
}
.fa-file-pdf-o:before {
  content: "\f1c1";
}
.fa-file-word-o:before {
  content: "\f1c2";
}
.fa-file-excel-o:before {
  content: "\f1c3";
}
.fa-file-powerpoint-o:before {
  content: "\f1c4";
}
.fa-file-photo-o:before,
.fa-file-picture-o:before,
.fa-file-image-o:before {
  content: "\f1c5";
}
.fa-file-zip-o:before,
.fa-file-archive-o:before {
  content: "\f1c6";
}
.fa-file-sound-o:before,
.fa-file-audio-o:before {
  content: "\f1c7";
}
.fa-file-movie-o:before,
.fa-file-video-o:before {
  content: "\f1c8";
}
.fa-file-code-o:before {
  content: "\f1c9";
}
.fa-vine:before {
  content: "\f1ca";
}
.fa-codepen:before {
  content: "\f1cb";
}
.fa-jsfiddle:before {
  content: "\f1cc";
}
.fa-life-bouy:before,
.fa-life-buoy:before,
.fa-life-saver:before,
.fa-support:before,
.fa-life-ring:before {
  content: "\f1cd";
}
.fa-circle-o-notch:before {
  content: "\f1ce";
}
.fa-ra:before,
.fa-resistance:before,
.fa-rebel:before {
  content: "\f1d0";
}
.fa-ge:before,
.fa-empire:before {
  content: "\f1d1";
}
.fa-git-square:before {
  content: "\f1d2";
}
.fa-git:before {
  content: "\f1d3";
}
.fa-y-combinator-square:before,
.fa-yc-square:before,
.fa-hacker-news:before {
  content: "\f1d4";
}
.fa-tencent-weibo:before {
  content: "\f1d5";
}
.fa-qq:before {
  content: "\f1d6";
}
.fa-wechat:before,
.fa-weixin:before {
  content: "\f1d7";
}
.fa-send:before,
.fa-paper-plane:before {
  content: "\f1d8";
}
.fa-send-o:before,
.fa-paper-plane-o:before {
  content: "\f1d9";
}
.fa-history:before {
  content: "\f1da";
}
.fa-circle-thin:before {
  content: "\f1db";
}
.fa-header:before {
  content: "\f1dc";
}
.fa-paragraph:before {
  content: "\f1dd";
}
.fa-sliders:before {
  content: "\f1de";
}
.fa-share-alt:before {
  content: "\f1e0";
}
.fa-share-alt-square:before {
  content: "\f1e1";
}
.fa-bomb:before {
  content: "\f1e2";
}
.fa-soccer-ball-o:before,
.fa-futbol-o:before {
  content: "\f1e3";
}
.fa-tty:before {
  content: "\f1e4";
}
.fa-binoculars:before {
  content: "\f1e5";
}
.fa-plug:before {
  content: "\f1e6";
}
.fa-slideshare:before {
  content: "\f1e7";
}
.fa-twitch:before {
  content: "\f1e8";
}
.fa-yelp:before {
  content: "\f1e9";
}
.fa-newspaper-o:before {
  content: "\f1ea";
}
.fa-wifi:before {
  content: "\f1eb";
}
.fa-calculator:before {
  content: "\f1ec";
}
.fa-paypal:before {
  content: "\f1ed";
}
.fa-google-wallet:before {
  content: "\f1ee";
}
.fa-cc-visa:before {
  content: "\f1f0";
}
.fa-cc-mastercard:before {
  content: "\f1f1";
}
.fa-cc-discover:before {
  content: "\f1f2";
}
.fa-cc-amex:before {
  content: "\f1f3";
}
.fa-cc-paypal:before {
  content: "\f1f4";
}
.fa-cc-stripe:before {
  content: "\f1f5";
}
.fa-bell-slash:before {
  content: "\f1f6";
}
.fa-bell-slash-o:before {
  content: "\f1f7";
}
.fa-trash:before {
  content: "\f1f8";
}
.fa-copyright:before {
  content: "\f1f9";
}
.fa-at:before {
  content: "\f1fa";
}
.fa-eyedropper:before {
  content: "\f1fb";
}
.fa-paint-brush:before {
  content: "\f1fc";
}
.fa-birthday-cake:before {
  content: "\f1fd";
}
.fa-area-chart:before {
  content: "\f1fe";
}
.fa-pie-chart:before {
  content: "\f200";
}
.fa-line-chart:before {
  content: "\f201";
}
.fa-lastfm:before {
  content: "\f202";
}
.fa-lastfm-square:before {
  content: "\f203";
}
.fa-toggle-off:before {
  content: "\f204";
}
.fa-toggle-on:before {
  content: "\f205";
}
.fa-bicycle:before {
  content: "\f206";
}
.fa-bus:before {
  content: "\f207";
}
.fa-ioxhost:before {
  content: "\f208";
}
.fa-angellist:before {
  content: "\f209";
}
.fa-cc:before {
  content: "\f20a";
}
.fa-shekel:before,
.fa-sheqel:before,
.fa-ils:before {
  content: "\f20b";
}
.fa-meanpath:before {
  content: "\f20c";
}
.fa-buysellads:before {
  content: "\f20d";
}
.fa-connectdevelop:before {
  content: "\f20e";
}
.fa-dashcube:before {
  content: "\f210";
}
.fa-forumbee:before {
  content: "\f211";
}
.fa-leanpub:before {
  content: "\f212";
}
.fa-sellsy:before {
  content: "\f213";
}
.fa-shirtsinbulk:before {
  content: "\f214";
}
.fa-simplybuilt:before {
  content: "\f215";
}
.fa-skyatlas:before {
  content: "\f216";
}
.fa-cart-plus:before {
  content: "\f217";
}
.fa-cart-arrow-down:before {
  content: "\f218";
}
.fa-diamond:before {
  content: "\f219";
}
.fa-ship:before {
  content: "\f21a";
}
.fa-user-secret:before {
  content: "\f21b";
}
.fa-motorcycle:before {
  content: "\f21c";
}
.fa-street-view:before {
  content: "\f21d";
}
.fa-heartbeat:before {
  content: "\f21e";
}
.fa-venus:before {
  content: "\f221";
}
.fa-mars:before {
  content: "\f222";
}
.fa-mercury:before {
  content: "\f223";
}
.fa-intersex:before,
.fa-transgender:before {
  content: "\f224";
}
.fa-transgender-alt:before {
  content: "\f225";
}
.fa-venus-double:before {
  content: "\f226";
}
.fa-mars-double:before {
  content: "\f227";
}
.fa-venus-mars:before {
  content: "\f228";
}
.fa-mars-stroke:before {
  content: "\f229";
}
.fa-mars-stroke-v:before {
  content: "\f22a";
}
.fa-mars-stroke-h:before {
  content: "\f22b";
}
.fa-neuter:before {
  content: "\f22c";
}
.fa-genderless:before {
  content: "\f22d";
}
.fa-facebook-official:before {
  content: "\f230";
}
.fa-pinterest-p:before {
  content: "\f231";
}
.fa-whatsapp:before {
  content: "\f232";
}
.fa-server:before {
  content: "\f233";
}
.fa-user-plus:before {
  content: "\f234";
}
.fa-user-times:before {
  content: "\f235";
}
.fa-hotel:before,
.fa-bed:before {
  content: "\f236";
}
.fa-viacoin:before {
  content: "\f237";
}
.fa-train:before {
  content: "\f238";
}
.fa-subway:before {
  content: "\f239";
}
.fa-medium:before {
  content: "\f23a";
}
.fa-yc:before,
.fa-y-combinator:before {
  content: "\f23b";
}
.fa-optin-monster:before {
  content: "\f23c";
}
.fa-opencart:before {
  content: "\f23d";
}
.fa-expeditedssl:before {
  content: "\f23e";
}
.fa-battery-4:before,
.fa-battery:before,
.fa-battery-full:before {
  content: "\f240";
}
.fa-battery-3:before,
.fa-battery-three-quarters:before {
  content: "\f241";
}
.fa-battery-2:before,
.fa-battery-half:before {
  content: "\f242";
}
.fa-battery-1:before,
.fa-battery-quarter:before {
  content: "\f243";
}
.fa-battery-0:before,
.fa-battery-empty:before {
  content: "\f244";
}
.fa-mouse-pointer:before {
  content: "\f245";
}
.fa-i-cursor:before {
  content: "\f246";
}
.fa-object-group:before {
  content: "\f247";
}
.fa-object-ungroup:before {
  content: "\f248";
}
.fa-sticky-note:before {
  content: "\f249";
}
.fa-sticky-note-o:before {
  content: "\f24a";
}
.fa-cc-jcb:before {
  content: "\f24b";
}
.fa-cc-diners-club:before {
  content: "\f24c";
}
.fa-clone:before {
  content: "\f24d";
}
.fa-balance-scale:before {
  content: "\f24e";
}
.fa-hourglass-o:before {
  content: "\f250";
}
.fa-hourglass-1:before,
.fa-hourglass-start:before {
  content: "\f251";
}
.fa-hourglass-2:before,
.fa-hourglass-half:before {
  content: "\f252";
}
.fa-hourglass-3:before,
.fa-hourglass-end:before {
  content: "\f253";
}
.fa-hourglass:before {
  content: "\f254";
}
.fa-hand-grab-o:before,
.fa-hand-rock-o:before {
  content: "\f255";
}
.fa-hand-stop-o:before,
.fa-hand-paper-o:before {
  content: "\f256";
}
.fa-hand-scissors-o:before {
  content: "\f257";
}
.fa-hand-lizard-o:before {
  content: "\f258";
}
.fa-hand-spock-o:before {
  content: "\f259";
}
.fa-hand-pointer-o:before {
  content: "\f25a";
}
.fa-hand-peace-o:before {
  content: "\f25b";
}
.fa-trademark:before {
  content: "\f25c";
}
.fa-registered:before {
  content: "\f25d";
}
.fa-creative-commons:before {
  content: "\f25e";
}
.fa-gg:before {
  content: "\f260";
}
.fa-gg-circle:before {
  content: "\f261";
}
.fa-tripadvisor:before {
  content: "\f262";
}
.fa-odnoklassniki:before {
  content: "\f263";
}
.fa-odnoklassniki-square:before {
  content: "\f264";
}
.fa-get-pocket:before {
  content: "\f265";
}
.fa-wikipedia-w:before {
  content: "\f266";
}
.fa-safari:before {
  content: "\f267";
}
.fa-chrome:before {
  content: "\f268";
}
.fa-firefox:before {
  content: "\f269";
}
.fa-opera:before {
  content: "\f26a";
}
.fa-internet-explorer:before {
  content: "\f26b";
}
.fa-tv:before,
.fa-television:before {
  content: "\f26c";
}
.fa-contao:before {
  content: "\f26d";
}
.fa-500px:before {
  content: "\f26e";
}
.fa-amazon:before {
  content: "\f270";
}
.fa-calendar-plus-o:before {
  content: "\f271";
}
.fa-calendar-minus-o:before {
  content: "\f272";
}
.fa-calendar-times-o:before {
  content: "\f273";
}
.fa-calendar-check-o:before {
  content: "\f274";
}
.fa-industry:before {
  content: "\f275";
}
.fa-map-pin:before {
  content: "\f276";
}
.fa-map-signs:before {
  content: "\f277";
}
.fa-map-o:before {
  content: "\f278";
}
.fa-map:before {
  content: "\f279";
}
.fa-commenting:before {
  content: "\f27a";
}
.fa-commenting-o:before {
  content: "\f27b";
}
.fa-houzz:before {
  content: "\f27c";
}
.fa-vimeo:before {
  content: "\f27d";
}
.fa-black-tie:before {
  content: "\f27e";
}
.fa-fonticons:before {
  content: "\f280";
}
.fa-reddit-alien:before {
  content: "\f281";
}
.fa-edge:before {
  content: "\f282";
}
.fa-credit-card-alt:before {
  content: "\f283";
}
.fa-codiepie:before {
  content: "\f284";
}
.fa-modx:before {
  content: "\f285";
}
.fa-fort-awesome:before {
  content: "\f286";
}
.fa-usb:before {
  content: "\f287";
}
.fa-product-hunt:before {
  content: "\f288";
}
.fa-mixcloud:before {
  content: "\f289";
}
.fa-scribd:before {
  content: "\f28a";
}
.fa-pause-circle:before {
  content: "\f28b";
}
.fa-pause-circle-o:before {
  content: "\f28c";
}
.fa-stop-circle:before {
  content: "\f28d";
}
.fa-stop-circle-o:before {
  content: "\f28e";
}
.fa-shopping-bag:before {
  content: "\f290";
}
.fa-shopping-basket:before {
  content: "\f291";
}
.fa-hashtag:before {
  content: "\f292";
}
.fa-bluetooth:before {
  content: "\f293";
}
.fa-bluetooth-b:before {
  content: "\f294";
}
.fa-percent:before {
  content: "\f295";
}
.fa-gitlab:before {
  content: "\f296";
}
.fa-wpbeginner:before {
  content: "\f297";
}
.fa-wpforms:before {
  content: "\f298";
}
.fa-envira:before {
  content: "\f299";
}
.fa-universal-access:before {
  content: "\f29a";
}
.fa-wheelchair-alt:before {
  content: "\f29b";
}
.fa-question-circle-o:before {
  content: "\f29c";
}
.fa-blind:before {
  content: "\f29d";
}
.fa-audio-description:before {
  content: "\f29e";
}
.fa-volume-control-phone:before {
  content: "\f2a0";
}
.fa-braille:before {
  content: "\f2a1";
}
.fa-assistive-listening-systems:before {
  content: "\f2a2";
}
.fa-asl-interpreting:before,
.fa-american-sign-language-interpreting:before {
  content: "\f2a3";
}
.fa-deafness:before,
.fa-hard-of-hearing:before,
.fa-deaf:before {
  content: "\f2a4";
}
.fa-glide:before {
  content: "\f2a5";
}
.fa-glide-g:before {
  content: "\f2a6";
}
.fa-signing:before,
.fa-sign-language:before {
  content: "\f2a7";
}
.fa-low-vision:before {
  content: "\f2a8";
}
.fa-viadeo:before {
  content: "\f2a9";
}
.fa-viadeo-square:before {
  content: "\f2aa";
}
.fa-snapchat:before {
  content: "\f2ab";
}
.fa-snapchat-ghost:before {
  content: "\f2ac";
}
.fa-snapchat-square:before {
  content: "\f2ad";
}
.fa-pied-piper:before {
  content: "\f2ae";
}
.fa-first-order:before {
  content: "\f2b0";
}
.fa-yoast:before {
  content: "\f2b1";
}
.fa-themeisle:before {
  content: "\f2b2";
}
.fa-google-plus-circle:before,
.fa-google-plus-official:before {
  content: "\f2b3";
}
.fa-fa:before,
.fa-font-awesome:before {
  content: "\f2b4";
}
.fa-handshake-o:before {
  content: "\f2b5";
}
.fa-envelope-open:before {
  content: "\f2b6";
}
.fa-envelope-open-o:before {
  content: "\f2b7";
}
.fa-linode:before {
  content: "\f2b8";
}
.fa-address-book:before {
  content: "\f2b9";
}
.fa-address-book-o:before {
  content: "\f2ba";
}
.fa-vcard:before,
.fa-address-card:before {
  content: "\f2bb";
}
.fa-vcard-o:before,
.fa-address-card-o:before {
  content: "\f2bc";
}
.fa-user-circle:before {
  content: "\f2bd";
}
.fa-user-circle-o:before {
  content: "\f2be";
}
.fa-user-o:before {
  content: "\f2c0";
}
.fa-id-badge:before {
  content: "\f2c1";
}
.fa-drivers-license:before,
.fa-id-card:before {
  content: "\f2c2";
}
.fa-drivers-license-o:before,
.fa-id-card-o:before {
  content: "\f2c3";
}
.fa-quora:before {
  content: "\f2c4";
}
.fa-free-code-camp:before {
  content: "\f2c5";
}
.fa-telegram:before {
  content: "\f2c6";
}
.fa-thermometer-4:before,
.fa-thermometer:before,
.fa-thermometer-full:before {
  content: "\f2c7";
}
.fa-thermometer-3:before,
.fa-thermometer-three-quarters:before {
  content: "\f2c8";
}
.fa-thermometer-2:before,
.fa-thermometer-half:before {
  content: "\f2c9";
}
.fa-thermometer-1:before,
.fa-thermometer-quarter:before {
  content: "\f2ca";
}
.fa-thermometer-0:before,
.fa-thermometer-empty:before {
  content: "\f2cb";
}
.fa-shower:before {
  content: "\f2cc";
}
.fa-bathtub:before,
.fa-s15:before,
.fa-bath:before {
  content: "\f2cd";
}
.fa-podcast:before {
  content: "\f2ce";
}
.fa-window-maximize:before {
  content: "\f2d0";
}
.fa-window-minimize:before {
  content: "\f2d1";
}
.fa-window-restore:before {
  content: "\f2d2";
}
.fa-times-rectangle:before,
.fa-window-close:before {
  content: "\f2d3";
}
.fa-times-rectangle-o:before,
.fa-window-close-o:before {
  content: "\f2d4";
}
.fa-bandcamp:before {
  content: "\f2d5";
}
.fa-grav:before {
  content: "\f2d6";
}
.fa-etsy:before {
  content: "\f2d7";
}
.fa-imdb:before {
  content: "\f2d8";
}
.fa-ravelry:before {
  content: "\f2d9";
}
.fa-eercast:before {
  content: "\f2da";
}
.fa-microchip:before {
  content: "\f2db";
}
.fa-snowflake-o:before {
  content: "\f2dc";
}
.fa-superpowers:before {
  content: "\f2dd";
}
.fa-wpexplorer:before {
  content: "\f2de";
}
.fa-meetup:before {
  content: "\f2e0";
}
.sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}
.sr-only-focusable:active,
.sr-only-focusable:focus {
  position: static;
  width: auto;
  height: auto;
  margin: 0;
  overflow: visible;
  clip: auto;
}

.d-flex{display:-webkit-box !important;display:-ms-flexbox !important;display:flex !important}.d-inline-flex{display:-webkit-inline-box !important;display:-ms-inline-flexbox !important;display:inline-flex !important}.flex-row{-ms-flex-direction:row !important;flex-direction:row !important;-webkit-box-direction:normal !important;-webkit-box-orient:horizontal !important}.flex-column{-ms-flex-direction:column !important;flex-direction:column !important;-webkit-box-direction:normal !important;-webkit-box-orient:vertical !important}.flex-row-reverse{-ms-flex-direction:row-reverse !important;flex-direction:row-reverse !important;-webkit-box-direction:reverse !important;-webkit-box-orient:horizontal !important}.flex-column-reverse{-ms-flex-direction:column-reverse !important;flex-direction:column-reverse !important;-webkit-box-direction:reverse !important;-webkit-box-orient:vertical !important}.flex-wrap{-ms-flex-wrap:wrap !important;flex-wrap:wrap !important}.flex-nowrap{-ms-flex-wrap:nowrap !important;flex-wrap:nowrap !important}.flex-wrap-reverse{-ms-flex-wrap:wrap-reverse !important;flex-wrap:wrap-reverse !important}.justify-content-start{justify-content:flex-start !important;-webkit-box-pack:start !important;-ms-flex-pack:start !important}.justify-content-end{justify-content:flex-end !important;-webkit-box-pack:end !important;-ms-flex-pack:end !important}.justify-content-center{justify-content:center !important;-webkit-box-pack:center !important;-ms-flex-pack:center !important}.justify-content-between{justify-content:space-between !important;-webkit-box-pack:justify !important;-ms-flex-pack:justify !important}.justify-content-around{justify-content:space-around !important;-ms-flex-pack:distribute !important}.align-items-start{align-items:flex-start !important;-webkit-box-align:start !important;-ms-flex-align:start !important}.align-items-end{align-items:flex-end !important;-webkit-box-align:end !important;-ms-flex-align:end !important}.align-items-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.align-items-baseline{align-items:baseline !important;-webkit-box-align:baseline !important;-ms-flex-align:baseline !important}.align-items-stretch{align-items:stretch !important;-webkit-box-align:stretch !important;-ms-flex-align:stretch !important}.align-content-start{align-content:flex-start !important;-ms-flex-line-pack:start !important}.align-content-end{align-content:flex-end !important;-ms-flex-line-pack:end !important}.align-content-center{align-content:center !important;-ms-flex-line-pack:center !important}.align-content-between{align-content:space-between !important;-ms-flex-line-pack:justify !important}.align-content-around{align-content:space-around !important;-ms-flex-line-pack:distribute !important}.align-content-stretch{align-content:stretch !important;-ms-flex-line-pack:stretch !important}.align-self-auto{align-self:auto !important;-ms-flex-item-align:auto !important}.align-self-start{align-self:flex-start !important;-ms-flex-item-align:start !important}.align-self-end{align-self:flex-end !important;-ms-flex-item-align:end !important}.align-self-center{align-self:center !important;-ms-flex-item-align:center !important}.align-self-baseline{align-self:baseline !important;-ms-flex-item-align:baseline !important}.align-self-stretch{align-self:stretch !important;-ms-flex-item-align:stretch !important}@media(min-width: 576px){.flex-sm-row{-ms-flex-direction:row !important;flex-direction:row !important;-webkit-box-direction:normal !important;-webkit-box-orient:horizontal !important}.flex-sm-column{-ms-flex-direction:column !important;flex-direction:column !important;-webkit-box-direction:normal !important;-webkit-box-orient:vertical !important}.flex-sm-row-reverse{-ms-flex-direction:row-reverse !important;flex-direction:row-reverse !important;-webkit-box-direction:reverse !important;-webkit-box-orient:horizontal !important}.flex-sm-column-reverse{-ms-flex-direction:column-reverse !important;flex-direction:column-reverse !important;-webkit-box-direction:reverse !important;-webkit-box-orient:vertical !important}.flex-sm-wrap{-ms-flex-wrap:wrap !important;flex-wrap:wrap !important}.flex-sm-nowrap{-ms-flex-wrap:nowrap !important;flex-wrap:nowrap !important}.flex-sm-wrap-reverse{-ms-flex-wrap:wrap-reverse !important;flex-wrap:wrap-reverse !important}.justify-content-sm-start{justify-content:flex-start !important;-webkit-box-pack:start !important;-ms-flex-pack:start !important}.justify-content-sm-end{justify-content:flex-end !important;-webkit-box-pack:end !important;-ms-flex-pack:end !important}.justify-content-sm-center{justify-content:center !important;-webkit-box-pack:center !important;-ms-flex-pack:center !important}.justify-content-sm-between{justify-content:space-between !important;-webkit-box-pack:justify !important;-ms-flex-pack:justify !important}.justify-content-sm-around{justify-content:space-around !important;-ms-flex-pack:distribute !important}.align-items-sm-start{align-items:flex-start !important;-webkit-box-align:start !important;-ms-flex-align:start !important}.align-items-sm-end{align-items:flex-end !important;-webkit-box-align:end !important;-ms-flex-align:end !important}.align-items-sm-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.align-items-sm-baseline{align-items:baseline !important;-webkit-box-align:baseline !important;-ms-flex-align:baseline !important}.align-items-sm-stretch{align-items:stretch !important;-webkit-box-align:stretch !important;-ms-flex-align:stretch !important}.align-content-sm-start{align-content:flex-start !important;-ms-flex-line-pack:start !important}.align-content-sm-end{align-content:flex-end !important;-ms-flex-line-pack:end !important}.align-content-sm-center{align-content:center !important;-ms-flex-line-pack:center !important}.align-content-sm-between{align-content:space-between !important;-ms-flex-line-pack:justify !important}.align-content-sm-around{align-content:space-around !important;-ms-flex-line-pack:distribute !important}.align-content-sm-stretch{align-content:stretch !important;-ms-flex-line-pack:stretch !important}.align-self-sm-auto{align-self:auto !important;-ms-flex-item-align:auto !important}.align-self-sm-start{align-self:flex-start !important;-ms-flex-item-align:start !important}.align-self-sm-end{align-self:flex-end !important;-ms-flex-item-align:end !important}.align-self-sm-center{align-self:center !important;-ms-flex-item-align:center !important}.align-self-sm-baseline{align-self:baseline !important;-ms-flex-item-align:baseline !important}.align-self-sm-stretch{align-self:stretch !important;-ms-flex-item-align:stretch !important}}@media(min-width: 768px){.flex-md-row{-ms-flex-direction:row !important;flex-direction:row !important;-webkit-box-direction:normal !important;-webkit-box-orient:horizontal !important}.flex-md-column{-ms-flex-direction:column !important;flex-direction:column !important;-webkit-box-direction:normal !important;-webkit-box-orient:vertical !important}.flex-md-row-reverse{-ms-flex-direction:row-reverse !important;flex-direction:row-reverse !important;-webkit-box-direction:reverse !important;-webkit-box-orient:horizontal !important}.flex-md-column-reverse{-ms-flex-direction:column-reverse !important;flex-direction:column-reverse !important;-webkit-box-direction:reverse !important;-webkit-box-orient:vertical !important}.flex-md-wrap{-ms-flex-wrap:wrap !important;flex-wrap:wrap !important}.flex-md-nowrap{-ms-flex-wrap:nowrap !important;flex-wrap:nowrap !important}.flex-md-wrap-reverse{-ms-flex-wrap:wrap-reverse !important;flex-wrap:wrap-reverse !important}.justify-content-md-start{justify-content:flex-start !important;-webkit-box-pack:start !important;-ms-flex-pack:start !important}.justify-content-md-end{justify-content:flex-end !important;-webkit-box-pack:end !important;-ms-flex-pack:end !important}.justify-content-md-center{justify-content:center !important;-webkit-box-pack:center !important;-ms-flex-pack:center !important}.justify-content-md-between{justify-content:space-between !important;-webkit-box-pack:justify !important;-ms-flex-pack:justify !important}.justify-content-md-around{justify-content:space-around !important;-ms-flex-pack:distribute !important}.align-items-md-start{align-items:flex-start !important;-webkit-box-align:start !important;-ms-flex-align:start !important}.align-items-md-end{align-items:flex-end !important;-webkit-box-align:end !important;-ms-flex-align:end !important}.align-items-md-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.align-items-md-baseline{align-items:baseline !important;-webkit-box-align:baseline !important;-ms-flex-align:baseline !important}.align-items-md-stretch{align-items:stretch !important;-webkit-box-align:stretch !important;-ms-flex-align:stretch !important}.align-content-md-start{align-content:flex-start !important;-ms-flex-line-pack:start !important}.align-content-md-end{align-content:flex-end !important;-ms-flex-line-pack:end !important}.align-content-md-center{align-content:center !important;-ms-flex-line-pack:center !important}.align-content-md-between{align-content:space-between !important;-ms-flex-line-pack:justify !important}.align-content-md-around{align-content:space-around !important;-ms-flex-line-pack:distribute !important}.align-content-md-stretch{align-content:stretch !important;-ms-flex-line-pack:stretch !important}.align-self-md-auto{align-self:auto !important;-ms-flex-item-align:auto !important}.align-self-md-start{align-self:flex-start !important;-ms-flex-item-align:start !important}.align-self-md-end{align-self:flex-end !important;-ms-flex-item-align:end !important}.align-self-md-center{align-self:center !important;-ms-flex-item-align:center !important}.align-self-md-baseline{align-self:baseline !important;-ms-flex-item-align:baseline !important}.align-self-md-stretch{align-self:stretch !important;-ms-flex-item-align:stretch !important}}@media(min-width: 992px){.flex-lg-row{-ms-flex-direction:row !important;flex-direction:row !important;-webkit-box-direction:normal !important;-webkit-box-orient:horizontal !important}.flex-lg-column{-ms-flex-direction:column !important;flex-direction:column !important;-webkit-box-direction:normal !important;-webkit-box-orient:vertical !important}.flex-lg-row-reverse{-ms-flex-direction:row-reverse !important;flex-direction:row-reverse !important;-webkit-box-direction:reverse !important;-webkit-box-orient:horizontal !important}.flex-lg-column-reverse{-ms-flex-direction:column-reverse !important;flex-direction:column-reverse !important;-webkit-box-direction:reverse !important;-webkit-box-orient:vertical !important}.flex-lg-wrap{-ms-flex-wrap:wrap !important;flex-wrap:wrap !important}.flex-lg-nowrap{-ms-flex-wrap:nowrap !important;flex-wrap:nowrap !important}.flex-lg-wrap-reverse{-ms-flex-wrap:wrap-reverse !important;flex-wrap:wrap-reverse !important}.justify-content-lg-start{justify-content:flex-start !important;-webkit-box-pack:start !important;-ms-flex-pack:start !important}.justify-content-lg-end{justify-content:flex-end !important;-webkit-box-pack:end !important;-ms-flex-pack:end !important}.justify-content-lg-center{justify-content:center !important;-webkit-box-pack:center !important;-ms-flex-pack:center !important}.justify-content-lg-between{justify-content:space-between !important;-webkit-box-pack:justify !important;-ms-flex-pack:justify !important}.justify-content-lg-around{justify-content:space-around !important;-ms-flex-pack:distribute !important}.align-items-lg-start{align-items:flex-start !important;-webkit-box-align:start !important;-ms-flex-align:start !important}.align-items-lg-end{align-items:flex-end !important;-webkit-box-align:end !important;-ms-flex-align:end !important}.align-items-lg-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.align-items-lg-baseline{align-items:baseline !important;-webkit-box-align:baseline !important;-ms-flex-align:baseline !important}.align-items-lg-stretch{align-items:stretch !important;-webkit-box-align:stretch !important;-ms-flex-align:stretch !important}.align-content-lg-start{align-content:flex-start !important;-ms-flex-line-pack:start !important}.align-content-lg-end{align-content:flex-end !important;-ms-flex-line-pack:end !important}.align-content-lg-center{align-content:center !important;-ms-flex-line-pack:center !important}.align-content-lg-between{align-content:space-between !important;-ms-flex-line-pack:justify !important}.align-content-lg-around{align-content:space-around !important;-ms-flex-line-pack:distribute !important}.align-content-lg-stretch{align-content:stretch !important;-ms-flex-line-pack:stretch !important}.align-self-lg-auto{align-self:auto !important;-ms-flex-item-align:auto !important}.align-self-lg-start{align-self:flex-start !important;-ms-flex-item-align:start !important}.align-self-lg-end{align-self:flex-end !important;-ms-flex-item-align:end !important}.align-self-lg-center{align-self:center !important;-ms-flex-item-align:center !important}.align-self-lg-baseline{align-self:baseline !important;-ms-flex-item-align:baseline !important}.align-self-lg-stretch{align-self:stretch !important;-ms-flex-item-align:stretch !important}}@media(min-width: 1200px){.flex-xl-row{-ms-flex-direction:row !important;flex-direction:row !important;-webkit-box-direction:normal !important;-webkit-box-orient:horizontal !important}.flex-xl-column{-ms-flex-direction:column !important;flex-direction:column !important;-webkit-box-direction:normal !important;-webkit-box-orient:vertical !important}.flex-xl-row-reverse{-ms-flex-direction:row-reverse !important;flex-direction:row-reverse !important;-webkit-box-direction:reverse !important;-webkit-box-orient:horizontal !important}.flex-xl-column-reverse{-ms-flex-direction:column-reverse !important;flex-direction:column-reverse !important;-webkit-box-direction:reverse !important;-webkit-box-orient:vertical !important}.flex-xl-wrap{-ms-flex-wrap:wrap !important;flex-wrap:wrap !important}.flex-xl-nowrap{-ms-flex-wrap:nowrap !important;flex-wrap:nowrap !important}.flex-xl-wrap-reverse{-ms-flex-wrap:wrap-reverse !important;flex-wrap:wrap-reverse !important}.justify-content-xl-start{justify-content:flex-start !important;-webkit-box-pack:start !important;-ms-flex-pack:start !important}.justify-content-xl-end{justify-content:flex-end !important;-webkit-box-pack:end !important;-ms-flex-pack:end !important}.justify-content-xl-center{justify-content:center !important;-webkit-box-pack:center !important;-ms-flex-pack:center !important}.justify-content-xl-between{justify-content:space-between !important;-webkit-box-pack:justify !important;-ms-flex-pack:justify !important}.justify-content-xl-around{justify-content:space-around !important;-ms-flex-pack:distribute !important}.align-items-xl-start{align-items:flex-start !important;-webkit-box-align:start !important;-ms-flex-align:start !important}.align-items-xl-end{align-items:flex-end !important;-webkit-box-align:end !important;-ms-flex-align:end !important}.align-items-xl-center{align-items:center !important;-webkit-box-align:center !important;-ms-flex-align:center !important}.align-items-xl-baseline{align-items:baseline !important;-webkit-box-align:baseline !important;-ms-flex-align:baseline !important}.align-items-xl-stretch{align-items:stretch !important;-webkit-box-align:stretch !important;-ms-flex-align:stretch !important}.align-content-xl-start{align-content:flex-start !important;-ms-flex-line-pack:start !important}.align-content-xl-end{align-content:flex-end !important;-ms-flex-line-pack:end !important}.align-content-xl-center{align-content:center !important;-ms-flex-line-pack:center !important}.align-content-xl-between{align-content:space-between !important;-ms-flex-line-pack:justify !important}.align-content-xl-around{align-content:space-around !important;-ms-flex-line-pack:distribute !important}.align-content-xl-stretch{align-content:stretch !important;-ms-flex-line-pack:stretch !important}.align-self-xl-auto{align-self:auto !important;-ms-flex-item-align:auto !important}.align-self-xl-start{align-self:flex-start !important;-ms-flex-item-align:start !important}.align-self-xl-end{align-self:flex-end !important;-ms-flex-item-align:end !important}.align-self-xl-center{align-self:center !important;-ms-flex-item-align:center !important}.align-self-xl-baseline{align-self:baseline !important;-ms-flex-item-align:baseline !important}.align-self-xl-stretch{align-self:stretch !important;-ms-flex-item-align:stretch !important}}.col{max-width:100%;flex-basis:0;flex-grow:1;-ms-flex-positive:1;-ms-flex-preferred-size:0}.col-auto{width:auto;max-width:100%;-ms-flex:0 0 auto;flex:0 0 auto}.integration-option:hover{box-shadow:rgba(0,0,0,.1) 0 1px 16px}.signup-team__container .has-error .control-label::before{display:inline-block;font:normal normal normal 14px/1 FontAwesome;font-size:inherit;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:auto;transform:translate(0, 0)}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}@keyframes spin{from{transform:scale(1) rotate(0deg)}to{transform:scale(1) rotate(360deg)}}@keyframes highlight{from{background:rgba(255,255,0,.5)}to{background:none}}@keyframes fadeInOpacity{0%{opacity:0}100%{opacity:1}}.pt-0{padding-top:0px !important}.pb-0{padding-bottom:0px !important}.pl-0{padding-left:0px !important}.pr-0{padding-right:0px !important}.mt-0{margin-top:0px !important}.mb-0{margin-bottom:0px !important}.ml-0{margin-left:0px !important}.mr-0{margin-right:0px !important}.m-0{margin:0px !important}.p-0{padding:0px !important}.px-0{padding:0 0px 0 0px !important}.py-0{padding:0px 0 0px 0 !important}.h-0{height:0px !important}.pt-1{padding-top:4px !important}.pb-1{padding-bottom:4px !important}.pl-1{padding-left:4px !important}.pr-1{padding-right:4px !important}.mt-1{margin-top:4px !important}.mb-1{margin-bottom:4px !important}.ml-1{margin-left:4px !important}.mr-1{margin-right:4px !important}.m-1{margin:4px !important}.p-1{padding:4px !important}.px-1{padding:0 4px 0 4px !important}.py-1{padding:4px 0 4px 0 !important}.h-1{height:4px !important}.pt-2{padding-top:8px !important}.pb-2{padding-bottom:8px !important}.pl-2{padding-left:8px !important}.pr-2{padding-right:8px !important}.mt-2{margin-top:8px !important}.mb-2{margin-bottom:8px !important}.ml-2{margin-left:8px !important}.mr-2{margin-right:8px !important}.m-2{margin:8px !important}.p-2{padding:8px !important}.px-2{padding:0 8px 0 8px !important}.py-2{padding:8px 0 8px 0 !important}.h-2{height:8px !important}.pt-3{padding-top:12px !important}.pb-3{padding-bottom:12px !important}.pl-3{padding-left:12px !important}.pr-3{padding-right:12px !important}.mt-3{margin-top:12px !important}.mb-3{margin-bottom:12px !important}.ml-3{margin-left:12px !important}.mr-3{margin-right:12px !important}.m-3{margin:12px !important}.p-3{padding:12px !important}.px-3{padding:0 12px 0 12px !important}.py-3{padding:12px 0 12px 0 !important}.h-3{height:12px !important}.pt-4{padding-top:16px !important}.pb-4{padding-bottom:16px !important}.pl-4{padding-left:16px !important}.pr-4{padding-right:16px !important}.mt-4{margin-top:16px !important}.mb-4{margin-bottom:16px !important}.ml-4{margin-left:16px !important}.mr-4{margin-right:16px !important}.m-4{margin:16px !important}.p-4{padding:16px !important}.px-4{padding:0 16px 0 16px !important}.py-4{padding:16px 0 16px 0 !important}.h-4{height:16px !important}.pt-5{padding-top:20px !important}.pb-5{padding-bottom:20px !important}.pl-5{padding-left:20px !important}.pr-5{padding-right:20px !important}.mt-5{margin-top:20px !important}.mb-5{margin-bottom:20px !important}.ml-5{margin-left:20px !important}.mr-5{margin-right:20px !important}.m-5{margin:20px !important}.p-5{padding:20px !important}.px-5{padding:0 20px 0 20px !important}.py-5{padding:20px 0 20px 0 !important}.h-5{height:20px !important}.pt-6{padding-top:24px !important}.pb-6{padding-bottom:24px !important}.pl-6{padding-left:24px !important}.pr-6{padding-right:24px !important}.mt-6{margin-top:24px !important}.mb-6{margin-bottom:24px !important}.ml-6{margin-left:24px !important}.mr-6{margin-right:24px !important}.m-6{margin:24px !important}.p-6{padding:24px !important}.px-6{padding:0 24px 0 24px !important}.py-6{padding:24px 0 24px 0 !important}.h-6{height:24px !important}.pt-7{padding-top:28px !important}.pb-7{padding-bottom:28px !important}.pl-7{padding-left:28px !important}.pr-7{padding-right:28px !important}.mt-7{margin-top:28px !important}.mb-7{margin-bottom:28px !important}.ml-7{margin-left:28px !important}.mr-7{margin-right:28px !important}.m-7{margin:28px !important}.p-7{padding:28px !important}.px-7{padding:0 28px 0 28px !important}.py-7{padding:28px 0 28px 0 !important}.h-7{height:28px !important}.pt-8{padding-top:32px !important}.pb-8{padding-bottom:32px !important}.pl-8{padding-left:32px !important}.pr-8{padding-right:32px !important}.mt-8{margin-top:32px !important}.mb-8{margin-bottom:32px !important}.ml-8{margin-left:32px !important}.mr-8{margin-right:32px !important}.m-8{margin:32px !important}.p-8{padding:32px !important}.px-8{padding:0 32px 0 32px !important}.py-8{padding:32px 0 32px 0 !important}.h-8{height:32px !important}.pt-9{padding-top:36px !important}.pb-9{padding-bottom:36px !important}.pl-9{padding-left:36px !important}.pr-9{padding-right:36px !important}.mt-9{margin-top:36px !important}.mb-9{margin-bottom:36px !important}.ml-9{margin-left:36px !important}.mr-9{margin-right:36px !important}.m-9{margin:36px !important}.p-9{padding:36px !important}.px-9{padding:0 36px 0 36px !important}.py-9{padding:36px 0 36px 0 !important}.h-9{height:36px !important}.pt-10{padding-top:40px !important}.pb-10{padding-bottom:40px !important}.pl-10{padding-left:40px !important}.pr-10{padding-right:40px !important}.mt-10{margin-top:40px !important}.mb-10{margin-bottom:40px !important}.ml-10{margin-left:40px !important}.mr-10{margin-right:40px !important}.m-10{margin:40px !important}.p-10{padding:40px !important}.px-10{padding:0 40px 0 40px !important}.py-10{padding:40px 0 40px 0 !important}.h-10{height:40px !important}.pt-11{padding-top:44px !important}.pb-11{padding-bottom:44px !important}.pl-11{padding-left:44px !important}.pr-11{padding-right:44px !important}.mt-11{margin-top:44px !important}.mb-11{margin-bottom:44px !important}.ml-11{margin-left:44px !important}.mr-11{margin-right:44px !important}.m-11{margin:44px !important}.p-11{padding:44px !important}.px-11{padding:0 44px 0 44px !important}.py-11{padding:44px 0 44px 0 !important}.h-11{height:44px !important}.pt-12{padding-top:48px !important}.pb-12{padding-bottom:48px !important}.pl-12{padding-left:48px !important}.pr-12{padding-right:48px !important}.mt-12{margin-top:48px !important}.mb-12{margin-bottom:48px !important}.ml-12{margin-left:48px !important}.mr-12{margin-right:48px !important}.m-12{margin:48px !important}.p-12{padding:48px !important}.px-12{padding:0 48px 0 48px !important}.py-12{padding:48px 0 48px 0 !important}.h-12{height:48px !important}.pt-13{padding-top:52px !important}.pb-13{padding-bottom:52px !important}.pl-13{padding-left:52px !important}.pr-13{padding-right:52px !important}.mt-13{margin-top:52px !important}.mb-13{margin-bottom:52px !important}.ml-13{margin-left:52px !important}.mr-13{margin-right:52px !important}.m-13{margin:52px !important}.p-13{padding:52px !important}.px-13{padding:0 52px 0 52px !important}.py-13{padding:52px 0 52px 0 !important}.h-13{height:52px !important}.pt-14{padding-top:56px !important}.pb-14{padding-bottom:56px !important}.pl-14{padding-left:56px !important}.pr-14{padding-right:56px !important}.mt-14{margin-top:56px !important}.mb-14{margin-bottom:56px !important}.ml-14{margin-left:56px !important}.mr-14{margin-right:56px !important}.m-14{margin:56px !important}.p-14{padding:56px !important}.px-14{padding:0 56px 0 56px !important}.py-14{padding:56px 0 56px 0 !important}.h-14{height:56px !important}.pt-15{padding-top:60px !important}.pb-15{padding-bottom:60px !important}.pl-15{padding-left:60px !important}.pr-15{padding-right:60px !important}.mt-15{margin-top:60px !important}.mb-15{margin-bottom:60px !important}.ml-15{margin-left:60px !important}.mr-15{margin-right:60px !important}.m-15{margin:60px !important}.p-15{padding:60px !important}.px-15{padding:0 60px 0 60px !important}.py-15{padding:60px 0 60px 0 !important}.h-15{height:60px !important}.pt-16{padding-top:64px !important}.pb-16{padding-bottom:64px !important}.pl-16{padding-left:64px !important}.pr-16{padding-right:64px !important}.mt-16{margin-top:64px !important}.mb-16{margin-bottom:64px !important}.ml-16{margin-left:64px !important}.mr-16{margin-right:64px !important}.m-16{margin:64px !important}.p-16{padding:64px !important}.px-16{padding:0 64px 0 64px !important}.py-16{padding:64px 0 64px 0 !important}.h-16{height:64px !important}.pt-17{padding-top:68px !important}.pb-17{padding-bottom:68px !important}.pl-17{padding-left:68px !important}.pr-17{padding-right:68px !important}.mt-17{margin-top:68px !important}.mb-17{margin-bottom:68px !important}.ml-17{margin-left:68px !important}.mr-17{margin-right:68px !important}.m-17{margin:68px !important}.p-17{padding:68px !important}.px-17{padding:0 68px 0 68px !important}.py-17{padding:68px 0 68px 0 !important}.h-17{height:68px !important}.pt-18{padding-top:72px !important}.pb-18{padding-bottom:72px !important}.pl-18{padding-left:72px !important}.pr-18{padding-right:72px !important}.mt-18{margin-top:72px !important}.mb-18{margin-bottom:72px !important}.ml-18{margin-left:72px !important}.mr-18{margin-right:72px !important}.m-18{margin:72px !important}.p-18{padding:72px !important}.px-18{padding:0 72px 0 72px !important}.py-18{padding:72px 0 72px 0 !important}.h-18{height:72px !important}.pt-19{padding-top:76px !important}.pb-19{padding-bottom:76px !important}.pl-19{padding-left:76px !important}.pr-19{padding-right:76px !important}.mt-19{margin-top:76px !important}.mb-19{margin-bottom:76px !important}.ml-19{margin-left:76px !important}.mr-19{margin-right:76px !important}.m-19{margin:76px !important}.p-19{padding:76px !important}.px-19{padding:0 76px 0 76px !important}.py-19{padding:76px 0 76px 0 !important}.h-19{height:76px !important}.pt-20{padding-top:80px !important}.pb-20{padding-bottom:80px !important}.pl-20{padding-left:80px !important}.pr-20{padding-right:80px !important}.mt-20{margin-top:80px !important}.mb-20{margin-bottom:80px !important}.ml-20{margin-left:80px !important}.mr-20{margin-right:80px !important}.m-20{margin:80px !important}.p-20{padding:80px !important}.px-20{padding:0 80px 0 80px !important}.py-20{padding:80px 0 80px 0 !important}.h-20{height:80px !important}.d-block{display:block}.w-full{width:100%}.a11y--focused{border-radius:4px;box-shadow:0 0 1px 3px rgba(var(--link-color-rgb), 0.5),0 0 0 1px var(--link-color)}.pos-relative{position:relative}.hidden-label{position:absolute;overflow:hidden;width:1px;height:1px;padding:0;border:0;margin:-1px}.overflow--visible{overflow:visible}.bg--white{background:var(--center-channel-bg)}b,strong{font-weight:600}a{color:#166de0;cursor:pointer;text-decoration:none;word-break:break-word}a:focus,a:hover{color:#1156b2}.color--link{color:#2389d7;cursor:pointer}.color--link:hover,.color--link:focus{text-decoration:underline}body{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;font-family:"Open Sans",sans-serif}h1,h2,h3{font-family:Metropolis,sans-serif}h1{font-weight:600}.is-empty:empty{display:none}label.has-error{color:#d64946;font-weight:normal}.small{font-size:12px}.light{opacity:.56}.word-break--all{word-break:break-all}.whitespace--nowrap{white-space:nowrap}.whitespace--normal{white-space:normal}.overflow--ellipsis{overflow:hidden;text-overflow:ellipsis}ul,ol{padding-left:22px;margin-top:3px;margin-bottom:.11em}.fa.fa-1x{font-size:1.6rem}.font-weight--normal{font-weight:normal}.font-weight--semibold{font-weight:600}.cursor--pointer{cursor:pointer}@font-face{font-family:"Metropolis";font-style:normal;font-weight:600;src:url(/static/files/2958b47a121a8bd748c4605ce1f27097.woff) format("woff")}@font-face{font-family:"Metropolis";font-style:italic;font-weight:600;src:url(/static/files/86cf650fecf6c2bd8407d172ac0076ad.woff) format("woff")}@font-face{font-family:"Metropolis";font-style:normal;font-weight:400;src:url(/static/files/96bef01ba855a3b50904c906fd756133.woff) format("woff")}@font-face{font-family:"Metropolis";font-style:italic;font-weight:400;src:url(/static/files/6bf17d5beba5f18915c70ac17a870d38.woff) format("woff")}@font-face{font-family:"Metropolis";font-style:normal;font-weight:300;src:url(/static/files/3ccd9c3c74e5378d3961cde7504282b8.woff) format("woff")}@font-face{font-family:"Metropolis";font-style:italic;font-weight:300;src:url(/static/files/71ff9ed7909b8a4a57f7bcbd38d27866.woff) format("woff")}@font-face{font-family:"Open Sans";font-style:normal;font-weight:300;src:local(""),url(/static/files/d9ac1f0a85b42d5d4994256e44c51b1a.woff2) format("woff2"),url(/static/files/6a4927c0ce25f392d35edb25581398da.woff) format("woff")}@font-face{font-family:"Open Sans";font-style:italic;font-weight:300;src:local(""),url(/static/files/54b675363a5ef754113866bf0d5456df.woff2) format("woff2"),url(/static/files/72b8660cf48de307357526d68a32250e.woff) format("woff")}@font-face{font-family:"Open Sans";font-style:normal;font-weight:400;src:local(""),url(/static/files/3bd5f5c5dd54ccb0c7c26a01c3e99235.woff2) format("woff2"),url(/static/files/4f2cda059485c5f324fa636221498084.woff) format("woff")}@font-face{font-family:"Open Sans";font-style:italic;font-weight:400;src:local(""),url(/static/files/8a6c1879e3f4a4355b2e1676a9dc49ea.woff2) format("woff2"),url(/static/files/b2f7fa8bb26a2699b579d3eabbe950c8.woff) format("woff")}@font-face{font-family:"Open Sans";font-style:italic;font-weight:600;src:local(""),url(/static/files/2f6dbcfa410b96ca2a35ff27cc7f5e2a.woff2) format("woff2"),url(/static/files/46dadbd80fa9043a992a9d2b5bbd0dae.woff) format("woff")}@font-face{font-family:"Open Sans";font-style:normal;font-weight:600;src:local(""),url(/static/files/3c9c38b500586f2d033d6cc1055e45fb.woff2) format("woff2"),url(/static/files/6dc56ac51990a4e17b7452426c0218c8.woff) format("woff")}.app__body.font--open_sans{font-family:"Open Sans",sans-serif}.app__body h1,.app__body h2,.app__body h3{font-family:Metropolis,sans-serif}.color--link--adminack{padding-left:20px;color:#fff;cursor:pointer;text-decoration:underline}.color--link--adminack:hover,.color--link--adminack:focus{text-decoration:underline}html,body{height:100%}body{position:relative;width:100%;background:#f5f5f5}body.announcement-bar--fixed{padding-top:40px}body.sticky .container-fluid{overflow:auto;-webkit-overflow-scrolling:touch}body.admin-onboarding{background-image:url(/static/files/f7af6d2f96be0d3c4f19b943879a71f9.jpg);background-position:50%;background-repeat:no-repeat;background-size:cover}*:focus{outline:none}.sticky{background:#fff}.sticky>.channel-view{overflow:auto;height:100vh;padding:0 15px}.sticky .inner-wrap{width:100%}.sticky .inner-wrap>.row.content{min-height:calc(100vh - 89px)}@media(max-width: 768px){.sticky .inner-wrap>.row.content{min-height:calc(100vh - 187px)}}.help-page{overflow:hidden;padding:3em 0}.inner-wrap{height:100%}.inner-wrap.sticky{overflow:auto}.inner-wrap>.row.main{position:relative;height:100%}.container-fluid{*zoom:1;position:relative;height:100%}.container-fluid::after{display:table;clear:both;content:""}.channel-view{overflow:hidden;*zoom:1;position:relative;height:100%}.channel-view #root{display:flex;flex-direction:column}#channel_view.channel-view{background:var(--center-channel-bg)}img{max-width:100%}:root{--away-indicator: #ffbc42;--away-indicator-dark: #c79e3f;--button-bg: #166de0;--button-color: #fff;--center-channel-bg: #fff;--center-channel-color: #3d3c40;--dnd-indicator: #d24b4e;--error-text: #d24b4e;--link-color: #2389d7;--mention-bg: #fff;--mention-color: #145dbf;--mention-highlight-bg: #ffe577;--mention-highlight-link: #166de0;--new-message-separator: #f80;--online-indicator: #06d6a0;--sidebar-bg: #145dbf;--sidebar-header-bg: #1153ab;--sidebar-header-text-color: #fff;--sidebar-text: #fff;--sidebar-text-active-border: #579eff;--sidebar-text-active-color: #fff;--sidebar-text-hover-bg: #4578bf;--sidebar-unread-text: #fff;--sidebar-team-background: #0b428c;--secondary-blue: #22406d;--denim-button-bg: #1c58d9;--denim-status-online: #3db887;--denim-sidebar-active-border: #5d89ea;--center-channel-text: #3f4350;--title-color-indigo-500: #1e325c;--away-indicator-rgb: 255, 188, 66;--button-bg-rgb: 22, 109, 224;--button-color-rgb: 255, 255, 255;--center-channel-bg-rgb: 255, 255, 255;--center-channel-color-rgb: 61, 60, 64;--dnd-indicator-rgb: 247, 67, 67;--error-text-color-rgb: 253, 89, 96;--link-color-rgb: 35, 137, 215;--mention-bg-rgb: 255, 255, 255;--mention-color-rgb: 20, 93, 191;--mention-highlight-bg-rgb: 255, 229, 119;--mention-highlight-link-rgb: 22, 109, 224;--new-message-separator-rgb: 255, 136, 0;--online-indicator-rgb: 6, 214, 160;--sidebar-bg-rgb: 20, 93, 191;--sidebar-header-bg-rgb: 17, 83, 171;--sidebar-header-text-color-rgb: 255, 255, 255;--sidebar-text-rgb: 255, 255, 255;--sidebar-text-active-border-rgb: 87, 158, 255;--sidebar-text-active-color-rgb: 255, 255, 255;--sidebar-text-hover-bg-rgb: 69, 120, 191;--sidebar-unread-text-rgb: 255, 255, 255;--error-box-background: 197, 67, 72;--sidebar-team-background-rgb: 11, 66, 140;--secondary-blue-rgb: 34, 64, 109;--denim-status-online-rgb: 61, 184, 135;--denim-button-bg-rgb: 28, 88, 217;--center-channel-text-rgb: 63, 67, 80;--offline-indicator: rgba(175, 179, 192, 0.64);--elevation-1: 0 2px 3px 0 rgba(0, 0, 0, 0.08);--elevation-2: 0 4px 6px 0 rgba(0, 0, 0, 0.12);--elevation-3: 0 6px 14px 0 rgba(0, 0, 0, 0.12);--elevation-4: 0 8px 24px 0 rgba(0, 0, 0, 0.12);--elevation-5: 0 12px 32px 0 rgba(0, 0, 0, 0.12);--elevation-6: 0 20px 32px 0 rgba(0, 0, 0, 0.12);--global-header-background: var(--sidebar-teambar-bg);--global-header-text: var(--sidebar-header-text-color);--global-header-background-rgb: var(--sidebar-teambar-bg-rgb);--global-header-text-rgb: var(--sidebar-header-text-color-rgb)}.modal .modal-content{border-radius:2px;box-shadow:0 0 10px rgba(0,0,0,.5)}.modal .about-modal .modal-content .modal-header{display:flex;align-items:center;padding:20px 25px;border:none;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);background:transparent;color:inherit}.modal .about-modal .modal-content .modal-header .close{right:15px;color:inherit;font-size:30px;font-weight:normal;opacity:.5}.modal .about-modal .modal-content .modal-header .more-modal__image{margin-right:12px}.modal .about-modal .modal-content .modal-header .modal-title{color:inherit;font-size:17px;font-weight:600}.modal .about-modal .modal-content .modal-header .icon{position:relative;top:1px;margin:0 5px 0 8px}.modal .about-modal .modal-content .modal-header .icon svg{width:14px;height:14px;opacity:.8}.modal .about-modal .modal-body{max-height:calc(100vh - 220px);padding:15px 25px}.modal .about-modal .modal-footer .btn{height:40px;padding:0 20px;border-radius:4px;font-size:14px;font-weight:600}.modal .about-modal label{margin-bottom:8px}.modal .about-modal .form-group{margin-bottom:24px}.modal .about-modal .select-suggestion-container{margin:0}.modal .about-modal .select-suggestion-container .form-control{height:36px;padding:8px 12px}.modal .about-modal .select-suggestion-container::after{top:9px;right:12px;font-size:20px}.modal .about-modal .form-control{padding:8px 12px;font-size:14px}.modal .about-modal .form-control[type=input]{height:36px}.modal .about-modal.large .modal-body{padding-bottom:20px}.modal .about-modal .about-modal__content{overflow:hidden;*zoom:1;display:flex;flex-direction:row;padding:1em 0 3em}.modal .about-modal .about-modal__copyright{margin-top:.5em;opacity:.6}.modal .about-modal .about-modal__links{margin-top:.5em}.modal .about-modal .about-modal__footer{font-size:13.5px}.modal .about-modal .about-modal__title{margin:0 0 10px;line-height:1.5}.modal .about-modal .about-modal__subtitle{opacity:.6}.modal .about-modal .about-modal__hash{overflow:hidden;font-size:.75em;opacity:.4;text-align:right}.modal .about-modal .about-modal__hash p:first-child{float:left;text-align:left}.modal .about-modal .about-modal__notice{font-size:.79em;opacity:.8;text-align:right}.modal .about-modal .about-modal__notice p:first-child{text-align:left}.modal .about-modal .about-modal__logo{padding:0 40px 0 20px;opacity:.9}.modal .about-modal .about-modal__logo svg{width:125px;height:125px}.modal .about-modal .about-modal__logo path{fill:inherit}.access-history__table{display:table;width:100%;padding-top:15px;line-height:1.6}.access-history__table:first-child{padding:0}.access-history__table>div{display:table-cell;vertical-align:top}.access-history__table .access__date{width:190px;font-size:15px;font-weight:600}.access-history__table .access__report{padding-bottom:15px;border-bottom:1px solid #ddd}.access-history__table .report__info{opacity:.8}.animation--highlight::before{position:absolute;top:0;left:0;display:inline-block;width:100%;height:100%;animation:highlight 1.5s ease;content:""}.activity-log__table{display:table;width:100%;padding:15px 0;border-top:1px solid rgba(0,0,0,.15);line-height:1.8}.activity-log__table:first-child{padding-top:0;border:none}.activity-log__table>div{display:table-cell;vertical-align:top}.activity-log__table .activity-log__report{width:80%}.activity-log__table .activity-log__action{text-align:right}.activity-log__table .report__platform{font-size:15px;font-weight:600}.activity-log__table .report__platform .fa{margin-right:6px}.activity-log__table .report__info{opacity:.8}.session-help-text{padding:0 0 20px}.admin-console__wrapper{overflow:auto}.admin-console{height:100%;padding-left:220px;color:#333;-webkit-overflow-scrolling:touch}.admin-console .wrapper--fixed{display:flex;height:calc(100vh - 43px);flex-direction:column}@supports(-webkit-touch-callout: none){.admin-console .wrapper--fixed{height:-webkit-fill-available}}.announcement-bar--fixed .admin-console .wrapper--fixed{height:calc(100vh - 40px - 43px)}.admin-console .admin-console__wrapper{overflow:auto;height:100%;-webkit-flex:1 1 auto;flex:1 1 auto;padding:20px}.admin-console .admin-console__content{max-width:920px}.admin-console mark{background-color:#fcea8d;border-radius:5%}.admin-console .btn.btn-default{background:rgba(0,0,0,.7);color:#fff}.admin-console .btn.btn-default:hover,.admin-console .btn.btn-default:focus,.admin-console .btn.btn-default:active{background:rgba(0,0,0,.8);color:#fff}.admin-console .btn.btn-spacing--right{margin-right:10px}.admin-console .btn .fa{margin-right:7px}.admin-console .btn .fa.margin-left{margin-right:0;margin-left:7px}.admin-console .table{margin-bottom:0}.admin-console .color-picker__popover{position:absolute;z-index:5;top:40px;right:0}.admin-console .color-input{width:232px}.admin-console .dropdown-menu{background:var(--sys-center-channel-bg)}.admin-console .dropdown-menu>li>button:hover{background:rgba(var(--sys-center-channel-color-rgb), 0.1)}.admin-console .dropdown-menu .divider{opacity:1}.admin-console .filtered-user-list{height:calc(100vh - 175px)}.announcement-bar--fixed .admin-console .filtered-user-list{height:calc(100vh - 205px)}.admin-console .Select-value-label{white-space:nowrap}.admin-console .inner-wrap{position:absolute;width:100%}.admin-console h3{padding-bottom:.5em;margin:1em 0;font-weight:600}.admin-console h4{margin-bottom:2em;font-weight:600}.admin-console .form-control{border:1px solid rgba(0,0,0,.15);background-color:#fff}.admin-console .form-control:focus:not(.Input){border-color:#66afe9;box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 8px rgba(102,175,233,.6);outline:0}.admin-console .form-control.disabled{background-color:#f5f5f5}.admin-console .form-control .placeholder-text{color:rgba(0,0,0,.3)}.admin-console .form-control.Input{border:none}.admin-console .filter-control .fa{font-size:12px}.admin-console .log__panel{overflow:scroll;width:100%;height:calc(100vh - 280px);padding:10px;border:1px solid rgba(var(--center-channel-color-rgb), 0.12);margin-top:14px;background-color:#fff}.admin-console.admin{overflow:auto;min-height:600px;padding:0 40px 20px;background-color:#f1f1f1}.admin-console .form-horizontal .control-label{padding-right:0;font-weight:600;text-align:left}.admin-console .form-horizontal .has-error .control-label{font-weight:normal}.admin-console .form-horizontal .form-group{margin-bottom:25px}.admin-console .form-horizontal .form-group.half{margin-bottom:14px}.admin-console .form-horizontal .file__upload{position:relative;display:inline-block;margin:0 10px 10px 0}.admin-console .form-horizontal .file__upload input{position:absolute;z-index:5;top:0;left:0;width:100%;height:100%;padding-left:100%;cursor:pointer;opacity:0}.admin-console .form-horizontal .file__upload input[disabled]{cursor:not-allowed}.admin-console .form-horizontal .alert{position:relative;top:1px;display:inline-block;padding:5px 7px;margin:1em 0 0}.admin-console .form-horizontal .alert .fa{margin-right:5px}.admin-console .form-horizontal .alert.alert-transparent{width:100%;padding:12px 14px;border:1px solid rgba(var(--center-channel-color-rgb), 0.12);margin:0;background:#fff}.admin-console .form-horizontal .alert hr{border-color:#ddd;margin:.8em 0}.admin-console .form-horizontal .alert div:last-child hr{display:none}.admin-console .banner{padding:.8em 1.5rem;border:1px solid rgba(var(--center-channel-color-rgb), 0.12);margin:4px 0 2em;background:#fff;font-size:.95em}.admin-console .banner.banner--url{padding:1.2em}.admin-console .banner code{background:#f5f5f5}.admin-console .banner p:last-child{margin:0 0 2px}.admin-console .banner .banner__url{padding:.7em 1em;background:rgba(0,0,0,.07);border-radius:2px;word-break:break-all}.admin-console .banner .banner__heading{margin-bottom:.5em;font-size:1.5em}.admin-console .banner .banner__icon{padding:5px 10px 5px 5px}.admin-console .banner.warning{border-color:#faebcc;background:#fcf8e3;color:#8a6d3b}.admin-console .popover{width:100%;border-radius:3px;font-size:.95em}.admin-console .panel{border:none;background-color:transparent}.admin-console .panel-default>.panel-heading{padding:10px 0;background-color:transparent}.admin-console .panel-default .panel-body{padding:30px 0 10px}.admin-console .panel-group{margin-bottom:50px}.admin-console .panel-title{font-size:24px;line-height:1.5}.admin-console .panel-title a{overflow:hidden;*zoom:1;display:block;text-decoration:none}.admin-console .panel-title a.collapsed .fa-minus{display:none}.admin-console .panel-title a.collapsed .fa-plus{display:inline-block}.admin-console .panel-title a .fa{margin-top:8px;color:#aaa;float:right;font-size:18px}.admin-console .panel-title a .fa-plus{display:none}.admin-console .more-modal__list .filtered-user-list .filter-controls{padding-bottom:1em}.admin-console .more-modal__list .filter-row{margin:10px 0}.admin-console .member-list-holder{overflow:visible;padding:5px 0;background:#fff}.admin-console .member-list-holder .more-modal__list{overflow:visible}.admin-console .member-list-holder .more-modal__row:last-child{border:none}.admin-console .member-count{margin-top:8px;opacity:.7}.admin-console .admin-console__header{z-index:100;display:flex;height:65px;-webkit-flex:0 0 65px;flex:0 0 65px;flex-direction:row;align-items:center;justify-content:space-between;padding:10px 20px;border-bottom:1px solid rgba(0,0,0,.1);background:#fff;font-size:22px;font-weight:normal}.admin-console .admin-console__header.with-back{padding:0}.admin-console .admin-console__header.with-back>div{display:flex;align-items:center}.admin-console .admin-console__header.with-back .back{display:flex;width:60px;height:60px;align-items:center;justify-content:space-around;border-right:1px solid rgba(0,0,0,.1);margin-right:20px;font-size:3.2rem;text-decoration:none}.admin-console .admin-console__header.with-back .back::before{position:relative;top:1px}.admin-console .admin-console-save{z-index:100;display:flex;width:100%;height:60px;-webkit-flex:0 0 60px;flex:0 0 60px;align-items:center;padding:0 10px;border-top:1px solid rgba(0,0,0,.1);background:#fff}.admin-console .admin-console-save .save-button{min-width:100px;height:34px;margin:0 10px;background:rgba(0,0,0,.15);color:rgba(0,0,0,.5);opacity:1}.admin-console .admin-console-save .save-button.btn-primary{background:#166de0;color:#fff}.admin-console .admin-console-save .cancel-button{display:flex;min-width:100px;height:34px;align-items:center;justify-content:center;margin:0 10px 0 0;border-radius:2px;text-decoration:none;transition:all .15s ease}.admin-console .admin-console-save .cancel-button:hover{background-color:#166de0;color:#fff}.admin-console .admin-console-save .error-message{overflow:hidden}.admin-console .admin-console-save .error-message .control-label{padding:5px 0 0 0;display:-webkit-box;overflow:hidden;-webkit-box-orient:vertical;-webkit-line-clamp:2;max-height:50px}.admin-console .admin-console-save .error-message div:nth-child(2)>.control-label{padding:0}.admin-console .admin-console-save .reset-defaults-btn{position:absolute;right:0;padding-right:10px;padding-left:10px}.admin-console .status-icon-unknown{color:gray}.admin-console .status-icon-success{color:#69c169}.admin-console .status-icon-warning{color:#eac262}.admin-console .status-icon-error{color:#ea6262}.admin-console .suggestion--selected{background-color:#e2e2e2}.admin-console .trial{margin-top:15px}.admin-console .trial-error{margin-top:10px;color:rgba(0,0,0,.5);font-weight:400}.admin-console .trial-legal-terms,.admin-console .upgrade-legal-terms{margin-top:10px;margin-bottom:0;color:rgba(0,0,0,.5);font-size:12px;font-weight:400}.job-table__table{overflow:auto;width:100%;min-height:100px;max-height:240px;padding:5px;border:1px solid rgba(var(--center-channel-color-rgb), 0.12);margin:20px 0 10px;background-color:#fff}.admin-console__disabled-text{margin:10px 0 0 15px;color:#777}.admin-sidebar{position:fixed;z-index:10;top:43px;left:0;display:flex;width:220px;height:calc(100% - 40px);flex-direction:column;background:#111}.admin-sidebar .filter-container{position:relative}.admin-sidebar .filter-container .search__icon{position:absolute;top:16px;left:21px;width:16px;height:16px;fill:rgba(var(--sys-sidebar-text-rgb), 0.56);stroke:#999}.admin-sidebar .filter-container .filter{width:204px;padding:5px 36px;border:1px solid #666;margin:8px;background:rgba(255,255,255,.05);border-radius:20px;color:#fff;font-size:14px;outline:none}.admin-sidebar .filter-container .filter:focus,.admin-sidebar .filter-container .filter.active{border:2px solid #166de0;margin:7px}.admin-sidebar .filter-container .input-clear .input-clear-x{position:absolute;right:16px;color:#fff;font-weight:bold}.admin-sidebar .Menu .dropdown-menu{overflow:auto;background:var(--sys-center-channel-bg)}.admin-sidebar .Menu .dropdown-menu .MenuGroup.menu-divider{background:rgba(var(--sys-center-channel-color-rgb), 0.16)}.admin-sidebar mark{background-color:#fcea8d;border-radius:5%}body.announcement-bar--fixed .admin-sidebar{top:83px;padding-bottom:40px}.admin-sidebar .dropdown-menu{overflow:auto;min-width:200px;max-width:200px;max-height:80vh}.admin-sidebar .team__header{background:transparent}.admin-sidebar .nav-pills__container{-webkit-font-smoothing:subpixel-antialiased;-moz-osx-font-smoothing:auto;position:relative;height:calc(100% - 68px);padding-bottom:20px;margin-top:1px}.admin-sidebar .nav-pills__container ul{padding-bottom:20px;margin-top:1px}.admin-sidebar .nav-pills__container ul.nav-stacked.task-list-shown{padding-bottom:72px}.admin-sidebar .sidebar-category{margin-top:0}.admin-sidebar .sidebar-category .category-title{padding:10px 12px;background:rgba(255,255,255,.15);color:#fff;line-height:15.4px;text-transform:uppercase}.admin-sidebar .sidebar-category .category-title .category-icon{top:6px;overflow:hidden;width:16px;margin-right:6px;text-align:center;vertical-align:bottom}.admin-sidebar .sidebar-category .category-title .category-icon.fa-users{font-size:13px}.admin-sidebar .sidebar-category .sections{padding:5px 0}.admin-sidebar .sidebar-section>.sidebar-section-title{position:relative}.admin-sidebar .sidebar-section .nav__sub-menu{margin-bottom:7px}.admin-sidebar .sidebar-section .nav__sub-menu:empty{display:none}.admin-sidebar .sections.sections--settings .sidebar-section-title{text-transform:uppercase}.admin-sidebar .sections.sections--settings .sidebar-section-title:hover,.admin-sidebar .sections.sections--settings .sidebar-section-title:focus{color:rgba(255,255,255,.5)}.admin-sidebar .sidebar-section-title{padding:6px 35px 6px 12px}.admin-sidebar .sidebar-section-tag{position:relative;top:-1px;height:16px;padding:0 4px 0 4px;margin-left:8px;background-color:rgba(255,255,255,.64);border-radius:4px;color:#3d3c40;font-size:10px;font-weight:600;text-transform:uppercase}.admin-sidebar .sidebar-subsection-title{padding:6px 35px 6px 30px}.admin-sidebar .sidebar-subsection-title--active::after{top:4px}.admin-sidebar .sidebar-section-title,.admin-sidebar .sidebar-subsection-title{position:relative;display:block;color:rgba(255,255,255,.5);font-size:13px}.admin-sidebar .sidebar-section-title:focus,.admin-sidebar .sidebar-subsection-title:focus{text-decoration:none}.admin-sidebar .sidebar-section-title:hover,.admin-sidebar .sidebar-subsection-title:hover{color:#3d88ec;text-decoration:none}.admin-sidebar .sidebar-section-title--active,.admin-sidebar .sidebar-subsection-title--active{background:rgba(255,255,255,.1);color:#fff}.admin-sidebar .sidebar-section-title--active:hover,.admin-sidebar .sidebar-section-title--active:focus,.admin-sidebar .sidebar-subsection-title--active:hover,.admin-sidebar .sidebar-subsection-title--active:focus{background:rgba(255,255,255,.1);color:#fff}.admin-sidebar .sidebar-section-title--active::after,.admin-sidebar .sidebar-subsection-title--active::after{position:absolute;top:3px;right:-1px;display:inline-block;color:#f5f5f5;content:"";font:normal normal normal 26px/1 FontAwesome;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;text-rendering:auto}.admin-sidebar .menu-icon--right{position:absolute;top:8px;right:12px;width:20px;height:20px;font-size:18px;font-weight:600;line-height:20px;text-align:center}.admin-sidebar .menu-icon--right .fa{position:relative;right:-2px;color:#fff;font-size:13px}.admin-sidebar .menu-icon--right.menu__close{top:3px;right:10px;cursor:pointer}.email-connection-test{margin-top:-15px}.s3-connection-test{margin-top:-15px}.recycle-db{margin-top:50px !important}.cluster-status{width:24px;height:24px}.config-hash{overflow:hidden;width:130px;text-overflow:ellipsis;white-space:nowrap}.system-users__filter-row{display:flex;margin-right:15px;margin-left:15px}.system-users__filter-row .system-users__filter{flex:1 1 140px}.system-users__filter-row .system-users__team-filter{flex:1 1 auto}.system-users__filter-row>label{display:flex;flex:1 1 auto;align-items:center}.system-users__filter-row>label span{padding:0 4px 0 8px}.system-users__filter-row label{font-weight:normal}.manage-teams .modal-body{padding:15px 15px 0}.manage-teams .manage-teams__user{display:flex;align-items:center}.manage-teams .manage-teams__teams{border-top:1px solid rgba(var(--center-channel-color-rgb), 0.12);margin:1em 0 .3em;margin-top:1em}.manage-teams .manage-teams__teams .btn-link.danger{color:#c55151}.manage-teams .manage-teams__teams .manage-row__empty{padding:9px 0}.manage-teams .member-row--padded{padding-left:20px}.manage-teams .member-row--padded strong{margin-right:10px}.manage-teams .member-row-lone-padding{padding-top:10px}.manage-teams .manage-row--inner{padding:15px 0 4px}.manage-teams .manage-row--inner+div{border-top:1px solid rgba(var(--center-channel-color-rgb), 0.12)}.manage-teams .manage-teams__info{overflow:hidden;flex:1;margin-left:10px;white-space:nowrap}.manage-teams .manage-teams__info .manage-teams__name{overflow:hidden;font-weight:bold;text-overflow:ellipsis}.manage-teams .manage-teams__info .manage-teams__email{overflow:hidden;opacity:.5;text-overflow:ellipsis}.manage-teams .manage-teams__system-admin{padding-right:10px;margin-left:10px;opacity:.5}.manage-teams .manage-teams__team{display:flex;align-items:center;padding:7px 10px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.12)}.manage-teams .manage-teams__team .btn{font-size:.9em}.manage-teams .manage-teams__team .dropdown{padding:6px 0}.manage-teams .manage-teams__team-name{overflow:hidden;flex:1;text-overflow:ellipsis}.manage-teams .manage-teams__team-actions{margin-left:10px}.manage-teams .manage-teams__team-actions .dropdown-toggle{box-shadow:none}.discard-changes-modal .modal-dialog .btn-default,.discard-changes-modal .modal-dialog .btn-default:hover,.discard-changes-modal .modal-dialog .btn-default:active,.discard-changes-modal .modal-dialog .btn-default:focus{border:none;background-color:transparent;color:#166de0}.admin-setting-user__dropdown{position:relative}.admin-setting-user__dropdown::before{position:absolute;top:15px;right:11px;width:0;height:0;border-width:5px 5px 2.5px;border-style:solid;border-color:#999 transparent transparent;content:"";pointer-events:none}.admin-setting-user__fullname{opacity:.5}.password__group-addon{min-width:150px;text-align:left}.password__group-addon-space{margin-bottom:20px}#error-tooltip .tooltip-inner{max-width:none}.admin-console .admin-console__content.admin-logs-content{max-width:none}.admin-console .admin-console__content.admin-logs-content .banner{max-width:920px}div[disabled]{opacity:.7;pointer-events:none}.backstage{width:100vw;height:100vh}.backstage-navbar{z-index:10;height:43px;padding:10px 20px;border-bottom:1px solid rgba(0,0,0,.15);background:#fff}.backstage-navbar__back{color:var(--sys-button-bg);text-decoration:none}.backstage-navbar__back .fa{margin-right:7px;font-size:1.1em;font-weight:bold}.backstage-navbar__back:hover,.backstage-navbar__back:active{color:var(--sys-button-bg);text-decoration:underline}.backstage-body{top:0;bottom:0;display:inline-block;overflow:auto;width:100%;height:calc(100% - 40px);background-color:#f5f5f5}body.announcement-bar--fixed .backstage-body{height:calc(100vh - 40px - 43px)}.backstage-content{max-width:1200px;padding-left:135px;margin:46px auto;background-color:#f5f5f5;vertical-align:top}.backstage-sidebar{position:absolute;width:260px;padding:46px 20px;vertical-align:top}.backstage-sidebar ul{padding:0;list-style:none}.backstage-sidebar>ul{overflow:hidden;*zoom:1;border-right:1px solid rgba(0,0,0,.15);border-left:1px solid rgba(0,0,0,.15);border-radius:2px}.backstage-sidebar__category+.backstage-sidebar__category .category-title{border-top:none}.backstage-sidebar__category .category-title{position:relative;display:block;padding:0 10px;border-top:1px solid rgba(0,0,0,.15);border-bottom:1px solid rgba(0,0,0,.15);color:#000;line-height:35px}.backstage-sidebar__category .category-title .fa{position:relative;top:1px;width:20px;opacity:.5;text-align:center}.backstage-sidebar__category .category-title .fa-smile-o{font-size:17px}.backstage-sidebar__category .category-title--active{background-color:#166de0;color:#fff}.backstage-sidebar__category .category-title--active .fa{opacity:1}.backstage-sidebar__category .category-title__text{position:absolute;left:2.5em}.backstage-sidebar__category .sections{border-bottom:1px solid rgba(0,0,0,.15);background:#fff}.backstage-sidebar__category .section-title,.backstage-sidebar__category .subsection-title{display:block;padding-left:2em;font-size:.95em;line-height:29px;text-decoration:none}.backstage-sidebar__category .subsection-title{padding-left:3em}.backstage-sidebar__category .section-title--active,.backstage-sidebar__category .subsection-title--active{background-color:#166de0;color:#fff;font-weight:600}.backstage-header__divider{margin:0 10px;color:rgba(0,0,0,.3)}.backstage-header{overflow:hidden;*zoom:1;display:flex;width:100%;justify-content:space-between;margin-bottom:20px}.backstage-header h1{margin:5px 0;font-size:20px}.backstage-filters{display:flex;width:100%;flex-direction:row}.backstage-filters__sort{flex-grow:1;flex-shrink:0;line-height:30px}.backstage-filters__sort .filter-sort{text-decoration:none}.backstage-filters__sort .filter-sort.filter-sort--active{color:inherit;cursor:default}.backstage-filters__sort .divider{margin-right:8px;margin-left:8px}.backstage-filter__search{position:relative;width:270px;flex-grow:0;flex-shrink:0}.backstage-filter__search .fa{position:absolute;top:11px;left:11px;opacity:.4}.backstage-filter__search input{padding-left:30px;background:#fff}.backstage-list{min-height:50px;padding:5px 15px;border:1px solid rgba(0,0,0,.15);background-color:#fff}.backstage-list__help{display:block;margin:1em 0}.backstage-list__item{position:relative;padding:20px 15px;border-bottom:1px solid rgba(0,0,0,.15)}.backstage-list__item:last-child{border:none}.backstage-list__item .item-details{overflow:hidden;flex-grow:1;flex-shrink:1;text-overflow:ellipsis}.backstage-list__item .item-details__row+.item-details__row{overflow:hidden;*zoom:1;text-overflow:ellipsis}.backstage-list__item .item-details__trigger{margin-left:6px}.backstage-list__item .item-details__description,.backstage-list__item .item-details__content_type,.backstage-list__item .item-details__token,.backstage-list__item .item-details__trigger-words,.backstage-list__item .item-details__trigger-when,.backstage-list__item .item-details__url,.backstage-list__item .item-details__creation{display:inline-block;margin-top:10px;vertical-align:top}.backstage-list__item .item-details__description:empty,.backstage-list__item .item-details__content_type:empty,.backstage-list__item .item-details__token:empty,.backstage-list__item .item-details__trigger-words:empty,.backstage-list__item .item-details__trigger-when:empty,.backstage-list__item .item-details__url:empty,.backstage-list__item .item-details__creation:empty{display:none}.backstage-list__item .item-details__trigger-words{white-space:nowrap}.backstage-form{position:relative;padding:40px 30px 30px;border:1px solid rgba(0,0,0,.15);background-color:#fff}.backstage-form.backstage-form__confirmation{padding:30px 30px 20px}.backstage-form label{font-weight:normal}.backstage-form .backstage-form__title{margin:5px 0 1.5em}.backstage-form .radio input,.backstage-form .checkbox input{position:relative;top:2px;width:16px;height:16px;margin:0 5px 0 0}.backstage-form .form-control{background:#fff}.backstage-form .form-control:focus{border-color:#166de0}.backstage-form .form__help{margin-top:1em;color:rgba(0,0,0,.5);font-size:.95em}.backstage-form .form__help+.form__help{margin-top:.4em}.backstage-form__footer{overflow:hidden;padding-top:1.8em;border-top:1px solid rgba(0,0,0,.15);margin-top:2.5em;text-align:right}.backstage-form__footer .has-error{max-width:50%;margin:0;float:left}.backstage-form__footer .has-error .control-label{padding:0;text-align:left}.integration__icon{position:absolute;right:20px;width:80px;height:80px}.integration__icon.integration-list__icon{top:50px}.integration-option{flex:0 0 30%;padding:20px;border:1px solid rgba(0,0,0,.15);margin:0 30px 30px 0;background-color:#fff;border-radius:4px;text-align:center;transition:all .2s ease}.integration-option:hover{color:initial;text-decoration:none}.integration-option__image{height:80px;margin:.5em 0 .7em}.integration-option__title{margin-bottom:10px;color:#000}.integration-option__description{color:rgba(0,0,0,.5)}.emoji-list__table{width:100%}.emoji-list__table .backstage-list__item{display:table-row}.emoji-list__table .backstage-list__empty td{padding:15px 20px}.emoji-list__table-header{font-weight:bold}.emoji-list__name{width:30%;padding:20px 0 20px 15px}.emoji-list__image{width:15%;padding:15px 0}.emoji-list__creator{width:40%;padding:15px 0}.emoji-list__actions{width:15%;padding:20px 15px 20px 0}.add-emoji__upload{position:relative;display:inline-block;margin:0 10px 10px 0}.add-emoji__upload input{position:absolute;z-index:5;top:0;left:0;width:100%;height:100%;opacity:0}.add-emoji__filename,.add-emoji__preview{padding-top:7px}.bot-list{border:1px solid rgba(0,0,0,.1);margin-top:12px;border-radius:4px;line-height:24px}.bot-list__item{padding:8px 12px;background:rgba(0,0,0,.02);font-size:13px}.bot-list__item:first-child{border:none}.bot-list__item:hover{background:rgba(0,0,0,.06)}.bot-list__item.alert{padding:12px;margin:0;border-radius:0}.bot-list__item .form-horizontal .control-label{padding-top:4px}.bot-details__description{margin:4px 0}.bot-disabled{width:100%;height:11px;border-bottom:1px solid rgba(0,0,0,.1);margin-top:10px;margin-bottom:10px;text-align:left}.bot-disabled span{padding:0 10px;background-color:#fff;color:#000;font-family:"Open Sans";font-size:14px;font-weight:600;line-height:19px;opacity:.9}.bot-list-img{width:32px;height:32px}.bot-list-img-container{overflow:hidden;width:32px;height:32px;flex:0 0 32px;margin-right:15px;border-radius:50%;float:left}.bot-img{width:129px;height:129px}.bot-img-container{overflow:hidden;width:129px;height:129px;margin-bottom:20px;border-radius:50%}.bot-profile__remove{position:absolute;top:4px;left:110px;display:flex;width:26px;height:26px;align-items:center;justify-content:center;background:#000;border-radius:50%;color:#fff;text-decoration:none;transition:all .15s ease}.bot-profile__remove span{font-size:22px}.bot-profile__section{padding-top:1em;border-top:1px solid rgba(0,0,0,.15);margin-bottom:1em}.bot-list__disabled .item-details{color:rgba(0,0,0,.6)}.bot-list__disabled .bot-list{opacity:.6}.bot-token-has-error{color:#a94442}@media screen and (min-width: 769px){.backstage{position:relative;z-index:110;margin-top:-40px}}.compliance-panel__table,.audit-panel__table,.cluster-panel__table{overflow:auto;width:100%;min-height:100px;max-height:70vh;padding:5px;border:1px solid 1px solid rgba(var(--center-channel-color-rgb), 0.12);margin-top:10px;background-color:#fff}.compliance-panel .row>.form-group,.audit-panel .row>.form-group{padding-left:0}.compliance-panel .row>.form-group:first-child,.audit-panel .row>.form-group:first-child{padding-left:15px}.compliance-panel .row label,.audit-panel .row label{font-weight:600}.compliance-panel .fa-refresh,.audit-panel .fa-refresh{margin-right:5px}.compliance-panel{margin-bottom:3em}.docs__page{padding-bottom:20px;line-height:1.7}.docs__page>div{width:1170px;max-width:100%;padding:0 15px;margin:0 auto}.docs__page h1.markdown__heading{padding-bottom:1rem;border-bottom:1px solid #ddd;margin:1em 0 1em}body.error .container-fluid{display:table;height:90%}body.error .error__container{display:table-cell;max-width:800px;padding:5em 0;margin:0 auto;color:#555;text-align:left;vertical-align:top}body.error .error__icon{color:#ccc;font-size:4em}body.error h2{margin:.8em 0 .5em;font-size:1.5em;font-weight:600}body.error p{font-size:1.2em}.get-app{min-height:100vh;background-color:#fff}.get-app__header{display:flex;width:100%;height:102px;box-shadow:0 2px 10px 0 rgba(0,0,0,.2)}.get-app__header .get-app__logo{width:255px;height:auto;margin:30px 40px}.get-app__header .get-app__custom-logo{max-width:240px;max-height:40px;align-self:center;margin-left:40px}.get-app__header .get-app__custom-site-name{align-self:center;margin-left:40px}.get-app__header .get-app__custom-site-name>span{color:#000;font-family:"Open Sans";font-size:40px;font-weight:bold;line-height:40px;opacity:.8}.get-app__header .get-app__custom-logo+.get-app__custom-site-name{margin-left:8px}.get-app__dialog{display:flex;width:1280px;justify-content:center;margin:80px auto}.get-app__graphic{flex:0 0 600px;background-color:var(--sidebar-bg)}.get-app__graphic.mobile{flex:0 1 300px}.get-app__graphic>img{max-width:100%}.get-app__dialog-body{flex:0 1 600px;margin-top:60px;margin-left:60px}.get-app__launching>span{color:#000;font-family:"Open Sans";font-size:32px;font-weight:600;line-height:43px;opacity:.8}.get-app__alternative{margin-top:8px}.get-app__alternative span{font-family:"Open Sans";font-size:20px;line-height:27px;opacity:.8}.get-app__alternative>a{color:#145dbf;text-decoration:none}.get-app__alternative>span{color:#000}.get-app__alternative.redirect-page{margin-top:24px;margin-bottom:32px}.get-app__alternative.redirect-page>br.mobile-only{display:none}.get-app__buttons{margin-top:28px}.get-app__status{display:inline-block;margin-right:20px;font-family:"Open Sans"}.get-app__status>a{padding:13px 30px;border-radius:4px;font-size:16px;font-weight:600;line-height:22px}.get-app__download{border:none !important;background-color:#145dbf !important}.get-app__download:hover{background-color:#145dbf !important;box-shadow:0 2px 5px 0 rgba(0,0,0,.1),0 2px 10px 0 rgba(0,0,0,.1)}.get-app__download:active,.get-app__download:focus{background-color:#1151a6 !important}.get-app__continue{border-color:#145dbf !important;color:#145dbf !important}.get-app__continue:hover{background-color:rgba(255,255,255,.1) !important;box-shadow:0 2px 5px 0 rgba(0,0,0,.1),0 2px 10px 0 rgba(0,0,0,.1)}.get-app__continue:active{background-color:rgba(20,93,191,.1) !important;box-shadow:0 2px 5px 0 rgba(0,0,0,.1),0 2px 10px 0 rgba(0,0,0,.1)}.get-app__continue:focus{background-color:rgba(20,93,191,.1) !important}.get-app__preference{display:flex;margin-top:23px}.get-app__preference>span{margin-top:-2px;color:#000;font-family:"Open Sans";font-size:16px;font-weight:normal;line-height:22px;opacity:.8}.get-app__checkbox{width:18px;height:18px;padding:0;border:2px solid rgba(0,0,0,.5);margin-right:7px;background:none;border-radius:3px}.get-app__checkbox>*{pointer-events:none}.get-app__checkbox.checked{border:0}.get-app__checkbox.checked svg{fill:#145dbf}.get-app__download-link{margin-top:40px;color:#000;font-family:"Open Sans";font-size:16px;line-height:22px;opacity:.8}.get-app__download-link>span>a{color:#145dbf;text-decoration:none}.get-app__download-link>br{display:none}@media only screen and (max-width: 1280px){.get-app__dialog{width:100%;align-items:center;padding:0 80px 0 0;margin:80px 0}.get-app__dialog-body{align-self:baseline;margin-top:40px}.get-app__graphic{flex-shrink:1}}@media only screen and (max-width: 1082px){.get-app__dialog{flex-direction:column-reverse;padding:0;margin:40px 0 0 0;text-align:center}.get-app__dialog-body{display:flex;flex:0 1 270px;flex-direction:column;align-self:center;margin-top:0;margin-left:0}.get-app__preference{align-self:center}.get-app__graphic{flex:0 1 500px;margin-top:40px}.get-app__graphic.mobile{flex:0 1 347px}.get-app__graphic>img{max-height:100%}}@media only screen and (max-width: 768px){.get-app__header{height:52px;justify-content:center;box-shadow:0 1px 5px 0 rgba(0,0,0,.2)}.get-app__header .get-app__logo{display:block;width:170px;height:auto;margin:0 auto}.get-app__header .get-app__custom-logo{margin-left:0}.get-app__header .get-app__custom-site-name{margin-left:0}.get-app__header .get-app__custom-site-name>span{font-size:24px;font-weight:bold;line-height:24px}.get-app__header .get-app__custom-logo+.get-app__custom-site-name{margin-left:4px}.get-app__dialog{height:auto;flex-direction:column-reverse;margin:32px auto}.get-app__graphic{flex-basis:unset !important;margin:16px 40px 0 40px}.get-app__dialog-body{margin-left:0}.get-app__launching{padding:0 24px;margin:0 auto;text-align:center}.get-app__alternative{display:none}.get-app__alternative span{font-size:16px;line-height:22px}.get-app__alternative.redirect-page{display:block}.get-app__alternative.redirect-page>br.mobile-only{display:block}.get-app__buttons{margin-top:25px}.get-app__preference{margin-top:0}.get-app__status{display:block;margin-right:0;margin-bottom:20px}.get-app__status>a{width:219px}.get-app__download-link{padding:0 24px}.get-app__download-link>br{display:block}}@keyframes move{from{opacity:1}to{opacity:.1}}.loading-screen{display:block;width:100%;height:100%;padding:60px;text-align:center}.loading-screen .loading__content{display:flex;align-items:center;justify-content:center}.loading-screen .loading__content p{display:inline-block;margin:0 .2em;font-size:14px;font-weight:500}.loading-screen .loading__content .round{display:inline-block;width:4px;height:4px;margin:0 2px;animation:move .75s infinite linear;background-color:#444;border-radius:10px;opacity:.1}.loading-screen .loading__content .round-1{animation-delay:.2s}.loading-screen .loading__content .round-2{animation-delay:.4s}.loading-screen .loading__content .round-3{animation-delay:.6s}.loading-screen .hideAnimation{display:none}@media print{*{background:transparent !important;color:#000 !important;text-shadow:none !important}.post-list__content,.post-list__table,.app__content{display:block}a:not(.mention-link),a:not(.mention-link):visited{text-decoration:underline}a[href^=http]::after{content:" <" attr(href) "> "}tr,img,pre,blockquote,code,.post,.date-separator{page-break-inside:avoid}.post__header{page-break-after:avoid}thead{display:table-header-group}img{max-width:100% !important}p,h2,h3{orphans:3;widows:3}#sidebar-left,#sidebar-right,#channel-header,#post-create,#post-list .more-messages-text,.post .post__header .post-menu,.post .post__content>div.post__img,.attachment__content,.post__body .img-div,.post-image__thumbnail,.post.post--system,#archive-link-home,.channel-intro{display:none}#post-list,#channel_view,#post-list .post-list-holder-by-time{overflow:visible;overflow-y:visible}#app-content{margin-left:0}#channel_view .inner-wrap.move--left{margin-right:0}.post-image__columns>div:first-child::before{display:block;content:"Attachments:";font-weight:bold}.post-image__column{display:inline;width:inherit;height:inherit;border:0 none;border-color:transparent;background:transparent}.post-image__details{width:100%;border:0 none;line-height:98px}.post-image__details .post-image__name::before{content:"["}.post-image__details .post-image__name::after{content:": " attr(href) "]"}.post-image__details .post-image__name+div{display:none}}.user-settings{min-height:300px}.user-settings .table-responsive{max-width:560px;max-height:300px}.user-settings .authorized-apps__help{margin-top:7px;font-size:13px;font-weight:400}.user-settings .authorized-apps__wrapper{padding:10px 0}.user-settings .authorized-app{display:inline-block;width:100%}.user-settings .authorized-app:not(:last-child){border-bottom:1px solid #ccc;margin-bottom:10px}.user-settings .authorized-app .authorized-app__name{font-weight:600}.user-settings .authorized-app .authorized-app__url{font-size:13px;font-weight:400}.user-settings .authorized-app .authorized-app__description,.user-settings .authorized-app .authorized-app__deauthorize{margin:5px 0;font-size:13px}.user-settings textarea{resize:vertical}.modal .settings-modal{width:800px}.modal .settings-modal .modal-back{position:absolute;top:12px;left:0;width:50px;height:40px;font-size:27px;font-weight:normal;line-height:32px;text-align:center}.modal .settings-modal .modal-back .fa{position:absolute;left:0;width:100%;height:100%;line-height:inherit}.modal .settings-modal .modal-body{min-height:calc(100% - 62px);padding:0;margin:0 auto}.modal .settings-modal li{list-style:none}.modal .settings-modal label{font-weight:600}.modal .settings-modal label.text-left{text-align:left}.modal .settings-modal label.has-error{font-weight:normal}.modal .settings-modal .no-padding--left{padding-left:0}.modal .settings-modal .profile-img{width:128px;height:128px;border-radius:100%}.modal .settings-modal .profile-img-preview{width:128px;height:128px;background-position:50% 50%;background-size:cover;border-radius:100%}.modal .settings-modal .profile-img__container{position:relative;width:128px;height:128px}.modal .settings-modal .profile-img__remove{position:absolute;top:4px;right:8px;display:flex;width:26px;height:26px;align-items:center;justify-content:center;padding:0;border:none;background:#000;border-radius:50%;color:#fff;text-decoration:none;transition:all .15s ease}.modal .settings-modal .profile-img__remove span{margin-top:-3px;font-size:22px}.modal .settings-modal .team-img-preview,.modal .settings-modal .team-img__container{position:relative;width:128px;height:128px}.modal .settings-modal .team-img-preview img,.modal .settings-modal .team-img__container img{width:100%;height:auto}.modal .settings-modal .team-img-preview .img-preview__image,.modal .settings-modal .team-img__container .img-preview__image{overflow:hidden;border:1px solid rgba(0,0,0,.15);background-color:#fff;border-radius:6px}.modal .settings-modal .team-img-preview div,.modal .settings-modal .team-img__container div{width:100%;height:100%;background-color:#fff;background-position:center;background-repeat:no-repeat;background-size:cover}.modal .settings-modal .team-img__remove{position:absolute;top:-8px;right:-8px;width:24px;height:24px;padding:0;border:none;background:#000;border-radius:50%;color:#fff;line-height:23px;text-align:center;text-decoration:none;transition:all .15s ease}.modal .settings-modal .team-img__remove span{margin-top:-3px;font-size:22px}.modal .settings-modal .settings-table{display:table;width:100%;max-width:1000px;margin:0 auto;table-layout:fixed}.modal .settings-modal .settings-table>div{display:table-cell;vertical-align:top}.modal .settings-modal .settings-table .nav{position:fixed;width:179px}.modal .settings-modal .settings-table .nav.position--top{top:57px}.modal .settings-modal .settings-table .security-links{margin-right:20px}.modal .settings-modal .settings-table .security-links .fa{margin-right:6px}.modal .settings-modal .settings-table .settings-links{width:180px;background:var(--sidebar-bg)}.modal .settings-modal .settings-table .settings-content{padding:0 20px 30px}.modal .settings-modal .settings-table .settings-content .modal-header{display:none}.modal .settings-modal .settings-table .settings-content .section-max{*zoom:1;background:rgba(0,0,0,.05);padding:1em 0 1.3em;margin-bottom:0}.modal .settings-modal .settings-table .settings-content .section-max::after{display:table;clear:both;content:""}.modal .settings-modal .settings-table .settings-content .section-max .section-title{margin:0 0 5px;font-size:14px;line-height:20px}.modal .settings-modal .settings-table .settings-content .timezone-container{display:table;overflow:visible;width:100%}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-group .input-group-addon{width:40px;padding:4px 5px}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-group img{width:29px;border:1px solid rgba(0,0,0,.15)}.modal .settings-modal .settings-table .settings-content .appearance-section .group--code select{padding-right:25px;appearance:none}.modal .settings-modal .settings-table .settings-content .appearance-section .group--code::before{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;position:absolute;z-index:5;top:11px;right:50px;display:inline-block;content:"";font:normal normal normal 14px/1 FontAwesome;pointer-events:none;text-rendering:auto}.browser--ie .modal .settings-modal .settings-table .settings-content .appearance-section .group--code::before{display:none}.modal .settings-modal .settings-table .settings-content .appearance-section .premade-themes{margin-bottom:10px}.modal .settings-modal .settings-table .settings-content .appearance-section .premade-themes .theme-label{overflow:hidden;margin-top:5px;font-weight:400;text-overflow:ellipsis;white-space:nowrap}.modal .settings-modal .settings-table .settings-content .appearance-section .premade-themes label{width:100%}.modal .settings-modal .settings-table .settings-content .appearance-section .premade-themes svg{overflow:hidden;width:100%;height:auto;border:solid 2px rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px}.modal .settings-modal .settings-table .settings-content .appearance-section .premade-themes svg:hover{cursor:pointer}.modal .settings-modal .settings-table .settings-content .appearance-section .premade-themes .active svg{border-color:var(--sidebar-text-active-border)}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements{padding-left:16px}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements .element{margin-right:10px}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements .element:nth-child(2n){margin-right:0}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements__header{padding:1px 0 10px;border-bottom:1px solid;margin:10px 20px 0 0;cursor:pointer;font-size:.9642857143em;font-weight:600}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements__header .fa-minus{display:none}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements__header.open .fa-minus{display:inline-block}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements__header.open .fa-plus{display:none}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements__header .header__icon{float:right;opacity:.5}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements__body{max-height:0;padding:0 0 0 24px;margin:0 20px 0 0;background-color:rgba(255,255,255,.05);border-radius:0 0 3px 3px;overflow-y:hidden;transition:all .4s ease-out;*zoom:1}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements__body::after{display:table;clear:both;content:""}.modal .settings-modal .settings-table .settings-content .appearance-section .theme-elements__body.open{max-height:1200px;padding:24px 0 0 24px;margin:0 20px 0 0}.modal .settings-modal .settings-table .settings-content .appearance-section .custom-label{overflow:hidden;width:100%;font-size:12px;font-weight:normal;text-overflow:ellipsis;white-space:nowrap}.modal .settings-modal .settings-table .settings-content .appearance-section .input-group-addon{background:transparent}.modal .settings-modal .settings-table .settings-content .appearance-section .radio label{font-weight:600}.modal .settings-modal .settings-table .settings-content .appearance-section .copy-theme-button{padding:5px 8px;border:1px solid var(--link-color);text-decoration:none}.modal .settings-modal .settings-table .settings-content .appearance-section .copy-theme-success{height:30px;padding:5px 12px;margin-left:10px}.modal .settings-modal .settings-table .settings-content .divider-dark{border-bottom:1px solid #aaa}.modal .settings-modal .settings-table .settings-content .divider-light{border-bottom:1px solid #d3d3d3}.modal .settings-modal .settings-table .settings-content .divider-light+.divider-light{display:none}.modal .settings-modal .settings-table .settings-content .divider-light+.divider-dark{display:none}.modal .settings-modal .settings-table .settings-content .setting-list{padding:0;list-style-type:none}.modal .settings-modal .settings-table .settings-content .setting-box__item:first-child{padding-top:3px}.modal .settings-modal .settings-table .settings-content .setting-box__item:last-child hr{display:none}.modal .settings-modal .settings-table .settings-content .setting-box__token-id{margin:4px 0}.modal .settings-modal .settings-table .settings-content .setting-box__inline-error{margin-left:5px}.modal .settings-modal .settings-table .settings-content .setting-list__hint{margin-top:20px}.modal .settings-modal .settings-table .settings-content .fa-wrapper{margin:0 5px}.modal .settings-modal .settings-table .settings-content .resend-verification-wrapper::before{content:" "}.modal .settings-modal .settings-table .settings-content .mentions-input{margin-top:10px}.modal .settings-modal .settings-table .settings-content .setting-list-item{margin-top:7px}.modal .settings-modal .settings-table .settings-content .has-error{color:#a94442}.modal .settings-modal .settings-table .settings-content .file-status{margin-top:8px;color:#555;font-size:13px}.modal .settings-modal .settings-table .settings-content .confirm-import{padding:4px 10px;margin:10px 0}.modal .settings-modal .disabledMessage{padding:15px;margin-top:10px;background-color:rgba(0,0,0,.1)}.modal .settings-modal .nav-pills>li button{color:rgba(var(--sidebar-text-rgb), 0.6)}.modal .nav-pills>li{margin:0}.modal .nav-pills>li button{overflow:hidden;width:100%;padding:8px 15px;border-radius:0;color:rgba(0,0,0,.3);text-align:left;text-overflow:ellipsis;white-space:nowrap}.modal .nav-pills>li .icon{top:2px;width:14px;margin-right:10px;font-size:15px;text-align:center}.modal .nav-pills>li:hover button,.modal .nav-pills>li:hover button:hover,.modal .nav-pills>li:hover button:focus{background:var(--sidebar-text-hover-bg)}.modal .nav-pills>li.active div{background-color:#e1e1e1;color:#111}.modal .nav-pills>li.active div::before{position:absolute;top:0;left:0;width:5px;height:100%;background:#000;content:""}.modal .nav-pills>li.active button,.modal .nav-pills>li.active button:hover,.modal .nav-pills>li.active button:focus{position:relative;border-radius:0;font-weight:400}.modal .nav-pills>li.active button{background-color:rgba(0,0,0,.1)}.modal h3{font-size:1.4285714286em}.channel-settings{padding:0 10px}.tab-header{margin-bottom:1em;font-weight:600}.setting-name{color:gray;font-weight:500}.sel-btn{margin-right:5px}.member-div{position:relative;width:100%;padding:2px;border-bottom:1px solid #d3d3d3;margin:0}.member-div:first-child{border-top:1px solid #d3d3d3}.member-div .post-profile-img{margin-right:8px;border-radius:50px}.member-role .fa,.member-drop .fa{margin:0 0 0 4px;font-size:16px}.member-role .member-menu,.member-drop .member-menu{top:24px;right:0}.member-invite{position:absolute;top:7px;right:10px}.member-menu{right:0;left:auto}.member-list{width:100%;overflow-x:visible}.member-page{padding-top:50px}.no-resize{resize:none}.user-settings__submit-checkbox{padding-top:0;padding-bottom:20px}.section-min{position:relative;padding:1em;cursor:pointer;overflow:hidden;*zoom:1}.section-min:hover{background:#f9f9f9}.section-min:hover .fa{display:inline-block}.section-min:hover .section-min__edit{text-decoration:underline}.section-min .d-flex{justify-content:space-between}.section-min__title{padding-right:50px;margin:0 0 5px;font-size:14px;font-weight:600;line-height:20px}.section-min__edit{margin-bottom:5px;text-align:right}.section-min__edit .fa{display:none;margin-right:5px;font-size:12px;opacity:.5}.section-min__describe{overflow:hidden;*zoom:1;opacity:.7;text-overflow:ellipsis;white-space:pre}body.announcement-bar--fixed .signup-header{top:24px}.signup-header{position:fixed;z-index:5;top:0;left:0;width:100%;padding:0 1em .2em;background:#f5f5f5;line-height:33px}.signup-header .fa{margin-right:4px}.signup-team__container{position:relative;max-width:400px;padding:100px 0 50px;margin:0 auto}.signup-team__container .medium-center{width:70%;margin-right:auto;margin-left:auto}.signup-team__container .terms-of-service__markdown{min-width:100vw;padding-top:3em;padding-bottom:3em;background-color:#fff;overflow-y:auto}.signup-team__container.branded{display:flex;max-width:900px;flex-direction:row}.signup-team__container.branded .signup__markdown{flex:1.3 0 0;padding-right:80px}.signup-team__container.branded .signup__markdown ul+p,.signup-team__container.branded .signup__markdown ol+p{margin-top:.6em}.signup-team__container.branded .signup__markdown p+ul,.signup-team__container.branded .signup__markdown p+ol{margin-top:.6em}.signup-team__container.branded .signup__markdown img{max-width:450px}.signup-team__container.branded .signup__markdown p{width:100%;margin:0;color:gray;line-height:1.6em;white-space:pre-wrap;word-break:break-word}.signup-team__container.branded .signup__content{flex:1 0 0}.signup-team__container.padding--less{padding-top:70px}.signup-team__container.terms-of-service__container{max-width:100%;padding-top:33px}.signup-team__container .terms-of-service__footer{padding-top:.5em;padding-bottom:.5em}.signup-team__container .terms-of-service__footer .terms-of-service__button-group{padding-top:1em;padding-bottom:1em}.signup-team__container .terms-of-service__footer .terms-of-service__server-error{padding-bottom:1em}.signup-team__container.max-width--full{max-width:100%}.signup-team__container .form-control:focus{box-shadow:inset 0 1px 1px rgba(0,0,0,.075),0 0 8px rgba(102,175,233,.6)}.signup-team__container .terms-of-service-error__height--fill{height:calc(100vh - 107px - 4em);min-height:calc(100vh - 107px - 4em)}.signup-team__container .terms-of-service__height--fill{height:calc(100vh - 69px - 3em);min-height:calc(100vh - 69px - 3em)}.signup-team__container h1,.signup-team__container h2,.signup-team__container h3,.signup-team__container h4,.signup-team__container h5,.signup-team__container h6,.signup-team__container p{line-height:1.3}.signup-team__container h1{font-weight:600}.signup-team__container h2{margin-bottom:.8em;font-size:2.1428571429em;font-weight:600;letter-spacing:-0.5px}.signup-team__container h3{margin:0 0 1.3em;font-size:1.5em;font-weight:600}.signup-team__container h4{margin-bottom:1em;font-size:1.4285714286em;font-weight:600}.signup-team__container h5{font-size:1.1428571429em}.signup-team__container hr{margin:2em 0}.signup-team__container p{margin-bottom:1em;color:#555;line-height:1.5}.signup-team__container p .black,.signup-team__container p.black{color:#000}.signup-team__container .input-group.input-group--limit{width:100%;table-layout:fixed}.signup-team__container .input-group.input-group--limit .tooltip-inner{word-wrap:break-word}.signup-team__container .input-group.input-group--limit .form-control{display:table-cell;width:100%;text-align:left}.signup-team__container .input-group.input-group--limit .input-group-addon{display:table-cell;overflow:hidden;width:50%;text-align:left;text-overflow:ellipsis}.signup-team__container .inner__content{margin:30px 0 20px}.signup-team__container .block--gray{display:inline-block;padding:.85em 1.2em;background:#f2f2f2;border-radius:3px;font-weight:600}.signup-team__container form{margin-bottom:.8em}.signup-team__container .signup-team-confirm__container{padding:100px 0}.signup-team__container .signup-team-logo{display:none;width:210px;margin:0 0 2em}.signup-team__container .signup-team-login{padding-bottom:10px;font-weight:600}.signup-team__container .signup-team__name{margin:.5em 0 0;font-size:2.2em;font-weight:600}.signup-team__container .signup-team__subdomain{margin:.2em 0 1.2em;font-size:1.5em;font-weight:300;text-transform:uppercase}.signup-team__container .form-control{height:2.7142857143em}.signup-team__container .or__container{height:1px;margin:2em 0;margin:2.5em 0 2.5em -1rem;background:#ddd;text-align:left}.signup-team__container .or__container span{position:relative;top:-10px;display:inline-block;width:40px;background:#fff;font-size:1.14286em;font-weight:600;line-height:20px;text-align:center}.signup-team__container ul{padding-left:18px;margin-bottom:0}.signup-team__container .btn{padding:.5em 1.0714285714em;margin-right:5px;font-size:1em;font-weight:600}.signup-team__container .btn .fa{position:relative;top:1px;margin:0;font-size:17px}.signup-team__container .btn .fa:last-child{margin-left:8px}.signup-team__container .btn .fa:first-child{margin-right:8px}.signup-team__container .btn .fa.fa--margin-top{position:relative;top:1px}.signup-team__container .btn .fa.fa-check,.signup-team__container .btn .fa.fa-refresh{left:-2px;margin-right:.5em;font-size:.9em}.signup-team__container .btn .icon{position:relative;display:inline-block;width:18px;height:18px;margin-right:12px;background-size:100% 100%;text-align:center}.signup-team__container .btn.btn-custom-login{display:flex;width:200px;min-width:200px;height:40px;align-items:center;padding:0 24px;margin:1em 0;border-radius:2px;color:#fff;text-align:left}.signup-team__container .btn.btn-custom-login>span{position:relative;display:flex;align-items:center}.signup-team__container .btn.btn-custom-login>span>span{line-height:normal}.signup-team__container .btn.btn-custom-login.gitlab{background:#548}.signup-team__container .btn.btn-custom-login.gitlab:hover{background:#403366}.signup-team__container .btn.btn-custom-login.gitlab .icon{background-image:url(/static/files/20785e8b14e143de1e183339d3e28694.png)}.signup-team__container .btn.btn-custom-login.google{background:#dd4b39}.signup-team__container .btn.btn-custom-login.google:hover{background:#c23321}.signup-team__container .btn.btn-custom-login.google .icon{background-image:url(/static/files/711d6ebe91314060556c8f28bd9ce152.png)}.signup-team__container .btn.btn-custom-login.office365{background:#0079d6}.signup-team__container .btn.btn-custom-login.office365:hover{background:#005ca3}.signup-team__container .btn.btn-custom-login.office365 .icon{background-image:url(/static/files/c1a25e53f866b24a6c3625843183a5e1.png)}.signup-team__container .btn.btn-custom-login.openid{background:#0079d6;white-space:normal}.signup-team__container .btn.btn-custom-login.openid:hover{background:#005ca3}.signup-team__container .btn.btn-custom-login.openid>span>span{overflow:hidden;width:150px;line-height:normal;text-overflow:ellipsis;white-space:nowrap}.signup-team__container .btn.btn-custom-login.ldap{background:#3aa1cf}.signup-team__container .btn.btn-custom-login.ldap:hover{background:#2a84ac}.signup-team__container .btn.btn-custom-login.email{background:#166de0}.signup-team__container .btn.btn-custom-login.email:hover{background:#1156b2}.signup-team__container .btn.btn-custom-login.saml{background:#34a28b}.signup-team__container .btn.btn-custom-login.saml:hover{background:#287b6a}.signup-team__container .btn.btn-custom-login.btn--full{width:100%;max-width:350px;text-align:left}.signup-team__container .btn.btn-custom-login.btn--large{width:300px}.signup-team__container .btn.btn-default{color:#444}.signup-team__container .has-error.no-padding{padding:0}.signup-team__container .has-error .control-label{width:100%;padding:.7em 1em;margin:1em 0 0;background:#f2f2f2;border-radius:3px;color:#999;font-size:14px;font-weight:normal}.signup-team__container .has-error .control-label::before{margin-right:4px;color:#aaa;content:""}.signup-team__container .reset-form{position:relative;border-radius:3px;font-size:.95em}.signup-team__container .reset-form p{color:inherit}.signup-team__container h1.sub-heading,.signup-team__container h2.sub-heading,.signup-team__container h3.sub-heading,.signup-team__container h4.sub-heading,.signup-team__container h5.sub-heading,.signup-team__container h6.sub-heading{margin-bottom:0;font-weight:400}.signup-team__container h1.color--light,.signup-team__container h2.color--light,.signup-team__container h3.color--light,.signup-team__container h4.color--light,.signup-team__container h5.color--light,.signup-team__container h6.color--light{font-weight:300}.signup-team__container .color--light{color:#777}.select-team__container{max-width:800px}.signup-team-all{max-height:calc(75vh - (108px + 89px));border:1px solid #ddd;margin:0 0 20px;border-radius:2px;border-radius:4px}.signup-team-all .signup-team-dir{*zoom:1;position:relative;display:flex;max-width:100%;height:3.8em;align-items:center;padding-top:3px;border-top:1px solid #ddd;background:#fafafa}.signup-team-all .signup-team-dir::after{display:table;clear:both;content:""}.signup-team-all .signup-team-dir:hover{background:#fff;transition:background-color .15s ease}.signup-team-all .signup-team-dir:first-child{border:none}.signup-team-all .signup-team-dir .tooltip{margin:10px 0 0 14px}.signup-team-all .signup-team-dir .icon{height:20px;margin:0 -8px 0 15px;cursor:pointer;float:left;opacity:.45}.signup-team-all .signup-team-dir .icon svg{width:20px;height:20px}.signup-team-all .signup-team-dir .fa-lock{position:relative;top:1px;font-size:18px}.signup-team-all .signup-team-dir a{display:flex;height:3.5em;flex:1 1 auto;align-items:center;justify-content:space-between;padding:0 20px 0 16px;color:inherit;font-size:1.1em;line-height:3.6em;text-decoration:none}.signup-team-all .signup-team-dir a.disabled{color:rgba(0,0,0,.5);cursor:default}.signup-team-all .signup-team-dir-err{padding:5px 15px;border-top:1px solid #d5d5d5;background:#fafafa;color:inherit}.signup-team-all .signup-team-dir-err:first-child{border:none}.signup-team-all .signup-team-dir__name{overflow:hidden;width:calc(100% - 50px);float:left;text-overflow:ellipsis;white-space:nowrap}.signup-team-all .signup-team__icon{position:relative;color:rgba(0,0,0,.5);font-size:1.5em}.signup-team-all .signup-team__icon.fa-spin{top:16px;right:-2px;font-size:.9em}.signup-team-all .signup-team__icon.fa-info-circle{top:11px;padding-left:.5em;margin-right:.3em;float:left;font-size:1.5em;line-height:1.5em}.authorize-box{width:500px;height:280px;border:1px solid #000;margin:100px auto}.authorize-inner{padding:20px}.authorize-btn{margin-right:6px}.verify_panel{max-width:380px;margin:60px auto auto}.team_statistics .total-count{width:100%;border:1px solid rgba(0,0,0,.15);margin:1em 0;background:#fff;border-radius:3px;text-align:center}.team_statistics .total-count .title{padding:7px 10px;border-bottom:1px solid rgba(0,0,0,.15);font-size:13px;font-weight:400;text-align:left}.team_statistics .total-count .title span{display:inline-block;overflow:hidden;width:calc(100% - 20px);text-overflow:ellipsis;white-space:nowrap}.team_statistics .total-count .title .fa{margin:0;color:#555;float:right;font-size:16px}.team_statistics .total-count .content{overflow:auto;padding:.3em 0 .35em;color:#555;font-size:30px;font-weight:600}.team_statistics .total-count--day{width:760px;height:275px;padding:5px 10px 10px;border:1px solid rgba(0,0,0,.15);margin:10px;background:#fff;clear:both}.team_statistics .total-count--day>div{font-size:18px;font-weight:300}.team_statistics .recent-active-users table{width:100%;table-layout:fixed}.team_statistics .recent-active-users .content{overflow:auto;max-height:400px;padding:0}.team_statistics .recent-active-users tr:first-child td{border-top:none}.team_statistics .recent-active-users tr td{overflow:hidden;*zoom:1;padding:5px 5px 6px;border-top:1px solid rgba(0,0,0,.15);border-left:1px solid rgba(0,0,0,.15);font-size:13px;font-weight:400;text-overflow:ellipsis;white-space:nowrap}.team_statistics .recent-active-users tr td:first-child{border-left:none}.team_statistics .team-statistics__header-row{align-items:center;justify-content:space-between}.team_statistics .team-statistics__team-filter{display:inline-block;width:200px}.inner-wrap.move--left .search-btns{display:none}.inner-wrap.move--left .header-list__right{position:relative;z-index:6;padding-right:0 !important;float:right}.inner-wrap.move--right .search-bar__container{display:none}.inner-wrap.move--right .search-btns{display:none}.inner-wrap.move--right .header-list__right{position:relative;z-index:6;padding-right:0 !important;margin-right:-18px;float:right}.app__content{position:relative;display:flex;height:100%;flex-direction:column;padding-top:50px;margin-left:220px;background:var(--center-channel-bg)}.channel__wrap .app__content{padding-top:0}#archive-link-home{flex:0 0 auto;cursor:pointer;font-size:13px}#archive-link-home .fa{font-size:11px;opacity:.7}#archive-link-home a{display:block;width:100%;padding:10px 20px;color:inherit}.delete-message-text{margin-top:10px}.col-sm-auto{padding-right:15px;padding-left:15px}.footer-pane{padding-bottom:1em;background:#f5f5f5}.footer-pane .footer-link{padding:0 1.5em}.footer-pane .footer-link.copyright{padding-right:0;color:rgba(0,0,0,.5)}.footer-pane .footer-site-name{padding:1.5em 0 1em;font-size:14px;font-weight:bold;text-transform:uppercase}.footer,.footer-pane{height:89px}.channel-header{position:relative;z-index:15;width:100%;max-height:63px;flex:0 0 63px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.12);background:var(--center-channel-bg);font-size:14px}.channel-header .Badge{display:inline-block}.channel-header .channel-header__trigger{display:flex;min-width:0;height:24px;flex:1 1 0;align-items:center;padding:4px 4px;border-radius:4px}.channel-header .channel-header__trigger:hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.channel-header .channel-header__trigger.active{background:rgba(var(--button-bg-rgb), 0.08)}.channel-header .channel-header__trigger.active .heading,.channel-header .channel-header__trigger.active .header-dropdown-chevron-icon{color:var(--button-bg)}.channel-header .channel-header__trigger .heading>span{overflow:hidden;line-height:20px;text-overflow:ellipsis}.channel-header .icon::before{margin-right:0;margin-left:0}.channel-header .channel-header__favorites{position:relative;z-index:1;height:24px;padding:4px;margin-left:4px;border-radius:4px;color:var(--center-channel-color);float:left}.channel-header .channel-header__favorites:hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.channel-header .channel-header__favorites:hover i{opacity:.72}.channel-header .channel-header__favorites.inactive .icon{color:var(--center-channel-color)}.channel-header .channel-header__favorites.active i{opacity:1}.channel-header .channel-header__favorites i{position:relative;top:-1px;font-size:18px;opacity:.56}.channel-header .channel-header__mute{position:relative;z-index:1;height:24px;padding:4px;margin-left:4px;border-radius:4px;color:var(--center-channel-color);float:left}.channel-header .channel-header__mute:hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.channel-header .channel-header__mute:hover i{opacity:.72}.channel-header .channel-header__mute.inactive .icon{color:var(--center-channel-color)}.channel-header .channel-header__mute.active i{opacity:1}.channel-header .channel-header__mute i{position:relative;top:-2px;font-size:16px;opacity:.56}.channel-header .channel-header__icon{line-height:16px}.channel-header .channel-header__icon .channel-header__members{font-size:14.4px}.channel-header .channel-header__icon .channel-header__pin{font-size:14.4px}.channel-header .flex-parent{display:flex;padding:0 16px 0 8px}.channel-header .flex-child:first-child{min-width:0;flex:1;padding:0 28px 0 0}.channel-header .flex-child .markdown__paragraph-inline{display:inline-block;overflow:hidden;width:100%;margin:0;text-overflow:ellipsis}.channel-header .channel-header_plugin-dropdown{min-width:200px;max-width:300px;padding:0}.channel-header .channel-header_plugin-dropdown .icon{width:20px;height:20px;margin-right:8px;color:rgba(var(--center-channel-color-rgb), 0.56);fill:rgba(var(--center-channel-color-rgb), 0.56);font-size:1.6rem;text-align:center}.channel-header .channel-header_plugin-dropdown .icon svg,.channel-header .channel-header_plugin-dropdown .icon img{width:16px;height:16px}.channel-header .channel-header_plugin-dropdown a{padding:10px 16px;border-left:3px solid transparent;background:rgba(var(--sidebar-text-rgb), 0.08)}.channel-header .channel-header_plugin-dropdown a:hover .fa{opacity:1}.channel-header .channel-header_plugin-dropdown a:hover svg{opacity:1}.move--left .channel-header .icon--hidden{display:none}.channel-header.alt{margin:0}.channel-header.alt th{font-weight:normal;vertical-align:top}.channel-header.alt th.header-list__right{padding-right:4px;white-space:nowrap}.channel-header.alt td{border:none}.channel-header .heading{overflow:hidden;margin:0 0 0 2px;font-family:Metropolis,sans-serif;font-size:16px;font-weight:600;line-height:16px;text-overflow:ellipsis}.channel-header .heading .Badge{font-family:"Open Sans",sans-serif}.channel-header .caret{margin-top:3px}.channel-header .more{display:inline-block;color:#81848b;font-size:13px;text-transform:capitalize;vertical-align:top}.channel-header .disabled{color:#999}.channel-header .shared-channel-icon{width:16px;height:16px;margin:0 4px;font-size:16px;line-height:16px}.channel-header .shared-channel-icon::before{margin:0}.row.header{position:relative}.channel__wrap .row.header{display:none}.header-dropdown__icon{position:relative;top:0;margin:0 0 0 4px;color:inherit;font-size:16px;line-height:16px}.channel-header__top{display:flex;min-width:0;align-items:center}.channel-header__bot{margin-left:4px}.channel-header__info{margin-top:8px;white-space:nowrap}.channel-header__info .dropdown-toggle{display:flex;overflow:hidden;text-align:left;text-overflow:ellipsis}.channel-header__info .header-dropdown__icon{flex:0 0 auto}.channel-header__info .channel-header__title{display:flex}.channel-header__info .channel-header__title .channel-header__favorites{flex:0 0 auto}.channel-header__info .channel-header__title .channel-header-archived-icon{opacity:.5}.channel-header__info .channel-header__title>div{display:flex;min-width:0;flex:0 1 auto}.channel-header__info .channel-header__title>a{display:inline-block;width:calc(100% - 65px);text-decoration:none}.channel-header__info .channel-header__title .MenuWrapper{width:100%}.channel-header__info .channel-header__title .modal{white-space:normal}.channel-header__info .channel-header__description{position:relative;display:flex;overflow:hidden;width:100%;height:25px;align-items:center;margin:0;font-size:12px;text-overflow:ellipsis}.channel-header__info .channel-header__description span[data-emoticon] .emoticon,.channel-header__info .channel-header__description span[data-emoticon] .emoticon--post-menu{position:relative;top:-1px;overflow:hidden}.channel-header__info .channel-header__description blockquote{overflow:hidden;padding:0 0 0 20px;font-size:13px;text-overflow:ellipsis}.channel-header__info .channel-header__description blockquote::before{top:0;left:2px;font-size:15px}.channel-header__info .channel-header__description .header-placeholder{display:flex;overflow:hidden;align-items:center;margin-left:4px;line-height:16px}.channel-header__info .channel-header__description .header-placeholder span{overflow:hidden;text-overflow:ellipsis}.channel-header__info .channel-header__description .header-placeholder .icon{margin-left:4px}.channel-header__info .channel-header__description .header-description__text{display:flex;overflow:hidden;flex-direction:column;align-self:start;margin-top:4px;margin-left:4px;line-height:19px}.channel-header__info .channel-header__description .header-description__text ul:first-child{margin:0}.channel-header__info .channel-header__description .header-description__text li{margin-bottom:8px}.channel-header__info .channel-header__description .header-description__text li p{display:inline;margin:0}.channel-header__info .channel-header__description .markdown__heading{margin:0;font-size:1em}.channel-header__info .channel-header__description code{padding:2px 5px 0;margin:1px 0 0}.channel-header__info .channel-header__description.light{overflow:visible;color:inherit;opacity:1}.channel-header__info .channel-header__description.light button{color:rgba(var(--center-channel-color-rgb), 0.64)}.channel-header__info .channel-header__description.light button .edit-icon{display:none}.channel-header__info .channel-header__description.light button:focus,.channel-header__info .channel-header__description.light button:hover{color:rgba(var(--center-channel-color-rgb), 0.72);text-decoration:none}.channel-header__info .channel-header__description.light button:hover .edit-icon{display:block}.channel-header__info .channel-header__description .markdown-inline-img{max-height:45px}.channel-header__info .channel-header__description .edit-icon{font-size:14px}.channel-header__info .channel-header__description .status{margin-left:6px;line-height:16px}.channel-header__info .has-guest-header::after{position:relative;top:1px;margin:0 2px 0 5px;content:"•"}.channel-header__info .header-status__text{display:flex;overflow:hidden;align-items:center;margin-right:7px;line-height:16px}.channel-header__info .header-status__text p{margin:0}.channel-header__info .status{width:auto;margin:0 4px 0 0}.channel-header__info .status svg{width:12px}.channel-header__popover p,.navbar__popover p{white-space:pre-wrap}.channel-intro{padding:110px 15px 0;margin:0 auto 10px}.channel-intro.channel-intro--centered{max-width:1020px}.channel-intro .intro-links{display:inline-block;padding:8px 16px;margin-bottom:10px}.channel-intro .intro-links .fa,.channel-intro .intro-links i{margin-right:5px}.channel-intro .channel-intro-profile{margin:0 0 4px}.channel-intro .channel-intro-profile .user-popover{overflow:hidden;max-width:calc(100% - 100px);font-family:Metropolis,sans-serif;font-size:28px;font-weight:600;text-overflow:ellipsis}.channel-intro .channel-intro-img .status-wrapper{height:50px;margin:0 10px 10px 0}.channel-intro .channel-intro-img img{border-radius:100px}.channel-intro .channel-intro__title{margin-bottom:15px;font-size:28px;font-weight:600}.channel-intro .channel-intro__content{padding:10px 15px;background:#f5f5f5;border-radius:3px}.sidebar--left .divider,#SidebarContainer .divider,.sidebar--menu .divider,.admin-sidebar .divider{border-top:1px solid transparent}.sidebar--left .divider+.divider,#SidebarContainer .divider+.divider,.sidebar--menu .divider+.divider,.admin-sidebar .divider+.divider{display:none}.sidebar--left .team__header,#SidebarContainer .team__header,.sidebar--menu .team__header,.admin-sidebar .team__header{*zoom:1;position:relative;display:flex;max-height:63px;flex:0 0 63px;flex-direction:row-reverse;align-items:center;padding:10px}.sidebar--left .team__header::after,#SidebarContainer .team__header::after,.sidebar--menu .team__header::after,.admin-sidebar .team__header::after{display:table;clear:both;content:""}.sidebar--left .team__header::before,#SidebarContainer .team__header::before,.sidebar--menu .team__header::before,.admin-sidebar .team__header::before{position:absolute;top:0;left:0;width:100%;height:100%;background:none;content:"";transition:all .12s ease-in-out}.sidebar--left .team__header:hover::before,#SidebarContainer .team__header:hover::before,.sidebar--menu .team__header:hover::before,.admin-sidebar .team__header:hover::before{background:rgba(var(--sidebar-text-rgb), 0.08)}.sidebar--left .team__header:hover .user__name,#SidebarContainer .team__header:hover .user__name,.sidebar--menu .team__header:hover .user__name,.admin-sidebar .team__header:hover .user__name{color:var(--sidebar-header-text-color)}.sidebar--left .team__header:hover .sidebar-header-dropdown .sidebar-header-dropdown__toggle,#SidebarContainer .team__header:hover .sidebar-header-dropdown .sidebar-header-dropdown__toggle,.sidebar--menu .team__header:hover .sidebar-header-dropdown .sidebar-header-dropdown__toggle,.admin-sidebar .team__header:hover .sidebar-header-dropdown .sidebar-header-dropdown__toggle{opacity:1}.sidebar--left .team__header:hover .navbar-right .dropdown-toggle,#SidebarContainer .team__header:hover .navbar-right .dropdown-toggle,.sidebar--menu .team__header:hover .navbar-right .dropdown-toggle,.admin-sidebar .team__header:hover .navbar-right .dropdown-toggle{opacity:1}.sidebar--left .team__header .d-flex,#SidebarContainer .team__header .d-flex,.sidebar--menu .team__header .d-flex,.admin-sidebar .team__header .d-flex{width:100%}.sidebar--left .team__header .d-flex .MenuWrapper,#SidebarContainer .team__header .d-flex .MenuWrapper,.sidebar--menu .team__header .d-flex .MenuWrapper,.admin-sidebar .team__header .d-flex .MenuWrapper{flex:1}.sidebar--left .team__header .d-flex .MenuWrapper.status-dropdown-menu,#SidebarContainer .team__header .d-flex .MenuWrapper.status-dropdown-menu,.sidebar--menu .team__header .d-flex .MenuWrapper.status-dropdown-menu,.admin-sidebar .team__header .d-flex .MenuWrapper.status-dropdown-menu{flex-grow:0}.sidebar--left .team__header a,#SidebarContainer .team__header a,.sidebar--menu .team__header a,.admin-sidebar .team__header a{flex-grow:1;text-decoration:none}.sidebar--left .team__header a.out_of_office,#SidebarContainer .team__header a.out_of_office,.sidebar--menu .team__header a.out_of_office,.admin-sidebar .team__header a.out_of_office{background-color:transparent !important;cursor:default}.sidebar--left .team__header .dropdown,#SidebarContainer .team__header .dropdown,.sidebar--menu .team__header .dropdown,.admin-sidebar .team__header .dropdown{padding:3px 0 0 16px}.sidebar--left .team__header .dropdown-menu,#SidebarContainer .team__header .dropdown-menu,.sidebar--menu .team__header .dropdown-menu,.admin-sidebar .team__header .dropdown-menu{overflow:auto;min-width:240px;margin:4px 0 0 6px}.sidebar--left .team__header .dropdown-menu .SubMenu,#SidebarContainer .team__header .dropdown-menu .SubMenu,.sidebar--menu .team__header .dropdown-menu .SubMenu,.admin-sidebar .team__header .dropdown-menu .SubMenu{margin:-4px 0 0 -4px}.sidebar--left .team__header .status-dropdown-menu .dropdown-menu,#SidebarContainer .team__header .status-dropdown-menu .dropdown-menu,.sidebar--menu .team__header .status-dropdown-menu .dropdown-menu,.admin-sidebar .team__header .status-dropdown-menu .dropdown-menu{overflow:visible;min-width:256px}.sidebar--left .team__header .sidebar-header-dropdown,.sidebar--left .team__header .admin-navbar-dropdown,#SidebarContainer .team__header .sidebar-header-dropdown,#SidebarContainer .team__header .admin-navbar-dropdown,.sidebar--menu .team__header .sidebar-header-dropdown,.sidebar--menu .team__header .admin-navbar-dropdown,.admin-sidebar .team__header .sidebar-header-dropdown,.admin-sidebar .team__header .admin-navbar-dropdown{position:absolute;top:0;right:22px;left:0;height:100%;margin-right:-22px;font-size:.85em}.sidebar--left .team__header .sidebar-header-dropdown li,.sidebar--left .team__header .admin-navbar-dropdown li,#SidebarContainer .team__header .sidebar-header-dropdown li,#SidebarContainer .team__header .admin-navbar-dropdown li,.sidebar--menu .team__header .sidebar-header-dropdown li,.sidebar--menu .team__header .admin-navbar-dropdown li,.admin-sidebar .team__header .sidebar-header-dropdown li,.admin-sidebar .team__header .admin-navbar-dropdown li{width:100%}.sidebar--left .team__header .sidebar-header-dropdown .sidebar-header-dropdown__toggle,.sidebar--left .team__header .sidebar-header-dropdown .admin-navbar-dropdown__toggle,.sidebar--left .team__header .admin-navbar-dropdown .sidebar-header-dropdown__toggle,.sidebar--left .team__header .admin-navbar-dropdown .admin-navbar-dropdown__toggle,#SidebarContainer .team__header .sidebar-header-dropdown .sidebar-header-dropdown__toggle,#SidebarContainer .team__header .sidebar-header-dropdown .admin-navbar-dropdown__toggle,#SidebarContainer .team__header .admin-navbar-dropdown .sidebar-header-dropdown__toggle,#SidebarContainer .team__header .admin-navbar-dropdown .admin-navbar-dropdown__toggle,.sidebar--menu .team__header .sidebar-header-dropdown .sidebar-header-dropdown__toggle,.sidebar--menu .team__header .sidebar-header-dropdown .admin-navbar-dropdown__toggle,.sidebar--menu .team__header .admin-navbar-dropdown .sidebar-header-dropdown__toggle,.sidebar--menu .team__header .admin-navbar-dropdown .admin-navbar-dropdown__toggle,.admin-sidebar .team__header .sidebar-header-dropdown .sidebar-header-dropdown__toggle,.admin-sidebar .team__header .sidebar-header-dropdown .admin-navbar-dropdown__toggle,.admin-sidebar .team__header .admin-navbar-dropdown .sidebar-header-dropdown__toggle,.admin-sidebar .team__header .admin-navbar-dropdown .admin-navbar-dropdown__toggle{left:0;display:block;width:100%;height:100%;padding:10px;background:none;color:#fff;font-size:1em;line-height:1.8;opacity:.8}.sidebar--left .team__header .sidebar-header-dropdown .dropdown-menu,.sidebar--left .team__header .admin-navbar-dropdown .dropdown-menu,#SidebarContainer .team__header .sidebar-header-dropdown .dropdown-menu,#SidebarContainer .team__header .admin-navbar-dropdown .dropdown-menu,.sidebar--menu .team__header .sidebar-header-dropdown .dropdown-menu,.sidebar--menu .team__header .admin-navbar-dropdown .dropdown-menu,.admin-sidebar .team__header .sidebar-header-dropdown .dropdown-menu,.admin-sidebar .team__header .admin-navbar-dropdown .dropdown-menu{min-width:199px;margin-top:4px;margin-left:10px}.sidebar--left .team__header .sidebar-header-dropdown .dropdown-menu a,.sidebar--left .team__header .sidebar-header-dropdown .dropdown-menu button,.sidebar--left .team__header .admin-navbar-dropdown .dropdown-menu a,.sidebar--left .team__header .admin-navbar-dropdown .dropdown-menu button,#SidebarContainer .team__header .sidebar-header-dropdown .dropdown-menu a,#SidebarContainer .team__header .sidebar-header-dropdown .dropdown-menu button,#SidebarContainer .team__header .admin-navbar-dropdown .dropdown-menu a,#SidebarContainer .team__header .admin-navbar-dropdown .dropdown-menu button,.sidebar--menu .team__header .sidebar-header-dropdown .dropdown-menu a,.sidebar--menu .team__header .sidebar-header-dropdown .dropdown-menu button,.sidebar--menu .team__header .admin-navbar-dropdown .dropdown-menu a,.sidebar--menu .team__header .admin-navbar-dropdown .dropdown-menu button,.admin-sidebar .team__header .sidebar-header-dropdown .dropdown-menu a,.admin-sidebar .team__header .sidebar-header-dropdown .dropdown-menu button,.admin-sidebar .team__header .admin-navbar-dropdown .dropdown-menu a,.admin-sidebar .team__header .admin-navbar-dropdown .dropdown-menu button{overflow:hidden;padding:3px 20px;text-overflow:ellipsis}.sidebar--left .team__header .sidebar-header-dropdown .admin-navbar-dropdown__icon,.sidebar--left .team__header .admin-navbar-dropdown .admin-navbar-dropdown__icon,#SidebarContainer .team__header .sidebar-header-dropdown .admin-navbar-dropdown__icon,#SidebarContainer .team__header .admin-navbar-dropdown .admin-navbar-dropdown__icon,.sidebar--menu .team__header .sidebar-header-dropdown .admin-navbar-dropdown__icon,.sidebar--menu .team__header .admin-navbar-dropdown .admin-navbar-dropdown__icon,.admin-sidebar .team__header .sidebar-header-dropdown .admin-navbar-dropdown__icon,.admin-sidebar .team__header .admin-navbar-dropdown .admin-navbar-dropdown__icon{position:relative;top:0;right:-5px;width:36px;height:36px;border-radius:36px;fill:#fff;float:right;line-height:36px;text-align:center}.sidebar--left .team__header .Avatar,#SidebarContainer .team__header .Avatar,.sidebar--menu .team__header .Avatar,.admin-sidebar .team__header .Avatar{float:left}.sidebar--left .team__header .header__info,#SidebarContainer .team__header .header__info,.sidebar--menu .team__header .header__info,.admin-sidebar .team__header .header__info{position:relative;width:100%;flex-grow:1;padding:2px 36px 0 0;color:var(--sidebar-header-text-color)}.sidebar--left .team__header .header__info__content,#SidebarContainer .team__header .header__info__content,.sidebar--menu .team__header .header__info__content,.admin-sidebar .team__header .header__info__content{display:flex;max-width:120px}.sidebar--left .team__header .team__name,.sidebar--left .team__header .user__name,#SidebarContainer .team__header .team__name,#SidebarContainer .team__header .user__name,.sidebar--menu .team__header .team__name,.sidebar--menu .team__header .user__name,.admin-sidebar .team__header .team__name,.admin-sidebar .team__header .user__name{display:block;overflow:hidden;font-size:16px;font-weight:600;text-decoration:none;text-overflow:ellipsis;white-space:nowrap}.sidebar--left .team__header .team__name,#SidebarContainer .team__header .team__name,.sidebar--menu .team__header .team__name,.admin-sidebar .team__header .team__name{margin:0;font-family:Metropolis,sans-serif;line-height:22px}.sidebar--left .team__header .user__name,#SidebarContainer .team__header .user__name,.sidebar--menu .team__header .user__name,.admin-sidebar .team__header .user__name{position:relative;top:-3px;padding-right:4px;color:rgba(var(--sidebar-header-text-color-rgb), 0.8);font-size:14px;font-weight:400;transition:all .12s ease-in-out}.sidebar--left .team__header .custom-status,#SidebarContainer .team__header .custom-status,.sidebar--menu .team__header .custom-status,.admin-sidebar .team__header .custom-status{display:flex;font-size:12px;font-weight:bold}.sidebar--left .team__header .custom-status-text,#SidebarContainer .team__header .custom-status-text,.sidebar--menu .team__header .custom-status-text,.admin-sidebar .team__header .custom-status-text{margin-left:4px}.sidebar--left .team__header .custom-status-emoji,#SidebarContainer .team__header .custom-status-emoji,.sidebar--menu .team__header .custom-status-emoji,.admin-sidebar .team__header .custom-status-emoji{display:flex;min-width:16px;height:16px}.sidebar--left .team__header .custom-status-emoji>span:first-child,#SidebarContainer .team__header .custom-status-emoji>span:first-child,.sidebar--menu .team__header .custom-status-emoji>span:first-child,.admin-sidebar .team__header .custom-status-emoji>span:first-child{width:16px;min-width:16px;height:16px;min-height:16px}.sidebar--left .search__clear,#SidebarContainer .search__clear,.sidebar--menu .search__clear,.admin-sidebar .search__clear{display:none}#navbar_wrapper .navbar-default .navbar-toggle.menu-toggle{padding:0 1em}.channel-header__navbar{font-size:16px}.channel-header__navbar .heading{margin-right:3px}.channel-header__navbar .header-dropdown__icon{top:1px}.app__body .channel-header__links{display:inline-block;width:30px;height:30px;margin-right:1px;font-family:"Open Sans",sans-serif;font-size:22px;line-height:26px;text-align:center}.app__body .channel-header__links th:last-child div{margin-right:10px}.channel__wrap.move--left .app__body .channel-header__links{position:absolute;top:14px;right:-400px}.app__body .channel-header__links>a{color:inherit;opacity:.6;text-decoration:none;transition:all .1s ease-in}.app__body .channel-header__links>a:hover{opacity:.7}.app__body .channel-header__links>a:focus{color:inherit}.app__body .channel-header__links>a.active{color:#166de0;opacity:1}.app__body .channel-header__links>a.active .icon{fill:#166de0}.channel-header-archived-icon{position:relative;top:2px;margin-right:5px}h1.markdown__heading{font-size:28px}h2.markdown__heading{font-size:25px}h3.markdown__heading{font-size:22px}h4.markdown__heading{font-size:19px}h5.markdown__heading{font-size:15px}h6.markdown__heading{font-size:1em}.markdown__heading{margin:10px 0;font-weight:700;line-height:1.5}.markdown__heading:first-child{margin:5px 0 10px}.markdown__heading .emoticon,.markdown__heading .emoticon--post-menu{min-width:1.5em;min-height:1.5em;vertical-align:top}.markdown__paragraph-inline{display:inline}.markdown__paragraph-inline+.markdown__paragraph-inline{margin-left:4px}#post-list .markdown-inline-img,#rhsContainer .markdown-inline-img{max-height:500px;margin:5px 2px;border-radius:4px;-moz-force-broken-image-icon:1}#post-list div.markdown-inline-img,#rhsContainer div.markdown-inline-img{display:inline-block;width:100%;min-width:50px;vertical-align:top}#post-list .post.post--system .markdown-inline-img,#rhsContainer .post.post--system .markdown-inline-img{width:auto;max-width:200px}#post-list .markdown-inline-img__container,#rhsContainer .markdown-inline-img__container{display:inline-block;width:calc(100% - 5px)}#post-list .markdown-inline-img__container .markdown-image-expand__collapse-button,#rhsContainer .markdown-inline-img__container .markdown-image-expand__collapse-button{z-index:3}#post-list .markdown-inline-img__container .image-preview-utility-buttons-container,#rhsContainer .markdown-inline-img__container .image-preview-utility-buttons-container{top:14px;right:12px}#post-list .markdown-inline-img--loading,#rhsContainer .markdown-inline-img--loading{visibility:hidden}#post-list .markdown-inline-img--hover,#rhsContainer .markdown-inline-img--hover{border:1px solid transparent}#post-list .markdown-inline-img--hover:hover,#rhsContainer .markdown-inline-img--hover:hover{z-index:2;box-shadow:0 2px 5px 0 rgba(0,0,0,.1),0 2px 5px 0 rgba(0,0,0,.1);transition:all .1s linear}#post-list .markdown-inline-img--no-border,#rhsContainer .markdown-inline-img--no-border{border:unset}#post-list .markdown-inline-img--scaled-down,#rhsContainer .markdown-inline-img--scaled-down{max-height:18px;margin:2px;border-radius:2px}#post-list .markdown-inline-img--scaled-down:hover,#rhsContainer .markdown-inline-img--scaled-down:hover{z-index:2;box-shadow:0 2px 2px 0 rgba(0,0,0,.1),0 2px 2px 0 rgba(0,0,0,.1);transition:all .1s linear}#post-list .markdown-inline-img--scaled-down-loading,#rhsContainer .markdown-inline-img--scaled-down-loading{height:18px;margin:2px;visibility:hidden}#post-list .broken-image,#rhsContainer .broken-image{border-radius:unset}#post-list .broken-image--scaled-down,#rhsContainer .broken-image--scaled-down{max-height:18px;margin:2px}#channelHeaderDescription .markdown-inline-img,#header-popover .markdown-inline-img{max-height:18px;margin:2px;border-radius:2px;-moz-force-broken-image-icon:1}#channelHeaderDescription .markdown-inline-img--loading,#header-popover .markdown-inline-img--loading{height:18px;visibility:hidden}#channelHeaderDescription .markdown-inline-img--hover,#header-popover .markdown-inline-img--hover{border:1px solid transparent}#channelHeaderDescription .markdown-inline-img--hover:hover,#header-popover .markdown-inline-img--hover:hover{z-index:2;box-shadow:0 2px 2px 0 rgba(0,0,0,.1),0 2px 2px 0 rgba(0,0,0,.1);transition:all .1s linear}#channelHeaderDescription .markdown-inline-img--no-border,#header-popover .markdown-inline-img--no-border{border:unset}#channelHeaderDescription div.markdown__paragraph-inline,#header-popover div.markdown__paragraph-inline{display:inline-block;line-height:22px}#channelHeaderDescription .broken-image,#header-popover .broken-image{max-height:18px;border-radius:unset}.post-code{position:relative;overflow-x:auto;overflow-y:hidden}.post-code code{position:relative;display:block;padding:0;background-color:inherit;font-size:13px;text-align:left;white-space:pre}.post-code:hover .post-code__clipboard{opacity:1}.post-code:hover .post-code__language{opacity:1}.post-code:hover .post-code__overlay{top:6px;right:1px;padding:4px 4px 0;background:var(--center-channel-bg);border-radius:4px}.post-code.post-code--wrap code{white-space:pre-wrap}.post-code .post-code__line-numbers{min-width:36px;padding:0 4px 4px;border-right:1px solid #ccc;margin-right:12px;color:#ccc;font-family:Menlo,Monaco,Consolas,"Courier New",monospace;user-select:none}.post-code .hljs{position:relative;display:flex;flex-direction:row;padding:8.5px;border:1px solid rgba(var(--center-channel-color-rgb), 0.2);margin:5px 0;border-radius:.25em;cursor:auto;font-size:13px;overflow-x:auto;visibility:visible;white-space:pre}.post-code__context-menu.react-contextmenu{background-color:#fff}.post-code__context-menu .react-contextmenu-item .span{display:inline-block;padding:3px 0}.post-code__context-menu .react-contextmenu-item.react-contextmenu-item--divider{border-top:1px solid rgba(63,67,80,.16);margin:5px 15px}.post-code__context-menu .react-contextmenu-item.react-contextmenu-item--divider:hover{background:unset;color:unset}.post-code__overlay{position:absolute;z-index:5;top:5px;right:0;display:flex;height:36px;padding:4px 4px 0;border-radius:0 0 0 2px;color:#fff;user-select:none}.post-code__overlay>span{position:relative;padding:4px;opacity:0}.post-code__overlay .post-code__clipboard{width:28px;height:28px;margin-right:0;border-radius:4px;cursor:pointer}.post-code__overlay .post-code__clipboard:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.post-code__overlay .post-code__clipboard:active{background:rgba(28,88,217,.08)}.post-code__overlay .post-code__clipboard:active i{color:#1c58d9}.post-code__overlay .post-code__clipboard>i{margin-top:1px;margin-left:-2px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:18px}.post-code__overlay .post-code__clipboard .icon-check{animation-duration:.3s;animation-iteration-count:1;animation-name:fadeInOpacity;animation-timing-function:ease-in;opacity:1;color:#3db887}.post-code__overlay .post-code__language{height:28px;padding:4px 8px;margin-left:4px;background-color:rgba(var(--center-channel-color-rgb), 0.56);border-radius:4px;color:var(--center-channel-bg);user-select:none}.post-code__search-highlighting{position:absolute;color:transparent;pointer-events:none;user-select:none}.post__body hr{height:4px;padding:0;border:0 none;margin:15px 0 16px;background-color:#e7e7e7;opacity:.2}.post__body .codespan__pre-wrap code{cursor:auto;white-space:pre-wrap}.markdown__table{margin:5px 0 10px;background:var(--center-channel-bg)}.markdown__table th,.markdown__table td{padding:6px 13px;border:1px solid #ddd}.markdown__table a{white-space:nowrap;word-break:initial}.markdown__table tbody tr{background:var(--center-channel-bg)}.markdown__table tbody tr:nth-child(2n){background-color:#f8f8f8}ol.markdown__list{display:table;padding:0;counter-reset:list}ol.markdown__list>li{display:table-row;counter-increment:list}ol.markdown__list>li::before{display:table-cell;padding-right:8px;content:counter(list) ".";text-align:right}blockquote{position:relative;padding:10px 10px 10px 38px;border:none;margin-bottom:0;font-size:inherit}blockquote::before{position:absolute;top:5px;left:8px;display:inline-block;content:"";font-family:FontAwesome,sans-serif;font-size:20px;font-style:normal;font-weight:normal;opacity:.6;text-decoration:inherit}pre{padding:0;margin:5px 0;color:inherit}code{background-color:rgba(var(--center-channel-color-rgb), 0.1);color:inherit}.help code{background:rgba(51,51,51,.1)}.help .hljs{display:block;padding:.5em;background:#f8f8f8;color:#333;overflow-x:auto}.help .container{margin-bottom:40px}.help .links{margin-top:30px;font-size:1.2em}.nav>li>a:focus,.nav>li>a:hover{background:transparent}.nav-tabs{margin-bottom:10px;background:var(--center-channel-bg)}.nav-tabs>li{margin-right:5px}.nav-tabs>li.active>a{background:var(--center-channel-bg)}.nav-tabs>li>a{padding:7px 15px;border-bottom-color:transparent !important}.nav-tabs>li>a .small{margin-left:4px;opacity:.8}#navbar_wrapper input{margin:0 5px 0 2px}#navbar_wrapper .navbar-header{display:flex}#navbar_wrapper .flex-parent--center{display:flex;justify-content:center}.browser--ie #navbar_wrapper .navbar-default .navbar-brand{overflow:visible;padding:1px}.browser--ie #navbar_wrapper .navbar-default .navbar-brand .heading{max-width:100px}#navbar_wrapper .navbar-default{position:absolute;min-height:50px;border:none;background:var(--sidebar-teambar-bg)}#navbar_wrapper .navbar-default .navbar-nav>li>a{height:50px;padding:0 1.3em}#navbar_wrapper .navbar-default .navbar-nav>li>a i{line-height:50px}#navbar_wrapper .navbar-default .navbar-plugin-button{position:relative;top:1px}#navbar_wrapper .navbar-default .navbar-toggle{z-index:5;width:50px;height:50px;padding:0 10px;border-width:0;border-color:transparent;margin:0;border-radius:0;fill:var(--sidebar-header-text-color);float:left;line-height:48px}#navbar_wrapper .navbar-default .navbar-toggle.navbar-right__icon{display:flex;width:32px;height:32px;align-items:center;justify-content:center;padding:0;margin:9px 10px 0 0;background:rgba(var(--sidebar-header-text-color-rgb), 0.2);border-radius:50px;line-height:0}#navbar_wrapper .navbar-default .navbar-toggle.navbar-right__icon:hover,#navbar_wrapper .navbar-default .navbar-toggle.navbar-right__icon:focus{background:rgba(var(--sidebar-header-text-color-rgb), 0.3)}#navbar_wrapper .navbar-default .navbar-toggle.menu-toggle{margin-right:16px}#navbar_wrapper .navbar-default .navbar-toggle .icon-bar{width:21px;background:var(--sidebar-header-text-color)}#navbar_wrapper .navbar-default .navbar-toggle .icon__search svg{position:relative;left:-1px;width:17px}#navbar_wrapper .navbar-default .navbar-toggle.icon__mute{width:30px;padding:0;font-size:15px;opacity:.6}#navbar_wrapper .navbar-default .navbar-toggle .icon--white{color:#fff}#navbar_wrapper .navbar-default .navbar-brand{display:flex;overflow:hidden;height:50px;flex:1 1 auto;padding:0;font-size:16px;line-height:50px}.app__body #navbar_wrapper .navbar-default .navbar-brand{color:var(--sidebar-header-text-color)}#navbar_wrapper .navbar-default .navbar-brand .dropdown,#navbar_wrapper .navbar-default .navbar-brand .MenuWrapper{max-width:calc(100% - 40px)}#navbar_wrapper .navbar-default .navbar-brand .heading{overflow:hidden;width:auto;text-overflow:ellipsis;white-space:nowrap}#navbar_wrapper .navbar-default .navbar-brand .header-dropdown__icon{margin-left:6px}#navbar_wrapper .navbar-default .navbar-brand .dropdown-toggle,#navbar_wrapper .navbar-default .navbar-brand .MenuWrapper>a{display:flex;overflow:hidden;align-items:center;color:inherit;text-decoration:none}#navbar_wrapper .navbar-default .navbar-brand .description{display:inline-block;margin-right:1em;color:inherit}#navbar_wrapper .sidebar-name{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}#navbar_wrapper .sidebar-name span{margin-left:2px;white-space:nowrap}#navbar_wrapper .channel-create-btn{margin-right:15px}#navbar_wrapper .more-channel-table{width:100%;border:1px solid #dbdbdc}#navbar_wrapper .more-channel-table td{padding:7px}#navbar_wrapper .more-channel-table button{width:110px}#navbar_wrapper .badge-notify{background:#d64946}#TeamSidebar{position:fixed;z-index:13;left:0;display:flex;width:65px;height:100%;flex-direction:column;background-color:var(--sidebar-header-bg);text-align:center}#TeamSidebar .TeamSidebarWrapper{position:relative;overflow:hidden;height:100%;flex:1 1 auto;background-color:rgba(0,0,0,.2);-webkit-overflow-scrolling:touch}#SidebarContainer{position:fixed;z-index:16;left:0;display:flex;width:240px;height:100%;flex-direction:column;border-right:1px solid rgba(var(--center-channel-color-rgb), 0.12);background-color:var(--sidebar-bg)}#SidebarContainer h1,#SidebarContainer h2,#SidebarContainer h3{font-family:"Open Sans",sans-serif}#SidebarContainer.dragging{z-index:14}#SidebarContainer.dragging+div{cursor:no-drop !important}#SidebarContainer.dragging>:not(.SidebarNavContainer){cursor:no-drop !important}#SidebarContainer.dragging .dropDisabled{cursor:no-drop !important}#SidebarContainer.dragging .dropDisabled .SidebarChannelGroupHeader_groupButton,#SidebarContainer.dragging .dropDisabled .SidebarLink{opacity:.4}#SidebarContainer.dragging .dropDisabled .SidebarLink{cursor:no-drop !important}#SidebarContainer.dragging .dropDisabled .SidebarLink:hover{background:none}#SidebarContainer.dragging .SidebarNavContainer:not(.disabled) .SidebarChannelGroup .SidebarChannelGroupHeader_groupButton:hover{color:inherit;cursor:inherit}body.announcement-bar--fixed #SidebarContainer{height:calc(100% - 40px)}#SidebarContainer .a11y--focused{box-shadow:inset 0 0 1px 3px rgba(var(--sidebar-text-rgb), 0.5),inset 0 0 0 1px var(--sidebar-text) !important}#SidebarContainer .a11y--focused .SidebarChannelGroupHeader_groupButton{background-color:inherit !important}#SidebarContainer .SidebarContainer_filterAddChannel{display:flex;width:100%;flex-direction:row;justify-content:space-between}#SidebarContainer .SidebarContainer_rightContainer{display:flex}#SidebarContainer .SidebarHeader{background-color:var(--sidebar-header-bg)}#SidebarContainer .SidebarHeader .header__info{color:var(--sidebar-header-text-color)}#SidebarContainer .SidebarHeader .header__info .user__name{color:rgba(var(--sidebar-header-text-color-rgb), 0.8)}#SidebarContainer .SidebarHeader .header__info .team__name,#SidebarContainer .SidebarHeader .header__info .user__name{max-width:130px}#SidebarContainer .SidebarHeader .header__info:hover .user__name{color:var(--sidebar-header-text-color)}#SidebarContainer .SidebarHeader .status-wrapper{width:36px;height:36px}#SidebarContainer .SidebarHeader .status-wrapper .status{right:-6px;bottom:-5px;width:19px;height:19px;background:var(--sidebar-header-bg);color:var(--sidebar-header-text-color)}#SidebarContainer .SidebarHeader .status-wrapper .status .offline--icon{fill:var(--offline-indicator)}#SidebarContainer .SidebarHeader .status-wrapper .status svg{position:relative;z-index:1;top:0;left:0;width:13px;height:13px;max-height:initial}#SidebarContainer .SidebarChannelNavigator{margin:16px 14px 8px 14px}#SidebarContainer .SidebarChannelNavigator.desktop{display:block}#SidebarContainer .SidebarChannelNavigator.desktop .AddChannelDropdown_dropdownButton,#SidebarContainer .SidebarChannelNavigator.desktop .SidebarFilters_filterButton,#SidebarContainer .SidebarChannelNavigator.desktop .SidebarChannelNavigator_backButton,#SidebarContainer .SidebarChannelNavigator.desktop .SidebarChannelNavigator_inviteUsers,#SidebarContainer .SidebarChannelNavigator.desktop .SidebarChannelNavigator_forwardButton{background:transparent}#SidebarContainer .SidebarChannelNavigator.desktop .AddChannelDropdown_dropdownButton:hover:not(.active),#SidebarContainer .SidebarChannelNavigator.desktop .SidebarFilters_filterButton:hover:not(.active),#SidebarContainer .SidebarChannelNavigator.desktop .SidebarChannelNavigator_backButton:hover:not(.active),#SidebarContainer .SidebarChannelNavigator.desktop .SidebarChannelNavigator_inviteUsers:hover:not(.active),#SidebarContainer .SidebarChannelNavigator.desktop .SidebarChannelNavigator_forwardButton:hover:not(.active){background:rgba(var(--sidebar-text-rgb), 0.08);color:var(--sidebar-text)}#SidebarContainer .SidebarChannelNavigator.webapp{display:flex}#SidebarContainer .SidebarChannelNavigator.webapp .AddChannelDropdown_dropdownButton,#SidebarContainer .SidebarChannelNavigator.webapp .SidebarChannelNavigator_inviteUsers,#SidebarContainer .SidebarChannelNavigator.webapp .SidebarChannelNavigator_jumpToButton,#SidebarContainer .SidebarChannelNavigator.webapp .SidebarFilters_filterButton{margin:0 2px;background:rgba(var(--sidebar-text-rgb), 0.08)}#SidebarContainer .SidebarChannelNavigator.webapp .AddChannelDropdown_dropdownButton:hover:not(.active),#SidebarContainer .SidebarChannelNavigator.webapp .SidebarChannelNavigator_inviteUsers:hover:not(.active),#SidebarContainer .SidebarChannelNavigator.webapp .SidebarChannelNavigator_jumpToButton:hover:not(.active),#SidebarContainer .SidebarChannelNavigator.webapp .SidebarFilters_filterButton:hover:not(.active){background:rgba(var(--sidebar-text-rgb), 0.16);color:var(--sidebar-text)}#SidebarContainer .SidebarChannelNavigator .AddChannelDropdown_dropdownButton,#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_inviteUsers,#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_jumpToButton,#SidebarContainer .SidebarChannelNavigator .SidebarFilters_filterButtontton,#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_backButton,#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_forwardButton{min-width:28px;height:28px;border:0;color:rgba(var(--sidebar-text-rgb), 0.72);font-size:18px;vertical-align:middle}#SidebarContainer .SidebarChannelNavigator .AddChannelDropdown_dropdownButton.disabled,#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_inviteUsers.disabled,#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_jumpToButton.disabled,#SidebarContainer .SidebarChannelNavigator .SidebarFilters_filterButtontton.disabled,#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_backButton.disabled,#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_forwardButton.disabled{background:rgba(255,255,255,.08)}#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_jumpToButton{display:flex;width:100%;align-items:center;padding:0 5px 0 2px;margin-bottom:8px;background:rgba(var(--sidebar-text-rgb), 0.08);border-radius:4px;font-family:"Open Sans",sans-serif;font-size:12px;text-align:left}#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_jumpToButton .icon-magnify{display:inline-flex;margin-right:2px;font-size:18px}#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_jumpToButton .SidebarChannelNavigator_shortcutText{display:none;padding-right:3px;margin-left:auto}#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_jumpToButton:hover{background:rgba(var(--sidebar-text-rgb), 0.16);color:var(--sidebar-text)}#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_jumpToButton:hover .SidebarChannelNavigator_shortcutText{display:inherit}#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_jumpToButton span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_divider{height:28px;border-right:1px solid rgba(var(--sidebar-text-rgb), 0.16);margin-right:8px;margin-left:8px}#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_backButton{padding:0;background:transparent;border-radius:4px}#SidebarContainer .SidebarChannelNavigator .SidebarChannelNavigator_forwardButton{padding:0;background:transparent;border-radius:4px}#SidebarContainer .SidebarFilters{align-items:center}#SidebarContainer .SidebarFilters .SidebarFilters_filterButton{display:block;width:28px;height:28px;border-radius:4px;color:rgba(var(--sidebar-text-rgb), 0.6);font-size:18px;font-weight:400;line-height:26px;text-align:center}#SidebarContainer .SidebarFilters .SidebarFilters_filterButton:hover{color:rgba(var(--sidebar-text-rgb), 0.8)}#SidebarContainer .SidebarFilters .SidebarFilters_filterButton.active{background:var(--sidebar-text);color:var(--sidebar-bg)}#SidebarContainer .AddChannelDropdown{height:30px}#SidebarContainer .AddChannelDropdown .dropdown-menu{min-width:0;margin-top:0;line-height:19px}#SidebarContainer .AddChannelDropdown .dropdown-menu span{color:rgba(var(--center-channel-color-rgb), 0.9);white-space:nowrap}#SidebarContainer .AddChannelDropdown .dropdown-menu button{padding:1px 16px}#SidebarContainer .AddChannelDropdown .dropdown-menu i{color:rgba(var(--center-channel-color-rgb), 0.72);font-size:16px;line-height:16px}#SidebarContainer .AddChannelDropdown_dropdownButton,#SidebarContainer .SidebarChannelNavigator_inviteUsers{z-index:1;width:28px;height:28px;padding:0;border:none;background:transparent;border-radius:4px;color:rgba(var(--sidebar-text-rgb), 0.8);font-size:20px}#SidebarContainer .AddChannelDropdown_dropdownButton:hover,#SidebarContainer .AddChannelDropdown_dropdownButton:active,#SidebarContainer .AddChannelDropdown_dropdownButton:focus{background-color:rgba(var(--sidebar-text-rgb), 0.16);color:var(--sidebar-text);cursor:pointer}#SidebarContainer .AddChannelDropdown_dropdownButton:focus{outline-style:none}#SidebarContainer .SidebarHeaderMenuWrapper{padding-left:5px;background:transparent;border-radius:4px}#SidebarContainer .SidebarHeaderMenuWrapper:hover,#SidebarContainer .SidebarHeaderMenuWrapper:active,#SidebarContainer .SidebarHeaderMenuWrapper:focus{background-color:rgba(var(--sidebar-text-rgb), 0.08)}#SidebarContainer .SidebarHeaderMenuWrapper.MenuWrapper--open{background-color:rgba(var(--sidebar-text-rgb), 0.16)}#SidebarContainer .AddChannelDropdown_dropdownButton{background-color:rgba(var(--sidebar-text-rgb), 0.08);color:rgba(var(--sidebar-text-rgb), 0.72)}#SidebarContainer .SidebarMenu{opacity:1}#SidebarContainer .SidebarMenu .dropdown-menu{min-width:0;padding:8px 0;line-height:20px}#SidebarContainer .SidebarMenu .dropdown-menu span{white-space:nowrap}#SidebarContainer .SidebarMenu .dropdown-menu button{padding:1px 16px}#SidebarContainer .SidebarMenu .dropdown-menu i{color:rgba(var(--center-channel-color-rgb), 0.72);font-size:16px;line-height:16px}#SidebarContainer .SidebarMenu .Menu{position:fixed}#SidebarContainer .SidebarMenu .Menu .MenuItem span.icon{padding-right:12px}#SidebarContainer .SidebarMenu .Menu .MenuItem i::before{margin:0}#SidebarContainer .SidebarMenu .Menu .SubMenu{position:absolute;margin-top:-8px;margin-left:-1px}#SidebarContainer .SidebarMenu .Menu .SubMenu .MenuItem{text-transform:capitalize}#SidebarContainer .SidebarMenu .Menu #SidebarChannelMenu-moveToDivider{padding:1px 0;pointer-events:none}#SidebarContainer .SidebarMenu .Menu #SidebarChannelMenu-moveToDivider .MenuGroup.menu-divider{margin-right:-32px}#SidebarContainer .SidebarMenu .Menu #SidebarChannelMenu-moveToDivider span{display:none}#SidebarContainer .SidebarMenu .styleSelectableItem{text-transform:capitalize}#SidebarContainer .SidebarMenu .styleSelectableItem .MenuItem{width:100%}#SidebarContainer .SidebarMenu .styleSelectableItem .MenuItem div:hover,#SidebarContainer .SidebarMenu .styleSelectableItem .MenuItem div:focus{background:none !important}#SidebarContainer .SidebarMenu .styleSelectableItem .SubMenu__icon-right{padding:0 9px 0 8px;margin-right:0}#SidebarContainer .SidebarMenu .styleSelectableItem .SubMenu__icon-right.mobile{padding:0 4px 0 9px}#SidebarContainer .SidebarMenu .styleSelectableItem .styleSelectableItemDiv{display:flex;height:34px;align-items:center;justify-content:space-between;padding:0 15px;margin:0}#SidebarContainer .SidebarMenu .styleSelectableItem .sorting-menu-checkbox{width:0;padding-right:30px}#SidebarContainer .SidebarMenu .styleSelectableItem .sorting-menu-checkbox i{color:var(--button-bg)}#SidebarContainer .SidebarMenu .styleSelectableItem .SubMenuItemContainer:not(.hasDivider){display:flex;align-items:center;justify-content:space-between}#SidebarContainer .SidebarMenu .styleSelectableItem .selected{width:60%;margin-top:1px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:12px;text-align:right;text-transform:none}#SidebarContainer .SidebarMenu_menuButton{z-index:1;padding:0;border:none;background:transparent;border-radius:4px;color:rgba(var(--sidebar-text-rgb), 0.6);font-size:16px;line-height:16px}#SidebarContainer .SidebarMenu_menuButton:hover,#SidebarContainer .SidebarMenu_menuButton:active,#SidebarContainer .SidebarMenu_menuButton:focus{color:var(--sidebar-text);cursor:pointer}#SidebarContainer .SidebarMenu_menuButton:focus{outline-style:none}#SidebarContainer .SidebarNavContainer{position:relative;flex:1 1 auto}#SidebarContainer .SidebarNavContainer .scrollbar--view{z-index:unset !important}#SidebarContainer .SidebarNavContainer .scrollbar--view~div{z-index:2}#SidebarContainer .SidebarNavContainer .scrollbar--view~div div{z-index:2}#SidebarContainer .SidebarNavContainer .scrollbar--verticalTrack{top:2px;right:2px;bottom:2px;border-radius:3px;pointer-events:none}#SidebarContainer .SidebarNavContainer .scrollbar--vertical{pointer-events:all}#SidebarContainer .SidebarCategory_newLabel{display:flex;width:32px;height:16px;align-items:center;padding:0 4px;margin-right:16px;margin-left:4px;background:var(--mention-bg);border-radius:4px;color:var(--mention-color);font-size:10px;font-weight:600;letter-spacing:.01em;line-height:16px;text-transform:uppercase}#SidebarContainer .SidebarCategory_newDropBox{padding-bottom:6px;margin-bottom:-6px}#SidebarContainer .SidebarCategory_newDropBox .SidebarCategory_newDropBox-content{display:flex;align-items:center;padding:10px;border:1px dashed rgba(var(--sidebar-text-rgb), 0.3);margin:0 16px;border-radius:4px;opacity:1}#SidebarContainer .SidebarCategory_newDropBox .SidebarCategory_newDropBox-content>i{color:rgba(var(--sidebar-text-rgb), 0.6);font-size:18px;line-height:16px}#SidebarContainer .SidebarCategory_newDropBox .SidebarCategory_newDropBox-content .SidebarCategory_newDropBox-label{margin-left:8px;color:rgba(var(--sidebar-text-rgb), 0.72);font-size:12px;line-height:16px}#SidebarContainer .SidebarCategory_newDropBox .SidebarCategory_newDropBox-content.animating{transition-duration:.15s;transition-property:height,padding,color,opacity;transition-timing-function:ease-out}#SidebarContainer .SidebarCategory_newDropBox .SidebarCategory_newDropBox-content.collapsed{height:0;padding-top:0;padding-bottom:0;border-top:none;border-bottom:none;overflow-y:hidden}#SidebarContainer .SidebarCategory_newDropBox .SidebarCategory_newDropBox-content.isDraggingOver{opacity:.25}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarCategory_newLabel{opacity:0}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarMenu{display:block !important}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarMenu .SidebarMenu_menuButton{opacity:0}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarChannelGroupHeader_sortButton{display:block !important;opacity:0}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarChannelGroupHeader_groupButton.a11y--focused+.SidebarMenu .SidebarMenu_menuButton{opacity:1}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarChannelGroupHeader_groupButton.a11y--focused+.SidebarChannelGroupHeader_sortButton{opacity:1}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarLink.a11y--focused .SidebarMenu .SidebarMenu_menuButton{opacity:1}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarMenu_menuButton.a11y--focused{opacity:1}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarChannelGroupHeader_sortButton.a11y--focused{opacity:1}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarMenu.menuOpen .SidebarMenu_menuButton{opacity:1}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader{z-index:1;top:0;display:flex;height:32px;align-items:center;border:none;background-color:var(--sidebar-bg);box-shadow:0 0 0 0 rgba(0,0,0,.33);color:rgba(var(--sidebar-text-rgb), 0.6);font-family:"Open Sans",sans-serif;text-align:left;text-overflow:ellipsis;text-transform:uppercase;transition:box-shadow .25s ease-in-out}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader .SidebarMenu_menuButton{width:28px;height:28px;margin:2px 16px 2px 2px}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader .SidebarMenu_menuButton:hover,#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader .SidebarMenu_menuButton:focus{background-color:rgba(255,255,255,.08)}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader .SidebarMenu_menuButton.additionalClass{margin:0}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader .SidebarMenu:not(.menuOpen){display:none}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader.muted .icon-chevron-down,#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader.muted .SidebarChannelGroupHeader_text{opacity:.4}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader.dragging{border-radius:4px;box-shadow:0 4px 6px rgba(0,0,0,.12);color:var(--sidebar-text)}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader.dragging .SidebarChannelGroupHeader_groupButton{border-radius:4px}#SidebarContainer .SidebarChannelNavigator_inviteMembersLhsButton{display:flex;padding:6px 0;margin-left:15px;color:rgba(var(--sidebar-text-rgb), 0.72);line-height:20px;list-style:none}#SidebarContainer .SidebarChannelNavigator_inviteMembersLhsButton i{font-size:20px}#SidebarContainer .SidebarChannelNavigator_inviteMembersLhsButton span{align-self:flex-end;margin-top:-2px;margin-left:5px}#SidebarContainer .SidebarChannelNavigator_inviteMembersLhsButton--untouched{color:var(--sidebar-unread-text);font-weight:600}#SidebarContainer .SidebarChannelNavigator_inviteMembersLhsButton--untouched i::before{font-weight:600}#SidebarContainer #introTextInvite{display:flex;width:100%}#SidebarContainer #introTextInvite:hover{background-color:var(--sidebar-text-hover-bg)}#SidebarContainer .SidebarChannelNavigator_inviteUsersSticky{position:absolute;z-index:2;bottom:0;display:flex;width:100%;justify-content:space-evenly;padding:16px;background-color:var(--sidebar-bg)}#SidebarContainer .SidebarChannelNavigator_inviteUsersSticky button{min-width:100%;height:32px;padding:3px 10px;border:1px solid var(--sidebar-text);background-color:inherit;border-radius:4px;color:var(--sidebar-text);cursor:pointer;font-size:12px;font-weight:600}#SidebarContainer .SidebarChannelNavigator_inviteUsersSticky button i{margin-right:4px;font-size:14px}#SidebarContainer .SidebarChannelNavigator_inviteUsersSticky button:hover{border:1px solid var(--sidebar-text);color:var(--sidebar-text)}#SidebarContainer .SidebarChannelGroupHeader_groupButton{z-index:1;top:0;display:flex;min-width:0;height:32px;flex:1 1 auto;align-items:center;padding:0;border:none;background-color:transparent;box-shadow:0 0 0 0 rgba(0,0,0,.33);color:rgba(var(--sidebar-text-rgb), 0.6);font-family:"Open Sans",sans-serif;font-size:12px;font-weight:600;text-align:left;text-transform:uppercase;transition:box-shadow .25s ease-in-out;white-space:nowrap}#SidebarContainer .SidebarChannelGroupHeader_groupButton .emoji{color:var(--sidebar-text)}#SidebarContainer .SidebarChannelGroupHeader_groupButton .SidebarChannelGroupHeader_text{overflow:hidden;width:100%;flex:0 1 auto;padding-left:16px;text-overflow:ellipsis}#SidebarContainer .SidebarChannelGroupHeader_groupButton i.icon-chevron-down{max-width:16px}#SidebarContainer .SidebarChannelGroupHeader_groupButton i.icon-chevron-down.hide-arrow{visibility:hidden}#SidebarContainer .SidebarChannelGroupHeader_groupButton i.icon-chevron-down+.SidebarChannelGroupHeader_text{padding-left:0}#SidebarContainer .SidebarChannelGroupHeader--static{padding-left:0}#SidebarContainer button.SidebarChannelGroupHeader_groupButton>div{cursor:pointer}#SidebarContainer .SidebarChannelGroup.menuIsOpen~.SidebarChannelGroup .SidebarChannelGroupHeader_groupButton{background-color:inherit !important}#SidebarContainer .SidebarChannelGroup.menuIsOpen~.SidebarChannelGroup .SidebarChannelGroupHeader_groupButton .SidebarCategory_newLabel{display:none}#SidebarContainer .SidebarChannelGroup.menuIsOpen .SidebarCategory_newLabel{display:none}#SidebarContainer .SidebarNavContainer.disabled .SidebarChannelGroup .SidebarChannelGroupHeader_groupButton{cursor:default}#SidebarContainer .SidebarNavContainer.disabled .SidebarChannelGroup .SidebarChannelGroupHeader_groupButton i.icon-chevron-down{visibility:hidden}#SidebarContainer .SidebarNavContainer:not(.disabled) .SidebarChannelGroup .SidebarChannelGroupHeader:hover .SidebarMenu{display:block}#SidebarContainer .SidebarNavContainer:not(.disabled) .SidebarChannelGroup .SidebarChannelGroupHeader:hover .SidebarCategory_newLabel{display:none}#SidebarContainer .SidebarNavContainer:not(.disabled) .SidebarChannelGroup .SidebarChannelGroupHeader:hover .SidebarChannelGroupHeader_sortButton{display:block}#SidebarContainer .SidebarNavContainer:not(.disabled) .SidebarChannelGroup:not(.dropDisabled) .SidebarChannelGroupHeader:not(.SidebarChannelGroupHeader--static) .SidebarChannelGroupHeader_groupButton:hover>div:not(.SidebarCategory_newLabel),#SidebarContainer .SidebarNavContainer:not(.disabled) .SidebarChannelGroup:not(.dropDisabled) .SidebarChannelGroupHeader:not(.SidebarChannelGroupHeader--static) .SidebarChannelGroupHeader_groupButton:hover>i{color:var(--sidebar-text)}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader_groupButton:focus{outline-style:none}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader_groupButton.directMessages{width:208px}#SidebarContainer .SidebarChannelGroup .SidebarChannelGroupHeader>i{font-size:12px}#SidebarContainer .SidebarChannelGroup .draggingOver{border-radius:4px;box-shadow:inset -1px 0 0 rgba(var(--sidebar-text-rgb), 0.6),inset 0 -1px 0 rgba(var(--sidebar-text-rgb), 0.6),inset 1px 0 0 rgba(var(--sidebar-text-rgb), 0.6),inset 0 1px 0 rgba(var(--sidebar-text-rgb), 0.6)}#SidebarContainer .SidebarChannelGroup .draggingOver .SidebarChannelGroupHeader{background-color:var(--sidebar-bg);border-radius:4px 4px 0 0;box-shadow:inset -1px 0 0 rgba(var(--sidebar-text-rgb), 0.6),inset 1px 0 0 rgba(var(--sidebar-text-rgb), 0.6),inset 0 1px 0 rgba(var(--sidebar-text-rgb), 0.6)}#SidebarContainer .SidebarChannelGroup.capture .SidebarChannelGroup_content{padding-bottom:14px;margin-bottom:0}#SidebarContainer .SidebarChannelGroup.capture .SidebarChannelGroup_content.hasFollowingSibling{padding-bottom:0}#SidebarContainer .SidebarChannelGroup.capture .followingSibling{padding-bottom:14px;margin-bottom:0}#SidebarContainer .SidebarChannelGroupHeader_addButton{z-index:1;width:28px;min-width:28px;height:28px;padding:0;border:none;margin:2px 16px 2px 2px;background:transparent;border-radius:4px;color:rgba(var(--sidebar-text-rgb), 0.64);font-size:18px;line-height:16px}#SidebarContainer .SidebarChannelGroupHeader_addButton:hover{background-color:rgba(255,255,255,.08);color:var(--sidebar-text);cursor:pointer}#SidebarContainer .SidebarChannelGroupHeader_addButton:focus{outline-style:none}#SidebarContainer .SidebarChannelGroupHeader_sortButton{z-index:1;display:none;width:28px;min-width:28px;height:28px;padding:0;border:none;margin:2px 2px 2px auto;background:transparent;border-radius:4px;color:rgba(var(--sidebar-text-rgb), 0.64);font-size:16px;line-height:16px}#SidebarContainer .SidebarChannelGroupHeader_sortButton:hover{background-color:rgba(255,255,255,.08);color:var(--sidebar-text);cursor:pointer}#SidebarContainer .SidebarChannelGroupHeader_sortButton:focus{outline-style:none}#SidebarContainer .SidebarChannelGroup_content{min-height:2px;margin-bottom:14px}#SidebarContainer .SidebarChannelGroup_content.hasFollowingSibling{margin-bottom:0}#SidebarContainer .followingSibling{min-height:2px;margin-bottom:14px}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarChannelGroup_content{padding-bottom:14px;margin-bottom:0}#SidebarContainer .SidebarChannelGroup.a11y--active .SidebarChannelGroup_content.hasFollowingSibling{padding-bottom:0}#SidebarContainer .SidebarChannelGroup.a11y--active .followingSibling{padding-bottom:14px;margin-bottom:0}#SidebarContainer .SidebarChannelGroup_content ul,#SidebarContainer .NavGroupContent{padding:0;margin:0}#SidebarContainer .SidebarChannelGroup .SidebarChannel.newChannelSpacer{height:0}#SidebarContainer .SidebarChannel{display:flex;overflow:hidden;height:32px;align-items:center;color:rgba(var(--sidebar-text-rgb), 0.6);list-style-type:none;opacity:1;transition-duration:.18s;transition-property:height;transition-timing-function:ease;visibility:visible}#SidebarContainer .SidebarChannel:hover .btn-close{opacity:.8;visibility:visible}#SidebarContainer .SidebarChannel.dragging{overflow:visible;background-color:var(--sidebar-bg);border-radius:4px;box-shadow:0 4px 6px rgba(0,0,0,.12)}#SidebarContainer .SidebarChannel.dragging .SidebarLink{background:rgba(255,255,255,.08);border-radius:4px}#SidebarContainer .SidebarChannel.fadeOnDrop{opacity:0;transition:all cubic-bezier(0.2, 1, 0.1, 1) .33s}#SidebarContainer .SidebarChannel.noFloat{transform:none !important}#SidebarContainer .SidebarChannel.selectedDragging{opacity:.25;transition:all cubic-bezier(0.2, 1, 0.1, 1) .33s}#SidebarContainer .SidebarChannel .btn-close{position:relative;width:24px;height:20px;margin-right:16px;font-family:"Open Sans",sans-serif;font-size:21px;font-weight:600;line-height:16px;opacity:0;text-align:center;visibility:hidden}#SidebarContainer .SidebarChannel .btn-close:hover{opacity:1}#SidebarContainer .SidebarChannel .SidebarMenu_menuButton{width:28px;height:28px}#SidebarContainer .SidebarChannel .SidebarChannel__selectedCount{position:absolute;top:-8px;right:-8px;height:25px;padding:2px 9px 7px 9px;background:var(--center-channel-color);border-radius:20px;box-shadow:0 4px 6px rgba(0,0,0,.12)}#SidebarContainer .SidebarChannel .SidebarChannel__selectedCount>span{color:var(--center-channel-bg);font-size:12px;font-weight:600;line-height:11px}#SidebarContainer .SidebarChannel>span{flex-grow:1}#SidebarContainer .SidebarChannel span.SidebarChannelLinkLabel{max-width:100%;height:18px;line-height:18px;text-align:justify;white-space:nowrap}#SidebarContainer .SidebarChannel.expanded{animation-direction:normal;animation-duration:.15s;animation-iteration-count:1;animation-name:toOpaqueAnimation;animation-play-state:running}#SidebarContainer .SidebarChannel.collapsed{height:0 !important;animation-direction:normal;animation-duration:.15s;animation-iteration-count:1;animation-name:toTransparentAnimation;animation-play-state:running}#SidebarContainer .SidebarChannel.invisible{opacity:0}#SidebarContainer .SidebarChannel.animating .SidebarLink{transition-duration:.15s;transition-property:color;transition-timing-function:ease-out}#SidebarContainer .SidebarChannel .SidebarLink{position:relative;display:flex;width:240px;height:32px;align-items:center;padding:7px 16px 7px 19px;border-top:0;border-bottom:0;margin-right:0;color:rgba(var(--sidebar-text-rgb), 0.72);font-size:14px;text-decoration:none}#SidebarContainer .SidebarChannel .SidebarLink .emoji{color:var(--sidebar-text)}#SidebarContainer .SidebarChannel .SidebarLink.muted div.SidebarChannelLinkLabel_wrapper,#SidebarContainer .SidebarChannel .SidebarLink.muted>i,#SidebarContainer .SidebarChannel .SidebarLink.muted .status.status--group,#SidebarContainer .SidebarChannel .SidebarLink.muted .badge,#SidebarContainer .SidebarChannel .SidebarLink.muted .status-wrapper{opacity:.4}#SidebarContainer .SidebarChannel .SidebarLink .SidebarMenu:not(.menuOpen){display:none}#SidebarContainer .SidebarChannel .SidebarLink:focus{outline-style:none}#SidebarContainer .SidebarChannel .SidebarLink:hover,#SidebarContainer .SidebarChannel .SidebarLink.menuOpen{padding-right:5px;background-color:var(--sidebar-text-hover-bg)}#SidebarContainer .SidebarChannel .SidebarLink:hover .DirectChannel__status-icon,#SidebarContainer .SidebarChannel .SidebarLink.menuOpen .DirectChannel__status-icon{box-shadow:inset 0 0 14px rgba(255,255,255,.12)}#SidebarContainer .SidebarChannel .SidebarLink:hover .SidebarMenu_menuButton,#SidebarContainer .SidebarChannel .SidebarLink.menuOpen .SidebarMenu_menuButton{margin-right:11px}#SidebarContainer .SidebarChannel .SidebarLink:hover .SidebarMenu,#SidebarContainer .SidebarChannel .SidebarLink.menuOpen .SidebarMenu{display:block}#SidebarContainer .SidebarChannel .SidebarLink:hover .badge,#SidebarContainer .SidebarChannel .SidebarLink.menuOpen .badge{position:absolute;visibility:hidden}#SidebarContainer .SidebarChannel.active .SidebarLink{background:rgba(var(--sidebar-text-rgb), 0.08)}#SidebarContainer .SidebarChannel.active .SidebarLink .DirectChannel__profile-picture .DirectChannel__status-icon{box-shadow:inset 0 0 14px rgba(255,255,255,.24)}#SidebarContainer .SidebarChannel.active .SidebarLink .SidebarChannelLinkLabel{color:var(--sidebar-text)}#SidebarContainer .SidebarChannel.active .SidebarLink.selected{background:rgba(var(--sidebar-text-active-border-rgb), 0.56)}#SidebarContainer .SidebarChannel.active .SidebarLink.selected:hover{background:rgba(var(--sidebar-text-active-border-rgb), 0.72)}#SidebarContainer .SidebarLink.selected{background:rgba(var(--sidebar-text-active-border-rgb), 0.56);color:rgba(var(--sidebar-text-rgb), 1)}#SidebarContainer .SidebarLink.selected:hover{background:rgba(var(--sidebar-text-active-border-rgb), 0.72)}#SidebarContainer .SidebarChannel.active .SidebarLink::before{position:absolute;top:0;left:-2px;width:4px;height:100%;background:var(--sidebar-text-active-border);border-radius:4px;content:""}#SidebarContainer .SidebarChannel.unread .SidebarChannelLinkLabel,#SidebarContainer .SidebarChannel.unread .SidebarLink>i,#SidebarContainer .SidebarChannel.unread .SidebarLink:hover .SidebarChannelLinkLabel{color:var(--sidebar-unread-text);font-weight:600}#SidebarContainer .SidebarChannel .SidebarLink>i{display:flex;margin:0 6px 0 -2px;font-size:18px}#SidebarContainer .SidebarChannelLinkLabel_wrapper,#SidebarContainer .SidebarChannelLinkLabel_wrapper>div{display:flex;overflow:hidden;flex-grow:1}#SidebarContainer .SidebarChannelLinkLabel_wrapper>div.truncated{display:block;overflow:hidden;width:100%;text-overflow:ellipsis}#SidebarContainer .DirectChannel__profile-picture{height:20px;margin-right:9px}#SidebarContainer .DirectChannel__profile-picture .DirectChannel__status-icon{position:absolute;top:10px;left:10px;display:flex;width:13px;height:13px;align-items:center;justify-content:center;background:var(--sidebar-bg);border-radius:100%;font-size:12px}#SidebarContainer .icon{display:inline-block;font-size:inherit;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:auto;transition:transform .15s ease-out}#SidebarContainer .icon-rotate-minus-90{-webkit-transform:rotate(-90deg);-ms-transform:rotate(-90deg);transform:rotate(-90deg);transition:transform .15s ease-out}#SidebarContainer :root .icon-rotate-180{filter:none}#SidebarContainer .status.status--group{width:18px;height:18px;flex-shrink:0;margin:0 9px 0 1px;background:rgba(var(--sidebar-text-rgb), 0.16);font-size:12px;line-height:18px}#SidebarContainer .status-away{color:var(--away-indicator)}#SidebarContainer .status-online{color:var(--online-indicator)}#SidebarContainer .status-dnd{color:var(--dnd-indicator)}#SidebarContainer+.inner-wrap #app-content{margin-left:240px}.multi-teams #SidebarContainer{left:65px}.multi-teams #SidebarContainer+.inner-wrap #app-content{margin-left:305px}.react-contextmenu--visible{z-index:100;padding:2px 0;border:1px solid #c6c6c6;background:#f0f0f0;border-radius:5px;color:#000;cursor:pointer}.react-contextmenu-item{padding:0 22px;margin:1px 0}.react-contextmenu-item:hover{background:#489dfe;color:#fff}.react-contextmenu-item:focus,.react-contextmenu-item span{outline:none}#sidebarDropdownMenu .MenuItem>button,#sidebarDropdownMenu .MenuItem>div,#sidebarDropdownMenu .MenuItem>a{padding:0 32px 0 24px}@media screen and (min-width: 769px){#SidebarContainer{height:calc(100% - 40px)}#SidebarContainer .SidebarChannelNavigator{margin-top:0;margin-bottom:11px}}@keyframes toOpaqueAnimation{from{opacity:0}to{opacity:1}}@keyframes toTransparentAnimation{from{opacity:1}to{opacity:0}}.sidebar--menu{position:absolute;right:0;display:none;overflow:auto;width:220px;height:100%;padding:0 0 2em;border-right:1px solid rgba(var(--center-channel-color-rgb), 0.12);background:var(--sidebar-bg);color:rgba(var(--sidebar-text-rgb), 0.8);-webkit-overflow-scrolling:touch}.sidebar--menu .icon{display:inline-block;width:20px;margin-right:8px;text-align:center}.sidebar--menu .icon svg{max-width:16px;max-height:16px;fill:var(--sidebar-text)}.sidebar--menu .nav-pills__container{padding-top:5px}.sidebar--menu .team__header{*zoom:1;display:none;padding:0 15px;background:var(--sidebar-header-bg)}.sidebar--menu .team__header::after{display:table;clear:both;content:""}.sidebar--menu .team__header a{color:#fff}.sidebar--menu .team__header .navbar-right{margin:16px -5px 0;font-size:.85em}.sidebar--menu .team__header .navbar-right .dropdown-toggle{padding:0 10px}.sidebar--menu .team__header .navbar-right .dropdown-menu li a{padding:3 20px;color:#555}.sidebar--menu .team__header .navbar-right .dropdown__icon{display:inline-block;width:4px;height:16px;background-size:100% 100%}.sidebar--menu .team__header .team__name{overflow:hidden;max-width:80%;float:left;font-size:1.2em;font-weight:600;line-height:50px;text-decoration:none;text-overflow:ellipsis;white-space:nowrap}.sidebar--menu .nav>li>a,.sidebar--menu .nav>li>button{padding:0 15px;background:none !important;color:inherit;font-size:15px;line-height:40px}.sidebar--menu .nav>li>a svg,.sidebar--menu .nav>li>button svg{position:relative;top:4px;width:18px;height:18px;fill-opacity:.85}.sidebar--menu .nav>li>a .icon,.sidebar--menu .nav>li>button .icon{position:relative;left:-5px;display:inline-block;width:25px;text-align:center}.sidebar--menu .nav>li>a .mentions,.sidebar--menu .nav>li>button .mentions{font-size:17px;font-weight:bold}.app__body .modal-tabs .nav-tabs>li{background-color:var(--center-channel-bg)}.sidebar--right{position:absolute;z-index:11;right:0;width:400px;height:100%;padding:0;transform:translateX(100%)}body.announcement-bar--fixed .sidebar--right{height:calc(100% - 40px)}.sidebar--right.move--left{transition:width .25s 0s ease-in,z-index .25s 0s step-end}.sidebar--right.sidebar--right--expanded{z-index:13;box-shadow:0 8px 24px rgba(0,0,0,.24)}.sidebar--right.sidebar--right--expanded .sidebar-right__body{overflow:hidden}.sidebar--right.sidebar--right--expanded.move--left{transition:width .25s 0s ease-in,z-index .15s .1s step-start}.sidebar--right.sidebar--right--expanded .sidebar--right__bg{visibility:visible}.sidebar--right .sidebar--right__bg{position:absolute;z-index:5;top:-70px;left:-500%;width:1000%;height:110%;background-color:transparent;visibility:hidden}.sidebar--right .sidebar-right__table{display:table}.sidebar--right .sidebar-right__table>div:not(.sidebar-collapse__container){display:table-cell;vertical-align:top}.sidebar--right .sidebar-right__table>div:not(.sidebar-collapse__container):last-child .channel-header__icon{margin-right:12px}.sidebar--right .sidebar-right__table .search-form__container{width:100%}.sidebar--right .sidebar--right__content{display:flex;height:100%;flex-direction:column}.sidebar--right .sidebar--right__back{display:flex;width:2.4rem;height:2.4rem;align-items:center;justify-content:center;margin-right:4px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:12px;text-decoration:none;transition:all .2s ease-in}.sidebar--right .sidebar--right__back:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.sidebar--right .sidebar--right__back:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.sidebar--right .sidebar-right__body{display:flex;height:calc(100% - 56px);flex:1 1 auto;flex-direction:column;border-left:1px solid rgba(var(--center-channel-color-rgb), 0.12);background:var(--center-channel-bg)}.sidebar--right .sidebar-right__body .loading-screen{position:relative;height:40px;padding:0}.sidebar--right .sidebar-right__body .loading-screen .loading__content{height:40px}.sidebar--right .sidebar-right__body .info-card{padding:5px 15px 60px 15px}.emoji-picker--active .sidebar--right .sidebar-right__body .scrollbar--view{pointer-events:none}.sidebar--right .sidebar__overlay{position:absolute;z-index:5;width:100%;height:100%;background-color:#ff0;opacity:.1;pointer-events:none}.sidebar--right .input-group{word-break:break-word}.sidebar--right .sidebar--right__buttons{float:right}.sidebar--right .sidebar--right__expand{margin:0 4px 0 0}.sidebar--right .sidebar--right__expand i{top:0}.sidebar--right .sidebar--right__expand .icon-arrow-collapse{display:none}.sidebar--right .sidebar--right__title{display:flex;height:2.4rem;flex:1 1 auto;padding:0 1.6rem;font-family:Metropolis,sans-serif;font-size:1.6rem;font-weight:600;overflow:hidden;*zoom:1}.sidebar--right .sidebar--right__title__channel{overflow:hidden;height:2.4rem;padding:0 8px;border-left:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin:0 0 0 8px;color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;font-family:"Open Sans",sans-serif;font-size:12px;font-weight:normal;line-height:2.4rem;text-overflow:ellipsis;white-space:nowrap}.sidebar--right .sidebar--right__title__channel:hover{border-color:transparent;background:rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.72)}.sidebar--right .sidebar--right__title__channel:active{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.sidebar--right .sidebar--right__title__subtitle{overflow:hidden;height:2.4rem;padding:0 8px;border-left:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin:0 0 0 8px;color:rgba(var(--center-channel-color-rgb), 0.56);font-family:"Open Sans",sans-serif;font-size:12px;font-weight:normal;line-height:2.4rem;text-overflow:ellipsis;white-space:nowrap}.sidebar--right .sidebar--right__follow__thread{height:2.4rem;margin-right:4px;font-size:12px;line-height:16px}.sidebar--right .sidebar--right__header{display:flex;overflow:hidden;flex:0 0 56px;align-items:center;justify-content:space-between;padding:0 16px 0 0;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);background:rgba(var(--center-channel-color-rgb), 0.04);color:inherit;white-space:nowrap}.sidebar--right .sidebar--right__header .btn-icon{font-size:20px}.sidebar--right .sidebar--right__header .controls{display:flex;align-items:center;justify-content:flex-end}.sidebar--right .sidebar--right__loading{opacity:.7;text-align:center}.sidebar--right .sidebar--right__loading .fa{margin-right:5px}.sidebar--right .sidebar--right__subheader{width:100%;padding-bottom:10vh;margin:auto;font-size:1em;transition:width .25s ease-in}.sidebar--right .sidebar--right__subheader.search__hints{margin:0}.sidebar--right .sidebar--right__subheader h4{margin:0 0 16px;font-size:1em}.sidebar--right .sidebar--right__subheader ul{padding:0 0 0 30px;margin:0;opacity:.7}.sidebar--right .sidebar--right__subheader li{padding-bottom:10px;font-size:.95em}.sidebar--right .sidebar--right__subheader .usage__icon{position:relative;top:3px;margin:0 3px;opacity:.9}.sidebar--right .sidebar--right__subheader.sidebar-expanded{width:52%}.sidebar--right .suggestion-list__content{max-height:120px}.sidebar-right-container{height:calc(100% - 63px)}.sidebar-collapse__container{display:none}.sidebar-collapse{z-index:5;display:flex;width:45px;height:48px;align-items:center;justify-content:center;cursor:pointer;text-align:center;transform:translateX(0);transition:all .2s linear}.sidebar-collapse .fa{position:relative;top:1px}@media screen and (min-width: 769px){#sidebar-right{z-index:20;top:0}#sidebar-right .sidebar-right-container{height:100%}#sidebar-right .sidebar--right__header{flex-basis:63px}#sidebar-right .sidebar--right__title{height:auto;align-items:center;line-height:63px}#sidebar-right .search-bar__container{display:none !important}}.team-btn{position:relative;border-radius:8px;font-weight:bold;letter-spacing:-0.5px;text-align:center;text-transform:capitalize;vertical-align:top}.team-btn.team-btn__add{font-size:25px;line-height:41px;vertical-align:middle}.team-btn.team-btn__add .TeamIcon{border-color:transparent;background-color:transparent;transform-origin:center bottom;transition:transform .1s,background-color .2s}.team-btn.team-btn__add .TeamIcon .TeamIcon__initials{transition:transform .2s}.team-btn.team-btn__add .TeamIcon:hover{border-color:transparent;background-color:rgba(var(--sidebar-text-rgb), 0.08);box-shadow:none}.team-btn.team-btn__add .TeamIcon:active{background-color:rgba(var(--sidebar-text-rgb), 0.16);transform:scale(0.9)}.team-btn.team-btn__add .TeamIcon:active .TeamIcon__initials{transform:scale(1.1)}.team-btn.team-btn__add .TeamIcon::before{display:none}.team-btn.team-btn__add .TeamIcon .icon-plus{font-size:22px}.team-sidebar{position:fixed;z-index:17;bottom:0;left:0;display:flex;width:65px;height:100%;flex-direction:column;background:var(--sidebar-teambar-bg);text-align:center}body.announcement-bar--fixed .team-sidebar{height:calc(100% - 40px)}.team-sidebar .fa{color:var(--sidebar-header-text-color);opacity:.6;transition:all .15s ease}.team-sidebar .fa:hover{opacity:1}.team-sidebar .team-sidebar-bottom-plugin{width:100%;flex:0 0 auto;padding:16px 0 6px;background-color:var(--sidebar-teambar-bg)}.team-sidebar .team-wrapper{position:relative;overflow:hidden;height:100%;flex:1 1 auto;background-color:var(--sidebar-teambar-bg);-webkit-overflow-scrolling:touch}.team-sidebar .team-wrapper .draggable-team-container{position:relative;margin-right:auto;margin-bottom:12px;margin-left:auto}.team-sidebar .team-wrapper .team-container{display:flex;align-items:center;justify-content:center;text-align:center}.team-sidebar .team-wrapper .team-container.unread .unread-badge{position:absolute;z-index:1;top:-2px;right:-3px;width:8px;height:8px;background:var(--mention-bg);border-radius:100%;box-shadow:0 0 0 3px var(--sidebar-teambar-bg)}.team-sidebar .team-wrapper .team-container a{display:block;text-decoration:none;transform:translate(0, 0);transform-origin:center center;transition:transform .1s}.team-sidebar .team-wrapper .team-container a:active{transform:translate(0, 2px)}.team-sidebar .team-wrapper .team-container.active .TeamIcon__content{opacity:1}.team-sidebar .team-wrapper .team-container button{padding:0;border:none;text-decoration:none}.team-sidebar .team-wrapper .team-container a.team-disabled{cursor:not-allowed;opacity:.5}.team-sidebar .team-wrapper .team-container .team-btn{color:var(--sidebar-header-text-color)}.team-sidebar .team-wrapper .team-container .team-btn .badge{border-color:rgba(var(--sidebar-text-rgb), 0.5)}.team-sidebar .team-wrapper .team-container .order-indicator{position:absolute;top:28px;left:12px;display:flex;width:16px;height:16px;justify-content:center;background:#000;border-radius:4px;color:#fff;font-size:12px;font-style:normal;font-weight:500;text-align:center}.team-sidebar .team-wrapper .team-container.isDragging{cursor:grab}.team-sidebar .team-wrapper .team-container.isDragging .TeamIcon{background-color:rgba(255,255,255,.32)}.team-sidebar .team-wrapper .team-container.isDragging .TeamIcon .TeamIcon__image{box-shadow:inset 0 0 0 3px var(--sidebar-teambar-bg)}.team-sidebar .team-wrapper .scrollbar--view{padding-top:15px}.team-sidebar .team-wrapper .team-container a:hover{text-decoration:none}.multi-teams .sidebar--left{left:65px}.multi-teams .app__content{margin-left:285px}.multi-teams .product-wrapper{width:calc(100% - 65px)}@media screen and (min-width: 769px){.team-sidebar{--sidebar-teambar-bg: var(--sidebar-header-bg);--sidebar-header-text-color: var(--sidebar-text);--sidebar-teambar-bg-rgb: var(--sidebar-header-bg-rgb);--sidebar-header-text-color-rgb: var(--sidebar-text-rgb);height:calc(100% - 40px);border-right:solid 1px rgba(var(--center-channel-color-rgb), 0.08)}body.announcement-bar--fixed .team-sidebar{height:calc(100% - 40px - 40px)}}.product-wrapper{width:100%;height:calc(100% - 40px);margin-left:auto}.product-wrapper.wide{width:100%}.webhooks__container{padding:0 13px 15px;border:1px solid;margin-top:10px;border-radius:3px;background:rgba(0,0,0,.1)}.post-attachment-dropdown .select-suggestion-container::after{left:20rem}.post-attachment-dropdown .form-control{width:22rem;text-overflow:ellipsis}.webhook__item{position:relative;font-size:13px}.webhook__item:last-child .divider-light:last-child{display:none}.webhook__item .webhook__remove{position:absolute;top:8px;right:-7px;width:30px;height:30px;color:#e05f5d;font-size:22px;font-weight:bold;text-align:center;text-decoration:none}.webhook__item .webhook__url{padding-right:20px}.post.post--comment .attachment .attachment__body__wrap .btn-close{left:-11px}.sidebar--right .post .attachment .attachment-actions .alert{position:relative;top:0;left:0;display:inline-block;margin:1rem 0 .4rem}.post .attachment{position:relative;margin-left:-20px;cursor:default}.post .attachment:hover .attachment__body__wrap .btn-close{visibility:visible}.post .attachment:hover .attachment__content.attachment__content--permalink{box-shadow:0 4px 6px rgba(0,0,0,.12)}.post .attachment.attachment--permalink{max-width:720px}.post .attachment.attachment--permalink:hover{cursor:pointer}.post .attachment .attachment__content{border-width:1px;border-style:solid;border-left:none;margin:5px 0 5px 20px;background:var(--center-channel-bg);border-radius:0 4px 4px 0}.post .attachment .attachment__content.permalink--opengraph{margin:5px 0 0 20px}.post .attachment .attachment__content.attachment__content--permalink{border-left-width:1px;border-left-style:solid;border-radius:4px 4px 4px 4px;box-shadow:0 2px 3px rgba(0,0,0,.08)}.post .attachment .attachment__thumb-pretext{border:none;margin-left:25px;background:transparent}.post .attachment .attachment__container{padding:12px;border-left-width:4px;border-left-style:solid;border-left-color:var(--sidebar-header-bg)}.post .attachment .attachment__container.attachment__container--good{border-left-color:#00c100}.post .attachment .attachment__container.attachment__container--warning{border-left-color:#dede01}.post .attachment .attachment__container.attachment__container--danger{border-left-color:#e40303}.post .attachment .attachment__container.attachment__container--opengraph,.post .attachment .attachment__container.attachment__container--permalink{display:table;width:100%;padding-bottom:13px;margin:0;table-layout:fixed}.post .attachment .attachment__container.attachment__container--permalink{padding:16px;border-left:none}.post .attachment .attachment__container .sitename{color:#a3a3a3}.post .attachment .attachment__body__wrap.attachment__body__wrap--opengraph{display:table-cell;width:100%;vertical-align:top}.post .attachment .attachment__body__wrap.attachment__body__wrap--permalink{display:table-cell;width:100%;vertical-align:top}.post .attachment .attachment__body__wrap .btn-close{position:absolute;z-index:5;left:-7px;width:20px;height:20px;padding:0;border:none;background:transparent;color:inherit;font-size:21px;font-weight:500;line-height:20px;opacity:.4;outline:none;text-align:center;text-decoration:none;text-shadow:none;visibility:hidden}.post .attachment .attachment__body__wrap .btn-close span{font-family:"Open Sans",sans-serif;line-height:10px}.post .attachment .attachment__body__wrap .btn-close:hover{opacity:.9}.post .attachment .attachment__body__wrap:hover .btn-close{visibility:visible}.post .attachment .attachment__body{width:80%;padding-right:5px;float:left}.post .attachment .attachment__body.attachment__body--no_thumb{width:100%}.post .attachment .attachment__body.attachment__body--opengraph,.post .attachment .attachment__body.attachment__body--permalink{width:100%;padding-right:0;float:none;word-wrap:break-word}.post .attachment .attachment__body .permalink__body--opengraph{overflow:hidden;width:100%;height:1.5em;line-height:1.5em;text-overflow:ellipsis;white-space:nowrap}.post .attachment .attachment__image__container--opengraph{display:table-cell;width:95px;padding-top:3px;padding-left:15px;vertical-align:top}.post .attachment .attachment__image-container{max-width:500px}.post .attachment .attachment__image{max-height:300px;border:1px solid transparent;margin-bottom:1em}.post .attachment .attachment__image.attachment__image--opengraph{max-width:100%;max-height:80px;margin-bottom:0}.post .attachment .attachment__image.attachment__image--opengraph.loading{height:80px;border-color:transparent}.post .attachment .attachment__image.attachment__image--opengraph.large_image{width:100%;max-width:400px;max-height:200px;margin-top:10px;border-radius:3px}.post .attachment .attachment__image.attachment__image--opengraph.large_image.loading{height:150px;border-color:transparent}.post .attachment .attachment__author-name{opacity:.6}.post .attachment .attachment__title{padding:0;margin:5px 0;font-size:14px;font-weight:600;line-height:18px}.post .attachment .attachment__title.has-link{overflow:hidden;color:#2f81b7;text-overflow:ellipsis;white-space:nowrap}.post .attachment .attachment__title.attachment__title--opengraph{height:auto;word-wrap:break-word}.post .attachment .attachment__title.attachment__title--opengraph.is-url{word-break:break-all}.post .attachment .attachment__author-icon{width:14px;height:14px;margin-right:5px;border-radius:50px}.post .attachment .attachment__thumb-container{width:80px;float:right;text-align:right}.post .attachment .attachment__thumb-container img{max-width:100%;max-height:75px}.post .attachment .attachment-fields{width:100%;table-layout:fixed}.post .attachment .attachment-fields .attachment-field__caption{padding-top:.7em;font-weight:600}.post .attachment .attachment-fields .attachment-field p{margin:0}.post .attachment .attachment__footer-container{position:relative;padding-top:.7em;color:#a3a3a3;font-size:12px}.post .attachment .attachment__footer-container .attachment__footer-icon{margin-top:-2px;margin-right:5px}.post .attachment .attachment-actions{position:relative;display:flex;flex-wrap:wrap;padding-bottom:4px}.post .attachment .attachment-actions .form-group{margin-bottom:0}.post .attachment .attachment-actions .form-group:last-child{margin-bottom:0}.post .attachment .attachment-actions button{height:auto;padding:6px 12px;border-width:1px;border-style:solid;margin:8px 8px 0 0;background:var(--center-channel-bg);border-radius:3px;font-size:13px;font-weight:700;outline:0}.post .attachment .attachment-actions button[disabled]{cursor:auto;opacity:.5}.post .attachment .attachment-actions .alert{position:absolute;top:0;left:23rem;padding:5px 10px}.channel-icon{position:relative;display:inline-block;width:15px;margin:0 8px 0 0;text-align:left;vertical-align:top}.channel-icon__lock,.channel-icon__globe{top:1px}.channel-icon__archive,.channel-icon__unarchive{top:2px;left:-2px}.radio.margin-bottom--none,.checkbox.margin-bottom--none{margin-bottom:0}.radio.no-padding,.checkbox.no-padding{padding:0}.radio.no-padding label,.checkbox.no-padding label{padding:0}.form-control ::placeholder{color:inherit}.form-control.form-sm{height:32px;font-size:13px}.form-legend{border:none;margin:0 0 .8rem;color:inherit;font-size:inherit;font-weight:600}.input__help{margin:10px 0 0 0;color:inherit;opacity:.8;word-break:break-word}.input__help.dark{opacity:1}.input__help.error{color:#952321}.form-horizontal .modal-intro{margin:-10px 0 30px}.form-horizontal .form__label{padding-right:3px;font-size:1.1em;font-weight:600;text-align:left}.form-horizontal .form__label.light{padding-top:2px;font-size:1.05em;font-style:italic;font-weight:normal;opacity:.6}.form-horizontal .form-control{font-weight:normal}.form-horizontal .form-group{margin-bottom:25px}.form-horizontal .form-group.less{margin-bottom:10px}.help-block{margin:10px 0 0;color:rgba(0,0,0,.5);font-size:.95em}.form-group{max-width:100%}.form-group.form-group--small{margin-bottom:10px}.has-error .help-block,.has-error .radio,.has-error .checkbox,.has-error .radio-inline,.has-error .checkbox-inline{color:#d64946}.has-error .form__label.control-label{color:inherit !important}.has-error.radio label,.has-error.checkbox label,.has-error.radio-inline label,.has-error.checkbox-inline label{color:#d64946}.multi-select__radio label{display:flex;align-items:center}.multi-select__radio input[type=radio]{width:13px;margin-top:0}.multi-select__radio .flex-parent{display:flex;align-items:center}.multi-select__radio .icon{display:flex;width:14px;height:21px;align-items:center;justify-content:center;padding-right:1px;margin-right:6px}.multi-select__radio .icon+span{margin-right:4px;font-weight:600}.multi-select__radio span:last-child{opacity:.8}.app__body .form-control{border-color:rgba(var(--center-channel-color-rgb), 0.16);background:var(--center-channel-bg);color:var(--center-channel-color)}.app__body .form-control:focus{border-color:rgba(var(--center-channel-color-rgb), 0.4)}.app__body .form-control.inline{display:inline-block;width:auto}.app__body .form-control::-moz-placeholder,.app__body .form-control:-moz-placeholder{color:inherit !important;opacity:.6}.form-control[disabled],.form-control[readonly],fieldset[disabled] .form-control{background-color:#f9f9f9}input[type=file]:focus,input[type=radio]:focus,input[type=checkbox]:focus{outline:none}.notification-sound-dropdown{padding-top:5px}.alert{padding:8px 12px;border-radius:2px}.alert .alert-transparent{background:var(--center-channel-bg)}.alert-grey{background:#f2f2f2;color:#999}.alert--confirm{display:inline-block;padding:4px 10px;margin:1px 0 0 10px;float:left}.alert .btn-close{float:right;font-size:21px;line-height:20px}.alert .btn-close,.alert .btn-close:link,.alert .btn-close:visited,.alert .btn-close:hover,.alert .btn-close:focus,.alert .btn-close:active{color:inherit;text-decoration:none}.announcement-bar{position:fixed;z-index:999;top:0;display:flex;overflow:hidden;width:100%;min-height:40px;max-height:40px;align-items:center;justify-content:center;background-color:#579eff;color:#fff;text-align:center}.announcement-bar .announcement-bar__text{display:flex;overflow:hidden;width:100%;align-items:center;justify-content:center;white-space:nowrap}.announcement-bar .announcement-bar__text>span{overflow:hidden;padding:0 8px;font-size:14px;font-style:normal;font-weight:600;line-height:20px;text-overflow:ellipsis}.announcement-bar .announcement-bar__text>span .announcement-bar__configuration{display:flex;align-items:center;justify-content:center}.announcement-bar .announcement-bar__text>span::after{display:block;content:""}.announcement-bar .announcement-bar__text .annnouncementBar__purchaseNow,.announcement-bar .announcement-bar__text .annnouncementBar__renewLicense{margin-top:0}.announcement-bar .announcement-bar__text .annnouncementBar__renewLicense{border-color:#fff}.announcement-bar a{color:inherit !important;text-decoration:underline}.announcement-bar a:hover,.announcement-bar a:active,.announcement-bar a:focus{color:inherit !important}.announcement-bar a.announcement-bar__close{position:absolute;top:5px;right:0;padding:0 10px;color:#fff;font-family:"Open Sans",sans-serif;font-size:20px;font-weight:600;text-decoration:none}.announcement-bar a.announcement-bar__close:hover{color:#fff;text-decoration:none}.announcement-bar .fa-wrapper{margin:0 5px}.announcement-bar .resend-verification-wrapper::before{content:" "}.announcement-bar .content__icon,.announcement-bar i{margin-right:4px;color:#fff;font-family:"compass-icons";font-size:16px}.announcement-bar button{height:24px;box-sizing:border-box;padding:4px 8px;border:1px solid #fff;margin-left:8px;background-color:inherit !important;border-radius:4px;font-family:Open Sans;font-size:12px;font-style:normal;font-weight:600;line-height:16px}.announcement-bar button:hover{background-color:rgba(255,255,255,.08)}.announcement-bar-critical{background-color:#f74343}.announcement-bar-success{background-color:#06d6a0}.announcement-bar-advisor{background-color:#579eff}.announcement-bar-advisor-ack{background-color:#06d6a0}.announcement-bar-general{background-color:#3d3c40}.announcement-bar__link{margin-left:4px}.advisor-icon{width:16px;height:16px;margin-right:8px;margin-bottom:2px;margin-left:8px}.channel-view .badge{position:relative;display:flex;min-width:18px;height:18px;align-items:center;justify-content:center;padding:0 5px;border-radius:100px;font-size:11px;line-height:18px}.channel-view .team-sidebar .active .badge,.channel-view .team-sidebar .badge,.channel-view .sidebar--left .active .badge,.channel-view .sidebar--left .badge,.channel-view #SidebarContainer .active .badge,.channel-view #SidebarContainer .badge{background:var(--mention-bg);color:var(--mention-color)}.channel-view .team-sidebar .badge,.channel-view #SidebarContainer .badge{min-width:20px;height:auto;padding:0 6px;border-radius:8px;font-size:11px;-webkit-font-smoothing:subpixel-antialiased;-moz-osx-font-smoothing:grayscale;font-weight:700;letter-spacing:0;line-height:16px;text-align:center}.channel-view .team-sidebar .badge.badge-max-number,.channel-view #SidebarContainer .badge.badge-max-number{padding:0 4px 0 5px}.channel-view .team-sidebar .badge{position:absolute;z-index:5;top:-3px;right:-3px;display:inline-block;flex-shrink:0;box-shadow:0 0 0 3px var(--sidebar-teambar-bg)}.channel-view #SidebarContainer .badge{display:inline-block;flex-shrink:0;margin:0 4px}.channel-view .navbar-toggle .badge{position:absolute;top:10px;left:8px}button .unread-badge{display:inline-block;width:8px;height:8px;margin:0 0 0 40px;background:#f74343;border-radius:50%}button.style--none{padding:0;border:none;background:transparent}button.style--none:focus{outline:0;text-decoration:none}button.style--none.btn{padding:6px 12px}button.style--none.btn--block{width:100%;text-align:left}button.style--none:hover,button.style--none:active{text-decoration:none}.btn{border-radius:2px;transition:all .15s ease}.btn.btn-primary{border-color:transparent;background:#166de0}.btn.btn-primary:hover,.btn.btn-primary:focus,.btn.btn-primary:active{background:#1156b2}.btn.btn-danger{color:#fff}.app__body .btn.btn-danger{color:#fff}.app__body .btn.btn-danger:hover,.app__body .btn.btn-danger:focus,.app__body .btn.btn-danger:active{color:#fff}.btn.btn-danger:hover,.btn.btn-danger:focus,.btn.btn-danger:active{color:#fff}.btn.btn-transparent{padding:7px 12px;border:none;background:transparent}.btn.btn-inactive{border-color:transparent;background:rgba(0,0,0,.15);color:#fff}.btn .fa{margin-right:3px}.btn .fa.margin-right{margin-right:6px}.btn .fa.margin-left{margin-left:6px}.btn.btn-link:active,.btn.btn-link:focus{outline:none}.post .card-icon__container{transition:all .15s ease}.btn-icon{width:3.2rem;height:3.2rem;padding:0;border:none;background:transparent;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);fill:rgba(var(--center-channel-color-rgb), 0.56);font-size:1.6rem}.btn-icon:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);fill:rgba(var(--center-channel-color-rgb), 0.72)}.btn-icon:active,.btn-icon--active,.btn-icon--active:hover{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.channel-header__icon{position:relative;z-index:5;display:flex;min-width:32px;height:32px;align-items:center;justify-content:center;padding:0;border:none;margin:16px 0 0 4px;background:transparent;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;fill:rgba(var(--center-channel-color-rgb), 0.56);text-align:center}.channel-header__icon:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);fill:rgba(var(--center-channel-color-rgb), 0.72)}.channel-header__icon .icon{font-size:16px}.channel-header__icon .icon svg{width:16px;height:16px}.channel-header__icon .icon.icon__flag svg{width:18px;height:18px}.channel-header__icon:active,.channel-header__icon--active,.channel-header__icon--active:hover{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.channel-header__icon:active .icon__text,.channel-header__icon--active .icon__text,.channel-header__icon--active:hover .icon__text{color:var(--button-bg)}.channel-header__icon:active .icon,.channel-header__icon--active .icon,.channel-header__icon--active:hover .icon{color:var(--button-bg)}.channel-header__icon--active-inverted,.channel-header__icon--active-inverted:hover{background:var(--button-bg);color:var(--button-color);fill:var(--button-color)}.channel-header__icon .icon__text{margin:0 2px;font-weight:600}.channel-header__icon .icon__search{top:1px}.channel-header__icon--wide{width:auto;min-width:unset;padding:0 6px}.channel-header__icon--left{height:unset;padding:4px;margin:0 4px 0 0}.channel-header__icon--left .icon{width:16px;height:16px}.channel-header__icon--left svg{width:12px;height:12px}.userGuideHelp{display:inline-table}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.modal .channel-invite__content .multi-select__container,.modal .user-groups-modal__content .multi-select__container{padding:0 2.4rem}.modal .channel-invite__content .react-select__multi-value,.modal .user-groups-modal__content .react-select__multi-value{border-radius:50px}.modal .channel-invite__content .multi-select__help,.modal .user-groups-modal__content .multi-select__help{padding:8px 2.4rem 0}.modal .channel-invite__content .filtered-user-list,.modal .user-groups-modal__content .filtered-user-list{display:block;height:auto}.modal .channel-invite__content .react-select__multi-value__label,.modal .user-groups-modal__content .react-select__multi-value__label{display:flex;align-items:center;padding:4px;color:inherit;font-size:14px;font-weight:600}.modal .channel-invite__content .react-select__value__name,.modal .user-groups-modal__content .react-select__value__name{margin:0 0 0 8px}.modal .channel-invite__content .react-select__multi-value__remove,.modal .user-groups-modal__content .react-select__multi-value__remove{margin-right:4px}.modal .channel-invite__content .multi-select__wrapper,.modal .user-groups-modal__content .multi-select__wrapper{position:absolute;z-index:5;overflow:auto;width:calc(100% - 28px);height:auto;max-height:272px;padding:12px 0;margin:-10px 0 0 14px;border-radius:4px;box-shadow:var(--elevation-4)}.modal .channel-invite__content .multi-select__footer,.modal .user-groups-modal__content .multi-select__footer{padding:0 24px 24px 0;text-align:right}.modal .channel-invite__content .btn-primary,.modal .user-groups-modal__content .btn-primary{height:40px;padding:0 36px;border-radius:4px;font-size:14px;font-weight:600}.modal .channel-invite__content .no-channel-message,.modal .user-groups-modal__content .no-channel-message{padding:1rem;font-size:1.4rem}.modal .channel-invite__content .no-channel-message .primary-message,.modal .user-groups-modal__content .no-channel-message .primary-message{margin:0;font-size:inherit}.modal .channel-invite__content .react-select__value-container,.modal .user-groups-modal__content .react-select__value-container{padding:0 16px;font-size:16px}.modal .channel-invite__content .react-select__value-container.react-select__value-container--has-value,.modal .user-groups-modal__content .react-select__value-container.react-select__value-container--has-value{padding:0 8px}.modal .channel-invite__content .more-modal__list,.modal .user-groups-modal__content .more-modal__list{height:auto}.modal .channel-invite__content .more-modal__list .more-modal__options,.modal .user-groups-modal__content .more-modal__list .more-modal__options{overflow:visible;min-height:auto}.modal .channel-invite__content .react-select__control.react-select-auto,.modal .user-groups-modal__content .react-select__control.react-select-auto{min-height:48px;padding:3px 0}.modal .channel-invite__content .loading-screen,.modal .user-groups-modal__content .loading-screen{position:relative !important;padding:1rem}.modal .channel-invite__content .more-modal__actions,.modal .user-groups-modal__content .more-modal__actions{display:none}.modal .channel-invite__content .more-modal__row,.modal .user-groups-modal__content .more-modal__row{height:40px;padding:0 2.4rem;border:none}.modal .channel-invite__content .more-modal__row .more-modal__name,.modal .user-groups-modal__content .more-modal__row .more-modal__name{font-weight:400}.modal .channel-invite__content .more-modal__details,.modal .user-groups-modal__content .more-modal__details{padding-left:12px}.modal .channel-invite__content{display:flex;flex-direction:column}.modal .channel-invite__content .filtered-user-list{order:0}.modal .channel-invite__content .invite-as-guest{width:fit-content;order:1;padding-top:8px;margin-right:2.4rem;margin-bottom:22px;margin-left:auto;font-weight:600}.modal .channel-invite__content .multi-select__footer{order:2;margin-top:10px}.modal .channel-invite__content .multi-select__footer .btn-cancel{display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out;width:80px;height:40px;margin-right:10px}.modal .channel-invite__content .multi-select__footer .btn-cancel:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.modal .channel-invite__content .multi-select__footer .btn-cancel:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.modal .channel-invite__content .multi-select__footer .btn-cancel:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.modal .channel-invite__content .multi-select__footer .btn-cancel i{display:flex;font-size:18px}.modal .channel-invite__content .multi-select__footer .btn-cancel i::before{margin:0 7px 0 0}.modal .channel-invite__content .multi-select__footer .save-button{width:67px;padding:0}.modal .channel-invite__content .custom-no-options-message{padding:12px 15px;font-size:16px;line-height:24px}.modal .channel-invite__content .custom-no-options-message button{padding:0;margin-top:-3px;font-size:16px}body.app__body .channel-invite .multi-select__wrapper,body.app__body .user-groups-modal-create .multi-select__wrapper{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background:rgba(var(--center-channel-bg-rgb), 1)}body:not(.app__body) .channel-invite .multi-select__wrapper,body:not(.app__body) .user-groups-modal-create .multi-select__wrapper{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);background:rgba(var(--sys-center-channel-bg-rgb), 1)}.modal .channel-switcher.modal-dialog,.modal .channel-invite.modal-dialog{margin-top:calc(50vh - 240px)}.modal .channel-switcher .modal-body,.modal .channel-invite .modal-body{max-height:100%;padding:0}.modal .channel-switcher .modal-content,.modal .channel-invite .modal-content{border-radius:8px}.modal .channel-switcher .modal-header,.modal .channel-invite .modal-header{min-height:0;padding:0;border:none;background:transparent}.modal .channel-switcher .modal-header .close,.modal .channel-invite .modal-header .close{top:6px;right:4px;display:flex;width:4rem;height:4rem;align-items:center;justify-content:center;border-radius:4px;font-size:32px;font-weight:400}.modal .channel-switcher .suggestion-list{position:relative}.modal .channel-switcher .suggestion-list__content{height:calc(100vh - 110px);max-height:100%}.modal .channel-switcher__suggestion-box{position:relative;height:362px;padding:0}.modal .channel-switcher__suggestion-box .icon-magnify{position:absolute;top:1.1rem;left:3.4rem;display:flex;width:2rem;height:2rem;align-items:center;opacity:.48}.modal .channel-switcher__suggestion-box .form-control{width:calc(100% - 48px);height:40px;padding:0 34px;margin:0 24px;border-radius:4px}.modal .channel-switcher__suggestion-box .form-control:focus{padding:0 33px;border:2px solid var(--button-bg)}.modal .channel-switcher__suggestion-box .suggestion-list{padding-top:.6rem;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin-top:2.3rem}.modal .channel-switcher__suggestion-box .suggestion-list:first-child{padding-top:0;border:none;margin-top:1rem}.modal .channel-switcher__suggestion-box .suggestion-list__content{overflow:auto;width:100%;height:auto;padding:0;border:none;box-shadow:none}.modal .channel-switcher__suggestion-box .status-wrapper{overflow:visible;height:24px;margin-top:4px;margin-right:12px}.modal .channel-switcher__suggestion-box .status-wrapper .status{right:-2px;bottom:-4px}.modal .channel-switcher__suggestion-box .status-wrapper .status svg{left:2px;max-width:11px}.modal .channel-switcher__suggestion-box .Avatar{width:24px;height:24px}.modal .channel-switcher__suggestion-box .Avatar-sm{margin:0}.modal .channel-switcher__suggestion-box .suggestion-list__divider:first-child{margin:0}.modal .channel-switcher__suggestion-box .suggestion-list__divider:first-child::before{display:none}.modal .channel-switcher__suggestion-box .suggestion-list__icon{height:auto}body.app__body .modal .channel-switcher .modal-header .close,body.app__body .modal .channel-invite .modal-header .close{color:rgba(var(--center-channel-color-rgb), 0.56)}body.app__body .modal .channel-switcher .modal-header .close:hover,body.app__body .modal .channel-invite .modal-header .close:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}body.app__body .modal .channel-switcher .modal-header .close:active,body.app__body .modal .channel-invite .modal-header .close:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}body:not(.app__body) .channel-switcher .close,body:not(.app__body) .channel-invite .close{color:rgba(var(--sys-center-channel-color-rgb), 0.56)}body:not(.app__body) .channel-switcher .close:hover,body:not(.app__body) .channel-invite .close:hover{background-color:rgba(var(--sys-center-channel-color-rgb), 0.08);color:rgba(var(--sys-center-channel-color-rgb), 0.72)}body:not(.app__body) .channel-switcher .close:active,body:not(.app__body) .channel-invite .close:active{background-color:rgba(var(--sys-button-bg-rgb), 0.08);color:var(--sys-button-bg)}.channel-switcher__hint{font-size:12px}.channel-switcher__header,.channel-invite__header{padding:2.4rem 2.4rem 1.6rem}.channel-switcher__header h1,.channel-invite__header h1{margin:0 0 .8rem;font-size:2rem;font-weight:600}.dropdown-menu{background:var(--center-channel-bg);border-radius:4px}.dropdown-menu.colorpicker{z-index:2500;min-width:125px}.dropdown-menu .dropdown-item__plugin{display:flex;justify-content:center}.dropdown-menu .dropdown-item__plugin:empty{display:none}.dropdown-menu>li>a{color:inherit}.dropdown-menu>li>a:hover{color:inherit}.dropdown-menu .a11y--focused{box-shadow:none !important}.open>.dropdown-menu__content{display:block}.open>.dropdown-menu__content>.dropdown-menu{display:block}.dropdown-menu__content{display:none}.dropdown-menu__icons li .fa{width:25px;margin-left:-5px;text-align:center}@media screen and (min-width: 769px){.dropdown-menu{top:calc(100% + 4px);min-width:245px}}.reacticon{position:relative;top:2px;display:inline-block;fill:inherit;opacity:.7;vertical-align:middle;visibility:hidden}.emoticon,.emoticon--post-menu{display:inline-flex;overflow:hidden;width:21px;min-width:21px;height:21px;min-height:21px;align-items:end;justify-content:space-between;border:none !important;background-position:50% 50%;background-repeat:no-repeat;background-size:contain;vertical-align:middle}.emoticon--unicode{font-size:21px}.os--windows .emoticon--unicode{font-size:16px;line-height:1.3}.emoticon:not(.emoticon--unicode),.emoticon--post-menu:not(.emoticon--unicode){color:transparent}.emoticon:not(.emoticon--unicode)::selection,.emoticon--post-menu:not(.emoticon--unicode)::selection{background-color:transparent;color:transparent}.emoticon--post-menu{width:16px;min-width:16px;height:16px;min-height:16px}.emoticon-suggestion{overflow:hidden;*zoom:1;width:100%;height:30px;cursor:pointer;font-size:13px;line-height:30px}.emoticon-suggestion>div:first-child{width:30px;text-align:center}.emoticon-suggestion__image{max-width:20px;max-height:20px;padding:0;margin-top:-2px;text-align:center;vertical-align:middle}.emoji-picker{position:absolute;z-index:1100;display:flex;width:350px;flex-direction:column;border:1px solid;margin-right:3px;background:var(--center-channel-bg);border-radius:2px;border-radius:4px;box-shadow:0 8px 24px rgba(0,0,0,.12);user-select:none;overflow:hidden;*zoom:1}.emoji-picker .emoji-picker__header{background:var(--sidebar-header-bg)}.emoji-picker.emoji-picker--single .emoji-picker__header{position:relative}.browser--ie .emoji-picker{width:325px}.app__content .emoji-picker{margin-right:0}.emoji-picker.bottom{margin-top:10px}.emoji-picker .nav-tabs{display:flex;flex:0 0 34px;justify-content:flex-end;margin-bottom:0}.emoji-picker .nav-tabs li{height:34px;flex:1;font-size:12px;font-weight:600}.emoji-picker .nav-tabs li:first-child{margin-left:7px}.emoji-picker .nav-tabs li a{height:40px;padding:7px 12px;border:none !important;border-bottom:2px solid transparent !important;margin-right:5px;margin-left:5px;background:transparent;outline:none}.emoji-picker .nav-tabs li a:hover,.emoji-picker .nav-tabs li a:active,.emoji-picker .nav-tabs li a:focus{background:transparent}.emoji-picker .nav-tabs li.active a{height:34px;padding-top:9px;margin-right:5px;margin-left:5px;background:transparent;border-radius:0;opacity:1}.emoji-picker .nav-tabs li.active a:hover,.emoji-picker .nav-tabs li.active a:active,.emoji-picker .nav-tabs li.active a:focus{background:transparent}.emoji-picker .nav-tabs svg{position:relative;top:2px}.emoji-picker .tab-content{border-top:1px solid rgba(61,60,64,.2)}.emoji-picker__categories{display:flex;flex-grow:0;flex-shrink:0;justify-content:space-between;padding:0 10px;margin-bottom:8px}.emoji-picker__categories .emoji-picker__category{display:inline-flex;width:28px;height:28px;align-items:center;justify-content:center;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.48);text-decoration:none}.emoji-picker__categories .emoji-picker__category:hover{background-color:rgba(var(--center-channel-color-rgb), 0.04);color:rgba(var(--center-channel-color-rgb), 0.72)}.emoji-picker__categories .emoji-picker__category:active{color:var(--button-bg);color:var(--center-channel-color)}.emoji-picker__categories .emoji-picker__category--selected{background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);fill:var(--button-bg)}.emoji-picker__categories .emoji-picker__category.disable{pointer-events:none}.emoji-picker__categories .emoji-picker__category i{font-size:18px}.emoji-picker__header,.modal-body .emoji-picker .emoji-picker__header{position:absolute;top:0;display:none;width:100%;padding:13px 10px 13px 15px;border:1px solid rgba(0,0,0,.15);background:#166de0;color:var(--sidebar-header-text-color)}.emoji-picker__header .emoji-picker__header-title,.modal-body .emoji-picker .emoji-picker__header .emoji-picker__header-title{margin-top:2px;font-size:17px}.emoji-picker__header .emoji-picker__header-close-button,.modal-body .emoji-picker .emoji-picker__header .emoji-picker__header-close-button{width:30px;height:30px;background:transparent;color:var(--sidebar-header-text-color);opacity:1}.emoji-picker__header .emoji-picker__header-close-button:hover,.modal-body .emoji-picker .emoji-picker__header .emoji-picker__header-close-button:hover{background:rgba(0,0,0,.1)}.modal-body .emoji-picker .emoji-picker__header .emoji-picker__header-title{margin-top:0}.emoji-picker__search-container{position:relative;display:flex;height:32px;align-items:center;justify-content:space-between;border-color:transparent !important;margin:12px}.emoji-picker__search-container .skin-tones{z-index:10;display:flex;overflow:hidden;height:100%;align-items:center;background:var(--center-channel-bg);transition:all .35s ease}.emoji-picker__search-container .skin-tones--active{position:absolute;width:100%;justify-content:space-around}.emoji-picker__search-container .skin-tones--active .skin-tones__close,.emoji-picker__search-container .skin-tones--active .skin-tones__icons{position:relative;display:inline-flex;overflow:hidden;justify-content:center;margin:0 3px;opacity:1}.emoji-picker__search-container .skin-tones--active .skin-tones__close .skin-tones__icon,.emoji-picker__search-container .skin-tones--active .skin-tones__icons .skin-tones__icon{width:32px}.emoji-picker__search-container .skin-tones .skin-tones__icon{position:relative;display:inline-flex;overflow:hidden;width:32px;height:32px;justify-content:center;padding:3px;opacity:1}.emoji-picker__search-container .skin-tones .skin-tones__icon:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px}.emoji-picker__search-container .skin-tones .skin-tones__icon img{-moz-transform:matrix(0.35, 0, 0, 0.35, 0, -20)}.emoji-picker__search-container .skin-tones .emoji-picker__item:last-child{margin:0}.emoji-picker__search-container .skin-tones__content{display:flex;max-height:32px;align-items:center;justify-content:space-between}.emoji-picker__search-container .skin-tones__content.skin-tones__content__single{padding-right:4px;padding-left:10px}.emoji-picker__search-container .emoji-picker__text-container{position:relative;z-index:5;width:95%;height:32px;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:4px}.emoji-picker__search-container .emoji-picker__text-container:focus-within{border:2px solid var(--button-bg)}.emoji-picker__search-container .emoji-picker__text-container:focus-within .emoji-picker__search-icon{padding-top:7px;padding-left:8px}.emoji-picker__search-container .skin-tones__close{display:flex;align-items:center;transition:opacity .35s ease}.emoji-picker__search-container .skin-tones__icons{opacity:0;transition:opacity .35s ease}.emoji-picker__search-container .skin-tones__close-text{width:60px;font-size:12px;font-weight:600;line-height:14px}.emoji-picker__search-container .skin-tones__close-icon{width:32px;height:32px;border:none;margin-right:12px;background:none;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56)}.emoji-picker__search-container .skin-tones__close-icon:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.emoji-picker__search-container .skin-tones__close-icon:active,.emoji-picker__search-container .skin-tones__close-icon--active,.emoji-picker__search-container .skin-tones__close-icon--active:hover{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.emoji-picker__search-container .color-selector{z-index:11;display:flex;width:32px;height:32px;align-items:center;justify-content:center;margin-left:8px;border-radius:4px;transition:all .35s ease}.emoji-picker__search-container .color-selector:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08)}.emoji-picker__search-container .color-selector .emoji-picker__item{margin:0}.emoji-picker__search-container .color-selector .emoji-picker__item:hover{background:transparent}.emoji-picker__search-container .emoji-picker__search-icon{position:absolute;padding-top:8px;padding-left:9px;font-size:14px}.emoji-picker__search-container .emoji-picker__search{width:100%;height:26px;padding:4px 0 0 31px;border-width:0;background:var(--center-channel-bg);border-radius:inherit;font-size:13px}.emoji-picker__search-container .emoji-picker__search:focus{padding:2px 0 0 30px;outline:none}.emoji-picker__items{position:relative;width:100%;height:270px;padding:4px 0 4px 12px;border-top-width:1px;border-top-style:solid;-webkit-overflow-scrolling:touch;overflow-x:hidden;overflow-y:auto}.emoji-picker__items .emoji-picker__container{position:relative;min-width:325px;min-height:100%}.emoji-picker__items .emoji-picker__category-header{position:relative;padding-top:3px;margin-top:6px;color:rgba(var(--center-channel-color-rgb), 0.48);font-size:12px;font-weight:bold;text-transform:uppercase}.emoji-picker__items .emoji-picker__preview_sprite{display:inline-block;height:45px;padding:3px;margin:3px;vertical-align:top}.emoji-picker__item:nth-of-type(9n){margin-right:0}.emoji-picker__row{display:flex;justify-content:flex-start}.emoji-picker__item{position:relative;display:inline-flex;overflow:hidden;width:36px;height:36px;align-items:center;justify-content:center;border-radius:3px;cursor:pointer;vertical-align:middle}.emoji-picker__item.selected,.emoji-picker__item:hover{background-color:rgba(var(--center-channel-color-rgb), 0.16)}.emoji-picker__item:active{background-color:rgba(var(--center-channel-color-rgb), 0.32)}.emoji-picker__item>div{text-align:center}.emoji-picker__item img{position:relative}.emoji-picker__item img.emoji-category--custom{top:auto;left:auto;width:auto;max-width:22px;height:auto;max-height:22px;transform:scale(1)}.emoji-tooltip{z-index:99999}.emoji-picker__footer{display:flex;min-height:58px;align-items:center;justify-content:space-between;border-top:solid 1px rgba(61,60,64,.2)}.emoji-picker__custom{flex-shrink:0;margin:12px;text-decoration:none}.emoji-picker__custom a,.emoji-picker__custom a:hover{background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg) !important;fill:var(--button-bg);font-size:12px;font-weight:600;text-decoration:none}.emoji-picker__custom a:hover{background-color:rgba(var(--button-bg-rgb), 0.12)}.emoji-picker__preview{overflow:hidden;margin:12px;background:var(--center-channel-bg);text-overflow:ellipsis;white-space:nowrap}.emoji-picker__preview.emoji-picker__preview-placeholder span{font-weight:bold}.emoji-picker__preview .emoji-picker__preview-image-label-box{display:inline}.emoji-picker__preview .emoji-picker__preview-image-label-box .emoji-picker__preview-name{font-weight:bold;user-select:text}.emoji-picker__preview .emoji-picker__preview-image-box{margin-right:12px;vertical-align:middle}.emoji-picker__preview .emoji-picker__preview-image-box,.emoji-picker__preview .emoji-picker__preview-image-box .sprite-preview{display:inline-block;width:33px;height:33px}.emoji-picker__preview .emoji-picker__preview-image{max-width:33px;max-height:33px}.emojisprite-preview{width:66px;max-width:none;height:66px;background-repeat:no-repeat;cursor:pointer;-moz-transform:scale(0.5);transform-origin:0 0;zoom:.5}.emojisprite{width:66px;max-width:none;height:66px;background-repeat:no-repeat;border-radius:18px;cursor:pointer;-moz-transform:scale(0.35);zoom:.35}.emojisprite-loading{width:66px;max-width:none;height:66px;background-image:none !important;background-repeat:no-repeat;border-radius:18px;cursor:pointer;-moz-transform:scale(0.35);zoom:.35}.emoji-category-recent{background-image:url(/static/files/9ea8998d9c0389f02c4380b430ab01e6.png)}.emoji-category-smileys-emotion{background-image:url(/static/files/9ea8998d9c0389f02c4380b430ab01e6.png)}.emoji-category-people-body{background-image:url(/static/files/9ea8998d9c0389f02c4380b430ab01e6.png)}.emoji-category-animals-nature{background-image:url(/static/files/9ea8998d9c0389f02c4380b430ab01e6.png)}.emoji-category-food-drink{background-image:url(/static/files/9ea8998d9c0389f02c4380b430ab01e6.png)}.emoji-category-travel-places{background-image:url(/static/files/9ea8998d9c0389f02c4380b430ab01e6.png)}.emoji-category-activities{background-image:url(/static/files/9ea8998d9c0389f02c4380b430ab01e6.png)}.emoji-category-objects{background-image:url(/static/files/9ea8998d9c0389f02c4380b430ab01e6.png)}.emoji-category-symbols{background-image:url(/static/files/9ea8998d9c0389f02c4380b430ab01e6.png)}.emoji-category-flags{background-image:url(/static/files/9ea8998d9c0389f02c4380b430ab01e6.png)}.emoji-1f600{background-position:-1980px -2112px}.emoji-1f603{background-position:-1980px -2310px}.emoji-1f604{background-position:-1980px -2376px}.emoji-1f601{background-position:-1980px -2178px}.emoji-1f606{background-position:-1980px -2508px}.emoji-1f605{background-position:-1980px -2442px}.emoji-1f923{background-position:-2508px -1254px}.emoji-1f602{background-position:-1980px -2244px}.emoji-1f642{background-position:-2046px -2640px}.emoji-1f643{background-position:-2046px -2706px}.emoji-1f609{background-position:-1980px -2706px}.emoji-1f60a{background-position:-1980px -2772px}.emoji-1f607{background-position:-1980px -2574px}.emoji-1f970{background-position:-2772px -858px}.emoji-1f60d{background-position:-1980px -2970px}.emoji-1f929{background-position:-2508px -2772px}.emoji-1f618{background-position:-1980px -3696px}.emoji-1f617{background-position:-1980px -3630px}.emoji-263a-fe0f{background-position:-3564px -1452px}.emoji-1f61a{background-position:-2046px 0}.emoji-1f619{background-position:-1980px -3762px}.emoji-1f972{background-position:-2772px -990px}.emoji-1f60b{background-position:-1980px -2838px}.emoji-1f61b{background-position:-2046px -66px}.emoji-1f61c{background-position:-2046px -132px}.emoji-1f92a{background-position:-2508px -2838px}.emoji-1f61d{background-position:-2046px -198px}.emoji-1f911{background-position:-2442px -1584px}.emoji-1f917{background-position:-2442px -1980px}.emoji-1f92d{background-position:-2508px -3036px}.emoji-1f92b{background-position:-2508px -2904px}.emoji-1f914{background-position:-2442px -1782px}.emoji-1f910{background-position:-2442px -1518px}.emoji-1f928{background-position:-2508px -2706px}.emoji-1f610{background-position:-1980px -3168px}.emoji-1f611{background-position:-1980px -3234px}.emoji-1f636{background-position:-2046px -1848px}.emoji-1f60f{background-position:-1980px -3102px}.emoji-1f612{background-position:-1980px -3300px}.emoji-1f644{background-position:-2046px -2772px}.emoji-1f62c{background-position:-2046px -1188px}.emoji-1f925{background-position:-2508px -1386px}.emoji-1f60c{background-position:-1980px -2904px}.emoji-1f614{background-position:-1980px -3432px}.emoji-1f62a{background-position:-2046px -1056px}.emoji-1f924{background-position:-2508px -1320px}.emoji-1f634{background-position:-2046px -1716px}.emoji-1f637{background-position:-2046px -1914px}.emoji-1f912{background-position:-2442px -1650px}.emoji-1f915{background-position:-2442px -1848px}.emoji-1f922{background-position:-2508px -1188px}.emoji-1f92e{background-position:-2508px -3102px}.emoji-1f927{background-position:-2508px -2640px}.emoji-1f975{background-position:-2772px -1188px}.emoji-1f976{background-position:-2772px -1254px}.emoji-1f974{background-position:-2772px -1122px}.emoji-1f635{background-position:-2046px -1782px}.emoji-1f92f{background-position:-2508px -3168px}.emoji-1f920{background-position:-2508px -1056px}.emoji-1f973{background-position:-2772px -1056px}.emoji-1f978{background-position:-2772px -1716px}.emoji-1f60e{background-position:-1980px -3036px}.emoji-1f913{background-position:-2442px -1716px}.emoji-1f9d0{background-position:-2970px -2244px}.emoji-1f615{background-position:-1980px -3498px}.emoji-1f61f{background-position:-2046px -330px}.emoji-1f641{background-position:-2046px -2574px}.emoji-2639-fe0f{background-position:-3564px -1386px}.emoji-1f62e{background-position:-2046px -1320px}.emoji-1f62f{background-position:-2046px -1386px}.emoji-1f632{background-position:-2046px -1584px}.emoji-1f633{background-position:-2046px -1650px}.emoji-1f97a{background-position:-2772px -1782px}.emoji-1f626{background-position:-2046px -792px}.emoji-1f627{background-position:-2046px -858px}.emoji-1f628{background-position:-2046px -924px}.emoji-1f630{background-position:-2046px -1452px}.emoji-1f625{background-position:-2046px -726px}.emoji-1f622{background-position:-2046px -528px}.emoji-1f62d{background-position:-2046px -1254px}.emoji-1f631{background-position:-2046px -1518px}.emoji-1f616{background-position:-1980px -3564px}.emoji-1f623{background-position:-2046px -594px}.emoji-1f61e{background-position:-2046px -264px}.emoji-1f613{background-position:-1980px -3366px}.emoji-1f629{background-position:-2046px -990px}.emoji-1f62b{background-position:-2046px -1122px}.emoji-1f971{background-position:-2772px -924px}.emoji-1f624{background-position:-2046px -660px}.emoji-1f621{background-position:-2046px -462px}.emoji-1f620{background-position:-2046px -396px}.emoji-1f92c{background-position:-2508px -2970px}.emoji-1f608{background-position:-1980px -2640px}.emoji-1f47f{background-position:-1518px -3234px}.emoji-1f480{background-position:-1518px -3300px}.emoji-2620-fe0f{background-position:-3564px -858px}.emoji-1f4a9{background-position:-1650px -3498px}.emoji-1f921{background-position:-2508px -1122px}.emoji-1f479{background-position:-1518px -2508px}.emoji-1f47a{background-position:-1518px -2574px}.emoji-1f47b{background-position:-1518px -2640px}.emoji-1f47d{background-position:-1518px -3102px}.emoji-1f47e{background-position:-1518px -3168px}.emoji-1f916{background-position:-2442px -1914px}.emoji-1f63a{background-position:-2046px -2112px}.emoji-1f638{background-position:-2046px -1980px}.emoji-1f639{background-position:-2046px -2046px}.emoji-1f63b{background-position:-2046px -2178px}.emoji-1f63c{background-position:-2046px -2244px}.emoji-1f63d{background-position:-2046px -2310px}.emoji-1f640{background-position:-2046px -2508px}.emoji-1f63f{background-position:-2046px -2442px}.emoji-1f63e{background-position:-2046px -2376px}.emoji-1f648{background-position:-2112px -2574px}.emoji-1f649{background-position:-2112px -2640px}.emoji-1f64a{background-position:-2112px -2706px}.emoji-1f48b{background-position:-1650px -1518px}.emoji-1f48c{background-position:-1650px -1584px}.emoji-1f498{background-position:-1650px -2376px}.emoji-1f49d{background-position:-1650px -2706px}.emoji-1f496{background-position:-1650px -2244px}.emoji-1f497{background-position:-1650px -2310px}.emoji-1f493{background-position:-1650px -2046px}.emoji-1f49e{background-position:-1650px -2772px}.emoji-1f495{background-position:-1650px -2178px}.emoji-1f49f{background-position:-1650px -2838px}.emoji-2763-fe0f{background-position:-3696px -2046px}.emoji-1f494{background-position:-1650px -2112px}.emoji-2764-fe0f{background-position:-3696px -2112px}.emoji-1f9e1{background-position:-3366px -2904px}.emoji-1f49b{background-position:-1650px -2574px}.emoji-1f49a{background-position:-1650px -2508px}.emoji-1f499{background-position:-1650px -2442px}.emoji-1f49c{background-position:-1650px -2640px}.emoji-1f90e{background-position:-2442px -1056px}.emoji-1f5a4{background-position:-1980px -396px}.emoji-1f90d{background-position:-2442px -990px}.emoji-1f4af{background-position:-1716px -396px}.emoji-1f4a2{background-position:-1650px -3036px}.emoji-1f4a5{background-position:-1650px -3234px}.emoji-1f4ab{background-position:-1716px -132px}.emoji-1f4a6{background-position:-1650px -3300px}.emoji-1f4a8{background-position:-1650px -3432px}.emoji-1f573-fe0f{background-position:-1914px -396px}.emoji-1f4a3{background-position:-1650px -3102px}.emoji-1f4ac{background-position:-1716px -198px}.emoji-1f441-fe0f-200d-1f5e8-fe0f{background-position:-792px -1848px}.emoji-1f5e8-fe0f{background-position:-1980px -1518px}.emoji-1f5ef-fe0f{background-position:-1980px -1584px}.emoji-1f4ad{background-position:-1716px -264px}.emoji-1f4a4{background-position:-1650px -3168px}.emoji-1f44b{background-position:-858px -1056px}.emoji-1f91a{background-position:-2442px -2838px}.emoji-1f590-fe0f{background-position:-1914px -3036px}.emoji-270b{background-position:-3630px -3564px}.emoji-1f596{background-position:-1980px 0}.emoji-1f44c{background-position:-858px -1452px}.emoji-1f90c{background-position:-2442px -594px}.emoji-1f90f{background-position:-2442px -1122px}.emoji-270c-fe0f{background-position:-3696px -132px}.emoji-1f91e{background-position:-2508px -264px}.emoji-1f91f{background-position:-2508px -660px}.emoji-1f918{background-position:-2442px -2046px}.emoji-1f919{background-position:-2442px -2442px}.emoji-1f448{background-position:-792px -3696px}.emoji-1f449{background-position:-858px -264px}.emoji-1f446{background-position:-792px -2904px}.emoji-1f595{background-position:-1914px -3432px}.emoji-1f447{background-position:-792px -3300px}.emoji-261d-fe0f{background-position:-3564px -462px}.emoji-1f44d{background-position:-858px -1848px}.emoji-1f44e{background-position:-858px -2244px}.emoji-270a{background-position:-3630px -3168px}.emoji-1f44a{background-position:-858px -660px}.emoji-1f91b{background-position:-2442px -3234px}.emoji-1f91c{background-position:-2442px -3630px}.emoji-1f44f{background-position:-858px -2640px}.emoji-1f64c{background-position:-2178px -132px}.emoji-1f450{background-position:-858px -3036px}.emoji-1f932{background-position:-2574px -198px}.emoji-1f91d{background-position:-2508px -198px}.emoji-1f64f{background-position:-2178px -2904px}.emoji-270d-fe0f{background-position:-3696px -528px}.emoji-1f485{background-position:-1584px -2376px}.emoji-1f933{background-position:-2574px -594px}.emoji-1f4aa{background-position:-1650px -3564px}.emoji-1f9be{background-position:-2904px -1584px}.emoji-1f9bf{background-position:-2904px -1650px}.emoji-1f9b5{background-position:-2838px -1584px}.emoji-1f9b6{background-position:-2838px -1980px}.emoji-1f442{background-position:-792px -1980px}.emoji-1f9bb{background-position:-2904px -1056px}.emoji-1f443{background-position:-792px -2376px}.emoji-1f9e0{background-position:-3366px -2838px}.emoji-1fac0{background-position:-3498px -396px}.emoji-1fac1{background-position:-3498px -462px}.emoji-1f9b7{background-position:-2838px -2376px}.emoji-1f9b4{background-position:-2838px -1518px}.emoji-1f440{background-position:-792px -1782px}.emoji-1f441-fe0f{background-position:-792px -1914px}.emoji-1f445{background-position:-792px -2838px}.emoji-1f444{background-position:-792px -2772px}.emoji-1f476{background-position:-1518px -528px}.emoji-1f9d2{background-position:-3168px -2838px}.emoji-1f466{background-position:-924px -990px}.emoji-1f467{background-position:-924px -1386px}.emoji-1f9d1{background-position:-3168px -2442px}.emoji-1f471{background-position:-1452px -1584px}.emoji-1f468{background-position:-1122px -924px}.emoji-1f9d4{background-position:-3168px -3630px}.emoji-1f468-200d-1f9b0{background-position:-1056px -1056px}.emoji-1f468-200d-1f9b1{background-position:-1056px -1452px}.emoji-1f468-200d-1f9b3{background-position:-1056px -2244px}.emoji-1f468-200d-1f9b2{background-position:-1056px -1848px}.emoji-1f469{background-position:-1320px -264px}.emoji-1f469-200d-1f9b0{background-position:-1254px -264px}.emoji-1f9d1-200d-1f9b0{background-position:-3102px -2706px}.emoji-1f469-200d-1f9b1{background-position:-1254px -660px}.emoji-1f9d1-200d-1f9b1{background-position:-3102px -3102px}.emoji-1f469-200d-1f9b3{background-position:-1254px -1452px}.emoji-1f9d1-200d-1f9b3{background-position:-3168px -66px}.emoji-1f469-200d-1f9b2{background-position:-1254px -1056px}.emoji-1f9d1-200d-1f9b2{background-position:-3102px -3498px}.emoji-1f471-200d-2640-fe0f{background-position:-1452px -792px}.emoji-1f471-200d-2642-fe0f{background-position:-1452px -1188px}.emoji-1f9d3{background-position:-3168px -3234px}.emoji-1f474{background-position:-1452px -3564px}.emoji-1f475{background-position:-1518px -132px}.emoji-1f64d{background-position:-2178px -1320px}.emoji-1f64d-200d-2642-fe0f{background-position:-2178px -924px}.emoji-1f64d-200d-2640-fe0f{background-position:-2178px -528px}.emoji-1f64e{background-position:-2178px -2508px}.emoji-1f64e-200d-2642-fe0f{background-position:-2178px -2112px}.emoji-1f64e-200d-2640-fe0f{background-position:-2178px -1716px}.emoji-1f645{background-position:-2046px -3630px}.emoji-1f645-200d-2642-fe0f{background-position:-2046px -3234px}.emoji-1f645-200d-2640-fe0f{background-position:-2046px -2838px}.emoji-1f646{background-position:-2112px -990px}.emoji-1f646-200d-2642-fe0f{background-position:-2112px -594px}.emoji-1f646-200d-2640-fe0f{background-position:-2112px -198px}.emoji-1f481{background-position:-1584px -330px}.emoji-1f481-200d-2642-fe0f{background-position:-1518px -3762px}.emoji-1f481-200d-2640-fe0f{background-position:-1518px -3366px}.emoji-1f64b{background-position:-2112px -3564px}.emoji-1f64b-200d-2642-fe0f{background-position:-2112px -3168px}.emoji-1f64b-200d-2640-fe0f{background-position:-2112px -2772px}.emoji-1f9cf{background-position:-2970px -1848px}.emoji-1f9cf-200d-2642-fe0f{background-position:-2970px -1452px}.emoji-1f9cf-200d-2640-fe0f{background-position:-2970px -1056px}.emoji-1f647{background-position:-2112px -2178px}.emoji-1f647-200d-2642-fe0f{background-position:-2112px -1782px}.emoji-1f647-200d-2640-fe0f{background-position:-2112px -1386px}.emoji-1f926{background-position:-2508px -2244px}.emoji-1f926-200d-2642-fe0f{background-position:-2508px -1848px}.emoji-1f926-200d-2640-fe0f{background-position:-2508px -1452px}.emoji-1f937{background-position:-2574px -3762px}.emoji-1f937-200d-2642-fe0f{background-position:-2574px -3366px}.emoji-1f937-200d-2640-fe0f{background-position:-2574px -2970px}.emoji-1f9d1-200d-2695-fe0f{background-position:-3168px -1254px}.emoji-1f468-200d-2695-fe0f{background-position:-1056px -3432px}.emoji-1f469-200d-2695-fe0f{background-position:-1254px -2640px}.emoji-1f9d1-200d-1f393{background-position:-3036px -66px}.emoji-1f468-200d-1f393{background-position:-924px -2970px}.emoji-1f469-200d-1f393{background-position:-1122px -2508px}.emoji-1f9d1-200d-1f3eb{background-position:-3036px -1254px}.emoji-1f468-200d-1f3eb{background-position:-990px -330px}.emoji-1f469-200d-1f3eb{background-position:-1122px -3696px}.emoji-1f9d1-200d-2696-fe0f{background-position:-3168px -1650px}.emoji-1f468-200d-2696-fe0f{background-position:-1122px 0}.emoji-1f469-200d-2696-fe0f{background-position:-1254px -3036px}.emoji-1f9d1-200d-1f33e{background-position:-2970px -2310px}.emoji-1f468-200d-1f33e{background-position:-924px -1782px}.emoji-1f469-200d-1f33e{background-position:-1122px -1320px}.emoji-1f9d1-200d-1f373{background-position:-2970px -2706px}.emoji-1f468-200d-1f373{background-position:-924px -2178px}.emoji-1f469-200d-1f373{background-position:-1122px -1716px}.emoji-1f9d1-200d-1f527{background-position:-3036px -2838px}.emoji-1f468-200d-1f527{background-position:-990px -2904px}.emoji-1f469-200d-1f527{background-position:-1188px -2112px}.emoji-1f9d1-200d-1f3ed{background-position:-3036px -1650px}.emoji-1f468-200d-1f3ed{background-position:-990px -726px}.emoji-1f469-200d-1f3ed{background-position:-1188px -264px}.emoji-1f9d1-200d-1f4bc{background-position:-3036px -2442px}.emoji-1f468-200d-1f4bc{background-position:-990px -2508px}.emoji-1f469-200d-1f4bc{background-position:-1188px -1716px}.emoji-1f9d1-200d-1f52c{background-position:-3036px -3234px}.emoji-1f468-200d-1f52c{background-position:-990px -3300px}.emoji-1f469-200d-1f52c{background-position:-1188px -2508px}.emoji-1f9d1-200d-1f4bb{background-position:-3036px -2046px}.emoji-1f468-200d-1f4bb{background-position:-990px -2112px}.emoji-1f469-200d-1f4bb{background-position:-1188px -1320px}.emoji-1f9d1-200d-1f3a4{background-position:-3036px -462px}.emoji-1f468-200d-1f3a4{background-position:-924px -3366px}.emoji-1f469-200d-1f3a4{background-position:-1122px -2904px}.emoji-1f9d1-200d-1f3a8{background-position:-3036px -858px}.emoji-1f468-200d-1f3a8{background-position:-924px -3762px}.emoji-1f469-200d-1f3a8{background-position:-1122px -3300px}.emoji-1f9d1-200d-2708-fe0f{background-position:-3168px -2046px}.emoji-1f468-200d-2708-fe0f{background-position:-1122px -396px}.emoji-1f469-200d-2708-fe0f{background-position:-1254px -3432px}.emoji-1f9d1-200d-1f680{background-position:-3036px -3630px}.emoji-1f468-200d-1f680{background-position:-990px -3696px}.emoji-1f469-200d-1f680{background-position:-1188px -2904px}.emoji-1f9d1-200d-1f692{background-position:-3102px -198px}.emoji-1f468-200d-1f692{background-position:-1056px -264px}.emoji-1f469-200d-1f692{background-position:-1188px -3300px}.emoji-1f46e{background-position:-1386px -2838px}.emoji-1f46e-200d-2642-fe0f{background-position:-1386px -2442px}.emoji-1f46e-200d-2640-fe0f{background-position:-1386px -2046px}.emoji-1f575-fe0f{background-position:-1914px -1650px}.emoji-1f575-fe0f-200d-2642-fe0f{background-position:-1914px -1254px}.emoji-1f575-fe0f-200d-2640-fe0f{background-position:-1914px -858px}.emoji-1f482{background-position:-1584px -1518px}.emoji-1f482-200d-2642-fe0f{background-position:-1584px -1122px}.emoji-1f482-200d-2640-fe0f{background-position:-1584px -726px}.emoji-1f977{background-position:-2772px -1320px}.emoji-1f477{background-position:-1518px -1716px}.emoji-1f477-200d-2642-fe0f{background-position:-1518px -1320px}.emoji-1f477-200d-2640-fe0f{background-position:-1518px -924px}.emoji-1f934{background-position:-2574px -990px}.emoji-1f478{background-position:-1518px -2112px}.emoji-1f473{background-position:-1452px -3168px}.emoji-1f473-200d-2642-fe0f{background-position:-1452px -2772px}.emoji-1f473-200d-2640-fe0f{background-position:-1452px -2376px}.emoji-1f472{background-position:-1452px -1980px}.emoji-1f9d5{background-position:-3234px -198px}.emoji-1f935{background-position:-2574px -2178px}.emoji-1f935-200d-2642-fe0f{background-position:-2574px -1782px}.emoji-1f935-200d-2640-fe0f{background-position:-2574px -1386px}.emoji-1f470{background-position:-1452px -396px}.emoji-1f470-200d-2642-fe0f{background-position:-1452px 0}.emoji-1f470-200d-2640-fe0f{background-position:-1386px -3432px}.emoji-1f930{background-position:-2508px -3234px}.emoji-1f931{background-position:-2508px -3630px}.emoji-1f469-200d-1f37c{background-position:-1122px -2112px}.emoji-1f468-200d-1f37c{background-position:-924px -2574px}.emoji-1f9d1-200d-1f37c{background-position:-2970px -3102px}.emoji-1f47c{background-position:-1518px -2706px}.emoji-1f385{background-position:-462px -1914px}.emoji-1f936{background-position:-2574px -2574px}.emoji-1f9d1-200d-1f384{background-position:-2970px -3498px}.emoji-1f9b8{background-position:-2838px -3234px}.emoji-1f9b8-200d-2642-fe0f{background-position:-2838px -2838px}.emoji-1f9b8-200d-2640-fe0f{background-position:-2838px -2442px}.emoji-1f9b9{background-position:-2904px -594px}.emoji-1f9b9-200d-2642-fe0f{background-position:-2904px -198px}.emoji-1f9b9-200d-2640-fe0f{background-position:-2838px -3630px}.emoji-1f9d9{background-position:-3300px -1122px}.emoji-1f9d9-200d-2642-fe0f{background-position:-3300px -726px}.emoji-1f9d9-200d-2640-fe0f{background-position:-3300px -330px}.emoji-1f9da{background-position:-3300px -2310px}.emoji-1f9da-200d-2642-fe0f{background-position:-3300px -1914px}.emoji-1f9da-200d-2640-fe0f{background-position:-3300px -1518px}.emoji-1f9db{background-position:-3300px -3498px}.emoji-1f9db-200d-2642-fe0f{background-position:-3300px -3102px}.emoji-1f9db-200d-2640-fe0f{background-position:-3300px -2706px}.emoji-1f9dc{background-position:-3366px -858px}.emoji-1f9dc-200d-2642-fe0f{background-position:-3366px -462px}.emoji-1f9dc-200d-2640-fe0f{background-position:-3366px -66px}.emoji-1f9dd{background-position:-3366px -2046px}.emoji-1f9dd-200d-2642-fe0f{background-position:-3366px -1650px}.emoji-1f9dd-200d-2640-fe0f{background-position:-3366px -1254px}.emoji-1f9de{background-position:-3366px -2574px}.emoji-1f9de-200d-2642-fe0f{background-position:-3366px -2508px}.emoji-1f9de-200d-2640-fe0f{background-position:-3366px -2442px}.emoji-1f9df{background-position:-3366px -2772px}.emoji-1f9df-200d-2642-fe0f{background-position:-3366px -2706px}.emoji-1f9df-200d-2640-fe0f{background-position:-3366px -2640px}.emoji-1f486{background-position:-1584px -3564px}.emoji-1f486-200d-2642-fe0f{background-position:-1584px -3168px}.emoji-1f486-200d-2640-fe0f{background-position:-1584px -2772px}.emoji-1f487{background-position:-1650px -924px}.emoji-1f487-200d-2642-fe0f{background-position:-1650px -528px}.emoji-1f487-200d-2640-fe0f{background-position:-1650px -132px}.emoji-1f6b6{background-position:-2310px -3366px}.emoji-1f6b6-200d-2642-fe0f{background-position:-2310px -2970px}.emoji-1f6b6-200d-2640-fe0f{background-position:-2310px -2574px}.emoji-1f9cd{background-position:-2904px -3300px}.emoji-1f9cd-200d-2642-fe0f{background-position:-2904px -2904px}.emoji-1f9cd-200d-2640-fe0f{background-position:-2904px -2508px}.emoji-1f9ce{background-position:-2970px -660px}.emoji-1f9ce-200d-2642-fe0f{background-position:-2970px -264px}.emoji-1f9ce-200d-2640-fe0f{background-position:-2904px -3696px}.emoji-1f9d1-200d-1f9af{background-position:-3102px -2310px}.emoji-1f468-200d-1f9af{background-position:-1056px -660px}.emoji-1f469-200d-1f9af{background-position:-1188px -3696px}.emoji-1f9d1-200d-1f9bc{background-position:-3168px -462px}.emoji-1f468-200d-1f9bc{background-position:-1056px -2640px}.emoji-1f469-200d-1f9bc{background-position:-1254px -1848px}.emoji-1f9d1-200d-1f9bd{background-position:-3168px -858px}.emoji-1f468-200d-1f9bd{background-position:-1056px -3036px}.emoji-1f469-200d-1f9bd{background-position:-1254px -2244px}.emoji-1f3c3{background-position:-528px -3300px}.emoji-1f3c3-200d-2642-fe0f{background-position:-528px -2904px}.emoji-1f3c3-200d-2640-fe0f{background-position:-528px -2508px}.emoji-1f483{background-position:-1584px -1914px}.emoji-1f57a{background-position:-1914px -2310px}.emoji-1f574-fe0f{background-position:-1914px -462px}.emoji-1f46f{background-position:-1386px -3366px}.emoji-1f46f-200d-2642-fe0f{background-position:-1386px -3300px}.emoji-1f46f-200d-2640-fe0f{background-position:-1386px -3234px}.emoji-1f9d6{background-position:-3234px -1386px}.emoji-1f9d6-200d-2642-fe0f{background-position:-3234px -990px}.emoji-1f9d6-200d-2640-fe0f{background-position:-3234px -594px}.emoji-1f9d7{background-position:-3234px -2574px}.emoji-1f9d7-200d-2642-fe0f{background-position:-3234px -2178px}.emoji-1f9d7-200d-2640-fe0f{background-position:-3234px -1782px}.emoji-1f93a{background-position:-2640px -2706px}.emoji-1f3c7{background-position:-594px -1188px}.emoji-26f7-fe0f{background-position:-3630px -1452px}.emoji-1f3c2{background-position:-528px -2112px}.emoji-1f3cc-fe0f{background-position:-660px -1056px}.emoji-1f3cc-fe0f-200d-2642-fe0f{background-position:-660px -660px}.emoji-1f3cc-fe0f-200d-2640-fe0f{background-position:-660px -264px}.emoji-1f3c4{background-position:-594px -660px}.emoji-1f3c4-200d-2642-fe0f{background-position:-594px -264px}.emoji-1f3c4-200d-2640-fe0f{background-position:-528px -3696px}.emoji-1f6a3{background-position:-2244px -2574px}.emoji-1f6a3-200d-2642-fe0f{background-position:-2244px -2178px}.emoji-1f6a3-200d-2640-fe0f{background-position:-2244px -1782px}.emoji-1f3ca{background-position:-594px -2508px}.emoji-1f3ca-200d-2642-fe0f{background-position:-594px -2112px}.emoji-1f3ca-200d-2640-fe0f{background-position:-594px -1716px}.emoji-26f9-fe0f{background-position:-3630px -2376px}.emoji-26f9-fe0f-200d-2642-fe0f{background-position:-3630px -1980px}.emoji-26f9-fe0f-200d-2640-fe0f{background-position:-3630px -1584px}.emoji-1f3cb-fe0f{background-position:-594px -3696px}.emoji-1f3cb-fe0f-200d-2642-fe0f{background-position:-594px -3300px}.emoji-1f3cb-fe0f-200d-2640-fe0f{background-position:-594px -2904px}.emoji-1f6b4{background-position:-2310px -990px}.emoji-1f6b4-200d-2642-fe0f{background-position:-2310px -594px}.emoji-1f6b4-200d-2640-fe0f{background-position:-2310px -198px}.emoji-1f6b5{background-position:-2310px -2178px}.emoji-1f6b5-200d-2642-fe0f{background-position:-2310px -1782px}.emoji-1f6b5-200d-2640-fe0f{background-position:-2310px -1386px}.emoji-1f938{background-position:-2640px -1122px}.emoji-1f938-200d-2642-fe0f{background-position:-2640px -726px}.emoji-1f938-200d-2640-fe0f{background-position:-2640px -330px}.emoji-1f93c{background-position:-2640px -2904px}.emoji-1f93c-200d-2642-fe0f{background-position:-2640px -2838px}.emoji-1f93c-200d-2640-fe0f{background-position:-2640px -2772px}.emoji-1f93d{background-position:-2640px -3762px}.emoji-1f93d-200d-2642-fe0f{background-position:-2640px -3366px}.emoji-1f93d-200d-2640-fe0f{background-position:-2640px -2970px}.emoji-1f93e{background-position:-2706px -1122px}.emoji-1f93e-200d-2642-fe0f{background-position:-2706px -726px}.emoji-1f93e-200d-2640-fe0f{background-position:-2706px -330px}.emoji-1f939{background-position:-2640px -2310px}.emoji-1f939-200d-2642-fe0f{background-position:-2640px -1914px}.emoji-1f939-200d-2640-fe0f{background-position:-2640px -1518px}.emoji-1f9d8{background-position:-3234px -3762px}.emoji-1f9d8-200d-2642-fe0f{background-position:-3234px -3366px}.emoji-1f9d8-200d-2640-fe0f{background-position:-3234px -2970px}.emoji-1f6c0{background-position:-2376px -528px}.emoji-1f6cc{background-position:-2376px -1320px}.emoji-1f9d1-200d-1f91d-200d-1f9d1{background-position:-3102px -594px}.emoji-1f46d{background-position:-1386px -330px}.emoji-1f46b{background-position:-1320px -726px}.emoji-1f46c{background-position:-1320px -2442px}.emoji-1f48f{background-position:-1650px -1782px}.emoji-1f469-200d-2764-fe0f-200d-1f48b-200d-1f468{background-position:-1320px -132px}.emoji-1f468-200d-2764-fe0f-200d-1f48b-200d-1f468{background-position:-1122px -858px}.emoji-1f469-200d-2764-fe0f-200d-1f48b-200d-1f469{background-position:-1320px -198px}.emoji-1f491{background-position:-1650px -1914px}.emoji-1f469-200d-2764-fe0f-200d-1f468{background-position:-1320px 0}.emoji-1f468-200d-2764-fe0f-200d-1f468{background-position:-1122px -792px}.emoji-1f469-200d-2764-fe0f-200d-1f469{background-position:-1320px -66px}.emoji-1f46a{background-position:-1320px -660px}.emoji-1f468-200d-1f469-200d-1f466{background-position:-990px -1782px}.emoji-1f468-200d-1f469-200d-1f467{background-position:-990px -1914px}.emoji-1f468-200d-1f469-200d-1f467-200d-1f466{background-position:-990px -1980px}.emoji-1f468-200d-1f469-200d-1f466-200d-1f466{background-position:-990px -1848px}.emoji-1f468-200d-1f469-200d-1f467-200d-1f467{background-position:-990px -2046px}.emoji-1f468-200d-1f468-200d-1f466{background-position:-990px -1452px}.emoji-1f468-200d-1f468-200d-1f467{background-position:-990px -1584px}.emoji-1f468-200d-1f468-200d-1f467-200d-1f466{background-position:-990px -1650px}.emoji-1f468-200d-1f468-200d-1f466-200d-1f466{background-position:-990px -1518px}.emoji-1f468-200d-1f468-200d-1f467-200d-1f467{background-position:-990px -1716px}.emoji-1f469-200d-1f469-200d-1f466{background-position:-1188px -990px}.emoji-1f469-200d-1f469-200d-1f467{background-position:-1188px -1122px}.emoji-1f469-200d-1f469-200d-1f467-200d-1f466{background-position:-1188px -1188px}.emoji-1f469-200d-1f469-200d-1f466-200d-1f466{background-position:-1188px -1056px}.emoji-1f469-200d-1f469-200d-1f467-200d-1f467{background-position:-1188px -1254px}.emoji-1f468-200d-1f466{background-position:-990px -1188px}.emoji-1f468-200d-1f466-200d-1f466{background-position:-990px -1122px}.emoji-1f468-200d-1f467{background-position:-990px -1386px}.emoji-1f468-200d-1f467-200d-1f466{background-position:-990px -1254px}.emoji-1f468-200d-1f467-200d-1f467{background-position:-990px -1320px}.emoji-1f469-200d-1f466{background-position:-1188px -726px}.emoji-1f469-200d-1f466-200d-1f466{background-position:-1188px -660px}.emoji-1f469-200d-1f467{background-position:-1188px -924px}.emoji-1f469-200d-1f467-200d-1f466{background-position:-1188px -792px}.emoji-1f469-200d-1f467-200d-1f467{background-position:-1188px -858px}.emoji-1f5e3-fe0f{background-position:-1980px -1452px}.emoji-1f464{background-position:-924px -858px}.emoji-1f465{background-position:-924px -924px}.emoji-1fac2{background-position:-3498px -528px}.emoji-1f463{background-position:-924px -792px}.emoji-1f3fb{background-position:-726px -858px}.emoji-1f3fc{background-position:-726px -924px}.emoji-1f3fd{background-position:-726px -990px}.emoji-1f3fe{background-position:-726px -1056px}.emoji-1f3ff{background-position:-726px -1122px}.emoji-1f435{background-position:-792px -990px}.emoji-1f412{background-position:-726px -2442px}.emoji-1f98d{background-position:-2772px -3036px}.emoji-1f9a7{background-position:-2838px -924px}.emoji-1f436{background-position:-792px -1056px}.emoji-1f415{background-position:-726px -2706px}.emoji-1f9ae{background-position:-2838px -1386px}.emoji-1f415-200d-1f9ba{background-position:-726px -2640px}.emoji-1f429{background-position:-792px -198px}.emoji-1f43a{background-position:-792px -1320px}.emoji-1f98a{background-position:-2772px -2838px}.emoji-1f99d{background-position:-2838px -264px}.emoji-1f431{background-position:-792px -726px}.emoji-1f408{background-position:-726px -1782px}.emoji-1f408-200d-2b1b{background-position:-726px -1716px}.emoji-1f981{background-position:-2772px -2244px}.emoji-1f42f{background-position:-792px -594px}.emoji-1f405{background-position:-726px -1518px}.emoji-1f406{background-position:-726px -1584px}.emoji-1f434{background-position:-792px -924px}.emoji-1f40e{background-position:-726px -2178px}.emoji-1f984{background-position:-2772px -2442px}.emoji-1f993{background-position:-2772px -3432px}.emoji-1f98c{background-position:-2772px -2970px}.emoji-1f9ac{background-position:-2838px -1254px}.emoji-1f42e{background-position:-792px -528px}.emoji-1f402{background-position:-726px -1320px}.emoji-1f403{background-position:-726px -1386px}.emoji-1f404{background-position:-726px -1452px}.emoji-1f437{background-position:-792px -1122px}.emoji-1f416{background-position:-726px -2772px}.emoji-1f417{background-position:-726px -2838px}.emoji-1f43d{background-position:-792px -1584px}.emoji-1f40f{background-position:-726px -2244px}.emoji-1f411{background-position:-726px -2376px}.emoji-1f410{background-position:-726px -2310px}.emoji-1f42a{background-position:-792px -264px}.emoji-1f42b{background-position:-792px -330px}.emoji-1f999{background-position:-2838px 0}.emoji-1f992{background-position:-2772px -3366px}.emoji-1f418{background-position:-726px -2904px}.emoji-1f9a3{background-position:-2838px -660px}.emoji-1f98f{background-position:-2772px -3168px}.emoji-1f99b{background-position:-2838px -132px}.emoji-1f42d{background-position:-792px -462px}.emoji-1f401{background-position:-726px -1254px}.emoji-1f400{background-position:-726px -1188px}.emoji-1f439{background-position:-792px -1254px}.emoji-1f430{background-position:-792px -660px}.emoji-1f407{background-position:-726px -1650px}.emoji-1f43f-fe0f{background-position:-792px -1716px}.emoji-1f9ab{background-position:-2838px -1188px}.emoji-1f994{background-position:-2772px -3498px}.emoji-1f987{background-position:-2772px -2640px}.emoji-1f43b{background-position:-792px -1452px}.emoji-1f43b-200d-2744-fe0f{background-position:-792px -1386px}.emoji-1f428{background-position:-792px -132px}.emoji-1f43c{background-position:-792px -1518px}.emoji-1f9a5{background-position:-2838px -792px}.emoji-1f9a6{background-position:-2838px -858px}.emoji-1f9a8{background-position:-2838px -990px}.emoji-1f998{background-position:-2772px -3762px}.emoji-1f9a1{background-position:-2838px -528px}.emoji-1f43e{background-position:-792px -1650px}.emoji-1f983{background-position:-2772px -2376px}.emoji-1f414{background-position:-726px -2574px}.emoji-1f413{background-position:-726px -2508px}.emoji-1f423{background-position:-726px -3630px}.emoji-1f424{background-position:-726px -3696px}.emoji-1f425{background-position:-726px -3762px}.emoji-1f426{background-position:-792px 0}.emoji-1f427{background-position:-792px -66px}.emoji-1f54a-fe0f{background-position:-1848px -2178px}.emoji-1f985{background-position:-2772px -2508px}.emoji-1f986{background-position:-2772px -2574px}.emoji-1f9a2{background-position:-2838px -594px}.emoji-1f989{background-position:-2772px -2772px}.emoji-1f9a4{background-position:-2838px -726px}.emoji-1fab6{background-position:-3498px -330px}.emoji-1f9a9{background-position:-2838px -1056px}.emoji-1f99a{background-position:-2838px -66px}.emoji-1f99c{background-position:-2838px -198px}.emoji-1f438{background-position:-792px -1188px}.emoji-1f40a{background-position:-726px -1914px}.emoji-1f422{background-position:-726px -3564px}.emoji-1f98e{background-position:-2772px -3102px}.emoji-1f40d{background-position:-726px -2112px}.emoji-1f432{background-position:-792px -792px}.emoji-1f409{background-position:-726px -1848px}.emoji-1f995{background-position:-2772px -3564px}.emoji-1f996{background-position:-2772px -3630px}.emoji-1f433{background-position:-792px -858px}.emoji-1f40b{background-position:-726px -1980px}.emoji-1f42c{background-position:-792px -396px}.emoji-1f9ad{background-position:-2838px -1320px}.emoji-1f41f{background-position:-726px -3366px}.emoji-1f420{background-position:-726px -3432px}.emoji-1f421{background-position:-726px -3498px}.emoji-1f988{background-position:-2772px -2706px}.emoji-1f419{background-position:-726px -2970px}.emoji-1f41a{background-position:-726px -3036px}.emoji-1f40c{background-position:-726px -2046px}.emoji-1f98b{background-position:-2772px -2904px}.emoji-1f41b{background-position:-726px -3102px}.emoji-1f41c{background-position:-726px -3168px}.emoji-1f41d{background-position:-726px -3234px}.emoji-1fab2{background-position:-3498px -66px}.emoji-1f41e{background-position:-726px -3300px}.emoji-1f997{background-position:-2772px -3696px}.emoji-1fab3{background-position:-3498px -132px}.emoji-1f577-fe0f{background-position:-1914px -2112px}.emoji-1f578-fe0f{background-position:-1914px -2178px}.emoji-1f982{background-position:-2772px -2310px}.emoji-1f99f{background-position:-2838px -396px}.emoji-1fab0{background-position:-3432px -3762px}.emoji-1fab1{background-position:-3498px 0}.emoji-1f9a0{background-position:-2838px -462px}.emoji-1f490{background-position:-1650px -1848px}.emoji-1f338{background-position:-396px -660px}.emoji-1f4ae{background-position:-1716px -330px}.emoji-1f3f5-fe0f{background-position:-726px -528px}.emoji-1f339{background-position:-396px -726px}.emoji-1f940{background-position:-2706px -1584px}.emoji-1f33a{background-position:-396px -792px}.emoji-1f33b{background-position:-396px -858px}.emoji-1f33c{background-position:-396px -924px}.emoji-1f337{background-position:-396px -594px}.emoji-1f331{background-position:-396px -198px}.emoji-1fab4{background-position:-3498px -198px}.emoji-1f332{background-position:-396px -264px}.emoji-1f333{background-position:-396px -330px}.emoji-1f334{background-position:-396px -396px}.emoji-1f335{background-position:-396px -462px}.emoji-1f33e{background-position:-396px -1056px}.emoji-1f33f{background-position:-396px -1122px}.emoji-2618-fe0f{background-position:-3564px -396px}.emoji-1f340{background-position:-396px -1188px}.emoji-1f341{background-position:-396px -1254px}.emoji-1f342{background-position:-396px -1320px}.emoji-1f343{background-position:-396px -1386px}.emoji-1f347{background-position:-396px -1650px}.emoji-1f348{background-position:-396px -1716px}.emoji-1f349{background-position:-396px -1782px}.emoji-1f34a{background-position:-396px -1848px}.emoji-1f34b{background-position:-396px -1914px}.emoji-1f34c{background-position:-396px -1980px}.emoji-1f34d{background-position:-396px -2046px}.emoji-1f96d{background-position:-2772px -660px}.emoji-1f34e{background-position:-396px -2112px}.emoji-1f34f{background-position:-396px -2178px}.emoji-1f350{background-position:-396px -2244px}.emoji-1f351{background-position:-396px -2310px}.emoji-1f352{background-position:-396px -2376px}.emoji-1f353{background-position:-396px -2442px}.emoji-1fad0{background-position:-3498px -594px}.emoji-1f95d{background-position:-2706px -3432px}.emoji-1f345{background-position:-396px -1518px}.emoji-1fad2{background-position:-3498px -726px}.emoji-1f965{background-position:-2772px -132px}.emoji-1f951{background-position:-2706px -2640px}.emoji-1f346{background-position:-396px -1584px}.emoji-1f954{background-position:-2706px -2838px}.emoji-1f955{background-position:-2706px -2904px}.emoji-1f33d{background-position:-396px -990px}.emoji-1f336-fe0f{background-position:-396px -528px}.emoji-1fad1{background-position:-3498px -660px}.emoji-1f952{background-position:-2706px -2706px}.emoji-1f96c{background-position:-2772px -594px}.emoji-1f966{background-position:-2772px -198px}.emoji-1f9c4{background-position:-2904px -1980px}.emoji-1f9c5{background-position:-2904px -2046px}.emoji-1f344{background-position:-396px -1452px}.emoji-1f95c{background-position:-2706px -3366px}.emoji-1f330{background-position:-396px -132px}.emoji-1f35e{background-position:-396px -3168px}.emoji-1f950{background-position:-2706px -2574px}.emoji-1f956{background-position:-2706px -2970px}.emoji-1fad3{background-position:-3498px -792px}.emoji-1f968{background-position:-2772px -330px}.emoji-1f96f{background-position:-2772px -792px}.emoji-1f95e{background-position:-2706px -3498px}.emoji-1f9c7{background-position:-2904px -2178px}.emoji-1f9c0{background-position:-2904px -1716px}.emoji-1f356{background-position:-396px -2640px}.emoji-1f357{background-position:-396px -2706px}.emoji-1f969{background-position:-2772px -396px}.emoji-1f953{background-position:-2706px -2772px}.emoji-1f354{background-position:-396px -2508px}.emoji-1f35f{background-position:-396px -3234px}.emoji-1f355{background-position:-396px -2574px}.emoji-1f32d{background-position:-330px -3762px}.emoji-1f96a{background-position:-2772px -462px}.emoji-1f32e{background-position:-396px 0}.emoji-1f32f{background-position:-396px -66px}.emoji-1fad4{background-position:-3498px -858px}.emoji-1f959{background-position:-2706px -3168px}.emoji-1f9c6{background-position:-2904px -2112px}.emoji-1f95a{background-position:-2706px -3234px}.emoji-1f373{background-position:-462px -726px}.emoji-1f958{background-position:-2706px -3102px}.emoji-1f372{background-position:-462px -660px}.emoji-1fad5{background-position:-3498px -924px}.emoji-1f963{background-position:-2772px 0}.emoji-1f957{background-position:-2706px -3036px}.emoji-1f37f{background-position:-462px -1518px}.emoji-1f9c8{background-position:-2904px -2244px}.emoji-1f9c2{background-position:-2904px -1848px}.emoji-1f96b{background-position:-2772px -528px}.emoji-1f371{background-position:-462px -594px}.emoji-1f358{background-position:-396px -2772px}.emoji-1f359{background-position:-396px -2838px}.emoji-1f35a{background-position:-396px -2904px}.emoji-1f35b{background-position:-396px -2970px}.emoji-1f35c{background-position:-396px -3036px}.emoji-1f35d{background-position:-396px -3102px}.emoji-1f360{background-position:-396px -3300px}.emoji-1f362{background-position:-396px -3432px}.emoji-1f363{background-position:-396px -3498px}.emoji-1f364{background-position:-396px -3564px}.emoji-1f365{background-position:-396px -3630px}.emoji-1f96e{background-position:-2772px -726px}.emoji-1f361{background-position:-396px -3366px}.emoji-1f95f{background-position:-2706px -3564px}.emoji-1f960{background-position:-2706px -3630px}.emoji-1f961{background-position:-2706px -3696px}.emoji-1f980{background-position:-2772px -2178px}.emoji-1f99e{background-position:-2838px -330px}.emoji-1f990{background-position:-2772px -3234px}.emoji-1f991{background-position:-2772px -3300px}.emoji-1f9aa{background-position:-2838px -1122px}.emoji-1f366{background-position:-396px -3696px}.emoji-1f367{background-position:-396px -3762px}.emoji-1f368{background-position:-462px 0}.emoji-1f369{background-position:-462px -66px}.emoji-1f36a{background-position:-462px -132px}.emoji-1f382{background-position:-462px -1716px}.emoji-1f370{background-position:-462px -528px}.emoji-1f9c1{background-position:-2904px -1782px}.emoji-1f967{background-position:-2772px -264px}.emoji-1f36b{background-position:-462px -198px}.emoji-1f36c{background-position:-462px -264px}.emoji-1f36d{background-position:-462px -330px}.emoji-1f36e{background-position:-462px -396px}.emoji-1f36f{background-position:-462px -462px}.emoji-1f37c{background-position:-462px -1320px}.emoji-1f95b{background-position:-2706px -3300px}.emoji-2615{background-position:-3564px -330px}.emoji-1fad6{background-position:-3498px -990px}.emoji-1f375{background-position:-462px -858px}.emoji-1f376{background-position:-462px -924px}.emoji-1f37e{background-position:-462px -1452px}.emoji-1f377{background-position:-462px -990px}.emoji-1f378{background-position:-462px -1056px}.emoji-1f379{background-position:-462px -1122px}.emoji-1f37a{background-position:-462px -1188px}.emoji-1f37b{background-position:-462px -1254px}.emoji-1f942{background-position:-2706px -1716px}.emoji-1f943{background-position:-2706px -1782px}.emoji-1f964{background-position:-2772px -66px}.emoji-1f9cb{background-position:-2904px -2442px}.emoji-1f9c3{background-position:-2904px -1914px}.emoji-1f9c9{background-position:-2904px -2310px}.emoji-1f9ca{background-position:-2904px -2376px}.emoji-1f962{background-position:-2706px -3762px}.emoji-1f37d-fe0f{background-position:-462px -1386px}.emoji-1f374{background-position:-462px -792px}.emoji-1f944{background-position:-2706px -1848px}.emoji-1f52a{background-position:-1848px -792px}.emoji-1f3fa{background-position:-726px -792px}.emoji-1f30d{background-position:-330px -1782px}.emoji-1f30e{background-position:-330px -1848px}.emoji-1f30f{background-position:-330px -1914px}.emoji-1f310{background-position:-330px -1980px}.emoji-1f5fa-fe0f{background-position:-1980px -1716px}.emoji-1f5fe{background-position:-1980px -1980px}.emoji-1f9ed{background-position:-3366px -3696px}.emoji-1f3d4-fe0f{background-position:-660px -1914px}.emoji-26f0-fe0f{background-position:-3630px -1056px}.emoji-1f30b{background-position:-330px -1650px}.emoji-1f5fb{background-position:-1980px -1782px}.emoji-1f3d5-fe0f{background-position:-660px -1980px}.emoji-1f3d6-fe0f{background-position:-660px -2046px}.emoji-1f3dc-fe0f{background-position:-660px -2442px}.emoji-1f3dd-fe0f{background-position:-660px -2508px}.emoji-1f3de-fe0f{background-position:-660px -2574px}.emoji-1f3df-fe0f{background-position:-660px -2640px}.emoji-1f3db-fe0f{background-position:-660px -2376px}.emoji-1f3d7-fe0f{background-position:-660px -2112px}.emoji-1f9f1{background-position:-3432px -132px}.emoji-1faa8{background-position:-3432px -3696px}.emoji-1fab5{background-position:-3498px -264px}.emoji-1f6d6{background-position:-2376px -2178px}.emoji-1f3d8-fe0f{background-position:-660px -2178px}.emoji-1f3da-fe0f{background-position:-660px -2310px}.emoji-1f3e0{background-position:-660px -2706px}.emoji-1f3e1{background-position:-660px -2772px}.emoji-1f3e2{background-position:-660px -2838px}.emoji-1f3e3{background-position:-660px -2904px}.emoji-1f3e4{background-position:-660px -2970px}.emoji-1f3e5{background-position:-660px -3036px}.emoji-1f3e6{background-position:-660px -3102px}.emoji-1f3e8{background-position:-660px -3234px}.emoji-1f3e9{background-position:-660px -3300px}.emoji-1f3ea{background-position:-660px -3366px}.emoji-1f3eb{background-position:-660px -3432px}.emoji-1f3ec{background-position:-660px -3498px}.emoji-1f3ed{background-position:-660px -3564px}.emoji-1f3ef{background-position:-660px -3696px}.emoji-1f3f0{background-position:-660px -3762px}.emoji-1f492{background-position:-1650px -1980px}.emoji-1f5fc{background-position:-1980px -1848px}.emoji-1f5fd{background-position:-1980px -1914px}.emoji-26ea{background-position:-3630px -990px}.emoji-1f54c{background-position:-1848px -2310px}.emoji-1f6d5{background-position:-2376px -2112px}.emoji-1f54d{background-position:-1848px -2376px}.emoji-26e9-fe0f{background-position:-3630px -924px}.emoji-1f54b{background-position:-1848px -2244px}.emoji-26f2{background-position:-3630px -1188px}.emoji-26fa{background-position:-3630px -2772px}.emoji-1f301{background-position:-330px -990px}.emoji-1f303{background-position:-330px -1122px}.emoji-1f3d9-fe0f{background-position:-660px -2244px}.emoji-1f304{background-position:-330px -1188px}.emoji-1f305{background-position:-330px -1254px}.emoji-1f306{background-position:-330px -1320px}.emoji-1f307{background-position:-330px -1386px}.emoji-1f309{background-position:-330px -1518px}.emoji-2668-fe0f{background-position:-3564px -2772px}.emoji-1f3a0{background-position:-462px -3696px}.emoji-1f3a1{background-position:-462px -3762px}.emoji-1f3a2{background-position:-528px 0}.emoji-1f488{background-position:-1650px -1320px}.emoji-1f3aa{background-position:-528px -528px}.emoji-1f682{background-position:-2178px -3432px}.emoji-1f683{background-position:-2178px -3498px}.emoji-1f684{background-position:-2178px -3564px}.emoji-1f685{background-position:-2178px -3630px}.emoji-1f686{background-position:-2178px -3696px}.emoji-1f687{background-position:-2178px -3762px}.emoji-1f688{background-position:-2244px 0}.emoji-1f689{background-position:-2244px -66px}.emoji-1f68a{background-position:-2244px -132px}.emoji-1f69d{background-position:-2244px -1386px}.emoji-1f69e{background-position:-2244px -1452px}.emoji-1f68b{background-position:-2244px -198px}.emoji-1f68c{background-position:-2244px -264px}.emoji-1f68d{background-position:-2244px -330px}.emoji-1f68e{background-position:-2244px -396px}.emoji-1f690{background-position:-2244px -528px}.emoji-1f691{background-position:-2244px -594px}.emoji-1f692{background-position:-2244px -660px}.emoji-1f693{background-position:-2244px -726px}.emoji-1f694{background-position:-2244px -792px}.emoji-1f695{background-position:-2244px -858px}.emoji-1f696{background-position:-2244px -924px}.emoji-1f697{background-position:-2244px -990px}.emoji-1f698{background-position:-2244px -1056px}.emoji-1f699{background-position:-2244px -1122px}.emoji-1f6fb{background-position:-2376px -3498px}.emoji-1f69a{background-position:-2244px -1188px}.emoji-1f69b{background-position:-2244px -1254px}.emoji-1f69c{background-position:-2244px -1320px}.emoji-1f3ce-fe0f{background-position:-660px -1518px}.emoji-1f3cd-fe0f{background-position:-660px -1452px}.emoji-1f6f5{background-position:-2376px -3102px}.emoji-1f9bd{background-position:-2904px -1518px}.emoji-1f9bc{background-position:-2904px -1452px}.emoji-1f6fa{background-position:-2376px -3432px}.emoji-1f6b2{background-position:-2310px -66px}.emoji-1f6f4{background-position:-2376px -3036px}.emoji-1f6f9{background-position:-2376px -3366px}.emoji-1f6fc{background-position:-2376px -3564px}.emoji-1f68f{background-position:-2244px -462px}.emoji-1f6e3-fe0f{background-position:-2376px -2508px}.emoji-1f6e4-fe0f{background-position:-2376px -2574px}.emoji-1f6e2-fe0f{background-position:-2376px -2442px}.emoji-26fd{background-position:-3630px -2838px}.emoji-1f6a8{background-position:-2244px -3234px}.emoji-1f6a5{background-position:-2244px -3036px}.emoji-1f6a6{background-position:-2244px -3102px}.emoji-1f6d1{background-position:-2376px -1980px}.emoji-1f6a7{background-position:-2244px -3168px}.emoji-2693{background-position:-3564px -3102px}.emoji-26f5{background-position:-3630px -1386px}.emoji-1f6f6{background-position:-2376px -3168px}.emoji-1f6a4{background-position:-2244px -2970px}.emoji-1f6f3-fe0f{background-position:-2376px -2970px}.emoji-26f4-fe0f{background-position:-3630px -1320px}.emoji-1f6e5-fe0f{background-position:-2376px -2640px}.emoji-1f6a2{background-position:-2244px -1716px}.emoji-2708-fe0f{background-position:-3630px -3036px}.emoji-1f6e9-fe0f{background-position:-2376px -2706px}.emoji-1f6eb{background-position:-2376px -2772px}.emoji-1f6ec{background-position:-2376px -2838px}.emoji-1fa82{background-position:-3432px -1782px}.emoji-1f4ba{background-position:-1716px -1122px}.emoji-1f681{background-position:-2178px -3366px}.emoji-1f69f{background-position:-2244px -1518px}.emoji-1f6a0{background-position:-2244px -1584px}.emoji-1f6a1{background-position:-2244px -1650px}.emoji-1f6f0-fe0f{background-position:-2376px -2904px}.emoji-1f680{background-position:-2178px -3300px}.emoji-1f6f8{background-position:-2376px -3300px}.emoji-1f6ce-fe0f{background-position:-2376px -1782px}.emoji-1f9f3{background-position:-3432px -264px}.emoji-231b{background-position:-3498px -1914px}.emoji-23f3{background-position:-3498px -2772px}.emoji-231a{background-position:-3498px -1848px}.emoji-23f0{background-position:-3498px -2574px}.emoji-23f1-fe0f{background-position:-3498px -2640px}.emoji-23f2-fe0f{background-position:-3498px -2706px}.emoji-1f570-fe0f{background-position:-1914px -330px}.emoji-1f55b{background-position:-1848px -3234px}.emoji-1f567{background-position:-1914px -198px}.emoji-1f550{background-position:-1848px -2508px}.emoji-1f55c{background-position:-1848px -3300px}.emoji-1f551{background-position:-1848px -2574px}.emoji-1f55d{background-position:-1848px -3366px}.emoji-1f552{background-position:-1848px -2640px}.emoji-1f55e{background-position:-1848px -3432px}.emoji-1f553{background-position:-1848px -2706px}.emoji-1f55f{background-position:-1848px -3498px}.emoji-1f554{background-position:-1848px -2772px}.emoji-1f560{background-position:-1848px -3564px}.emoji-1f555{background-position:-1848px -2838px}.emoji-1f561{background-position:-1848px -3630px}.emoji-1f556{background-position:-1848px -2904px}.emoji-1f562{background-position:-1848px -3696px}.emoji-1f557{background-position:-1848px -2970px}.emoji-1f563{background-position:-1848px -3762px}.emoji-1f558{background-position:-1848px -3036px}.emoji-1f564{background-position:-1914px 0}.emoji-1f559{background-position:-1848px -3102px}.emoji-1f565{background-position:-1914px -66px}.emoji-1f55a{background-position:-1848px -3168px}.emoji-1f566{background-position:-1914px -132px}.emoji-1f311{background-position:-330px -2046px}.emoji-1f312{background-position:-330px -2112px}.emoji-1f313{background-position:-330px -2178px}.emoji-1f314{background-position:-330px -2244px}.emoji-1f315{background-position:-330px -2310px}.emoji-1f316{background-position:-330px -2376px}.emoji-1f317{background-position:-330px -2442px}.emoji-1f318{background-position:-330px -2508px}.emoji-1f319{background-position:-330px -2574px}.emoji-1f31a{background-position:-330px -2640px}.emoji-1f31b{background-position:-330px -2706px}.emoji-1f31c{background-position:-330px -2772px}.emoji-1f321-fe0f{background-position:-330px -3102px}.emoji-2600-fe0f{background-position:-3498px -3630px}.emoji-1f31d{background-position:-330px -2838px}.emoji-1f31e{background-position:-330px -2904px}.emoji-1fa90{background-position:-3432px -2112px}.emoji-2b50{background-position:-3696px -3036px}.emoji-1f31f{background-position:-330px -2970px}.emoji-1f320{background-position:-330px -3036px}.emoji-1f30c{background-position:-330px -1716px}.emoji-2601-fe0f{background-position:-3498px -3696px}.emoji-26c5{background-position:-3630px -462px}.emoji-26c8-fe0f{background-position:-3630px -528px}.emoji-1f324-fe0f{background-position:-330px -3168px}.emoji-1f325-fe0f{background-position:-330px -3234px}.emoji-1f326-fe0f{background-position:-330px -3300px}.emoji-1f327-fe0f{background-position:-330px -3366px}.emoji-1f328-fe0f{background-position:-330px -3432px}.emoji-1f329-fe0f{background-position:-330px -3498px}.emoji-1f32a-fe0f{background-position:-330px -3564px}.emoji-1f32b-fe0f{background-position:-330px -3630px}.emoji-1f32c-fe0f{background-position:-330px -3696px}.emoji-1f300{background-position:-330px -924px}.emoji-1f308{background-position:-330px -1452px}.emoji-1f302{background-position:-330px -1056px}.emoji-2602-fe0f{background-position:-3498px -3762px}.emoji-2614{background-position:-3564px -264px}.emoji-26f1-fe0f{background-position:-3630px -1122px}.emoji-26a1{background-position:-3564px -3696px}.emoji-2744-fe0f{background-position:-3696px -1518px}.emoji-2603-fe0f{background-position:-3564px 0}.emoji-26c4{background-position:-3630px -396px}.emoji-2604-fe0f{background-position:-3564px -66px}.emoji-1f525{background-position:-1848px -462px}.emoji-1f4a7{background-position:-1650px -3366px}.emoji-1f30a{background-position:-330px -1584px}.emoji-1f383{background-position:-462px -1782px}.emoji-1f384{background-position:-462px -1848px}.emoji-1f386{background-position:-462px -2310px}.emoji-1f387{background-position:-462px -2376px}.emoji-1f9e8{background-position:-3366px -3366px}.emoji-2728{background-position:-3696px -1320px}.emoji-1f388{background-position:-462px -2442px}.emoji-1f389{background-position:-462px -2508px}.emoji-1f38a{background-position:-462px -2574px}.emoji-1f38b{background-position:-462px -2640px}.emoji-1f38d{background-position:-462px -2772px}.emoji-1f38e{background-position:-462px -2838px}.emoji-1f38f{background-position:-462px -2904px}.emoji-1f390{background-position:-462px -2970px}.emoji-1f391{background-position:-462px -3036px}.emoji-1f9e7{background-position:-3366px -3300px}.emoji-1f380{background-position:-462px -1584px}.emoji-1f381{background-position:-462px -1650px}.emoji-1f397-fe0f{background-position:-462px -3300px}.emoji-1f39f-fe0f{background-position:-462px -3630px}.emoji-1f3ab{background-position:-528px -594px}.emoji-1f396-fe0f{background-position:-462px -3234px}.emoji-1f3c6{background-position:-594px -1122px}.emoji-1f3c5{background-position:-594px -1056px}.emoji-1f947{background-position:-2706px -1980px}.emoji-1f948{background-position:-2706px -2046px}.emoji-1f949{background-position:-2706px -2112px}.emoji-26bd{background-position:-3630px -264px}.emoji-26be{background-position:-3630px -330px}.emoji-1f94e{background-position:-2706px -2442px}.emoji-1f3c0{background-position:-528px -1980px}.emoji-1f3d0{background-position:-660px -1650px}.emoji-1f3c8{background-position:-594px -1584px}.emoji-1f3c9{background-position:-594px -1650px}.emoji-1f3be{background-position:-528px -1848px}.emoji-1f94f{background-position:-2706px -2508px}.emoji-1f3b3{background-position:-528px -1122px}.emoji-1f3cf{background-position:-660px -1584px}.emoji-1f3d1{background-position:-660px -1716px}.emoji-1f3d2{background-position:-660px -1782px}.emoji-1f94d{background-position:-2706px -2376px}.emoji-1f3d3{background-position:-660px -1848px}.emoji-1f3f8{background-position:-726px -660px}.emoji-1f94a{background-position:-2706px -2178px}.emoji-1f94b{background-position:-2706px -2244px}.emoji-1f945{background-position:-2706px -1914px}.emoji-26f3{background-position:-3630px -1254px}.emoji-26f8-fe0f{background-position:-3630px -1518px}.emoji-1f3a3{background-position:-528px -66px}.emoji-1f93f{background-position:-2706px -1518px}.emoji-1f3bd{background-position:-528px -1782px}.emoji-1f3bf{background-position:-528px -1914px}.emoji-1f6f7{background-position:-2376px -3234px}.emoji-1f94c{background-position:-2706px -2310px}.emoji-1f3af{background-position:-528px -858px}.emoji-1fa80{background-position:-3432px -1650px}.emoji-1fa81{background-position:-3432px -1716px}.emoji-1f3b1{background-position:-528px -990px}.emoji-1f52e{background-position:-1848px -1056px}.emoji-1fa84{background-position:-3432px -1914px}.emoji-1f9ff{background-position:-3432px -1056px}.emoji-1f3ae{background-position:-528px -792px}.emoji-1f579-fe0f{background-position:-1914px -2244px}.emoji-1f3b0{background-position:-528px -924px}.emoji-1f3b2{background-position:-528px -1056px}.emoji-1f9e9{background-position:-3366px -3432px}.emoji-1f9f8{background-position:-3432px -594px}.emoji-1fa85{background-position:-3432px -1980px}.emoji-1fa86{background-position:-3432px -2046px}.emoji-2660-fe0f{background-position:-3564px -2508px}.emoji-2665-fe0f{background-position:-3564px -2640px}.emoji-2666-fe0f{background-position:-3564px -2706px}.emoji-2663-fe0f{background-position:-3564px -2574px}.emoji-265f-fe0f{background-position:-3564px -2442px}.emoji-1f0cf{background-position:0 -990px}.emoji-1f004{background-position:0 -924px}.emoji-1f3b4{background-position:-528px -1188px}.emoji-1f3ad{background-position:-528px -726px}.emoji-1f5bc-fe0f{background-position:-1980px -726px}.emoji-1f3a8{background-position:-528px -396px}.emoji-1f9f5{background-position:-3432px -396px}.emoji-1faa1{background-position:-3432px -3234px}.emoji-1f9f6{background-position:-3432px -462px}.emoji-1faa2{background-position:-3432px -3300px}.emoji-1f453{background-position:-858px -3564px}.emoji-1f576-fe0f{background-position:-1914px -2046px}.emoji-1f97d{background-position:-2772px -1980px}.emoji-1f97c{background-position:-2772px -1914px}.emoji-1f9ba{background-position:-2904px -990px}.emoji-1f454{background-position:-858px -3630px}.emoji-1f455{background-position:-858px -3696px}.emoji-1f456{background-position:-858px -3762px}.emoji-1f9e3{background-position:-3366px -3036px}.emoji-1f9e4{background-position:-3366px -3102px}.emoji-1f9e5{background-position:-3366px -3168px}.emoji-1f9e6{background-position:-3366px -3234px}.emoji-1f457{background-position:-924px 0}.emoji-1f458{background-position:-924px -66px}.emoji-1f97b{background-position:-2772px -1848px}.emoji-1fa71{background-position:-3432px -1188px}.emoji-1fa72{background-position:-3432px -1254px}.emoji-1fa73{background-position:-3432px -1320px}.emoji-1f459{background-position:-924px -132px}.emoji-1f45a{background-position:-924px -198px}.emoji-1f45b{background-position:-924px -264px}.emoji-1f45c{background-position:-924px -330px}.emoji-1f45d{background-position:-924px -396px}.emoji-1f6cd-fe0f{background-position:-2376px -1716px}.emoji-1f392{background-position:-462px -3102px}.emoji-1fa74{background-position:-3432px -1386px}.emoji-1f45e{background-position:-924px -462px}.emoji-1f45f{background-position:-924px -528px}.emoji-1f97e{background-position:-2772px -2046px}.emoji-1f97f{background-position:-2772px -2112px}.emoji-1f460{background-position:-924px -594px}.emoji-1f461{background-position:-924px -660px}.emoji-1fa70{background-position:-3432px -1122px}.emoji-1f462{background-position:-924px -726px}.emoji-1f451{background-position:-858px -3432px}.emoji-1f452{background-position:-858px -3498px}.emoji-1f3a9{background-position:-528px -462px}.emoji-1f393{background-position:-462px -3168px}.emoji-1f9e2{background-position:-3366px -2970px}.emoji-1fa96{background-position:-3432px -2508px}.emoji-26d1-fe0f{background-position:-3630px -726px}.emoji-1f4ff{background-position:-1782px -1782px}.emoji-1f484{background-position:-1584px -2310px}.emoji-1f48d{background-position:-1650px -1650px}.emoji-1f48e{background-position:-1650px -1716px}.emoji-1f507{background-position:-1782px -2310px}.emoji-1f508{background-position:-1782px -2376px}.emoji-1f509{background-position:-1782px -2442px}.emoji-1f50a{background-position:-1782px -2508px}.emoji-1f4e2{background-position:-1716px -3762px}.emoji-1f4e3{background-position:-1782px 0}.emoji-1f4ef{background-position:-1782px -792px}.emoji-1f514{background-position:-1782px -3168px}.emoji-1f515{background-position:-1782px -3234px}.emoji-1f3bc{background-position:-528px -1716px}.emoji-1f3b5{background-position:-528px -1254px}.emoji-1f3b6{background-position:-528px -1320px}.emoji-1f399-fe0f{background-position:-462px -3366px}.emoji-1f39a-fe0f{background-position:-462px -3432px}.emoji-1f39b-fe0f{background-position:-462px -3498px}.emoji-1f3a4{background-position:-528px -132px}.emoji-1f3a7{background-position:-528px -330px}.emoji-1f4fb{background-position:-1782px -1584px}.emoji-1f3b7{background-position:-528px -1386px}.emoji-1fa97{background-position:-3432px -2574px}.emoji-1f3b8{background-position:-528px -1452px}.emoji-1f3b9{background-position:-528px -1518px}.emoji-1f3ba{background-position:-528px -1584px}.emoji-1f3bb{background-position:-528px -1650px}.emoji-1fa95{background-position:-3432px -2442px}.emoji-1f941{background-position:-2706px -1650px}.emoji-1fa98{background-position:-3432px -2640px}.emoji-1f4f1{background-position:-1782px -924px}.emoji-1f4f2{background-position:-1782px -990px}.emoji-260e-fe0f{background-position:-3564px -132px}.emoji-1f4de{background-position:-1716px -3498px}.emoji-1f4df{background-position:-1716px -3564px}.emoji-1f4e0{background-position:-1716px -3630px}.emoji-1f50b{background-position:-1782px -2574px}.emoji-1f50c{background-position:-1782px -2640px}.emoji-1f4bb{background-position:-1716px -1188px}.emoji-1f5a5-fe0f{background-position:-1980px -462px}.emoji-1f5a8-fe0f{background-position:-1980px -528px}.emoji-2328-fe0f{background-position:-3498px -1980px}.emoji-1f5b1-fe0f{background-position:-1980px -594px}.emoji-1f5b2-fe0f{background-position:-1980px -660px}.emoji-1f4bd{background-position:-1716px -1320px}.emoji-1f4be{background-position:-1716px -1386px}.emoji-1f4bf{background-position:-1716px -1452px}.emoji-1f4c0{background-position:-1716px -1518px}.emoji-1f9ee{background-position:-3366px -3762px}.emoji-1f3a5{background-position:-528px -198px}.emoji-1f39e-fe0f{background-position:-462px -3564px}.emoji-1f4fd-fe0f{background-position:-1782px -1716px}.emoji-1f3ac{background-position:-528px -660px}.emoji-1f4fa{background-position:-1782px -1518px}.emoji-1f4f7{background-position:-1782px -1320px}.emoji-1f4f8{background-position:-1782px -1386px}.emoji-1f4f9{background-position:-1782px -1452px}.emoji-1f4fc{background-position:-1782px -1650px}.emoji-1f50d{background-position:-1782px -2706px}.emoji-1f50e{background-position:-1782px -2772px}.emoji-1f56f-fe0f{background-position:-1914px -264px}.emoji-1f4a1{background-position:-1650px -2970px}.emoji-1f526{background-position:-1848px -528px}.emoji-1f3ee{background-position:-660px -3630px}.emoji-1fa94{background-position:-3432px -2376px}.emoji-1f4d4{background-position:-1716px -2838px}.emoji-1f4d5{background-position:-1716px -2904px}.emoji-1f4d6{background-position:-1716px -2970px}.emoji-1f4d7{background-position:-1716px -3036px}.emoji-1f4d8{background-position:-1716px -3102px}.emoji-1f4d9{background-position:-1716px -3168px}.emoji-1f4da{background-position:-1716px -3234px}.emoji-1f4d3{background-position:-1716px -2772px}.emoji-1f4d2{background-position:-1716px -2706px}.emoji-1f4c3{background-position:-1716px -1716px}.emoji-1f4dc{background-position:-1716px -3366px}.emoji-1f4c4{background-position:-1716px -1782px}.emoji-1f4f0{background-position:-1782px -858px}.emoji-1f5de-fe0f{background-position:-1980px -1320px}.emoji-1f4d1{background-position:-1716px -2640px}.emoji-1f516{background-position:-1782px -3300px}.emoji-1f3f7-fe0f{background-position:-726px -594px}.emoji-1f4b0{background-position:-1716px -462px}.emoji-1fa99{background-position:-3432px -2706px}.emoji-1f4b4{background-position:-1716px -726px}.emoji-1f4b5{background-position:-1716px -792px}.emoji-1f4b6{background-position:-1716px -858px}.emoji-1f4b7{background-position:-1716px -924px}.emoji-1f4b8{background-position:-1716px -990px}.emoji-1f4b3{background-position:-1716px -660px}.emoji-1f9fe{background-position:-3432px -990px}.emoji-1f4b9{background-position:-1716px -1056px}.emoji-2709-fe0f{background-position:-3630px -3102px}.emoji-1f4e7{background-position:-1782px -264px}.emoji-1f4e8{background-position:-1782px -330px}.emoji-1f4e9{background-position:-1782px -396px}.emoji-1f4e4{background-position:-1782px -66px}.emoji-1f4e5{background-position:-1782px -132px}.emoji-1f4e6{background-position:-1782px -198px}.emoji-1f4eb{background-position:-1782px -528px}.emoji-1f4ea{background-position:-1782px -462px}.emoji-1f4ec{background-position:-1782px -594px}.emoji-1f4ed{background-position:-1782px -660px}.emoji-1f4ee{background-position:-1782px -726px}.emoji-1f5f3-fe0f{background-position:-1980px -1650px}.emoji-270f-fe0f{background-position:-3696px -924px}.emoji-2712-fe0f{background-position:-3696px -990px}.emoji-1f58b-fe0f{background-position:-1914px -2838px}.emoji-1f58a-fe0f{background-position:-1914px -2772px}.emoji-1f58c-fe0f{background-position:-1914px -2904px}.emoji-1f58d-fe0f{background-position:-1914px -2970px}.emoji-1f4dd{background-position:-1716px -3432px}.emoji-1f4bc{background-position:-1716px -1254px}.emoji-1f4c1{background-position:-1716px -1584px}.emoji-1f4c2{background-position:-1716px -1650px}.emoji-1f5c2-fe0f{background-position:-1980px -792px}.emoji-1f4c5{background-position:-1716px -1848px}.emoji-1f4c6{background-position:-1716px -1914px}.emoji-1f5d2-fe0f{background-position:-1980px -1056px}.emoji-1f5d3-fe0f{background-position:-1980px -1122px}.emoji-1f4c7{background-position:-1716px -1980px}.emoji-1f4c8{background-position:-1716px -2046px}.emoji-1f4c9{background-position:-1716px -2112px}.emoji-1f4ca{background-position:-1716px -2178px}.emoji-1f4cb{background-position:-1716px -2244px}.emoji-1f4cc{background-position:-1716px -2310px}.emoji-1f4cd{background-position:-1716px -2376px}.emoji-1f4ce{background-position:-1716px -2442px}.emoji-1f587-fe0f{background-position:-1914px -2706px}.emoji-1f4cf{background-position:-1716px -2508px}.emoji-1f4d0{background-position:-1716px -2574px}.emoji-2702-fe0f{background-position:-3630px -2904px}.emoji-1f5c3-fe0f{background-position:-1980px -858px}.emoji-1f5c4-fe0f{background-position:-1980px -924px}.emoji-1f5d1-fe0f{background-position:-1980px -990px}.emoji-1f512{background-position:-1782px -3036px}.emoji-1f513{background-position:-1782px -3102px}.emoji-1f50f{background-position:-1782px -2838px}.emoji-1f510{background-position:-1782px -2904px}.emoji-1f511{background-position:-1782px -2970px}.emoji-1f5dd-fe0f{background-position:-1980px -1254px}.emoji-1f528{background-position:-1848px -660px}.emoji-1fa93{background-position:-3432px -2310px}.emoji-26cf-fe0f{background-position:-3630px -660px}.emoji-2692-fe0f{background-position:-3564px -3036px}.emoji-1f6e0-fe0f{background-position:-2376px -2310px}.emoji-1f5e1-fe0f{background-position:-1980px -1386px}.emoji-2694-fe0f{background-position:-3564px -3168px}.emoji-1f52b{background-position:-1848px -858px}.emoji-1fa83{background-position:-3432px -1848px}.emoji-1f3f9{background-position:-726px -726px}.emoji-1f6e1-fe0f{background-position:-2376px -2376px}.emoji-1fa9a{background-position:-3432px -2772px}.emoji-1f527{background-position:-1848px -594px}.emoji-1fa9b{background-position:-3432px -2838px}.emoji-1f529{background-position:-1848px -726px}.emoji-2699-fe0f{background-position:-3564px -3432px}.emoji-1f5dc-fe0f{background-position:-1980px -1188px}.emoji-2696-fe0f{background-position:-3564px -3300px}.emoji-1f9af{background-position:-2838px -1452px}.emoji-1f517{background-position:-1782px -3366px}.emoji-26d3-fe0f{background-position:-3630px -792px}.emoji-1fa9d{background-position:-3432px -2970px}.emoji-1f9f0{background-position:-3432px -66px}.emoji-1f9f2{background-position:-3432px -198px}.emoji-1fa9c{background-position:-3432px -2904px}.emoji-2697-fe0f{background-position:-3564px -3366px}.emoji-1f9ea{background-position:-3366px -3498px}.emoji-1f9eb{background-position:-3366px -3564px}.emoji-1f9ec{background-position:-3366px -3630px}.emoji-1f52c{background-position:-1848px -924px}.emoji-1f52d{background-position:-1848px -990px}.emoji-1f4e1{background-position:-1716px -3696px}.emoji-1f489{background-position:-1650px -1386px}.emoji-1fa78{background-position:-3432px -1452px}.emoji-1f48a{background-position:-1650px -1452px}.emoji-1fa79{background-position:-3432px -1518px}.emoji-1fa7a{background-position:-3432px -1584px}.emoji-1f6aa{background-position:-2244px -3366px}.emoji-1f6d7{background-position:-2376px -2244px}.emoji-1fa9e{background-position:-3432px -3036px}.emoji-1fa9f{background-position:-3432px -3102px}.emoji-1f6cf-fe0f{background-position:-2376px -1848px}.emoji-1f6cb-fe0f{background-position:-2376px -1254px}.emoji-1fa91{background-position:-3432px -2178px}.emoji-1f6bd{background-position:-2376px -330px}.emoji-1faa0{background-position:-3432px -3168px}.emoji-1f6bf{background-position:-2376px -462px}.emoji-1f6c1{background-position:-2376px -924px}.emoji-1faa4{background-position:-3432px -3432px}.emoji-1fa92{background-position:-3432px -2244px}.emoji-1f9f4{background-position:-3432px -330px}.emoji-1f9f7{background-position:-3432px -528px}.emoji-1f9f9{background-position:-3432px -660px}.emoji-1f9fa{background-position:-3432px -726px}.emoji-1f9fb{background-position:-3432px -792px}.emoji-1faa3{background-position:-3432px -3366px}.emoji-1f9fc{background-position:-3432px -858px}.emoji-1faa5{background-position:-3432px -3498px}.emoji-1f9fd{background-position:-3432px -924px}.emoji-1f9ef{background-position:-3432px 0}.emoji-1f6d2{background-position:-2376px -2046px}.emoji-1f6ac{background-position:-2244px -3498px}.emoji-26b0-fe0f{background-position:-3630px -132px}.emoji-1faa6{background-position:-3432px -3564px}.emoji-26b1-fe0f{background-position:-3630px -198px}.emoji-1f5ff{background-position:-1980px -2046px}.emoji-1faa7{background-position:-3432px -3630px}.emoji-1f3e7{background-position:-660px -3168px}.emoji-1f6ae{background-position:-2244px -3630px}.emoji-1f6b0{background-position:-2244px -3762px}.emoji-267f{background-position:-3564px -2970px}.emoji-1f6b9{background-position:-2376px -66px}.emoji-1f6ba{background-position:-2376px -132px}.emoji-1f6bb{background-position:-2376px -198px}.emoji-1f6bc{background-position:-2376px -264px}.emoji-1f6be{background-position:-2376px -396px}.emoji-1f6c2{background-position:-2376px -990px}.emoji-1f6c3{background-position:-2376px -1056px}.emoji-1f6c4{background-position:-2376px -1122px}.emoji-1f6c5{background-position:-2376px -1188px}.emoji-26a0-fe0f{background-position:-3564px -3630px}.emoji-1f6b8{background-position:-2376px 0}.emoji-26d4{background-position:-3630px -858px}.emoji-1f6ab{background-position:-2244px -3432px}.emoji-1f6b3{background-position:-2310px -132px}.emoji-1f6ad{background-position:-2244px -3564px}.emoji-1f6af{background-position:-2244px -3696px}.emoji-1f6b1{background-position:-2310px 0}.emoji-1f6b7{background-position:-2310px -3762px}.emoji-1f4f5{background-position:-1782px -1188px}.emoji-1f51e{background-position:-1848px 0}.emoji-2622-fe0f{background-position:-3564px -924px}.emoji-2623-fe0f{background-position:-3564px -990px}.emoji-2b06-fe0f{background-position:-3696px -2772px}.emoji-2197-fe0f{background-position:-3498px -1518px}.emoji-27a1-fe0f{background-position:-3696px -2376px}.emoji-2198-fe0f{background-position:-3498px -1584px}.emoji-2b07-fe0f{background-position:-3696px -2838px}.emoji-2199-fe0f{background-position:-3498px -1650px}.emoji-2b05-fe0f{background-position:-3696px -2706px}.emoji-2196-fe0f{background-position:-3498px -1452px}.emoji-2195-fe0f{background-position:-3498px -1386px}.emoji-2194-fe0f{background-position:-3498px -1320px}.emoji-21a9-fe0f{background-position:-3498px -1716px}.emoji-21aa-fe0f{background-position:-3498px -1782px}.emoji-2934-fe0f{background-position:-3696px -2574px}.emoji-2935-fe0f{background-position:-3696px -2640px}.emoji-1f503{background-position:-1782px -2046px}.emoji-1f504{background-position:-1782px -2112px}.emoji-1f519{background-position:-1782px -3498px}.emoji-1f51a{background-position:-1782px -3564px}.emoji-1f51b{background-position:-1782px -3630px}.emoji-1f51c{background-position:-1782px -3696px}.emoji-1f51d{background-position:-1782px -3762px}.emoji-1f6d0{background-position:-2376px -1914px}.emoji-269b-fe0f{background-position:-3564px -3498px}.emoji-1f549-fe0f{background-position:-1848px -2112px}.emoji-2721-fe0f{background-position:-3696px -1254px}.emoji-2638-fe0f{background-position:-3564px -1320px}.emoji-262f-fe0f{background-position:-3564px -1254px}.emoji-271d-fe0f{background-position:-3696px -1188px}.emoji-2626-fe0f{background-position:-3564px -1056px}.emoji-262a-fe0f{background-position:-3564px -1122px}.emoji-262e-fe0f{background-position:-3564px -1188px}.emoji-1f54e{background-position:-1848px -2442px}.emoji-1f52f{background-position:-1848px -1122px}.emoji-2648{background-position:-3564px -1650px}.emoji-2649{background-position:-3564px -1716px}.emoji-264a{background-position:-3564px -1782px}.emoji-264b{background-position:-3564px -1848px}.emoji-264c{background-position:-3564px -1914px}.emoji-264d{background-position:-3564px -1980px}.emoji-264e{background-position:-3564px -2046px}.emoji-264f{background-position:-3564px -2112px}.emoji-2650{background-position:-3564px -2178px}.emoji-2651{background-position:-3564px -2244px}.emoji-2652{background-position:-3564px -2310px}.emoji-2653{background-position:-3564px -2376px}.emoji-26ce{background-position:-3630px -594px}.emoji-1f500{background-position:-1782px -1848px}.emoji-1f501{background-position:-1782px -1914px}.emoji-1f502{background-position:-1782px -1980px}.emoji-25b6-fe0f{background-position:-3498px -3234px}.emoji-23e9{background-position:-3498px -2112px}.emoji-23ed-fe0f{background-position:-3498px -2376px}.emoji-23ef-fe0f{background-position:-3498px -2508px}.emoji-25c0-fe0f{background-position:-3498px -3300px}.emoji-23ea{background-position:-3498px -2178px}.emoji-23ee-fe0f{background-position:-3498px -2442px}.emoji-1f53c{background-position:-1848px -1980px}.emoji-23eb{background-position:-3498px -2244px}.emoji-1f53d{background-position:-1848px -2046px}.emoji-23ec{background-position:-3498px -2310px}.emoji-23f8-fe0f{background-position:-3498px -2838px}.emoji-23f9-fe0f{background-position:-3498px -2904px}.emoji-23fa-fe0f{background-position:-3498px -2970px}.emoji-23cf-fe0f{background-position:-3498px -2046px}.emoji-1f3a6{background-position:-528px -264px}.emoji-1f505{background-position:-1782px -2178px}.emoji-1f506{background-position:-1782px -2244px}.emoji-1f4f6{background-position:-1782px -1254px}.emoji-1f4f3{background-position:-1782px -1056px}.emoji-1f4f4{background-position:-1782px -1122px}.emoji-2640-fe0f{background-position:-3564px -1518px}.emoji-2642-fe0f{background-position:-3564px -1584px}.emoji-26a7-fe0f{background-position:-3564px -3762px}.emoji-2716-fe0f{background-position:-3696px -1122px}.emoji-2795{background-position:-3696px -2178px}.emoji-2796{background-position:-3696px -2244px}.emoji-2797{background-position:-3696px -2310px}.emoji-267e-fe0f{background-position:-3564px -2904px}.emoji-203c-fe0f{background-position:-3498px -1056px}.emoji-2049-fe0f{background-position:-3498px -1122px}.emoji-2753{background-position:-3696px -1782px}.emoji-2754{background-position:-3696px -1848px}.emoji-2755{background-position:-3696px -1914px}.emoji-2757{background-position:-3696px -1980px}.emoji-3030-fe0f{background-position:-3696px -3168px}.emoji-1f4b1{background-position:-1716px -528px}.emoji-1f4b2{background-position:-1716px -594px}.emoji-2695-fe0f{background-position:-3564px -3234px}.emoji-267b-fe0f{background-position:-3564px -2838px}.emoji-269c-fe0f{background-position:-3564px -3564px}.emoji-1f531{background-position:-1848px -1254px}.emoji-1f4db{background-position:-1716px -3300px}.emoji-1f530{background-position:-1848px -1188px}.emoji-2b55{background-position:-3696px -3102px}.emoji-2705{background-position:-3630px -2970px}.emoji-2611-fe0f{background-position:-3564px -198px}.emoji-2714-fe0f{background-position:-3696px -1056px}.emoji-274c{background-position:-3696px -1650px}.emoji-274e{background-position:-3696px -1716px}.emoji-27b0{background-position:-3696px -2442px}.emoji-27bf{background-position:-3696px -2508px}.emoji-303d-fe0f{background-position:-3696px -3234px}.emoji-2733-fe0f{background-position:-3696px -1386px}.emoji-2734-fe0f{background-position:-3696px -1452px}.emoji-2747-fe0f{background-position:-3696px -1584px}.emoji-00a9-fe0f{background-position:0 -792px}.emoji-00ae-fe0f{background-position:0 -858px}.emoji-2122-fe0f{background-position:-3498px -1188px}.emoji-0023-fe0f-20e3{background-position:0 0}.emoji-002a-fe0f-20e3{background-position:0 -66px}.emoji-0030-fe0f-20e3{background-position:0 -132px}.emoji-0031-fe0f-20e3{background-position:0 -198px}.emoji-0032-fe0f-20e3{background-position:0 -264px}.emoji-0033-fe0f-20e3{background-position:0 -330px}.emoji-0034-fe0f-20e3{background-position:0 -396px}.emoji-0035-fe0f-20e3{background-position:0 -462px}.emoji-0036-fe0f-20e3{background-position:0 -528px}.emoji-0037-fe0f-20e3{background-position:0 -594px}.emoji-0038-fe0f-20e3{background-position:0 -660px}.emoji-0039-fe0f-20e3{background-position:0 -726px}.emoji-1f51f{background-position:-1848px -66px}.emoji-1f520{background-position:-1848px -132px}.emoji-1f521{background-position:-1848px -198px}.emoji-1f522{background-position:-1848px -264px}.emoji-1f523{background-position:-1848px -330px}.emoji-1f524{background-position:-1848px -396px}.emoji-1f170-fe0f{background-position:0 -1056px}.emoji-1f18e{background-position:0 -1320px}.emoji-1f171-fe0f{background-position:0 -1122px}.emoji-1f191{background-position:0 -1386px}.emoji-1f192{background-position:0 -1452px}.emoji-1f193{background-position:0 -1518px}.emoji-2139-fe0f{background-position:-3498px -1254px}.emoji-1f194{background-position:0 -1584px}.emoji-24c2-fe0f{background-position:-3498px -3036px}.emoji-1f195{background-position:0 -1650px}.emoji-1f196{background-position:0 -1716px}.emoji-1f17e-fe0f{background-position:0 -1188px}.emoji-1f197{background-position:0 -1782px}.emoji-1f17f-fe0f{background-position:0 -1254px}.emoji-1f198{background-position:0 -1848px}.emoji-1f199{background-position:0 -1914px}.emoji-1f19a{background-position:0 -1980px}.emoji-1f201{background-position:-264px -3762px}.emoji-1f202-fe0f{background-position:-330px 0}.emoji-1f237-fe0f{background-position:-330px -528px}.emoji-1f236{background-position:-330px -462px}.emoji-1f22f{background-position:-330px -132px}.emoji-1f250{background-position:-330px -792px}.emoji-1f239{background-position:-330px -660px}.emoji-1f21a{background-position:-330px -66px}.emoji-1f232{background-position:-330px -198px}.emoji-1f251{background-position:-330px -858px}.emoji-1f238{background-position:-330px -594px}.emoji-1f234{background-position:-330px -330px}.emoji-1f233{background-position:-330px -264px}.emoji-3297-fe0f{background-position:-3696px -3300px}.emoji-3299-fe0f{background-position:-3696px -3366px}.emoji-1f23a{background-position:-330px -726px}.emoji-1f235{background-position:-330px -396px}.emoji-1f534{background-position:-1848px -1452px}.emoji-1f7e0{background-position:-2376px -3630px}.emoji-1f7e1{background-position:-2376px -3696px}.emoji-1f7e2{background-position:-2376px -3762px}.emoji-1f535{background-position:-1848px -1518px}.emoji-1f7e3{background-position:-2442px 0}.emoji-1f7e4{background-position:-2442px -66px}.emoji-26ab{background-position:-3630px -66px}.emoji-26aa{background-position:-3630px 0}.emoji-1f7e5{background-position:-2442px -132px}.emoji-1f7e7{background-position:-2442px -264px}.emoji-1f7e8{background-position:-2442px -330px}.emoji-1f7e9{background-position:-2442px -396px}.emoji-1f7e6{background-position:-2442px -198px}.emoji-1f7ea{background-position:-2442px -462px}.emoji-1f7eb{background-position:-2442px -528px}.emoji-2b1b{background-position:-3696px -2904px}.emoji-2b1c{background-position:-3696px -2970px}.emoji-25fc-fe0f{background-position:-3498px -3432px}.emoji-25fb-fe0f{background-position:-3498px -3366px}.emoji-25fe{background-position:-3498px -3564px}.emoji-25fd{background-position:-3498px -3498px}.emoji-25aa-fe0f{background-position:-3498px -3102px}.emoji-25ab-fe0f{background-position:-3498px -3168px}.emoji-1f536{background-position:-1848px -1584px}.emoji-1f537{background-position:-1848px -1650px}.emoji-1f538{background-position:-1848px -1716px}.emoji-1f539{background-position:-1848px -1782px}.emoji-1f53a{background-position:-1848px -1848px}.emoji-1f53b{background-position:-1848px -1914px}.emoji-1f4a0{background-position:-1650px -2904px}.emoji-1f518{background-position:-1782px -3432px}.emoji-1f533{background-position:-1848px -1386px}.emoji-1f532{background-position:-1848px -1320px}.emoji-1f3c1{background-position:-528px -2046px}.emoji-1f6a9{background-position:-2244px -3300px}.emoji-1f38c{background-position:-462px -2706px}.emoji-1f3f4{background-position:-726px -462px}.emoji-1f3f3-fe0f{background-position:-726px -132px}.emoji-1f3f3-fe0f-200d-1f308{background-position:-726px 0}.emoji-1f3f3-fe0f-200d-26a7-fe0f{background-position:-726px -66px}.emoji-1f3f4-200d-2620-fe0f{background-position:-726px -198px}.emoji-1f1e6-1f1e8{background-position:0 -2046px}.emoji-1f1e6-1f1e9{background-position:0 -2112px}.emoji-1f1e6-1f1ea{background-position:0 -2178px}.emoji-1f1e6-1f1eb{background-position:0 -2244px}.emoji-1f1e6-1f1ec{background-position:0 -2310px}.emoji-1f1e6-1f1ee{background-position:0 -2376px}.emoji-1f1e6-1f1f1{background-position:0 -2442px}.emoji-1f1e6-1f1f2{background-position:0 -2508px}.emoji-1f1e6-1f1f4{background-position:0 -2574px}.emoji-1f1e6-1f1f6{background-position:0 -2640px}.emoji-1f1e6-1f1f7{background-position:0 -2706px}.emoji-1f1e6-1f1f8{background-position:0 -2772px}.emoji-1f1e6-1f1f9{background-position:0 -2838px}.emoji-1f1e6-1f1fa{background-position:0 -2904px}.emoji-1f1e6-1f1fc{background-position:0 -2970px}.emoji-1f1e6-1f1fd{background-position:0 -3036px}.emoji-1f1e6-1f1ff{background-position:0 -3102px}.emoji-1f1e7-1f1e6{background-position:0 -3168px}.emoji-1f1e7-1f1e7{background-position:0 -3234px}.emoji-1f1e7-1f1e9{background-position:0 -3300px}.emoji-1f1e7-1f1ea{background-position:0 -3366px}.emoji-1f1e7-1f1eb{background-position:0 -3432px}.emoji-1f1e7-1f1ec{background-position:0 -3498px}.emoji-1f1e7-1f1ed{background-position:0 -3564px}.emoji-1f1e7-1f1ee{background-position:0 -3630px}.emoji-1f1e7-1f1ef{background-position:0 -3696px}.emoji-1f1e7-1f1f1{background-position:0 -3762px}.emoji-1f1e7-1f1f2{background-position:-66px 0}.emoji-1f1e7-1f1f3{background-position:-66px -66px}.emoji-1f1e7-1f1f4{background-position:-66px -132px}.emoji-1f1e7-1f1f6{background-position:-66px -198px}.emoji-1f1e7-1f1f7{background-position:-66px -264px}.emoji-1f1e7-1f1f8{background-position:-66px -330px}.emoji-1f1e7-1f1f9{background-position:-66px -396px}.emoji-1f1e7-1f1fb{background-position:-66px -462px}.emoji-1f1e7-1f1fc{background-position:-66px -528px}.emoji-1f1e7-1f1fe{background-position:-66px -594px}.emoji-1f1e7-1f1ff{background-position:-66px -660px}.emoji-1f1e8-1f1e6{background-position:-66px -726px}.emoji-1f1e8-1f1e8{background-position:-66px -792px}.emoji-1f1e8-1f1e9{background-position:-66px -858px}.emoji-1f1e8-1f1eb{background-position:-66px -924px}.emoji-1f1e8-1f1ec{background-position:-66px -990px}.emoji-1f1e8-1f1ed{background-position:-66px -1056px}.emoji-1f1e8-1f1ee{background-position:-66px -1122px}.emoji-1f1e8-1f1f0{background-position:-66px -1188px}.emoji-1f1e8-1f1f1{background-position:-66px -1254px}.emoji-1f1e8-1f1f2{background-position:-66px -1320px}.emoji-1f1e8-1f1f3{background-position:-66px -1386px}.emoji-1f1e8-1f1f4{background-position:-66px -1452px}.emoji-1f1e8-1f1f5{background-position:-66px -1518px}.emoji-1f1e8-1f1f7{background-position:-66px -1584px}.emoji-1f1e8-1f1fa{background-position:-66px -1650px}.emoji-1f1e8-1f1fb{background-position:-66px -1716px}.emoji-1f1e8-1f1fc{background-position:-66px -1782px}.emoji-1f1e8-1f1fd{background-position:-66px -1848px}.emoji-1f1e8-1f1fe{background-position:-66px -1914px}.emoji-1f1e8-1f1ff{background-position:-66px -1980px}.emoji-1f1e9-1f1ea{background-position:-66px -2046px}.emoji-1f1e9-1f1ec{background-position:-66px -2112px}.emoji-1f1e9-1f1ef{background-position:-66px -2178px}.emoji-1f1e9-1f1f0{background-position:-66px -2244px}.emoji-1f1e9-1f1f2{background-position:-66px -2310px}.emoji-1f1e9-1f1f4{background-position:-66px -2376px}.emoji-1f1e9-1f1ff{background-position:-66px -2442px}.emoji-1f1ea-1f1e6{background-position:-66px -2508px}.emoji-1f1ea-1f1e8{background-position:-66px -2574px}.emoji-1f1ea-1f1ea{background-position:-66px -2640px}.emoji-1f1ea-1f1ec{background-position:-66px -2706px}.emoji-1f1ea-1f1ed{background-position:-66px -2772px}.emoji-1f1ea-1f1f7{background-position:-66px -2838px}.emoji-1f1ea-1f1f8{background-position:-66px -2904px}.emoji-1f1ea-1f1f9{background-position:-66px -2970px}.emoji-1f1ea-1f1fa{background-position:-66px -3036px}.emoji-1f1eb-1f1ee{background-position:-66px -3102px}.emoji-1f1eb-1f1ef{background-position:-66px -3168px}.emoji-1f1eb-1f1f0{background-position:-66px -3234px}.emoji-1f1eb-1f1f2{background-position:-66px -3300px}.emoji-1f1eb-1f1f4{background-position:-66px -3366px}.emoji-1f1eb-1f1f7{background-position:-66px -3432px}.emoji-1f1ec-1f1e6{background-position:-66px -3498px}.emoji-1f1ec-1f1e7{background-position:-66px -3564px}.emoji-1f1ec-1f1e9{background-position:-66px -3630px}.emoji-1f1ec-1f1ea{background-position:-66px -3696px}.emoji-1f1ec-1f1eb{background-position:-66px -3762px}.emoji-1f1ec-1f1ec{background-position:-132px 0}.emoji-1f1ec-1f1ed{background-position:-132px -66px}.emoji-1f1ec-1f1ee{background-position:-132px -132px}.emoji-1f1ec-1f1f1{background-position:-132px -198px}.emoji-1f1ec-1f1f2{background-position:-132px -264px}.emoji-1f1ec-1f1f3{background-position:-132px -330px}.emoji-1f1ec-1f1f5{background-position:-132px -396px}.emoji-1f1ec-1f1f6{background-position:-132px -462px}.emoji-1f1ec-1f1f7{background-position:-132px -528px}.emoji-1f1ec-1f1f8{background-position:-132px -594px}.emoji-1f1ec-1f1f9{background-position:-132px -660px}.emoji-1f1ec-1f1fa{background-position:-132px -726px}.emoji-1f1ec-1f1fc{background-position:-132px -792px}.emoji-1f1ec-1f1fe{background-position:-132px -858px}.emoji-1f1ed-1f1f0{background-position:-132px -924px}.emoji-1f1ed-1f1f2{background-position:-132px -990px}.emoji-1f1ed-1f1f3{background-position:-132px -1056px}.emoji-1f1ed-1f1f7{background-position:-132px -1122px}.emoji-1f1ed-1f1f9{background-position:-132px -1188px}.emoji-1f1ed-1f1fa{background-position:-132px -1254px}.emoji-1f1ee-1f1e8{background-position:-132px -1320px}.emoji-1f1ee-1f1e9{background-position:-132px -1386px}.emoji-1f1ee-1f1ea{background-position:-132px -1452px}.emoji-1f1ee-1f1f1{background-position:-132px -1518px}.emoji-1f1ee-1f1f2{background-position:-132px -1584px}.emoji-1f1ee-1f1f3{background-position:-132px -1650px}.emoji-1f1ee-1f1f4{background-position:-132px -1716px}.emoji-1f1ee-1f1f6{background-position:-132px -1782px}.emoji-1f1ee-1f1f7{background-position:-132px -1848px}.emoji-1f1ee-1f1f8{background-position:-132px -1914px}.emoji-1f1ee-1f1f9{background-position:-132px -1980px}.emoji-1f1ef-1f1ea{background-position:-132px -2046px}.emoji-1f1ef-1f1f2{background-position:-132px -2112px}.emoji-1f1ef-1f1f4{background-position:-132px -2178px}.emoji-1f1ef-1f1f5{background-position:-132px -2244px}.emoji-1f1f0-1f1ea{background-position:-132px -2310px}.emoji-1f1f0-1f1ec{background-position:-132px -2376px}.emoji-1f1f0-1f1ed{background-position:-132px -2442px}.emoji-1f1f0-1f1ee{background-position:-132px -2508px}.emoji-1f1f0-1f1f2{background-position:-132px -2574px}.emoji-1f1f0-1f1f3{background-position:-132px -2640px}.emoji-1f1f0-1f1f5{background-position:-132px -2706px}.emoji-1f1f0-1f1f7{background-position:-132px -2772px}.emoji-1f1f0-1f1fc{background-position:-132px -2838px}.emoji-1f1f0-1f1fe{background-position:-132px -2904px}.emoji-1f1f0-1f1ff{background-position:-132px -2970px}.emoji-1f1f1-1f1e6{background-position:-132px -3036px}.emoji-1f1f1-1f1e7{background-position:-132px -3102px}.emoji-1f1f1-1f1e8{background-position:-132px -3168px}.emoji-1f1f1-1f1ee{background-position:-132px -3234px}.emoji-1f1f1-1f1f0{background-position:-132px -3300px}.emoji-1f1f1-1f1f7{background-position:-132px -3366px}.emoji-1f1f1-1f1f8{background-position:-132px -3432px}.emoji-1f1f1-1f1f9{background-position:-132px -3498px}.emoji-1f1f1-1f1fa{background-position:-132px -3564px}.emoji-1f1f1-1f1fb{background-position:-132px -3630px}.emoji-1f1f1-1f1fe{background-position:-132px -3696px}.emoji-1f1f2-1f1e6{background-position:-132px -3762px}.emoji-1f1f2-1f1e8{background-position:-198px 0}.emoji-1f1f2-1f1e9{background-position:-198px -66px}.emoji-1f1f2-1f1ea{background-position:-198px -132px}.emoji-1f1f2-1f1eb{background-position:-198px -198px}.emoji-1f1f2-1f1ec{background-position:-198px -264px}.emoji-1f1f2-1f1ed{background-position:-198px -330px}.emoji-1f1f2-1f1f0{background-position:-198px -396px}.emoji-1f1f2-1f1f1{background-position:-198px -462px}.emoji-1f1f2-1f1f2{background-position:-198px -528px}.emoji-1f1f2-1f1f3{background-position:-198px -594px}.emoji-1f1f2-1f1f4{background-position:-198px -660px}.emoji-1f1f2-1f1f5{background-position:-198px -726px}.emoji-1f1f2-1f1f6{background-position:-198px -792px}.emoji-1f1f2-1f1f7{background-position:-198px -858px}.emoji-1f1f2-1f1f8{background-position:-198px -924px}.emoji-1f1f2-1f1f9{background-position:-198px -990px}.emoji-1f1f2-1f1fa{background-position:-198px -1056px}.emoji-1f1f2-1f1fb{background-position:-198px -1122px}.emoji-1f1f2-1f1fc{background-position:-198px -1188px}.emoji-1f1f2-1f1fd{background-position:-198px -1254px}.emoji-1f1f2-1f1fe{background-position:-198px -1320px}.emoji-1f1f2-1f1ff{background-position:-198px -1386px}.emoji-1f1f3-1f1e6{background-position:-198px -1452px}.emoji-1f1f3-1f1e8{background-position:-198px -1518px}.emoji-1f1f3-1f1ea{background-position:-198px -1584px}.emoji-1f1f3-1f1eb{background-position:-198px -1650px}.emoji-1f1f3-1f1ec{background-position:-198px -1716px}.emoji-1f1f3-1f1ee{background-position:-198px -1782px}.emoji-1f1f3-1f1f1{background-position:-198px -1848px}.emoji-1f1f3-1f1f4{background-position:-198px -1914px}.emoji-1f1f3-1f1f5{background-position:-198px -1980px}.emoji-1f1f3-1f1f7{background-position:-198px -2046px}.emoji-1f1f3-1f1fa{background-position:-198px -2112px}.emoji-1f1f3-1f1ff{background-position:-198px -2178px}.emoji-1f1f4-1f1f2{background-position:-198px -2244px}.emoji-1f1f5-1f1e6{background-position:-198px -2310px}.emoji-1f1f5-1f1ea{background-position:-198px -2376px}.emoji-1f1f5-1f1eb{background-position:-198px -2442px}.emoji-1f1f5-1f1ec{background-position:-198px -2508px}.emoji-1f1f5-1f1ed{background-position:-198px -2574px}.emoji-1f1f5-1f1f0{background-position:-198px -2640px}.emoji-1f1f5-1f1f1{background-position:-198px -2706px}.emoji-1f1f5-1f1f2{background-position:-198px -2772px}.emoji-1f1f5-1f1f3{background-position:-198px -2838px}.emoji-1f1f5-1f1f7{background-position:-198px -2904px}.emoji-1f1f5-1f1f8{background-position:-198px -2970px}.emoji-1f1f5-1f1f9{background-position:-198px -3036px}.emoji-1f1f5-1f1fc{background-position:-198px -3102px}.emoji-1f1f5-1f1fe{background-position:-198px -3168px}.emoji-1f1f6-1f1e6{background-position:-198px -3234px}.emoji-1f1f7-1f1ea{background-position:-198px -3300px}.emoji-1f1f7-1f1f4{background-position:-198px -3366px}.emoji-1f1f7-1f1f8{background-position:-198px -3432px}.emoji-1f1f7-1f1fa{background-position:-198px -3498px}.emoji-1f1f7-1f1fc{background-position:-198px -3564px}.emoji-1f1f8-1f1e6{background-position:-198px -3630px}.emoji-1f1f8-1f1e7{background-position:-198px -3696px}.emoji-1f1f8-1f1e8{background-position:-198px -3762px}.emoji-1f1f8-1f1e9{background-position:-264px 0}.emoji-1f1f8-1f1ea{background-position:-264px -66px}.emoji-1f1f8-1f1ec{background-position:-264px -132px}.emoji-1f1f8-1f1ed{background-position:-264px -198px}.emoji-1f1f8-1f1ee{background-position:-264px -264px}.emoji-1f1f8-1f1ef{background-position:-264px -330px}.emoji-1f1f8-1f1f0{background-position:-264px -396px}.emoji-1f1f8-1f1f1{background-position:-264px -462px}.emoji-1f1f8-1f1f2{background-position:-264px -528px}.emoji-1f1f8-1f1f3{background-position:-264px -594px}.emoji-1f1f8-1f1f4{background-position:-264px -660px}.emoji-1f1f8-1f1f7{background-position:-264px -726px}.emoji-1f1f8-1f1f8{background-position:-264px -792px}.emoji-1f1f8-1f1f9{background-position:-264px -858px}.emoji-1f1f8-1f1fb{background-position:-264px -924px}.emoji-1f1f8-1f1fd{background-position:-264px -990px}.emoji-1f1f8-1f1fe{background-position:-264px -1056px}.emoji-1f1f8-1f1ff{background-position:-264px -1122px}.emoji-1f1f9-1f1e6{background-position:-264px -1188px}.emoji-1f1f9-1f1e8{background-position:-264px -1254px}.emoji-1f1f9-1f1e9{background-position:-264px -1320px}.emoji-1f1f9-1f1eb{background-position:-264px -1386px}.emoji-1f1f9-1f1ec{background-position:-264px -1452px}.emoji-1f1f9-1f1ed{background-position:-264px -1518px}.emoji-1f1f9-1f1ef{background-position:-264px -1584px}.emoji-1f1f9-1f1f0{background-position:-264px -1650px}.emoji-1f1f9-1f1f1{background-position:-264px -1716px}.emoji-1f1f9-1f1f2{background-position:-264px -1782px}.emoji-1f1f9-1f1f3{background-position:-264px -1848px}.emoji-1f1f9-1f1f4{background-position:-264px -1914px}.emoji-1f1f9-1f1f7{background-position:-264px -1980px}.emoji-1f1f9-1f1f9{background-position:-264px -2046px}.emoji-1f1f9-1f1fb{background-position:-264px -2112px}.emoji-1f1f9-1f1fc{background-position:-264px -2178px}.emoji-1f1f9-1f1ff{background-position:-264px -2244px}.emoji-1f1fa-1f1e6{background-position:-264px -2310px}.emoji-1f1fa-1f1ec{background-position:-264px -2376px}.emoji-1f1fa-1f1f2{background-position:-264px -2442px}.emoji-1f1fa-1f1f3{background-position:-264px -2508px}.emoji-1f1fa-1f1f8{background-position:-264px -2574px}.emoji-1f1fa-1f1fe{background-position:-264px -2640px}.emoji-1f1fa-1f1ff{background-position:-264px -2706px}.emoji-1f1fb-1f1e6{background-position:-264px -2772px}.emoji-1f1fb-1f1e8{background-position:-264px -2838px}.emoji-1f1fb-1f1ea{background-position:-264px -2904px}.emoji-1f1fb-1f1ec{background-position:-264px -2970px}.emoji-1f1fb-1f1ee{background-position:-264px -3036px}.emoji-1f1fb-1f1f3{background-position:-264px -3102px}.emoji-1f1fb-1f1fa{background-position:-264px -3168px}.emoji-1f1fc-1f1eb{background-position:-264px -3234px}.emoji-1f1fc-1f1f8{background-position:-264px -3300px}.emoji-1f1fd-1f1f0{background-position:-264px -3366px}.emoji-1f1fe-1f1ea{background-position:-264px -3432px}.emoji-1f1fe-1f1f9{background-position:-264px -3498px}.emoji-1f1ff-1f1e6{background-position:-264px -3564px}.emoji-1f1ff-1f1f2{background-position:-264px -3630px}.emoji-1f1ff-1f1fc{background-position:-264px -3696px}.emoji-1f3f4-e0067-e0062-e0065-e006e-e0067-e007f{background-position:-726px -264px}.emoji-1f3f4-e0067-e0062-e0073-e0063-e0074-e007f{background-position:-726px -330px}.emoji-1f3f4-e0067-e0062-e0077-e006c-e0073-e007f{background-position:-726px -396px}.emoji-1f385-1f3fb{background-position:-462px -1980px}.emoji-1f385-1f3fc{background-position:-462px -2046px}.emoji-1f385-1f3fd{background-position:-462px -2112px}.emoji-1f385-1f3fe{background-position:-462px -2178px}.emoji-1f385-1f3ff{background-position:-462px -2244px}.emoji-1f3c2-1f3fb{background-position:-528px -2178px}.emoji-1f3c2-1f3fc{background-position:-528px -2244px}.emoji-1f3c2-1f3fd{background-position:-528px -2310px}.emoji-1f3c2-1f3fe{background-position:-528px -2376px}.emoji-1f3c2-1f3ff{background-position:-528px -2442px}.emoji-1f3c3-1f3fb-200d-2640-fe0f{background-position:-528px -2574px}.emoji-1f3c3-1f3fc-200d-2640-fe0f{background-position:-528px -2640px}.emoji-1f3c3-1f3fd-200d-2640-fe0f{background-position:-528px -2706px}.emoji-1f3c3-1f3fe-200d-2640-fe0f{background-position:-528px -2772px}.emoji-1f3c3-1f3ff-200d-2640-fe0f{background-position:-528px -2838px}.emoji-1f3c3-1f3fb-200d-2642-fe0f{background-position:-528px -2970px}.emoji-1f3c3-1f3fc-200d-2642-fe0f{background-position:-528px -3036px}.emoji-1f3c3-1f3fd-200d-2642-fe0f{background-position:-528px -3102px}.emoji-1f3c3-1f3fe-200d-2642-fe0f{background-position:-528px -3168px}.emoji-1f3c3-1f3ff-200d-2642-fe0f{background-position:-528px -3234px}.emoji-1f3c3-1f3fb{background-position:-528px -3366px}.emoji-1f3c3-1f3fc{background-position:-528px -3432px}.emoji-1f3c3-1f3fd{background-position:-528px -3498px}.emoji-1f3c3-1f3fe{background-position:-528px -3564px}.emoji-1f3c3-1f3ff{background-position:-528px -3630px}.emoji-1f3c4-1f3fb-200d-2640-fe0f{background-position:-528px -3762px}.emoji-1f3c4-1f3fc-200d-2640-fe0f{background-position:-594px 0}.emoji-1f3c4-1f3fd-200d-2640-fe0f{background-position:-594px -66px}.emoji-1f3c4-1f3fe-200d-2640-fe0f{background-position:-594px -132px}.emoji-1f3c4-1f3ff-200d-2640-fe0f{background-position:-594px -198px}.emoji-1f3c4-1f3fb-200d-2642-fe0f{background-position:-594px -330px}.emoji-1f3c4-1f3fc-200d-2642-fe0f{background-position:-594px -396px}.emoji-1f3c4-1f3fd-200d-2642-fe0f{background-position:-594px -462px}.emoji-1f3c4-1f3fe-200d-2642-fe0f{background-position:-594px -528px}.emoji-1f3c4-1f3ff-200d-2642-fe0f{background-position:-594px -594px}.emoji-1f3c4-1f3fb{background-position:-594px -726px}.emoji-1f3c4-1f3fc{background-position:-594px -792px}.emoji-1f3c4-1f3fd{background-position:-594px -858px}.emoji-1f3c4-1f3fe{background-position:-594px -924px}.emoji-1f3c4-1f3ff{background-position:-594px -990px}.emoji-1f3c7-1f3fb{background-position:-594px -1254px}.emoji-1f3c7-1f3fc{background-position:-594px -1320px}.emoji-1f3c7-1f3fd{background-position:-594px -1386px}.emoji-1f3c7-1f3fe{background-position:-594px -1452px}.emoji-1f3c7-1f3ff{background-position:-594px -1518px}.emoji-1f3ca-1f3fb-200d-2640-fe0f{background-position:-594px -1782px}.emoji-1f3ca-1f3fc-200d-2640-fe0f{background-position:-594px -1848px}.emoji-1f3ca-1f3fd-200d-2640-fe0f{background-position:-594px -1914px}.emoji-1f3ca-1f3fe-200d-2640-fe0f{background-position:-594px -1980px}.emoji-1f3ca-1f3ff-200d-2640-fe0f{background-position:-594px -2046px}.emoji-1f3ca-1f3fb-200d-2642-fe0f{background-position:-594px -2178px}.emoji-1f3ca-1f3fc-200d-2642-fe0f{background-position:-594px -2244px}.emoji-1f3ca-1f3fd-200d-2642-fe0f{background-position:-594px -2310px}.emoji-1f3ca-1f3fe-200d-2642-fe0f{background-position:-594px -2376px}.emoji-1f3ca-1f3ff-200d-2642-fe0f{background-position:-594px -2442px}.emoji-1f3ca-1f3fb{background-position:-594px -2574px}.emoji-1f3ca-1f3fc{background-position:-594px -2640px}.emoji-1f3ca-1f3fd{background-position:-594px -2706px}.emoji-1f3ca-1f3fe{background-position:-594px -2772px}.emoji-1f3ca-1f3ff{background-position:-594px -2838px}.emoji-1f3cb-1f3fb-200d-2640-fe0f{background-position:-594px -2970px}.emoji-1f3cb-1f3fc-200d-2640-fe0f{background-position:-594px -3036px}.emoji-1f3cb-1f3fd-200d-2640-fe0f{background-position:-594px -3102px}.emoji-1f3cb-1f3fe-200d-2640-fe0f{background-position:-594px -3168px}.emoji-1f3cb-1f3ff-200d-2640-fe0f{background-position:-594px -3234px}.emoji-1f3cb-1f3fb-200d-2642-fe0f{background-position:-594px -3366px}.emoji-1f3cb-1f3fc-200d-2642-fe0f{background-position:-594px -3432px}.emoji-1f3cb-1f3fd-200d-2642-fe0f{background-position:-594px -3498px}.emoji-1f3cb-1f3fe-200d-2642-fe0f{background-position:-594px -3564px}.emoji-1f3cb-1f3ff-200d-2642-fe0f{background-position:-594px -3630px}.emoji-1f3cb-1f3fb{background-position:-594px -3762px}.emoji-1f3cb-1f3fc{background-position:-660px 0}.emoji-1f3cb-1f3fd{background-position:-660px -66px}.emoji-1f3cb-1f3fe{background-position:-660px -132px}.emoji-1f3cb-1f3ff{background-position:-660px -198px}.emoji-1f3cc-1f3fb-200d-2640-fe0f{background-position:-660px -330px}.emoji-1f3cc-1f3fc-200d-2640-fe0f{background-position:-660px -396px}.emoji-1f3cc-1f3fd-200d-2640-fe0f{background-position:-660px -462px}.emoji-1f3cc-1f3fe-200d-2640-fe0f{background-position:-660px -528px}.emoji-1f3cc-1f3ff-200d-2640-fe0f{background-position:-660px -594px}.emoji-1f3cc-1f3fb-200d-2642-fe0f{background-position:-660px -726px}.emoji-1f3cc-1f3fc-200d-2642-fe0f{background-position:-660px -792px}.emoji-1f3cc-1f3fd-200d-2642-fe0f{background-position:-660px -858px}.emoji-1f3cc-1f3fe-200d-2642-fe0f{background-position:-660px -924px}.emoji-1f3cc-1f3ff-200d-2642-fe0f{background-position:-660px -990px}.emoji-1f3cc-1f3fb{background-position:-660px -1122px}.emoji-1f3cc-1f3fc{background-position:-660px -1188px}.emoji-1f3cc-1f3fd{background-position:-660px -1254px}.emoji-1f3cc-1f3fe{background-position:-660px -1320px}.emoji-1f3cc-1f3ff{background-position:-660px -1386px}.emoji-1f442-1f3fb{background-position:-792px -2046px}.emoji-1f442-1f3fc{background-position:-792px -2112px}.emoji-1f442-1f3fd{background-position:-792px -2178px}.emoji-1f442-1f3fe{background-position:-792px -2244px}.emoji-1f442-1f3ff{background-position:-792px -2310px}.emoji-1f443-1f3fb{background-position:-792px -2442px}.emoji-1f443-1f3fc{background-position:-792px -2508px}.emoji-1f443-1f3fd{background-position:-792px -2574px}.emoji-1f443-1f3fe{background-position:-792px -2640px}.emoji-1f443-1f3ff{background-position:-792px -2706px}.emoji-1f446-1f3fb{background-position:-792px -2970px}.emoji-1f446-1f3fc{background-position:-792px -3036px}.emoji-1f446-1f3fd{background-position:-792px -3102px}.emoji-1f446-1f3fe{background-position:-792px -3168px}.emoji-1f446-1f3ff{background-position:-792px -3234px}.emoji-1f447-1f3fb{background-position:-792px -3366px}.emoji-1f447-1f3fc{background-position:-792px -3432px}.emoji-1f447-1f3fd{background-position:-792px -3498px}.emoji-1f447-1f3fe{background-position:-792px -3564px}.emoji-1f447-1f3ff{background-position:-792px -3630px}.emoji-1f448-1f3fb{background-position:-792px -3762px}.emoji-1f448-1f3fc{background-position:-858px 0}.emoji-1f448-1f3fd{background-position:-858px -66px}.emoji-1f448-1f3fe{background-position:-858px -132px}.emoji-1f448-1f3ff{background-position:-858px -198px}.emoji-1f449-1f3fb{background-position:-858px -330px}.emoji-1f449-1f3fc{background-position:-858px -396px}.emoji-1f449-1f3fd{background-position:-858px -462px}.emoji-1f449-1f3fe{background-position:-858px -528px}.emoji-1f449-1f3ff{background-position:-858px -594px}.emoji-1f44a-1f3fb{background-position:-858px -726px}.emoji-1f44a-1f3fc{background-position:-858px -792px}.emoji-1f44a-1f3fd{background-position:-858px -858px}.emoji-1f44a-1f3fe{background-position:-858px -924px}.emoji-1f44a-1f3ff{background-position:-858px -990px}.emoji-1f44b-1f3fb{background-position:-858px -1122px}.emoji-1f44b-1f3fc{background-position:-858px -1188px}.emoji-1f44b-1f3fd{background-position:-858px -1254px}.emoji-1f44b-1f3fe{background-position:-858px -1320px}.emoji-1f44b-1f3ff{background-position:-858px -1386px}.emoji-1f44c-1f3fb{background-position:-858px -1518px}.emoji-1f44c-1f3fc{background-position:-858px -1584px}.emoji-1f44c-1f3fd{background-position:-858px -1650px}.emoji-1f44c-1f3fe{background-position:-858px -1716px}.emoji-1f44c-1f3ff{background-position:-858px -1782px}.emoji-1f44d-1f3fb{background-position:-858px -1914px}.emoji-1f44d-1f3fc{background-position:-858px -1980px}.emoji-1f44d-1f3fd{background-position:-858px -2046px}.emoji-1f44d-1f3fe{background-position:-858px -2112px}.emoji-1f44d-1f3ff{background-position:-858px -2178px}.emoji-1f44e-1f3fb{background-position:-858px -2310px}.emoji-1f44e-1f3fc{background-position:-858px -2376px}.emoji-1f44e-1f3fd{background-position:-858px -2442px}.emoji-1f44e-1f3fe{background-position:-858px -2508px}.emoji-1f44e-1f3ff{background-position:-858px -2574px}.emoji-1f44f-1f3fb{background-position:-858px -2706px}.emoji-1f44f-1f3fc{background-position:-858px -2772px}.emoji-1f44f-1f3fd{background-position:-858px -2838px}.emoji-1f44f-1f3fe{background-position:-858px -2904px}.emoji-1f44f-1f3ff{background-position:-858px -2970px}.emoji-1f450-1f3fb{background-position:-858px -3102px}.emoji-1f450-1f3fc{background-position:-858px -3168px}.emoji-1f450-1f3fd{background-position:-858px -3234px}.emoji-1f450-1f3fe{background-position:-858px -3300px}.emoji-1f450-1f3ff{background-position:-858px -3366px}.emoji-1f466-1f3fb{background-position:-924px -1056px}.emoji-1f466-1f3fc{background-position:-924px -1122px}.emoji-1f466-1f3fd{background-position:-924px -1188px}.emoji-1f466-1f3fe{background-position:-924px -1254px}.emoji-1f466-1f3ff{background-position:-924px -1320px}.emoji-1f467-1f3fb{background-position:-924px -1452px}.emoji-1f467-1f3fc{background-position:-924px -1518px}.emoji-1f467-1f3fd{background-position:-924px -1584px}.emoji-1f467-1f3fe{background-position:-924px -1650px}.emoji-1f467-1f3ff{background-position:-924px -1716px}.emoji-1f468-1f3fb-200d-1f33e{background-position:-924px -1848px}.emoji-1f468-1f3fc-200d-1f33e{background-position:-924px -1914px}.emoji-1f468-1f3fd-200d-1f33e{background-position:-924px -1980px}.emoji-1f468-1f3fe-200d-1f33e{background-position:-924px -2046px}.emoji-1f468-1f3ff-200d-1f33e{background-position:-924px -2112px}.emoji-1f468-1f3fb-200d-1f373{background-position:-924px -2244px}.emoji-1f468-1f3fc-200d-1f373{background-position:-924px -2310px}.emoji-1f468-1f3fd-200d-1f373{background-position:-924px -2376px}.emoji-1f468-1f3fe-200d-1f373{background-position:-924px -2442px}.emoji-1f468-1f3ff-200d-1f373{background-position:-924px -2508px}.emoji-1f468-1f3fb-200d-1f37c{background-position:-924px -2640px}.emoji-1f468-1f3fc-200d-1f37c{background-position:-924px -2706px}.emoji-1f468-1f3fd-200d-1f37c{background-position:-924px -2772px}.emoji-1f468-1f3fe-200d-1f37c{background-position:-924px -2838px}.emoji-1f468-1f3ff-200d-1f37c{background-position:-924px -2904px}.emoji-1f468-1f3fb-200d-1f393{background-position:-924px -3036px}.emoji-1f468-1f3fc-200d-1f393{background-position:-924px -3102px}.emoji-1f468-1f3fd-200d-1f393{background-position:-924px -3168px}.emoji-1f468-1f3fe-200d-1f393{background-position:-924px -3234px}.emoji-1f468-1f3ff-200d-1f393{background-position:-924px -3300px}.emoji-1f468-1f3fb-200d-1f3a4{background-position:-924px -3432px}.emoji-1f468-1f3fc-200d-1f3a4{background-position:-924px -3498px}.emoji-1f468-1f3fd-200d-1f3a4{background-position:-924px -3564px}.emoji-1f468-1f3fe-200d-1f3a4{background-position:-924px -3630px}.emoji-1f468-1f3ff-200d-1f3a4{background-position:-924px -3696px}.emoji-1f468-1f3fb-200d-1f3a8{background-position:-990px 0}.emoji-1f468-1f3fc-200d-1f3a8{background-position:-990px -66px}.emoji-1f468-1f3fd-200d-1f3a8{background-position:-990px -132px}.emoji-1f468-1f3fe-200d-1f3a8{background-position:-990px -198px}.emoji-1f468-1f3ff-200d-1f3a8{background-position:-990px -264px}.emoji-1f468-1f3fb-200d-1f3eb{background-position:-990px -396px}.emoji-1f468-1f3fc-200d-1f3eb{background-position:-990px -462px}.emoji-1f468-1f3fd-200d-1f3eb{background-position:-990px -528px}.emoji-1f468-1f3fe-200d-1f3eb{background-position:-990px -594px}.emoji-1f468-1f3ff-200d-1f3eb{background-position:-990px -660px}.emoji-1f468-1f3fb-200d-1f3ed{background-position:-990px -792px}.emoji-1f468-1f3fc-200d-1f3ed{background-position:-990px -858px}.emoji-1f468-1f3fd-200d-1f3ed{background-position:-990px -924px}.emoji-1f468-1f3fe-200d-1f3ed{background-position:-990px -990px}.emoji-1f468-1f3ff-200d-1f3ed{background-position:-990px -1056px}.emoji-1f468-1f3fb-200d-1f4bb{background-position:-990px -2178px}.emoji-1f468-1f3fc-200d-1f4bb{background-position:-990px -2244px}.emoji-1f468-1f3fd-200d-1f4bb{background-position:-990px -2310px}.emoji-1f468-1f3fe-200d-1f4bb{background-position:-990px -2376px}.emoji-1f468-1f3ff-200d-1f4bb{background-position:-990px -2442px}.emoji-1f468-1f3fb-200d-1f4bc{background-position:-990px -2574px}.emoji-1f468-1f3fc-200d-1f4bc{background-position:-990px -2640px}.emoji-1f468-1f3fd-200d-1f4bc{background-position:-990px -2706px}.emoji-1f468-1f3fe-200d-1f4bc{background-position:-990px -2772px}.emoji-1f468-1f3ff-200d-1f4bc{background-position:-990px -2838px}.emoji-1f468-1f3fb-200d-1f527{background-position:-990px -2970px}.emoji-1f468-1f3fc-200d-1f527{background-position:-990px -3036px}.emoji-1f468-1f3fd-200d-1f527{background-position:-990px -3102px}.emoji-1f468-1f3fe-200d-1f527{background-position:-990px -3168px}.emoji-1f468-1f3ff-200d-1f527{background-position:-990px -3234px}.emoji-1f468-1f3fb-200d-1f52c{background-position:-990px -3366px}.emoji-1f468-1f3fc-200d-1f52c{background-position:-990px -3432px}.emoji-1f468-1f3fd-200d-1f52c{background-position:-990px -3498px}.emoji-1f468-1f3fe-200d-1f52c{background-position:-990px -3564px}.emoji-1f468-1f3ff-200d-1f52c{background-position:-990px -3630px}.emoji-1f468-1f3fb-200d-1f680{background-position:-990px -3762px}.emoji-1f468-1f3fc-200d-1f680{background-position:-1056px 0}.emoji-1f468-1f3fd-200d-1f680{background-position:-1056px -66px}.emoji-1f468-1f3fe-200d-1f680{background-position:-1056px -132px}.emoji-1f468-1f3ff-200d-1f680{background-position:-1056px -198px}.emoji-1f468-1f3fb-200d-1f692{background-position:-1056px -330px}.emoji-1f468-1f3fc-200d-1f692{background-position:-1056px -396px}.emoji-1f468-1f3fd-200d-1f692{background-position:-1056px -462px}.emoji-1f468-1f3fe-200d-1f692{background-position:-1056px -528px}.emoji-1f468-1f3ff-200d-1f692{background-position:-1056px -594px}.emoji-1f468-1f3fb-200d-1f9af{background-position:-1056px -726px}.emoji-1f468-1f3fc-200d-1f9af{background-position:-1056px -792px}.emoji-1f468-1f3fd-200d-1f9af{background-position:-1056px -858px}.emoji-1f468-1f3fe-200d-1f9af{background-position:-1056px -924px}.emoji-1f468-1f3ff-200d-1f9af{background-position:-1056px -990px}.emoji-1f468-1f3fb-200d-1f9b0{background-position:-1056px -1122px}.emoji-1f468-1f3fc-200d-1f9b0{background-position:-1056px -1188px}.emoji-1f468-1f3fd-200d-1f9b0{background-position:-1056px -1254px}.emoji-1f468-1f3fe-200d-1f9b0{background-position:-1056px -1320px}.emoji-1f468-1f3ff-200d-1f9b0{background-position:-1056px -1386px}.emoji-1f468-1f3fb-200d-1f9b1{background-position:-1056px -1518px}.emoji-1f468-1f3fc-200d-1f9b1{background-position:-1056px -1584px}.emoji-1f468-1f3fd-200d-1f9b1{background-position:-1056px -1650px}.emoji-1f468-1f3fe-200d-1f9b1{background-position:-1056px -1716px}.emoji-1f468-1f3ff-200d-1f9b1{background-position:-1056px -1782px}.emoji-1f468-1f3fb-200d-1f9b2{background-position:-1056px -1914px}.emoji-1f468-1f3fc-200d-1f9b2{background-position:-1056px -1980px}.emoji-1f468-1f3fd-200d-1f9b2{background-position:-1056px -2046px}.emoji-1f468-1f3fe-200d-1f9b2{background-position:-1056px -2112px}.emoji-1f468-1f3ff-200d-1f9b2{background-position:-1056px -2178px}.emoji-1f468-1f3fb-200d-1f9b3{background-position:-1056px -2310px}.emoji-1f468-1f3fc-200d-1f9b3{background-position:-1056px -2376px}.emoji-1f468-1f3fd-200d-1f9b3{background-position:-1056px -2442px}.emoji-1f468-1f3fe-200d-1f9b3{background-position:-1056px -2508px}.emoji-1f468-1f3ff-200d-1f9b3{background-position:-1056px -2574px}.emoji-1f468-1f3fb-200d-1f9bc{background-position:-1056px -2706px}.emoji-1f468-1f3fc-200d-1f9bc{background-position:-1056px -2772px}.emoji-1f468-1f3fd-200d-1f9bc{background-position:-1056px -2838px}.emoji-1f468-1f3fe-200d-1f9bc{background-position:-1056px -2904px}.emoji-1f468-1f3ff-200d-1f9bc{background-position:-1056px -2970px}.emoji-1f468-1f3fb-200d-1f9bd{background-position:-1056px -3102px}.emoji-1f468-1f3fc-200d-1f9bd{background-position:-1056px -3168px}.emoji-1f468-1f3fd-200d-1f9bd{background-position:-1056px -3234px}.emoji-1f468-1f3fe-200d-1f9bd{background-position:-1056px -3300px}.emoji-1f468-1f3ff-200d-1f9bd{background-position:-1056px -3366px}.emoji-1f468-1f3fb-200d-2695-fe0f{background-position:-1056px -3498px}.emoji-1f468-1f3fc-200d-2695-fe0f{background-position:-1056px -3564px}.emoji-1f468-1f3fd-200d-2695-fe0f{background-position:-1056px -3630px}.emoji-1f468-1f3fe-200d-2695-fe0f{background-position:-1056px -3696px}.emoji-1f468-1f3ff-200d-2695-fe0f{background-position:-1056px -3762px}.emoji-1f468-1f3fb-200d-2696-fe0f{background-position:-1122px -66px}.emoji-1f468-1f3fc-200d-2696-fe0f{background-position:-1122px -132px}.emoji-1f468-1f3fd-200d-2696-fe0f{background-position:-1122px -198px}.emoji-1f468-1f3fe-200d-2696-fe0f{background-position:-1122px -264px}.emoji-1f468-1f3ff-200d-2696-fe0f{background-position:-1122px -330px}.emoji-1f468-1f3fb-200d-2708-fe0f{background-position:-1122px -462px}.emoji-1f468-1f3fc-200d-2708-fe0f{background-position:-1122px -528px}.emoji-1f468-1f3fd-200d-2708-fe0f{background-position:-1122px -594px}.emoji-1f468-1f3fe-200d-2708-fe0f{background-position:-1122px -660px}.emoji-1f468-1f3ff-200d-2708-fe0f{background-position:-1122px -726px}.emoji-1f468-1f3fb{background-position:-1122px -990px}.emoji-1f468-1f3fc{background-position:-1122px -1056px}.emoji-1f468-1f3fd{background-position:-1122px -1122px}.emoji-1f468-1f3fe{background-position:-1122px -1188px}.emoji-1f468-1f3ff{background-position:-1122px -1254px}.emoji-1f469-1f3fb-200d-1f33e{background-position:-1122px -1386px}.emoji-1f469-1f3fc-200d-1f33e{background-position:-1122px -1452px}.emoji-1f469-1f3fd-200d-1f33e{background-position:-1122px -1518px}.emoji-1f469-1f3fe-200d-1f33e{background-position:-1122px -1584px}.emoji-1f469-1f3ff-200d-1f33e{background-position:-1122px -1650px}.emoji-1f469-1f3fb-200d-1f373{background-position:-1122px -1782px}.emoji-1f469-1f3fc-200d-1f373{background-position:-1122px -1848px}.emoji-1f469-1f3fd-200d-1f373{background-position:-1122px -1914px}.emoji-1f469-1f3fe-200d-1f373{background-position:-1122px -1980px}.emoji-1f469-1f3ff-200d-1f373{background-position:-1122px -2046px}.emoji-1f469-1f3fb-200d-1f37c{background-position:-1122px -2178px}.emoji-1f469-1f3fc-200d-1f37c{background-position:-1122px -2244px}.emoji-1f469-1f3fd-200d-1f37c{background-position:-1122px -2310px}.emoji-1f469-1f3fe-200d-1f37c{background-position:-1122px -2376px}.emoji-1f469-1f3ff-200d-1f37c{background-position:-1122px -2442px}.emoji-1f469-1f3fb-200d-1f393{background-position:-1122px -2574px}.emoji-1f469-1f3fc-200d-1f393{background-position:-1122px -2640px}.emoji-1f469-1f3fd-200d-1f393{background-position:-1122px -2706px}.emoji-1f469-1f3fe-200d-1f393{background-position:-1122px -2772px}.emoji-1f469-1f3ff-200d-1f393{background-position:-1122px -2838px}.emoji-1f469-1f3fb-200d-1f3a4{background-position:-1122px -2970px}.emoji-1f469-1f3fc-200d-1f3a4{background-position:-1122px -3036px}.emoji-1f469-1f3fd-200d-1f3a4{background-position:-1122px -3102px}.emoji-1f469-1f3fe-200d-1f3a4{background-position:-1122px -3168px}.emoji-1f469-1f3ff-200d-1f3a4{background-position:-1122px -3234px}.emoji-1f469-1f3fb-200d-1f3a8{background-position:-1122px -3366px}.emoji-1f469-1f3fc-200d-1f3a8{background-position:-1122px -3432px}.emoji-1f469-1f3fd-200d-1f3a8{background-position:-1122px -3498px}.emoji-1f469-1f3fe-200d-1f3a8{background-position:-1122px -3564px}.emoji-1f469-1f3ff-200d-1f3a8{background-position:-1122px -3630px}.emoji-1f469-1f3fb-200d-1f3eb{background-position:-1122px -3762px}.emoji-1f469-1f3fc-200d-1f3eb{background-position:-1188px 0}.emoji-1f469-1f3fd-200d-1f3eb{background-position:-1188px -66px}.emoji-1f469-1f3fe-200d-1f3eb{background-position:-1188px -132px}.emoji-1f469-1f3ff-200d-1f3eb{background-position:-1188px -198px}.emoji-1f469-1f3fb-200d-1f3ed{background-position:-1188px -330px}.emoji-1f469-1f3fc-200d-1f3ed{background-position:-1188px -396px}.emoji-1f469-1f3fd-200d-1f3ed{background-position:-1188px -462px}.emoji-1f469-1f3fe-200d-1f3ed{background-position:-1188px -528px}.emoji-1f469-1f3ff-200d-1f3ed{background-position:-1188px -594px}.emoji-1f469-1f3fb-200d-1f4bb{background-position:-1188px -1386px}.emoji-1f469-1f3fc-200d-1f4bb{background-position:-1188px -1452px}.emoji-1f469-1f3fd-200d-1f4bb{background-position:-1188px -1518px}.emoji-1f469-1f3fe-200d-1f4bb{background-position:-1188px -1584px}.emoji-1f469-1f3ff-200d-1f4bb{background-position:-1188px -1650px}.emoji-1f469-1f3fb-200d-1f4bc{background-position:-1188px -1782px}.emoji-1f469-1f3fc-200d-1f4bc{background-position:-1188px -1848px}.emoji-1f469-1f3fd-200d-1f4bc{background-position:-1188px -1914px}.emoji-1f469-1f3fe-200d-1f4bc{background-position:-1188px -1980px}.emoji-1f469-1f3ff-200d-1f4bc{background-position:-1188px -2046px}.emoji-1f469-1f3fb-200d-1f527{background-position:-1188px -2178px}.emoji-1f469-1f3fc-200d-1f527{background-position:-1188px -2244px}.emoji-1f469-1f3fd-200d-1f527{background-position:-1188px -2310px}.emoji-1f469-1f3fe-200d-1f527{background-position:-1188px -2376px}.emoji-1f469-1f3ff-200d-1f527{background-position:-1188px -2442px}.emoji-1f469-1f3fb-200d-1f52c{background-position:-1188px -2574px}.emoji-1f469-1f3fc-200d-1f52c{background-position:-1188px -2640px}.emoji-1f469-1f3fd-200d-1f52c{background-position:-1188px -2706px}.emoji-1f469-1f3fe-200d-1f52c{background-position:-1188px -2772px}.emoji-1f469-1f3ff-200d-1f52c{background-position:-1188px -2838px}.emoji-1f469-1f3fb-200d-1f680{background-position:-1188px -2970px}.emoji-1f469-1f3fc-200d-1f680{background-position:-1188px -3036px}.emoji-1f469-1f3fd-200d-1f680{background-position:-1188px -3102px}.emoji-1f469-1f3fe-200d-1f680{background-position:-1188px -3168px}.emoji-1f469-1f3ff-200d-1f680{background-position:-1188px -3234px}.emoji-1f469-1f3fb-200d-1f692{background-position:-1188px -3366px}.emoji-1f469-1f3fc-200d-1f692{background-position:-1188px -3432px}.emoji-1f469-1f3fd-200d-1f692{background-position:-1188px -3498px}.emoji-1f469-1f3fe-200d-1f692{background-position:-1188px -3564px}.emoji-1f469-1f3ff-200d-1f692{background-position:-1188px -3630px}.emoji-1f469-1f3fb-200d-1f9af{background-position:-1188px -3762px}.emoji-1f469-1f3fc-200d-1f9af{background-position:-1254px 0}.emoji-1f469-1f3fd-200d-1f9af{background-position:-1254px -66px}.emoji-1f469-1f3fe-200d-1f9af{background-position:-1254px -132px}.emoji-1f469-1f3ff-200d-1f9af{background-position:-1254px -198px}.emoji-1f469-1f3fb-200d-1f9b0{background-position:-1254px -330px}.emoji-1f469-1f3fc-200d-1f9b0{background-position:-1254px -396px}.emoji-1f469-1f3fd-200d-1f9b0{background-position:-1254px -462px}.emoji-1f469-1f3fe-200d-1f9b0{background-position:-1254px -528px}.emoji-1f469-1f3ff-200d-1f9b0{background-position:-1254px -594px}.emoji-1f469-1f3fb-200d-1f9b1{background-position:-1254px -726px}.emoji-1f469-1f3fc-200d-1f9b1{background-position:-1254px -792px}.emoji-1f469-1f3fd-200d-1f9b1{background-position:-1254px -858px}.emoji-1f469-1f3fe-200d-1f9b1{background-position:-1254px -924px}.emoji-1f469-1f3ff-200d-1f9b1{background-position:-1254px -990px}.emoji-1f469-1f3fb-200d-1f9b2{background-position:-1254px -1122px}.emoji-1f469-1f3fc-200d-1f9b2{background-position:-1254px -1188px}.emoji-1f469-1f3fd-200d-1f9b2{background-position:-1254px -1254px}.emoji-1f469-1f3fe-200d-1f9b2{background-position:-1254px -1320px}.emoji-1f469-1f3ff-200d-1f9b2{background-position:-1254px -1386px}.emoji-1f469-1f3fb-200d-1f9b3{background-position:-1254px -1518px}.emoji-1f469-1f3fc-200d-1f9b3{background-position:-1254px -1584px}.emoji-1f469-1f3fd-200d-1f9b3{background-position:-1254px -1650px}.emoji-1f469-1f3fe-200d-1f9b3{background-position:-1254px -1716px}.emoji-1f469-1f3ff-200d-1f9b3{background-position:-1254px -1782px}.emoji-1f469-1f3fb-200d-1f9bc{background-position:-1254px -1914px}.emoji-1f469-1f3fc-200d-1f9bc{background-position:-1254px -1980px}.emoji-1f469-1f3fd-200d-1f9bc{background-position:-1254px -2046px}.emoji-1f469-1f3fe-200d-1f9bc{background-position:-1254px -2112px}.emoji-1f469-1f3ff-200d-1f9bc{background-position:-1254px -2178px}.emoji-1f469-1f3fb-200d-1f9bd{background-position:-1254px -2310px}.emoji-1f469-1f3fc-200d-1f9bd{background-position:-1254px -2376px}.emoji-1f469-1f3fd-200d-1f9bd{background-position:-1254px -2442px}.emoji-1f469-1f3fe-200d-1f9bd{background-position:-1254px -2508px}.emoji-1f469-1f3ff-200d-1f9bd{background-position:-1254px -2574px}.emoji-1f469-1f3fb-200d-2695-fe0f{background-position:-1254px -2706px}.emoji-1f469-1f3fc-200d-2695-fe0f{background-position:-1254px -2772px}.emoji-1f469-1f3fd-200d-2695-fe0f{background-position:-1254px -2838px}.emoji-1f469-1f3fe-200d-2695-fe0f{background-position:-1254px -2904px}.emoji-1f469-1f3ff-200d-2695-fe0f{background-position:-1254px -2970px}.emoji-1f469-1f3fb-200d-2696-fe0f{background-position:-1254px -3102px}.emoji-1f469-1f3fc-200d-2696-fe0f{background-position:-1254px -3168px}.emoji-1f469-1f3fd-200d-2696-fe0f{background-position:-1254px -3234px}.emoji-1f469-1f3fe-200d-2696-fe0f{background-position:-1254px -3300px}.emoji-1f469-1f3ff-200d-2696-fe0f{background-position:-1254px -3366px}.emoji-1f469-1f3fb-200d-2708-fe0f{background-position:-1254px -3498px}.emoji-1f469-1f3fc-200d-2708-fe0f{background-position:-1254px -3564px}.emoji-1f469-1f3fd-200d-2708-fe0f{background-position:-1254px -3630px}.emoji-1f469-1f3fe-200d-2708-fe0f{background-position:-1254px -3696px}.emoji-1f469-1f3ff-200d-2708-fe0f{background-position:-1254px -3762px}.emoji-1f469-1f3fb{background-position:-1320px -330px}.emoji-1f469-1f3fc{background-position:-1320px -396px}.emoji-1f469-1f3fd{background-position:-1320px -462px}.emoji-1f469-1f3fe{background-position:-1320px -528px}.emoji-1f469-1f3ff{background-position:-1320px -594px}.emoji-1f46b-1f3fb{background-position:-1320px -792px}.emoji-1f46b-1f3fc{background-position:-1320px -858px}.emoji-1f46b-1f3fd{background-position:-1320px -924px}.emoji-1f46b-1f3fe{background-position:-1320px -990px}.emoji-1f46b-1f3ff{background-position:-1320px -1056px}.emoji-1f469-1f3fb-200d-1f91d-200d-1f468-1f3fc{background-position:-1320px -1122px}.emoji-1f469-1f3fb-200d-1f91d-200d-1f468-1f3fd{background-position:-1320px -1188px}.emoji-1f469-1f3fb-200d-1f91d-200d-1f468-1f3fe{background-position:-1320px -1254px}.emoji-1f469-1f3fb-200d-1f91d-200d-1f468-1f3ff{background-position:-1320px -1320px}.emoji-1f469-1f3fc-200d-1f91d-200d-1f468-1f3fb{background-position:-1320px -1386px}.emoji-1f469-1f3fc-200d-1f91d-200d-1f468-1f3fd{background-position:-1320px -1452px}.emoji-1f469-1f3fc-200d-1f91d-200d-1f468-1f3fe{background-position:-1320px -1518px}.emoji-1f469-1f3fc-200d-1f91d-200d-1f468-1f3ff{background-position:-1320px -1584px}.emoji-1f469-1f3fd-200d-1f91d-200d-1f468-1f3fb{background-position:-1320px -1650px}.emoji-1f469-1f3fd-200d-1f91d-200d-1f468-1f3fc{background-position:-1320px -1716px}.emoji-1f469-1f3fd-200d-1f91d-200d-1f468-1f3fe{background-position:-1320px -1782px}.emoji-1f469-1f3fd-200d-1f91d-200d-1f468-1f3ff{background-position:-1320px -1848px}.emoji-1f469-1f3fe-200d-1f91d-200d-1f468-1f3fb{background-position:-1320px -1914px}.emoji-1f469-1f3fe-200d-1f91d-200d-1f468-1f3fc{background-position:-1320px -1980px}.emoji-1f469-1f3fe-200d-1f91d-200d-1f468-1f3fd{background-position:-1320px -2046px}.emoji-1f469-1f3fe-200d-1f91d-200d-1f468-1f3ff{background-position:-1320px -2112px}.emoji-1f469-1f3ff-200d-1f91d-200d-1f468-1f3fb{background-position:-1320px -2178px}.emoji-1f469-1f3ff-200d-1f91d-200d-1f468-1f3fc{background-position:-1320px -2244px}.emoji-1f469-1f3ff-200d-1f91d-200d-1f468-1f3fd{background-position:-1320px -2310px}.emoji-1f469-1f3ff-200d-1f91d-200d-1f468-1f3fe{background-position:-1320px -2376px}.emoji-1f46c-1f3fb{background-position:-1320px -2508px}.emoji-1f46c-1f3fc{background-position:-1320px -2574px}.emoji-1f46c-1f3fd{background-position:-1320px -2640px}.emoji-1f46c-1f3fe{background-position:-1320px -2706px}.emoji-1f46c-1f3ff{background-position:-1320px -2772px}.emoji-1f468-1f3fb-200d-1f91d-200d-1f468-1f3fc{background-position:-1320px -2838px}.emoji-1f468-1f3fb-200d-1f91d-200d-1f468-1f3fd{background-position:-1320px -2904px}.emoji-1f468-1f3fb-200d-1f91d-200d-1f468-1f3fe{background-position:-1320px -2970px}.emoji-1f468-1f3fb-200d-1f91d-200d-1f468-1f3ff{background-position:-1320px -3036px}.emoji-1f468-1f3fc-200d-1f91d-200d-1f468-1f3fb{background-position:-1320px -3102px}.emoji-1f468-1f3fc-200d-1f91d-200d-1f468-1f3fd{background-position:-1320px -3168px}.emoji-1f468-1f3fc-200d-1f91d-200d-1f468-1f3fe{background-position:-1320px -3234px}.emoji-1f468-1f3fc-200d-1f91d-200d-1f468-1f3ff{background-position:-1320px -3300px}.emoji-1f468-1f3fd-200d-1f91d-200d-1f468-1f3fb{background-position:-1320px -3366px}.emoji-1f468-1f3fd-200d-1f91d-200d-1f468-1f3fc{background-position:-1320px -3432px}.emoji-1f468-1f3fd-200d-1f91d-200d-1f468-1f3fe{background-position:-1320px -3498px}.emoji-1f468-1f3fd-200d-1f91d-200d-1f468-1f3ff{background-position:-1320px -3564px}.emoji-1f468-1f3fe-200d-1f91d-200d-1f468-1f3fb{background-position:-1320px -3630px}.emoji-1f468-1f3fe-200d-1f91d-200d-1f468-1f3fc{background-position:-1320px -3696px}.emoji-1f468-1f3fe-200d-1f91d-200d-1f468-1f3fd{background-position:-1320px -3762px}.emoji-1f468-1f3fe-200d-1f91d-200d-1f468-1f3ff{background-position:-1386px 0}.emoji-1f468-1f3ff-200d-1f91d-200d-1f468-1f3fb{background-position:-1386px -66px}.emoji-1f468-1f3ff-200d-1f91d-200d-1f468-1f3fc{background-position:-1386px -132px}.emoji-1f468-1f3ff-200d-1f91d-200d-1f468-1f3fd{background-position:-1386px -198px}.emoji-1f468-1f3ff-200d-1f91d-200d-1f468-1f3fe{background-position:-1386px -264px}.emoji-1f46d-1f3fb{background-position:-1386px -396px}.emoji-1f46d-1f3fc{background-position:-1386px -462px}.emoji-1f46d-1f3fd{background-position:-1386px -528px}.emoji-1f46d-1f3fe{background-position:-1386px -594px}.emoji-1f46d-1f3ff{background-position:-1386px -660px}.emoji-1f469-1f3fb-200d-1f91d-200d-1f469-1f3fc{background-position:-1386px -726px}.emoji-1f469-1f3fb-200d-1f91d-200d-1f469-1f3fd{background-position:-1386px -792px}.emoji-1f469-1f3fb-200d-1f91d-200d-1f469-1f3fe{background-position:-1386px -858px}.emoji-1f469-1f3fb-200d-1f91d-200d-1f469-1f3ff{background-position:-1386px -924px}.emoji-1f469-1f3fc-200d-1f91d-200d-1f469-1f3fb{background-position:-1386px -990px}.emoji-1f469-1f3fc-200d-1f91d-200d-1f469-1f3fd{background-position:-1386px -1056px}.emoji-1f469-1f3fc-200d-1f91d-200d-1f469-1f3fe{background-position:-1386px -1122px}.emoji-1f469-1f3fc-200d-1f91d-200d-1f469-1f3ff{background-position:-1386px -1188px}.emoji-1f469-1f3fd-200d-1f91d-200d-1f469-1f3fb{background-position:-1386px -1254px}.emoji-1f469-1f3fd-200d-1f91d-200d-1f469-1f3fc{background-position:-1386px -1320px}.emoji-1f469-1f3fd-200d-1f91d-200d-1f469-1f3fe{background-position:-1386px -1386px}.emoji-1f469-1f3fd-200d-1f91d-200d-1f469-1f3ff{background-position:-1386px -1452px}.emoji-1f469-1f3fe-200d-1f91d-200d-1f469-1f3fb{background-position:-1386px -1518px}.emoji-1f469-1f3fe-200d-1f91d-200d-1f469-1f3fc{background-position:-1386px -1584px}.emoji-1f469-1f3fe-200d-1f91d-200d-1f469-1f3fd{background-position:-1386px -1650px}.emoji-1f469-1f3fe-200d-1f91d-200d-1f469-1f3ff{background-position:-1386px -1716px}.emoji-1f469-1f3ff-200d-1f91d-200d-1f469-1f3fb{background-position:-1386px -1782px}.emoji-1f469-1f3ff-200d-1f91d-200d-1f469-1f3fc{background-position:-1386px -1848px}.emoji-1f469-1f3ff-200d-1f91d-200d-1f469-1f3fd{background-position:-1386px -1914px}.emoji-1f469-1f3ff-200d-1f91d-200d-1f469-1f3fe{background-position:-1386px -1980px}.emoji-1f46e-1f3fb-200d-2640-fe0f{background-position:-1386px -2112px}.emoji-1f46e-1f3fc-200d-2640-fe0f{background-position:-1386px -2178px}.emoji-1f46e-1f3fd-200d-2640-fe0f{background-position:-1386px -2244px}.emoji-1f46e-1f3fe-200d-2640-fe0f{background-position:-1386px -2310px}.emoji-1f46e-1f3ff-200d-2640-fe0f{background-position:-1386px -2376px}.emoji-1f46e-1f3fb-200d-2642-fe0f{background-position:-1386px -2508px}.emoji-1f46e-1f3fc-200d-2642-fe0f{background-position:-1386px -2574px}.emoji-1f46e-1f3fd-200d-2642-fe0f{background-position:-1386px -2640px}.emoji-1f46e-1f3fe-200d-2642-fe0f{background-position:-1386px -2706px}.emoji-1f46e-1f3ff-200d-2642-fe0f{background-position:-1386px -2772px}.emoji-1f46e-1f3fb{background-position:-1386px -2904px}.emoji-1f46e-1f3fc{background-position:-1386px -2970px}.emoji-1f46e-1f3fd{background-position:-1386px -3036px}.emoji-1f46e-1f3fe{background-position:-1386px -3102px}.emoji-1f46e-1f3ff{background-position:-1386px -3168px}.emoji-1f470-1f3fb-200d-2640-fe0f{background-position:-1386px -3498px}.emoji-1f470-1f3fc-200d-2640-fe0f{background-position:-1386px -3564px}.emoji-1f470-1f3fd-200d-2640-fe0f{background-position:-1386px -3630px}.emoji-1f470-1f3fe-200d-2640-fe0f{background-position:-1386px -3696px}.emoji-1f470-1f3ff-200d-2640-fe0f{background-position:-1386px -3762px}.emoji-1f470-1f3fb-200d-2642-fe0f{background-position:-1452px -66px}.emoji-1f470-1f3fc-200d-2642-fe0f{background-position:-1452px -132px}.emoji-1f470-1f3fd-200d-2642-fe0f{background-position:-1452px -198px}.emoji-1f470-1f3fe-200d-2642-fe0f{background-position:-1452px -264px}.emoji-1f470-1f3ff-200d-2642-fe0f{background-position:-1452px -330px}.emoji-1f470-1f3fb{background-position:-1452px -462px}.emoji-1f470-1f3fc{background-position:-1452px -528px}.emoji-1f470-1f3fd{background-position:-1452px -594px}.emoji-1f470-1f3fe{background-position:-1452px -660px}.emoji-1f470-1f3ff{background-position:-1452px -726px}.emoji-1f471-1f3fb-200d-2640-fe0f{background-position:-1452px -858px}.emoji-1f471-1f3fc-200d-2640-fe0f{background-position:-1452px -924px}.emoji-1f471-1f3fd-200d-2640-fe0f{background-position:-1452px -990px}.emoji-1f471-1f3fe-200d-2640-fe0f{background-position:-1452px -1056px}.emoji-1f471-1f3ff-200d-2640-fe0f{background-position:-1452px -1122px}.emoji-1f471-1f3fb-200d-2642-fe0f{background-position:-1452px -1254px}.emoji-1f471-1f3fc-200d-2642-fe0f{background-position:-1452px -1320px}.emoji-1f471-1f3fd-200d-2642-fe0f{background-position:-1452px -1386px}.emoji-1f471-1f3fe-200d-2642-fe0f{background-position:-1452px -1452px}.emoji-1f471-1f3ff-200d-2642-fe0f{background-position:-1452px -1518px}.emoji-1f471-1f3fb{background-position:-1452px -1650px}.emoji-1f471-1f3fc{background-position:-1452px -1716px}.emoji-1f471-1f3fd{background-position:-1452px -1782px}.emoji-1f471-1f3fe{background-position:-1452px -1848px}.emoji-1f471-1f3ff{background-position:-1452px -1914px}.emoji-1f472-1f3fb{background-position:-1452px -2046px}.emoji-1f472-1f3fc{background-position:-1452px -2112px}.emoji-1f472-1f3fd{background-position:-1452px -2178px}.emoji-1f472-1f3fe{background-position:-1452px -2244px}.emoji-1f472-1f3ff{background-position:-1452px -2310px}.emoji-1f473-1f3fb-200d-2640-fe0f{background-position:-1452px -2442px}.emoji-1f473-1f3fc-200d-2640-fe0f{background-position:-1452px -2508px}.emoji-1f473-1f3fd-200d-2640-fe0f{background-position:-1452px -2574px}.emoji-1f473-1f3fe-200d-2640-fe0f{background-position:-1452px -2640px}.emoji-1f473-1f3ff-200d-2640-fe0f{background-position:-1452px -2706px}.emoji-1f473-1f3fb-200d-2642-fe0f{background-position:-1452px -2838px}.emoji-1f473-1f3fc-200d-2642-fe0f{background-position:-1452px -2904px}.emoji-1f473-1f3fd-200d-2642-fe0f{background-position:-1452px -2970px}.emoji-1f473-1f3fe-200d-2642-fe0f{background-position:-1452px -3036px}.emoji-1f473-1f3ff-200d-2642-fe0f{background-position:-1452px -3102px}.emoji-1f473-1f3fb{background-position:-1452px -3234px}.emoji-1f473-1f3fc{background-position:-1452px -3300px}.emoji-1f473-1f3fd{background-position:-1452px -3366px}.emoji-1f473-1f3fe{background-position:-1452px -3432px}.emoji-1f473-1f3ff{background-position:-1452px -3498px}.emoji-1f474-1f3fb{background-position:-1452px -3630px}.emoji-1f474-1f3fc{background-position:-1452px -3696px}.emoji-1f474-1f3fd{background-position:-1452px -3762px}.emoji-1f474-1f3fe{background-position:-1518px 0}.emoji-1f474-1f3ff{background-position:-1518px -66px}.emoji-1f475-1f3fb{background-position:-1518px -198px}.emoji-1f475-1f3fc{background-position:-1518px -264px}.emoji-1f475-1f3fd{background-position:-1518px -330px}.emoji-1f475-1f3fe{background-position:-1518px -396px}.emoji-1f475-1f3ff{background-position:-1518px -462px}.emoji-1f476-1f3fb{background-position:-1518px -594px}.emoji-1f476-1f3fc{background-position:-1518px -660px}.emoji-1f476-1f3fd{background-position:-1518px -726px}.emoji-1f476-1f3fe{background-position:-1518px -792px}.emoji-1f476-1f3ff{background-position:-1518px -858px}.emoji-1f477-1f3fb-200d-2640-fe0f{background-position:-1518px -990px}.emoji-1f477-1f3fc-200d-2640-fe0f{background-position:-1518px -1056px}.emoji-1f477-1f3fd-200d-2640-fe0f{background-position:-1518px -1122px}.emoji-1f477-1f3fe-200d-2640-fe0f{background-position:-1518px -1188px}.emoji-1f477-1f3ff-200d-2640-fe0f{background-position:-1518px -1254px}.emoji-1f477-1f3fb-200d-2642-fe0f{background-position:-1518px -1386px}.emoji-1f477-1f3fc-200d-2642-fe0f{background-position:-1518px -1452px}.emoji-1f477-1f3fd-200d-2642-fe0f{background-position:-1518px -1518px}.emoji-1f477-1f3fe-200d-2642-fe0f{background-position:-1518px -1584px}.emoji-1f477-1f3ff-200d-2642-fe0f{background-position:-1518px -1650px}.emoji-1f477-1f3fb{background-position:-1518px -1782px}.emoji-1f477-1f3fc{background-position:-1518px -1848px}.emoji-1f477-1f3fd{background-position:-1518px -1914px}.emoji-1f477-1f3fe{background-position:-1518px -1980px}.emoji-1f477-1f3ff{background-position:-1518px -2046px}.emoji-1f478-1f3fb{background-position:-1518px -2178px}.emoji-1f478-1f3fc{background-position:-1518px -2244px}.emoji-1f478-1f3fd{background-position:-1518px -2310px}.emoji-1f478-1f3fe{background-position:-1518px -2376px}.emoji-1f478-1f3ff{background-position:-1518px -2442px}.emoji-1f47c-1f3fb{background-position:-1518px -2772px}.emoji-1f47c-1f3fc{background-position:-1518px -2838px}.emoji-1f47c-1f3fd{background-position:-1518px -2904px}.emoji-1f47c-1f3fe{background-position:-1518px -2970px}.emoji-1f47c-1f3ff{background-position:-1518px -3036px}.emoji-1f481-1f3fb-200d-2640-fe0f{background-position:-1518px -3432px}.emoji-1f481-1f3fc-200d-2640-fe0f{background-position:-1518px -3498px}.emoji-1f481-1f3fd-200d-2640-fe0f{background-position:-1518px -3564px}.emoji-1f481-1f3fe-200d-2640-fe0f{background-position:-1518px -3630px}.emoji-1f481-1f3ff-200d-2640-fe0f{background-position:-1518px -3696px}.emoji-1f481-1f3fb-200d-2642-fe0f{background-position:-1584px 0}.emoji-1f481-1f3fc-200d-2642-fe0f{background-position:-1584px -66px}.emoji-1f481-1f3fd-200d-2642-fe0f{background-position:-1584px -132px}.emoji-1f481-1f3fe-200d-2642-fe0f{background-position:-1584px -198px}.emoji-1f481-1f3ff-200d-2642-fe0f{background-position:-1584px -264px}.emoji-1f481-1f3fb{background-position:-1584px -396px}.emoji-1f481-1f3fc{background-position:-1584px -462px}.emoji-1f481-1f3fd{background-position:-1584px -528px}.emoji-1f481-1f3fe{background-position:-1584px -594px}.emoji-1f481-1f3ff{background-position:-1584px -660px}.emoji-1f482-1f3fb-200d-2640-fe0f{background-position:-1584px -792px}.emoji-1f482-1f3fc-200d-2640-fe0f{background-position:-1584px -858px}.emoji-1f482-1f3fd-200d-2640-fe0f{background-position:-1584px -924px}.emoji-1f482-1f3fe-200d-2640-fe0f{background-position:-1584px -990px}.emoji-1f482-1f3ff-200d-2640-fe0f{background-position:-1584px -1056px}.emoji-1f482-1f3fb-200d-2642-fe0f{background-position:-1584px -1188px}.emoji-1f482-1f3fc-200d-2642-fe0f{background-position:-1584px -1254px}.emoji-1f482-1f3fd-200d-2642-fe0f{background-position:-1584px -1320px}.emoji-1f482-1f3fe-200d-2642-fe0f{background-position:-1584px -1386px}.emoji-1f482-1f3ff-200d-2642-fe0f{background-position:-1584px -1452px}.emoji-1f482-1f3fb{background-position:-1584px -1584px}.emoji-1f482-1f3fc{background-position:-1584px -1650px}.emoji-1f482-1f3fd{background-position:-1584px -1716px}.emoji-1f482-1f3fe{background-position:-1584px -1782px}.emoji-1f482-1f3ff{background-position:-1584px -1848px}.emoji-1f483-1f3fb{background-position:-1584px -1980px}.emoji-1f483-1f3fc{background-position:-1584px -2046px}.emoji-1f483-1f3fd{background-position:-1584px -2112px}.emoji-1f483-1f3fe{background-position:-1584px -2178px}.emoji-1f483-1f3ff{background-position:-1584px -2244px}.emoji-1f485-1f3fb{background-position:-1584px -2442px}.emoji-1f485-1f3fc{background-position:-1584px -2508px}.emoji-1f485-1f3fd{background-position:-1584px -2574px}.emoji-1f485-1f3fe{background-position:-1584px -2640px}.emoji-1f485-1f3ff{background-position:-1584px -2706px}.emoji-1f486-1f3fb-200d-2640-fe0f{background-position:-1584px -2838px}.emoji-1f486-1f3fc-200d-2640-fe0f{background-position:-1584px -2904px}.emoji-1f486-1f3fd-200d-2640-fe0f{background-position:-1584px -2970px}.emoji-1f486-1f3fe-200d-2640-fe0f{background-position:-1584px -3036px}.emoji-1f486-1f3ff-200d-2640-fe0f{background-position:-1584px -3102px}.emoji-1f486-1f3fb-200d-2642-fe0f{background-position:-1584px -3234px}.emoji-1f486-1f3fc-200d-2642-fe0f{background-position:-1584px -3300px}.emoji-1f486-1f3fd-200d-2642-fe0f{background-position:-1584px -3366px}.emoji-1f486-1f3fe-200d-2642-fe0f{background-position:-1584px -3432px}.emoji-1f486-1f3ff-200d-2642-fe0f{background-position:-1584px -3498px}.emoji-1f486-1f3fb{background-position:-1584px -3630px}.emoji-1f486-1f3fc{background-position:-1584px -3696px}.emoji-1f486-1f3fd{background-position:-1584px -3762px}.emoji-1f486-1f3fe{background-position:-1650px 0}.emoji-1f486-1f3ff{background-position:-1650px -66px}.emoji-1f487-1f3fb-200d-2640-fe0f{background-position:-1650px -198px}.emoji-1f487-1f3fc-200d-2640-fe0f{background-position:-1650px -264px}.emoji-1f487-1f3fd-200d-2640-fe0f{background-position:-1650px -330px}.emoji-1f487-1f3fe-200d-2640-fe0f{background-position:-1650px -396px}.emoji-1f487-1f3ff-200d-2640-fe0f{background-position:-1650px -462px}.emoji-1f487-1f3fb-200d-2642-fe0f{background-position:-1650px -594px}.emoji-1f487-1f3fc-200d-2642-fe0f{background-position:-1650px -660px}.emoji-1f487-1f3fd-200d-2642-fe0f{background-position:-1650px -726px}.emoji-1f487-1f3fe-200d-2642-fe0f{background-position:-1650px -792px}.emoji-1f487-1f3ff-200d-2642-fe0f{background-position:-1650px -858px}.emoji-1f487-1f3fb{background-position:-1650px -990px}.emoji-1f487-1f3fc{background-position:-1650px -1056px}.emoji-1f487-1f3fd{background-position:-1650px -1122px}.emoji-1f487-1f3fe{background-position:-1650px -1188px}.emoji-1f487-1f3ff{background-position:-1650px -1254px}.emoji-1f4aa-1f3fb{background-position:-1650px -3630px}.emoji-1f4aa-1f3fc{background-position:-1650px -3696px}.emoji-1f4aa-1f3fd{background-position:-1650px -3762px}.emoji-1f4aa-1f3fe{background-position:-1716px 0}.emoji-1f4aa-1f3ff{background-position:-1716px -66px}.emoji-1f574-1f3fb{background-position:-1914px -528px}.emoji-1f574-1f3fc{background-position:-1914px -594px}.emoji-1f574-1f3fd{background-position:-1914px -660px}.emoji-1f574-1f3fe{background-position:-1914px -726px}.emoji-1f574-1f3ff{background-position:-1914px -792px}.emoji-1f575-1f3fb-200d-2640-fe0f{background-position:-1914px -924px}.emoji-1f575-1f3fc-200d-2640-fe0f{background-position:-1914px -990px}.emoji-1f575-1f3fd-200d-2640-fe0f{background-position:-1914px -1056px}.emoji-1f575-1f3fe-200d-2640-fe0f{background-position:-1914px -1122px}.emoji-1f575-1f3ff-200d-2640-fe0f{background-position:-1914px -1188px}.emoji-1f575-1f3fb-200d-2642-fe0f{background-position:-1914px -1320px}.emoji-1f575-1f3fc-200d-2642-fe0f{background-position:-1914px -1386px}.emoji-1f575-1f3fd-200d-2642-fe0f{background-position:-1914px -1452px}.emoji-1f575-1f3fe-200d-2642-fe0f{background-position:-1914px -1518px}.emoji-1f575-1f3ff-200d-2642-fe0f{background-position:-1914px -1584px}.emoji-1f575-1f3fb{background-position:-1914px -1716px}.emoji-1f575-1f3fc{background-position:-1914px -1782px}.emoji-1f575-1f3fd{background-position:-1914px -1848px}.emoji-1f575-1f3fe{background-position:-1914px -1914px}.emoji-1f575-1f3ff{background-position:-1914px -1980px}.emoji-1f57a-1f3fb{background-position:-1914px -2376px}.emoji-1f57a-1f3fc{background-position:-1914px -2442px}.emoji-1f57a-1f3fd{background-position:-1914px -2508px}.emoji-1f57a-1f3fe{background-position:-1914px -2574px}.emoji-1f57a-1f3ff{background-position:-1914px -2640px}.emoji-1f590-1f3fb{background-position:-1914px -3102px}.emoji-1f590-1f3fc{background-position:-1914px -3168px}.emoji-1f590-1f3fd{background-position:-1914px -3234px}.emoji-1f590-1f3fe{background-position:-1914px -3300px}.emoji-1f590-1f3ff{background-position:-1914px -3366px}.emoji-1f595-1f3fb{background-position:-1914px -3498px}.emoji-1f595-1f3fc{background-position:-1914px -3564px}.emoji-1f595-1f3fd{background-position:-1914px -3630px}.emoji-1f595-1f3fe{background-position:-1914px -3696px}.emoji-1f595-1f3ff{background-position:-1914px -3762px}.emoji-1f596-1f3fb{background-position:-1980px -66px}.emoji-1f596-1f3fc{background-position:-1980px -132px}.emoji-1f596-1f3fd{background-position:-1980px -198px}.emoji-1f596-1f3fe{background-position:-1980px -264px}.emoji-1f596-1f3ff{background-position:-1980px -330px}.emoji-1f645-1f3fb-200d-2640-fe0f{background-position:-2046px -2904px}.emoji-1f645-1f3fc-200d-2640-fe0f{background-position:-2046px -2970px}.emoji-1f645-1f3fd-200d-2640-fe0f{background-position:-2046px -3036px}.emoji-1f645-1f3fe-200d-2640-fe0f{background-position:-2046px -3102px}.emoji-1f645-1f3ff-200d-2640-fe0f{background-position:-2046px -3168px}.emoji-1f645-1f3fb-200d-2642-fe0f{background-position:-2046px -3300px}.emoji-1f645-1f3fc-200d-2642-fe0f{background-position:-2046px -3366px}.emoji-1f645-1f3fd-200d-2642-fe0f{background-position:-2046px -3432px}.emoji-1f645-1f3fe-200d-2642-fe0f{background-position:-2046px -3498px}.emoji-1f645-1f3ff-200d-2642-fe0f{background-position:-2046px -3564px}.emoji-1f645-1f3fb{background-position:-2046px -3696px}.emoji-1f645-1f3fc{background-position:-2046px -3762px}.emoji-1f645-1f3fd{background-position:-2112px 0}.emoji-1f645-1f3fe{background-position:-2112px -66px}.emoji-1f645-1f3ff{background-position:-2112px -132px}.emoji-1f646-1f3fb-200d-2640-fe0f{background-position:-2112px -264px}.emoji-1f646-1f3fc-200d-2640-fe0f{background-position:-2112px -330px}.emoji-1f646-1f3fd-200d-2640-fe0f{background-position:-2112px -396px}.emoji-1f646-1f3fe-200d-2640-fe0f{background-position:-2112px -462px}.emoji-1f646-1f3ff-200d-2640-fe0f{background-position:-2112px -528px}.emoji-1f646-1f3fb-200d-2642-fe0f{background-position:-2112px -660px}.emoji-1f646-1f3fc-200d-2642-fe0f{background-position:-2112px -726px}.emoji-1f646-1f3fd-200d-2642-fe0f{background-position:-2112px -792px}.emoji-1f646-1f3fe-200d-2642-fe0f{background-position:-2112px -858px}.emoji-1f646-1f3ff-200d-2642-fe0f{background-position:-2112px -924px}.emoji-1f646-1f3fb{background-position:-2112px -1056px}.emoji-1f646-1f3fc{background-position:-2112px -1122px}.emoji-1f646-1f3fd{background-position:-2112px -1188px}.emoji-1f646-1f3fe{background-position:-2112px -1254px}.emoji-1f646-1f3ff{background-position:-2112px -1320px}.emoji-1f647-1f3fb-200d-2640-fe0f{background-position:-2112px -1452px}.emoji-1f647-1f3fc-200d-2640-fe0f{background-position:-2112px -1518px}.emoji-1f647-1f3fd-200d-2640-fe0f{background-position:-2112px -1584px}.emoji-1f647-1f3fe-200d-2640-fe0f{background-position:-2112px -1650px}.emoji-1f647-1f3ff-200d-2640-fe0f{background-position:-2112px -1716px}.emoji-1f647-1f3fb-200d-2642-fe0f{background-position:-2112px -1848px}.emoji-1f647-1f3fc-200d-2642-fe0f{background-position:-2112px -1914px}.emoji-1f647-1f3fd-200d-2642-fe0f{background-position:-2112px -1980px}.emoji-1f647-1f3fe-200d-2642-fe0f{background-position:-2112px -2046px}.emoji-1f647-1f3ff-200d-2642-fe0f{background-position:-2112px -2112px}.emoji-1f647-1f3fb{background-position:-2112px -2244px}.emoji-1f647-1f3fc{background-position:-2112px -2310px}.emoji-1f647-1f3fd{background-position:-2112px -2376px}.emoji-1f647-1f3fe{background-position:-2112px -2442px}.emoji-1f647-1f3ff{background-position:-2112px -2508px}.emoji-1f64b-1f3fb-200d-2640-fe0f{background-position:-2112px -2838px}.emoji-1f64b-1f3fc-200d-2640-fe0f{background-position:-2112px -2904px}.emoji-1f64b-1f3fd-200d-2640-fe0f{background-position:-2112px -2970px}.emoji-1f64b-1f3fe-200d-2640-fe0f{background-position:-2112px -3036px}.emoji-1f64b-1f3ff-200d-2640-fe0f{background-position:-2112px -3102px}.emoji-1f64b-1f3fb-200d-2642-fe0f{background-position:-2112px -3234px}.emoji-1f64b-1f3fc-200d-2642-fe0f{background-position:-2112px -3300px}.emoji-1f64b-1f3fd-200d-2642-fe0f{background-position:-2112px -3366px}.emoji-1f64b-1f3fe-200d-2642-fe0f{background-position:-2112px -3432px}.emoji-1f64b-1f3ff-200d-2642-fe0f{background-position:-2112px -3498px}.emoji-1f64b-1f3fb{background-position:-2112px -3630px}.emoji-1f64b-1f3fc{background-position:-2112px -3696px}.emoji-1f64b-1f3fd{background-position:-2112px -3762px}.emoji-1f64b-1f3fe{background-position:-2178px 0}.emoji-1f64b-1f3ff{background-position:-2178px -66px}.emoji-1f64c-1f3fb{background-position:-2178px -198px}.emoji-1f64c-1f3fc{background-position:-2178px -264px}.emoji-1f64c-1f3fd{background-position:-2178px -330px}.emoji-1f64c-1f3fe{background-position:-2178px -396px}.emoji-1f64c-1f3ff{background-position:-2178px -462px}.emoji-1f64d-1f3fb-200d-2640-fe0f{background-position:-2178px -594px}.emoji-1f64d-1f3fc-200d-2640-fe0f{background-position:-2178px -660px}.emoji-1f64d-1f3fd-200d-2640-fe0f{background-position:-2178px -726px}.emoji-1f64d-1f3fe-200d-2640-fe0f{background-position:-2178px -792px}.emoji-1f64d-1f3ff-200d-2640-fe0f{background-position:-2178px -858px}.emoji-1f64d-1f3fb-200d-2642-fe0f{background-position:-2178px -990px}.emoji-1f64d-1f3fc-200d-2642-fe0f{background-position:-2178px -1056px}.emoji-1f64d-1f3fd-200d-2642-fe0f{background-position:-2178px -1122px}.emoji-1f64d-1f3fe-200d-2642-fe0f{background-position:-2178px -1188px}.emoji-1f64d-1f3ff-200d-2642-fe0f{background-position:-2178px -1254px}.emoji-1f64d-1f3fb{background-position:-2178px -1386px}.emoji-1f64d-1f3fc{background-position:-2178px -1452px}.emoji-1f64d-1f3fd{background-position:-2178px -1518px}.emoji-1f64d-1f3fe{background-position:-2178px -1584px}.emoji-1f64d-1f3ff{background-position:-2178px -1650px}.emoji-1f64e-1f3fb-200d-2640-fe0f{background-position:-2178px -1782px}.emoji-1f64e-1f3fc-200d-2640-fe0f{background-position:-2178px -1848px}.emoji-1f64e-1f3fd-200d-2640-fe0f{background-position:-2178px -1914px}.emoji-1f64e-1f3fe-200d-2640-fe0f{background-position:-2178px -1980px}.emoji-1f64e-1f3ff-200d-2640-fe0f{background-position:-2178px -2046px}.emoji-1f64e-1f3fb-200d-2642-fe0f{background-position:-2178px -2178px}.emoji-1f64e-1f3fc-200d-2642-fe0f{background-position:-2178px -2244px}.emoji-1f64e-1f3fd-200d-2642-fe0f{background-position:-2178px -2310px}.emoji-1f64e-1f3fe-200d-2642-fe0f{background-position:-2178px -2376px}.emoji-1f64e-1f3ff-200d-2642-fe0f{background-position:-2178px -2442px}.emoji-1f64e-1f3fb{background-position:-2178px -2574px}.emoji-1f64e-1f3fc{background-position:-2178px -2640px}.emoji-1f64e-1f3fd{background-position:-2178px -2706px}.emoji-1f64e-1f3fe{background-position:-2178px -2772px}.emoji-1f64e-1f3ff{background-position:-2178px -2838px}.emoji-1f64f-1f3fb{background-position:-2178px -2970px}.emoji-1f64f-1f3fc{background-position:-2178px -3036px}.emoji-1f64f-1f3fd{background-position:-2178px -3102px}.emoji-1f64f-1f3fe{background-position:-2178px -3168px}.emoji-1f64f-1f3ff{background-position:-2178px -3234px}.emoji-1f6a3-1f3fb-200d-2640-fe0f{background-position:-2244px -1848px}.emoji-1f6a3-1f3fc-200d-2640-fe0f{background-position:-2244px -1914px}.emoji-1f6a3-1f3fd-200d-2640-fe0f{background-position:-2244px -1980px}.emoji-1f6a3-1f3fe-200d-2640-fe0f{background-position:-2244px -2046px}.emoji-1f6a3-1f3ff-200d-2640-fe0f{background-position:-2244px -2112px}.emoji-1f6a3-1f3fb-200d-2642-fe0f{background-position:-2244px -2244px}.emoji-1f6a3-1f3fc-200d-2642-fe0f{background-position:-2244px -2310px}.emoji-1f6a3-1f3fd-200d-2642-fe0f{background-position:-2244px -2376px}.emoji-1f6a3-1f3fe-200d-2642-fe0f{background-position:-2244px -2442px}.emoji-1f6a3-1f3ff-200d-2642-fe0f{background-position:-2244px -2508px}.emoji-1f6a3-1f3fb{background-position:-2244px -2640px}.emoji-1f6a3-1f3fc{background-position:-2244px -2706px}.emoji-1f6a3-1f3fd{background-position:-2244px -2772px}.emoji-1f6a3-1f3fe{background-position:-2244px -2838px}.emoji-1f6a3-1f3ff{background-position:-2244px -2904px}.emoji-1f6b4-1f3fb-200d-2640-fe0f{background-position:-2310px -264px}.emoji-1f6b4-1f3fc-200d-2640-fe0f{background-position:-2310px -330px}.emoji-1f6b4-1f3fd-200d-2640-fe0f{background-position:-2310px -396px}.emoji-1f6b4-1f3fe-200d-2640-fe0f{background-position:-2310px -462px}.emoji-1f6b4-1f3ff-200d-2640-fe0f{background-position:-2310px -528px}.emoji-1f6b4-1f3fb-200d-2642-fe0f{background-position:-2310px -660px}.emoji-1f6b4-1f3fc-200d-2642-fe0f{background-position:-2310px -726px}.emoji-1f6b4-1f3fd-200d-2642-fe0f{background-position:-2310px -792px}.emoji-1f6b4-1f3fe-200d-2642-fe0f{background-position:-2310px -858px}.emoji-1f6b4-1f3ff-200d-2642-fe0f{background-position:-2310px -924px}.emoji-1f6b4-1f3fb{background-position:-2310px -1056px}.emoji-1f6b4-1f3fc{background-position:-2310px -1122px}.emoji-1f6b4-1f3fd{background-position:-2310px -1188px}.emoji-1f6b4-1f3fe{background-position:-2310px -1254px}.emoji-1f6b4-1f3ff{background-position:-2310px -1320px}.emoji-1f6b5-1f3fb-200d-2640-fe0f{background-position:-2310px -1452px}.emoji-1f6b5-1f3fc-200d-2640-fe0f{background-position:-2310px -1518px}.emoji-1f6b5-1f3fd-200d-2640-fe0f{background-position:-2310px -1584px}.emoji-1f6b5-1f3fe-200d-2640-fe0f{background-position:-2310px -1650px}.emoji-1f6b5-1f3ff-200d-2640-fe0f{background-position:-2310px -1716px}.emoji-1f6b5-1f3fb-200d-2642-fe0f{background-position:-2310px -1848px}.emoji-1f6b5-1f3fc-200d-2642-fe0f{background-position:-2310px -1914px}.emoji-1f6b5-1f3fd-200d-2642-fe0f{background-position:-2310px -1980px}.emoji-1f6b5-1f3fe-200d-2642-fe0f{background-position:-2310px -2046px}.emoji-1f6b5-1f3ff-200d-2642-fe0f{background-position:-2310px -2112px}.emoji-1f6b5-1f3fb{background-position:-2310px -2244px}.emoji-1f6b5-1f3fc{background-position:-2310px -2310px}.emoji-1f6b5-1f3fd{background-position:-2310px -2376px}.emoji-1f6b5-1f3fe{background-position:-2310px -2442px}.emoji-1f6b5-1f3ff{background-position:-2310px -2508px}.emoji-1f6b6-1f3fb-200d-2640-fe0f{background-position:-2310px -2640px}.emoji-1f6b6-1f3fc-200d-2640-fe0f{background-position:-2310px -2706px}.emoji-1f6b6-1f3fd-200d-2640-fe0f{background-position:-2310px -2772px}.emoji-1f6b6-1f3fe-200d-2640-fe0f{background-position:-2310px -2838px}.emoji-1f6b6-1f3ff-200d-2640-fe0f{background-position:-2310px -2904px}.emoji-1f6b6-1f3fb-200d-2642-fe0f{background-position:-2310px -3036px}.emoji-1f6b6-1f3fc-200d-2642-fe0f{background-position:-2310px -3102px}.emoji-1f6b6-1f3fd-200d-2642-fe0f{background-position:-2310px -3168px}.emoji-1f6b6-1f3fe-200d-2642-fe0f{background-position:-2310px -3234px}.emoji-1f6b6-1f3ff-200d-2642-fe0f{background-position:-2310px -3300px}.emoji-1f6b6-1f3fb{background-position:-2310px -3432px}.emoji-1f6b6-1f3fc{background-position:-2310px -3498px}.emoji-1f6b6-1f3fd{background-position:-2310px -3564px}.emoji-1f6b6-1f3fe{background-position:-2310px -3630px}.emoji-1f6b6-1f3ff{background-position:-2310px -3696px}.emoji-1f6c0-1f3fb{background-position:-2376px -594px}.emoji-1f6c0-1f3fc{background-position:-2376px -660px}.emoji-1f6c0-1f3fd{background-position:-2376px -726px}.emoji-1f6c0-1f3fe{background-position:-2376px -792px}.emoji-1f6c0-1f3ff{background-position:-2376px -858px}.emoji-1f6cc-1f3fb{background-position:-2376px -1386px}.emoji-1f6cc-1f3fc{background-position:-2376px -1452px}.emoji-1f6cc-1f3fd{background-position:-2376px -1518px}.emoji-1f6cc-1f3fe{background-position:-2376px -1584px}.emoji-1f6cc-1f3ff{background-position:-2376px -1650px}.emoji-1f90c-1f3fb{background-position:-2442px -660px}.emoji-1f90c-1f3fc{background-position:-2442px -726px}.emoji-1f90c-1f3fd{background-position:-2442px -792px}.emoji-1f90c-1f3fe{background-position:-2442px -858px}.emoji-1f90c-1f3ff{background-position:-2442px -924px}.emoji-1f90f-1f3fb{background-position:-2442px -1188px}.emoji-1f90f-1f3fc{background-position:-2442px -1254px}.emoji-1f90f-1f3fd{background-position:-2442px -1320px}.emoji-1f90f-1f3fe{background-position:-2442px -1386px}.emoji-1f90f-1f3ff{background-position:-2442px -1452px}.emoji-1f918-1f3fb{background-position:-2442px -2112px}.emoji-1f918-1f3fc{background-position:-2442px -2178px}.emoji-1f918-1f3fd{background-position:-2442px -2244px}.emoji-1f918-1f3fe{background-position:-2442px -2310px}.emoji-1f918-1f3ff{background-position:-2442px -2376px}.emoji-1f919-1f3fb{background-position:-2442px -2508px}.emoji-1f919-1f3fc{background-position:-2442px -2574px}.emoji-1f919-1f3fd{background-position:-2442px -2640px}.emoji-1f919-1f3fe{background-position:-2442px -2706px}.emoji-1f919-1f3ff{background-position:-2442px -2772px}.emoji-1f91a-1f3fb{background-position:-2442px -2904px}.emoji-1f91a-1f3fc{background-position:-2442px -2970px}.emoji-1f91a-1f3fd{background-position:-2442px -3036px}.emoji-1f91a-1f3fe{background-position:-2442px -3102px}.emoji-1f91a-1f3ff{background-position:-2442px -3168px}.emoji-1f91b-1f3fb{background-position:-2442px -3300px}.emoji-1f91b-1f3fc{background-position:-2442px -3366px}.emoji-1f91b-1f3fd{background-position:-2442px -3432px}.emoji-1f91b-1f3fe{background-position:-2442px -3498px}.emoji-1f91b-1f3ff{background-position:-2442px -3564px}.emoji-1f91c-1f3fb{background-position:-2442px -3696px}.emoji-1f91c-1f3fc{background-position:-2442px -3762px}.emoji-1f91c-1f3fd{background-position:-2508px 0}.emoji-1f91c-1f3fe{background-position:-2508px -66px}.emoji-1f91c-1f3ff{background-position:-2508px -132px}.emoji-1f91e-1f3fb{background-position:-2508px -330px}.emoji-1f91e-1f3fc{background-position:-2508px -396px}.emoji-1f91e-1f3fd{background-position:-2508px -462px}.emoji-1f91e-1f3fe{background-position:-2508px -528px}.emoji-1f91e-1f3ff{background-position:-2508px -594px}.emoji-1f91f-1f3fb{background-position:-2508px -726px}.emoji-1f91f-1f3fc{background-position:-2508px -792px}.emoji-1f91f-1f3fd{background-position:-2508px -858px}.emoji-1f91f-1f3fe{background-position:-2508px -924px}.emoji-1f91f-1f3ff{background-position:-2508px -990px}.emoji-1f926-1f3fb-200d-2640-fe0f{background-position:-2508px -1518px}.emoji-1f926-1f3fc-200d-2640-fe0f{background-position:-2508px -1584px}.emoji-1f926-1f3fd-200d-2640-fe0f{background-position:-2508px -1650px}.emoji-1f926-1f3fe-200d-2640-fe0f{background-position:-2508px -1716px}.emoji-1f926-1f3ff-200d-2640-fe0f{background-position:-2508px -1782px}.emoji-1f926-1f3fb-200d-2642-fe0f{background-position:-2508px -1914px}.emoji-1f926-1f3fc-200d-2642-fe0f{background-position:-2508px -1980px}.emoji-1f926-1f3fd-200d-2642-fe0f{background-position:-2508px -2046px}.emoji-1f926-1f3fe-200d-2642-fe0f{background-position:-2508px -2112px}.emoji-1f926-1f3ff-200d-2642-fe0f{background-position:-2508px -2178px}.emoji-1f926-1f3fb{background-position:-2508px -2310px}.emoji-1f926-1f3fc{background-position:-2508px -2376px}.emoji-1f926-1f3fd{background-position:-2508px -2442px}.emoji-1f926-1f3fe{background-position:-2508px -2508px}.emoji-1f926-1f3ff{background-position:-2508px -2574px}.emoji-1f930-1f3fb{background-position:-2508px -3300px}.emoji-1f930-1f3fc{background-position:-2508px -3366px}.emoji-1f930-1f3fd{background-position:-2508px -3432px}.emoji-1f930-1f3fe{background-position:-2508px -3498px}.emoji-1f930-1f3ff{background-position:-2508px -3564px}.emoji-1f931-1f3fb{background-position:-2508px -3696px}.emoji-1f931-1f3fc{background-position:-2508px -3762px}.emoji-1f931-1f3fd{background-position:-2574px 0}.emoji-1f931-1f3fe{background-position:-2574px -66px}.emoji-1f931-1f3ff{background-position:-2574px -132px}.emoji-1f932-1f3fb{background-position:-2574px -264px}.emoji-1f932-1f3fc{background-position:-2574px -330px}.emoji-1f932-1f3fd{background-position:-2574px -396px}.emoji-1f932-1f3fe{background-position:-2574px -462px}.emoji-1f932-1f3ff{background-position:-2574px -528px}.emoji-1f933-1f3fb{background-position:-2574px -660px}.emoji-1f933-1f3fc{background-position:-2574px -726px}.emoji-1f933-1f3fd{background-position:-2574px -792px}.emoji-1f933-1f3fe{background-position:-2574px -858px}.emoji-1f933-1f3ff{background-position:-2574px -924px}.emoji-1f934-1f3fb{background-position:-2574px -1056px}.emoji-1f934-1f3fc{background-position:-2574px -1122px}.emoji-1f934-1f3fd{background-position:-2574px -1188px}.emoji-1f934-1f3fe{background-position:-2574px -1254px}.emoji-1f934-1f3ff{background-position:-2574px -1320px}.emoji-1f935-1f3fb-200d-2640-fe0f{background-position:-2574px -1452px}.emoji-1f935-1f3fc-200d-2640-fe0f{background-position:-2574px -1518px}.emoji-1f935-1f3fd-200d-2640-fe0f{background-position:-2574px -1584px}.emoji-1f935-1f3fe-200d-2640-fe0f{background-position:-2574px -1650px}.emoji-1f935-1f3ff-200d-2640-fe0f{background-position:-2574px -1716px}.emoji-1f935-1f3fb-200d-2642-fe0f{background-position:-2574px -1848px}.emoji-1f935-1f3fc-200d-2642-fe0f{background-position:-2574px -1914px}.emoji-1f935-1f3fd-200d-2642-fe0f{background-position:-2574px -1980px}.emoji-1f935-1f3fe-200d-2642-fe0f{background-position:-2574px -2046px}.emoji-1f935-1f3ff-200d-2642-fe0f{background-position:-2574px -2112px}.emoji-1f935-1f3fb{background-position:-2574px -2244px}.emoji-1f935-1f3fc{background-position:-2574px -2310px}.emoji-1f935-1f3fd{background-position:-2574px -2376px}.emoji-1f935-1f3fe{background-position:-2574px -2442px}.emoji-1f935-1f3ff{background-position:-2574px -2508px}.emoji-1f936-1f3fb{background-position:-2574px -2640px}.emoji-1f936-1f3fc{background-position:-2574px -2706px}.emoji-1f936-1f3fd{background-position:-2574px -2772px}.emoji-1f936-1f3fe{background-position:-2574px -2838px}.emoji-1f936-1f3ff{background-position:-2574px -2904px}.emoji-1f937-1f3fb-200d-2640-fe0f{background-position:-2574px -3036px}.emoji-1f937-1f3fc-200d-2640-fe0f{background-position:-2574px -3102px}.emoji-1f937-1f3fd-200d-2640-fe0f{background-position:-2574px -3168px}.emoji-1f937-1f3fe-200d-2640-fe0f{background-position:-2574px -3234px}.emoji-1f937-1f3ff-200d-2640-fe0f{background-position:-2574px -3300px}.emoji-1f937-1f3fb-200d-2642-fe0f{background-position:-2574px -3432px}.emoji-1f937-1f3fc-200d-2642-fe0f{background-position:-2574px -3498px}.emoji-1f937-1f3fd-200d-2642-fe0f{background-position:-2574px -3564px}.emoji-1f937-1f3fe-200d-2642-fe0f{background-position:-2574px -3630px}.emoji-1f937-1f3ff-200d-2642-fe0f{background-position:-2574px -3696px}.emoji-1f937-1f3fb{background-position:-2640px 0}.emoji-1f937-1f3fc{background-position:-2640px -66px}.emoji-1f937-1f3fd{background-position:-2640px -132px}.emoji-1f937-1f3fe{background-position:-2640px -198px}.emoji-1f937-1f3ff{background-position:-2640px -264px}.emoji-1f938-1f3fb-200d-2640-fe0f{background-position:-2640px -396px}.emoji-1f938-1f3fc-200d-2640-fe0f{background-position:-2640px -462px}.emoji-1f938-1f3fd-200d-2640-fe0f{background-position:-2640px -528px}.emoji-1f938-1f3fe-200d-2640-fe0f{background-position:-2640px -594px}.emoji-1f938-1f3ff-200d-2640-fe0f{background-position:-2640px -660px}.emoji-1f938-1f3fb-200d-2642-fe0f{background-position:-2640px -792px}.emoji-1f938-1f3fc-200d-2642-fe0f{background-position:-2640px -858px}.emoji-1f938-1f3fd-200d-2642-fe0f{background-position:-2640px -924px}.emoji-1f938-1f3fe-200d-2642-fe0f{background-position:-2640px -990px}.emoji-1f938-1f3ff-200d-2642-fe0f{background-position:-2640px -1056px}.emoji-1f938-1f3fb{background-position:-2640px -1188px}.emoji-1f938-1f3fc{background-position:-2640px -1254px}.emoji-1f938-1f3fd{background-position:-2640px -1320px}.emoji-1f938-1f3fe{background-position:-2640px -1386px}.emoji-1f938-1f3ff{background-position:-2640px -1452px}.emoji-1f939-1f3fb-200d-2640-fe0f{background-position:-2640px -1584px}.emoji-1f939-1f3fc-200d-2640-fe0f{background-position:-2640px -1650px}.emoji-1f939-1f3fd-200d-2640-fe0f{background-position:-2640px -1716px}.emoji-1f939-1f3fe-200d-2640-fe0f{background-position:-2640px -1782px}.emoji-1f939-1f3ff-200d-2640-fe0f{background-position:-2640px -1848px}.emoji-1f939-1f3fb-200d-2642-fe0f{background-position:-2640px -1980px}.emoji-1f939-1f3fc-200d-2642-fe0f{background-position:-2640px -2046px}.emoji-1f939-1f3fd-200d-2642-fe0f{background-position:-2640px -2112px}.emoji-1f939-1f3fe-200d-2642-fe0f{background-position:-2640px -2178px}.emoji-1f939-1f3ff-200d-2642-fe0f{background-position:-2640px -2244px}.emoji-1f939-1f3fb{background-position:-2640px -2376px}.emoji-1f939-1f3fc{background-position:-2640px -2442px}.emoji-1f939-1f3fd{background-position:-2640px -2508px}.emoji-1f939-1f3fe{background-position:-2640px -2574px}.emoji-1f939-1f3ff{background-position:-2640px -2640px}.emoji-1f93d-1f3fb-200d-2640-fe0f{background-position:-2640px -3036px}.emoji-1f93d-1f3fc-200d-2640-fe0f{background-position:-2640px -3102px}.emoji-1f93d-1f3fd-200d-2640-fe0f{background-position:-2640px -3168px}.emoji-1f93d-1f3fe-200d-2640-fe0f{background-position:-2640px -3234px}.emoji-1f93d-1f3ff-200d-2640-fe0f{background-position:-2640px -3300px}.emoji-1f93d-1f3fb-200d-2642-fe0f{background-position:-2640px -3432px}.emoji-1f93d-1f3fc-200d-2642-fe0f{background-position:-2640px -3498px}.emoji-1f93d-1f3fd-200d-2642-fe0f{background-position:-2640px -3564px}.emoji-1f93d-1f3fe-200d-2642-fe0f{background-position:-2640px -3630px}.emoji-1f93d-1f3ff-200d-2642-fe0f{background-position:-2640px -3696px}.emoji-1f93d-1f3fb{background-position:-2706px 0}.emoji-1f93d-1f3fc{background-position:-2706px -66px}.emoji-1f93d-1f3fd{background-position:-2706px -132px}.emoji-1f93d-1f3fe{background-position:-2706px -198px}.emoji-1f93d-1f3ff{background-position:-2706px -264px}.emoji-1f93e-1f3fb-200d-2640-fe0f{background-position:-2706px -396px}.emoji-1f93e-1f3fc-200d-2640-fe0f{background-position:-2706px -462px}.emoji-1f93e-1f3fd-200d-2640-fe0f{background-position:-2706px -528px}.emoji-1f93e-1f3fe-200d-2640-fe0f{background-position:-2706px -594px}.emoji-1f93e-1f3ff-200d-2640-fe0f{background-position:-2706px -660px}.emoji-1f93e-1f3fb-200d-2642-fe0f{background-position:-2706px -792px}.emoji-1f93e-1f3fc-200d-2642-fe0f{background-position:-2706px -858px}.emoji-1f93e-1f3fd-200d-2642-fe0f{background-position:-2706px -924px}.emoji-1f93e-1f3fe-200d-2642-fe0f{background-position:-2706px -990px}.emoji-1f93e-1f3ff-200d-2642-fe0f{background-position:-2706px -1056px}.emoji-1f93e-1f3fb{background-position:-2706px -1188px}.emoji-1f93e-1f3fc{background-position:-2706px -1254px}.emoji-1f93e-1f3fd{background-position:-2706px -1320px}.emoji-1f93e-1f3fe{background-position:-2706px -1386px}.emoji-1f93e-1f3ff{background-position:-2706px -1452px}.emoji-1f977-1f3fb{background-position:-2772px -1386px}.emoji-1f977-1f3fc{background-position:-2772px -1452px}.emoji-1f977-1f3fd{background-position:-2772px -1518px}.emoji-1f977-1f3fe{background-position:-2772px -1584px}.emoji-1f977-1f3ff{background-position:-2772px -1650px}.emoji-1f9b5-1f3fb{background-position:-2838px -1650px}.emoji-1f9b5-1f3fc{background-position:-2838px -1716px}.emoji-1f9b5-1f3fd{background-position:-2838px -1782px}.emoji-1f9b5-1f3fe{background-position:-2838px -1848px}.emoji-1f9b5-1f3ff{background-position:-2838px -1914px}.emoji-1f9b6-1f3fb{background-position:-2838px -2046px}.emoji-1f9b6-1f3fc{background-position:-2838px -2112px}.emoji-1f9b6-1f3fd{background-position:-2838px -2178px}.emoji-1f9b6-1f3fe{background-position:-2838px -2244px}.emoji-1f9b6-1f3ff{background-position:-2838px -2310px}.emoji-1f9b8-1f3fb-200d-2640-fe0f{background-position:-2838px -2508px}.emoji-1f9b8-1f3fc-200d-2640-fe0f{background-position:-2838px -2574px}.emoji-1f9b8-1f3fd-200d-2640-fe0f{background-position:-2838px -2640px}.emoji-1f9b8-1f3fe-200d-2640-fe0f{background-position:-2838px -2706px}.emoji-1f9b8-1f3ff-200d-2640-fe0f{background-position:-2838px -2772px}.emoji-1f9b8-1f3fb-200d-2642-fe0f{background-position:-2838px -2904px}.emoji-1f9b8-1f3fc-200d-2642-fe0f{background-position:-2838px -2970px}.emoji-1f9b8-1f3fd-200d-2642-fe0f{background-position:-2838px -3036px}.emoji-1f9b8-1f3fe-200d-2642-fe0f{background-position:-2838px -3102px}.emoji-1f9b8-1f3ff-200d-2642-fe0f{background-position:-2838px -3168px}.emoji-1f9b8-1f3fb{background-position:-2838px -3300px}.emoji-1f9b8-1f3fc{background-position:-2838px -3366px}.emoji-1f9b8-1f3fd{background-position:-2838px -3432px}.emoji-1f9b8-1f3fe{background-position:-2838px -3498px}.emoji-1f9b8-1f3ff{background-position:-2838px -3564px}.emoji-1f9b9-1f3fb-200d-2640-fe0f{background-position:-2838px -3696px}.emoji-1f9b9-1f3fc-200d-2640-fe0f{background-position:-2838px -3762px}.emoji-1f9b9-1f3fd-200d-2640-fe0f{background-position:-2904px 0}.emoji-1f9b9-1f3fe-200d-2640-fe0f{background-position:-2904px -66px}.emoji-1f9b9-1f3ff-200d-2640-fe0f{background-position:-2904px -132px}.emoji-1f9b9-1f3fb-200d-2642-fe0f{background-position:-2904px -264px}.emoji-1f9b9-1f3fc-200d-2642-fe0f{background-position:-2904px -330px}.emoji-1f9b9-1f3fd-200d-2642-fe0f{background-position:-2904px -396px}.emoji-1f9b9-1f3fe-200d-2642-fe0f{background-position:-2904px -462px}.emoji-1f9b9-1f3ff-200d-2642-fe0f{background-position:-2904px -528px}.emoji-1f9b9-1f3fb{background-position:-2904px -660px}.emoji-1f9b9-1f3fc{background-position:-2904px -726px}.emoji-1f9b9-1f3fd{background-position:-2904px -792px}.emoji-1f9b9-1f3fe{background-position:-2904px -858px}.emoji-1f9b9-1f3ff{background-position:-2904px -924px}.emoji-1f9bb-1f3fb{background-position:-2904px -1122px}.emoji-1f9bb-1f3fc{background-position:-2904px -1188px}.emoji-1f9bb-1f3fd{background-position:-2904px -1254px}.emoji-1f9bb-1f3fe{background-position:-2904px -1320px}.emoji-1f9bb-1f3ff{background-position:-2904px -1386px}.emoji-1f9cd-1f3fb-200d-2640-fe0f{background-position:-2904px -2574px}.emoji-1f9cd-1f3fc-200d-2640-fe0f{background-position:-2904px -2640px}.emoji-1f9cd-1f3fd-200d-2640-fe0f{background-position:-2904px -2706px}.emoji-1f9cd-1f3fe-200d-2640-fe0f{background-position:-2904px -2772px}.emoji-1f9cd-1f3ff-200d-2640-fe0f{background-position:-2904px -2838px}.emoji-1f9cd-1f3fb-200d-2642-fe0f{background-position:-2904px -2970px}.emoji-1f9cd-1f3fc-200d-2642-fe0f{background-position:-2904px -3036px}.emoji-1f9cd-1f3fd-200d-2642-fe0f{background-position:-2904px -3102px}.emoji-1f9cd-1f3fe-200d-2642-fe0f{background-position:-2904px -3168px}.emoji-1f9cd-1f3ff-200d-2642-fe0f{background-position:-2904px -3234px}.emoji-1f9cd-1f3fb{background-position:-2904px -3366px}.emoji-1f9cd-1f3fc{background-position:-2904px -3432px}.emoji-1f9cd-1f3fd{background-position:-2904px -3498px}.emoji-1f9cd-1f3fe{background-position:-2904px -3564px}.emoji-1f9cd-1f3ff{background-position:-2904px -3630px}.emoji-1f9ce-1f3fb-200d-2640-fe0f{background-position:-2904px -3762px}.emoji-1f9ce-1f3fc-200d-2640-fe0f{background-position:-2970px 0}.emoji-1f9ce-1f3fd-200d-2640-fe0f{background-position:-2970px -66px}.emoji-1f9ce-1f3fe-200d-2640-fe0f{background-position:-2970px -132px}.emoji-1f9ce-1f3ff-200d-2640-fe0f{background-position:-2970px -198px}.emoji-1f9ce-1f3fb-200d-2642-fe0f{background-position:-2970px -330px}.emoji-1f9ce-1f3fc-200d-2642-fe0f{background-position:-2970px -396px}.emoji-1f9ce-1f3fd-200d-2642-fe0f{background-position:-2970px -462px}.emoji-1f9ce-1f3fe-200d-2642-fe0f{background-position:-2970px -528px}.emoji-1f9ce-1f3ff-200d-2642-fe0f{background-position:-2970px -594px}.emoji-1f9ce-1f3fb{background-position:-2970px -726px}.emoji-1f9ce-1f3fc{background-position:-2970px -792px}.emoji-1f9ce-1f3fd{background-position:-2970px -858px}.emoji-1f9ce-1f3fe{background-position:-2970px -924px}.emoji-1f9ce-1f3ff{background-position:-2970px -990px}.emoji-1f9cf-1f3fb-200d-2640-fe0f{background-position:-2970px -1122px}.emoji-1f9cf-1f3fc-200d-2640-fe0f{background-position:-2970px -1188px}.emoji-1f9cf-1f3fd-200d-2640-fe0f{background-position:-2970px -1254px}.emoji-1f9cf-1f3fe-200d-2640-fe0f{background-position:-2970px -1320px}.emoji-1f9cf-1f3ff-200d-2640-fe0f{background-position:-2970px -1386px}.emoji-1f9cf-1f3fb-200d-2642-fe0f{background-position:-2970px -1518px}.emoji-1f9cf-1f3fc-200d-2642-fe0f{background-position:-2970px -1584px}.emoji-1f9cf-1f3fd-200d-2642-fe0f{background-position:-2970px -1650px}.emoji-1f9cf-1f3fe-200d-2642-fe0f{background-position:-2970px -1716px}.emoji-1f9cf-1f3ff-200d-2642-fe0f{background-position:-2970px -1782px}.emoji-1f9cf-1f3fb{background-position:-2970px -1914px}.emoji-1f9cf-1f3fc{background-position:-2970px -1980px}.emoji-1f9cf-1f3fd{background-position:-2970px -2046px}.emoji-1f9cf-1f3fe{background-position:-2970px -2112px}.emoji-1f9cf-1f3ff{background-position:-2970px -2178px}.emoji-1f9d1-1f3fb-200d-1f33e{background-position:-2970px -2376px}.emoji-1f9d1-1f3fc-200d-1f33e{background-position:-2970px -2442px}.emoji-1f9d1-1f3fd-200d-1f33e{background-position:-2970px -2508px}.emoji-1f9d1-1f3fe-200d-1f33e{background-position:-2970px -2574px}.emoji-1f9d1-1f3ff-200d-1f33e{background-position:-2970px -2640px}.emoji-1f9d1-1f3fb-200d-1f373{background-position:-2970px -2772px}.emoji-1f9d1-1f3fc-200d-1f373{background-position:-2970px -2838px}.emoji-1f9d1-1f3fd-200d-1f373{background-position:-2970px -2904px}.emoji-1f9d1-1f3fe-200d-1f373{background-position:-2970px -2970px}.emoji-1f9d1-1f3ff-200d-1f373{background-position:-2970px -3036px}.emoji-1f9d1-1f3fb-200d-1f37c{background-position:-2970px -3168px}.emoji-1f9d1-1f3fc-200d-1f37c{background-position:-2970px -3234px}.emoji-1f9d1-1f3fd-200d-1f37c{background-position:-2970px -3300px}.emoji-1f9d1-1f3fe-200d-1f37c{background-position:-2970px -3366px}.emoji-1f9d1-1f3ff-200d-1f37c{background-position:-2970px -3432px}.emoji-1f9d1-1f3fb-200d-1f384{background-position:-2970px -3564px}.emoji-1f9d1-1f3fc-200d-1f384{background-position:-2970px -3630px}.emoji-1f9d1-1f3fd-200d-1f384{background-position:-2970px -3696px}.emoji-1f9d1-1f3fe-200d-1f384{background-position:-2970px -3762px}.emoji-1f9d1-1f3ff-200d-1f384{background-position:-3036px 0}.emoji-1f9d1-1f3fb-200d-1f393{background-position:-3036px -132px}.emoji-1f9d1-1f3fc-200d-1f393{background-position:-3036px -198px}.emoji-1f9d1-1f3fd-200d-1f393{background-position:-3036px -264px}.emoji-1f9d1-1f3fe-200d-1f393{background-position:-3036px -330px}.emoji-1f9d1-1f3ff-200d-1f393{background-position:-3036px -396px}.emoji-1f9d1-1f3fb-200d-1f3a4{background-position:-3036px -528px}.emoji-1f9d1-1f3fc-200d-1f3a4{background-position:-3036px -594px}.emoji-1f9d1-1f3fd-200d-1f3a4{background-position:-3036px -660px}.emoji-1f9d1-1f3fe-200d-1f3a4{background-position:-3036px -726px}.emoji-1f9d1-1f3ff-200d-1f3a4{background-position:-3036px -792px}.emoji-1f9d1-1f3fb-200d-1f3a8{background-position:-3036px -924px}.emoji-1f9d1-1f3fc-200d-1f3a8{background-position:-3036px -990px}.emoji-1f9d1-1f3fd-200d-1f3a8{background-position:-3036px -1056px}.emoji-1f9d1-1f3fe-200d-1f3a8{background-position:-3036px -1122px}.emoji-1f9d1-1f3ff-200d-1f3a8{background-position:-3036px -1188px}.emoji-1f9d1-1f3fb-200d-1f3eb{background-position:-3036px -1320px}.emoji-1f9d1-1f3fc-200d-1f3eb{background-position:-3036px -1386px}.emoji-1f9d1-1f3fd-200d-1f3eb{background-position:-3036px -1452px}.emoji-1f9d1-1f3fe-200d-1f3eb{background-position:-3036px -1518px}.emoji-1f9d1-1f3ff-200d-1f3eb{background-position:-3036px -1584px}.emoji-1f9d1-1f3fb-200d-1f3ed{background-position:-3036px -1716px}.emoji-1f9d1-1f3fc-200d-1f3ed{background-position:-3036px -1782px}.emoji-1f9d1-1f3fd-200d-1f3ed{background-position:-3036px -1848px}.emoji-1f9d1-1f3fe-200d-1f3ed{background-position:-3036px -1914px}.emoji-1f9d1-1f3ff-200d-1f3ed{background-position:-3036px -1980px}.emoji-1f9d1-1f3fb-200d-1f4bb{background-position:-3036px -2112px}.emoji-1f9d1-1f3fc-200d-1f4bb{background-position:-3036px -2178px}.emoji-1f9d1-1f3fd-200d-1f4bb{background-position:-3036px -2244px}.emoji-1f9d1-1f3fe-200d-1f4bb{background-position:-3036px -2310px}.emoji-1f9d1-1f3ff-200d-1f4bb{background-position:-3036px -2376px}.emoji-1f9d1-1f3fb-200d-1f4bc{background-position:-3036px -2508px}.emoji-1f9d1-1f3fc-200d-1f4bc{background-position:-3036px -2574px}.emoji-1f9d1-1f3fd-200d-1f4bc{background-position:-3036px -2640px}.emoji-1f9d1-1f3fe-200d-1f4bc{background-position:-3036px -2706px}.emoji-1f9d1-1f3ff-200d-1f4bc{background-position:-3036px -2772px}.emoji-1f9d1-1f3fb-200d-1f527{background-position:-3036px -2904px}.emoji-1f9d1-1f3fc-200d-1f527{background-position:-3036px -2970px}.emoji-1f9d1-1f3fd-200d-1f527{background-position:-3036px -3036px}.emoji-1f9d1-1f3fe-200d-1f527{background-position:-3036px -3102px}.emoji-1f9d1-1f3ff-200d-1f527{background-position:-3036px -3168px}.emoji-1f9d1-1f3fb-200d-1f52c{background-position:-3036px -3300px}.emoji-1f9d1-1f3fc-200d-1f52c{background-position:-3036px -3366px}.emoji-1f9d1-1f3fd-200d-1f52c{background-position:-3036px -3432px}.emoji-1f9d1-1f3fe-200d-1f52c{background-position:-3036px -3498px}.emoji-1f9d1-1f3ff-200d-1f52c{background-position:-3036px -3564px}.emoji-1f9d1-1f3fb-200d-1f680{background-position:-3036px -3696px}.emoji-1f9d1-1f3fc-200d-1f680{background-position:-3036px -3762px}.emoji-1f9d1-1f3fd-200d-1f680{background-position:-3102px 0}.emoji-1f9d1-1f3fe-200d-1f680{background-position:-3102px -66px}.emoji-1f9d1-1f3ff-200d-1f680{background-position:-3102px -132px}.emoji-1f9d1-1f3fb-200d-1f692{background-position:-3102px -264px}.emoji-1f9d1-1f3fc-200d-1f692{background-position:-3102px -330px}.emoji-1f9d1-1f3fd-200d-1f692{background-position:-3102px -396px}.emoji-1f9d1-1f3fe-200d-1f692{background-position:-3102px -462px}.emoji-1f9d1-1f3ff-200d-1f692{background-position:-3102px -528px}.emoji-1f9d1-1f3fb-200d-1f91d-200d-1f9d1-1f3fb{background-position:-3102px -660px}.emoji-1f9d1-1f3fb-200d-1f91d-200d-1f9d1-1f3fc{background-position:-3102px -726px}.emoji-1f9d1-1f3fb-200d-1f91d-200d-1f9d1-1f3fd{background-position:-3102px -792px}.emoji-1f9d1-1f3fb-200d-1f91d-200d-1f9d1-1f3fe{background-position:-3102px -858px}.emoji-1f9d1-1f3fb-200d-1f91d-200d-1f9d1-1f3ff{background-position:-3102px -924px}.emoji-1f9d1-1f3fc-200d-1f91d-200d-1f9d1-1f3fb{background-position:-3102px -990px}.emoji-1f9d1-1f3fc-200d-1f91d-200d-1f9d1-1f3fc{background-position:-3102px -1056px}.emoji-1f9d1-1f3fc-200d-1f91d-200d-1f9d1-1f3fd{background-position:-3102px -1122px}.emoji-1f9d1-1f3fc-200d-1f91d-200d-1f9d1-1f3fe{background-position:-3102px -1188px}.emoji-1f9d1-1f3fc-200d-1f91d-200d-1f9d1-1f3ff{background-position:-3102px -1254px}.emoji-1f9d1-1f3fd-200d-1f91d-200d-1f9d1-1f3fb{background-position:-3102px -1320px}.emoji-1f9d1-1f3fd-200d-1f91d-200d-1f9d1-1f3fc{background-position:-3102px -1386px}.emoji-1f9d1-1f3fd-200d-1f91d-200d-1f9d1-1f3fd{background-position:-3102px -1452px}.emoji-1f9d1-1f3fd-200d-1f91d-200d-1f9d1-1f3fe{background-position:-3102px -1518px}.emoji-1f9d1-1f3fd-200d-1f91d-200d-1f9d1-1f3ff{background-position:-3102px -1584px}.emoji-1f9d1-1f3fe-200d-1f91d-200d-1f9d1-1f3fb{background-position:-3102px -1650px}.emoji-1f9d1-1f3fe-200d-1f91d-200d-1f9d1-1f3fc{background-position:-3102px -1716px}.emoji-1f9d1-1f3fe-200d-1f91d-200d-1f9d1-1f3fd{background-position:-3102px -1782px}.emoji-1f9d1-1f3fe-200d-1f91d-200d-1f9d1-1f3fe{background-position:-3102px -1848px}.emoji-1f9d1-1f3fe-200d-1f91d-200d-1f9d1-1f3ff{background-position:-3102px -1914px}.emoji-1f9d1-1f3ff-200d-1f91d-200d-1f9d1-1f3fb{background-position:-3102px -1980px}.emoji-1f9d1-1f3ff-200d-1f91d-200d-1f9d1-1f3fc{background-position:-3102px -2046px}.emoji-1f9d1-1f3ff-200d-1f91d-200d-1f9d1-1f3fd{background-position:-3102px -2112px}.emoji-1f9d1-1f3ff-200d-1f91d-200d-1f9d1-1f3fe{background-position:-3102px -2178px}.emoji-1f9d1-1f3ff-200d-1f91d-200d-1f9d1-1f3ff{background-position:-3102px -2244px}.emoji-1f9d1-1f3fb-200d-1f9af{background-position:-3102px -2376px}.emoji-1f9d1-1f3fc-200d-1f9af{background-position:-3102px -2442px}.emoji-1f9d1-1f3fd-200d-1f9af{background-position:-3102px -2508px}.emoji-1f9d1-1f3fe-200d-1f9af{background-position:-3102px -2574px}.emoji-1f9d1-1f3ff-200d-1f9af{background-position:-3102px -2640px}.emoji-1f9d1-1f3fb-200d-1f9b0{background-position:-3102px -2772px}.emoji-1f9d1-1f3fc-200d-1f9b0{background-position:-3102px -2838px}.emoji-1f9d1-1f3fd-200d-1f9b0{background-position:-3102px -2904px}.emoji-1f9d1-1f3fe-200d-1f9b0{background-position:-3102px -2970px}.emoji-1f9d1-1f3ff-200d-1f9b0{background-position:-3102px -3036px}.emoji-1f9d1-1f3fb-200d-1f9b1{background-position:-3102px -3168px}.emoji-1f9d1-1f3fc-200d-1f9b1{background-position:-3102px -3234px}.emoji-1f9d1-1f3fd-200d-1f9b1{background-position:-3102px -3300px}.emoji-1f9d1-1f3fe-200d-1f9b1{background-position:-3102px -3366px}.emoji-1f9d1-1f3ff-200d-1f9b1{background-position:-3102px -3432px}.emoji-1f9d1-1f3fb-200d-1f9b2{background-position:-3102px -3564px}.emoji-1f9d1-1f3fc-200d-1f9b2{background-position:-3102px -3630px}.emoji-1f9d1-1f3fd-200d-1f9b2{background-position:-3102px -3696px}.emoji-1f9d1-1f3fe-200d-1f9b2{background-position:-3102px -3762px}.emoji-1f9d1-1f3ff-200d-1f9b2{background-position:-3168px 0}.emoji-1f9d1-1f3fb-200d-1f9b3{background-position:-3168px -132px}.emoji-1f9d1-1f3fc-200d-1f9b3{background-position:-3168px -198px}.emoji-1f9d1-1f3fd-200d-1f9b3{background-position:-3168px -264px}.emoji-1f9d1-1f3fe-200d-1f9b3{background-position:-3168px -330px}.emoji-1f9d1-1f3ff-200d-1f9b3{background-position:-3168px -396px}.emoji-1f9d1-1f3fb-200d-1f9bc{background-position:-3168px -528px}.emoji-1f9d1-1f3fc-200d-1f9bc{background-position:-3168px -594px}.emoji-1f9d1-1f3fd-200d-1f9bc{background-position:-3168px -660px}.emoji-1f9d1-1f3fe-200d-1f9bc{background-position:-3168px -726px}.emoji-1f9d1-1f3ff-200d-1f9bc{background-position:-3168px -792px}.emoji-1f9d1-1f3fb-200d-1f9bd{background-position:-3168px -924px}.emoji-1f9d1-1f3fc-200d-1f9bd{background-position:-3168px -990px}.emoji-1f9d1-1f3fd-200d-1f9bd{background-position:-3168px -1056px}.emoji-1f9d1-1f3fe-200d-1f9bd{background-position:-3168px -1122px}.emoji-1f9d1-1f3ff-200d-1f9bd{background-position:-3168px -1188px}.emoji-1f9d1-1f3fb-200d-2695-fe0f{background-position:-3168px -1320px}.emoji-1f9d1-1f3fc-200d-2695-fe0f{background-position:-3168px -1386px}.emoji-1f9d1-1f3fd-200d-2695-fe0f{background-position:-3168px -1452px}.emoji-1f9d1-1f3fe-200d-2695-fe0f{background-position:-3168px -1518px}.emoji-1f9d1-1f3ff-200d-2695-fe0f{background-position:-3168px -1584px}.emoji-1f9d1-1f3fb-200d-2696-fe0f{background-position:-3168px -1716px}.emoji-1f9d1-1f3fc-200d-2696-fe0f{background-position:-3168px -1782px}.emoji-1f9d1-1f3fd-200d-2696-fe0f{background-position:-3168px -1848px}.emoji-1f9d1-1f3fe-200d-2696-fe0f{background-position:-3168px -1914px}.emoji-1f9d1-1f3ff-200d-2696-fe0f{background-position:-3168px -1980px}.emoji-1f9d1-1f3fb-200d-2708-fe0f{background-position:-3168px -2112px}.emoji-1f9d1-1f3fc-200d-2708-fe0f{background-position:-3168px -2178px}.emoji-1f9d1-1f3fd-200d-2708-fe0f{background-position:-3168px -2244px}.emoji-1f9d1-1f3fe-200d-2708-fe0f{background-position:-3168px -2310px}.emoji-1f9d1-1f3ff-200d-2708-fe0f{background-position:-3168px -2376px}.emoji-1f9d1-1f3fb{background-position:-3168px -2508px}.emoji-1f9d1-1f3fc{background-position:-3168px -2574px}.emoji-1f9d1-1f3fd{background-position:-3168px -2640px}.emoji-1f9d1-1f3fe{background-position:-3168px -2706px}.emoji-1f9d1-1f3ff{background-position:-3168px -2772px}.emoji-1f9d2-1f3fb{background-position:-3168px -2904px}.emoji-1f9d2-1f3fc{background-position:-3168px -2970px}.emoji-1f9d2-1f3fd{background-position:-3168px -3036px}.emoji-1f9d2-1f3fe{background-position:-3168px -3102px}.emoji-1f9d2-1f3ff{background-position:-3168px -3168px}.emoji-1f9d3-1f3fb{background-position:-3168px -3300px}.emoji-1f9d3-1f3fc{background-position:-3168px -3366px}.emoji-1f9d3-1f3fd{background-position:-3168px -3432px}.emoji-1f9d3-1f3fe{background-position:-3168px -3498px}.emoji-1f9d3-1f3ff{background-position:-3168px -3564px}.emoji-1f9d4-1f3fb{background-position:-3168px -3696px}.emoji-1f9d4-1f3fc{background-position:-3168px -3762px}.emoji-1f9d4-1f3fd{background-position:-3234px 0}.emoji-1f9d4-1f3fe{background-position:-3234px -66px}.emoji-1f9d4-1f3ff{background-position:-3234px -132px}.emoji-1f9d5-1f3fb{background-position:-3234px -264px}.emoji-1f9d5-1f3fc{background-position:-3234px -330px}.emoji-1f9d5-1f3fd{background-position:-3234px -396px}.emoji-1f9d5-1f3fe{background-position:-3234px -462px}.emoji-1f9d5-1f3ff{background-position:-3234px -528px}.emoji-1f9d6-1f3fb-200d-2640-fe0f{background-position:-3234px -660px}.emoji-1f9d6-1f3fc-200d-2640-fe0f{background-position:-3234px -726px}.emoji-1f9d6-1f3fd-200d-2640-fe0f{background-position:-3234px -792px}.emoji-1f9d6-1f3fe-200d-2640-fe0f{background-position:-3234px -858px}.emoji-1f9d6-1f3ff-200d-2640-fe0f{background-position:-3234px -924px}.emoji-1f9d6-1f3fb-200d-2642-fe0f{background-position:-3234px -1056px}.emoji-1f9d6-1f3fc-200d-2642-fe0f{background-position:-3234px -1122px}.emoji-1f9d6-1f3fd-200d-2642-fe0f{background-position:-3234px -1188px}.emoji-1f9d6-1f3fe-200d-2642-fe0f{background-position:-3234px -1254px}.emoji-1f9d6-1f3ff-200d-2642-fe0f{background-position:-3234px -1320px}.emoji-1f9d6-1f3fb{background-position:-3234px -1452px}.emoji-1f9d6-1f3fc{background-position:-3234px -1518px}.emoji-1f9d6-1f3fd{background-position:-3234px -1584px}.emoji-1f9d6-1f3fe{background-position:-3234px -1650px}.emoji-1f9d6-1f3ff{background-position:-3234px -1716px}.emoji-1f9d7-1f3fb-200d-2640-fe0f{background-position:-3234px -1848px}.emoji-1f9d7-1f3fc-200d-2640-fe0f{background-position:-3234px -1914px}.emoji-1f9d7-1f3fd-200d-2640-fe0f{background-position:-3234px -1980px}.emoji-1f9d7-1f3fe-200d-2640-fe0f{background-position:-3234px -2046px}.emoji-1f9d7-1f3ff-200d-2640-fe0f{background-position:-3234px -2112px}.emoji-1f9d7-1f3fb-200d-2642-fe0f{background-position:-3234px -2244px}.emoji-1f9d7-1f3fc-200d-2642-fe0f{background-position:-3234px -2310px}.emoji-1f9d7-1f3fd-200d-2642-fe0f{background-position:-3234px -2376px}.emoji-1f9d7-1f3fe-200d-2642-fe0f{background-position:-3234px -2442px}.emoji-1f9d7-1f3ff-200d-2642-fe0f{background-position:-3234px -2508px}.emoji-1f9d7-1f3fb{background-position:-3234px -2640px}.emoji-1f9d7-1f3fc{background-position:-3234px -2706px}.emoji-1f9d7-1f3fd{background-position:-3234px -2772px}.emoji-1f9d7-1f3fe{background-position:-3234px -2838px}.emoji-1f9d7-1f3ff{background-position:-3234px -2904px}.emoji-1f9d8-1f3fb-200d-2640-fe0f{background-position:-3234px -3036px}.emoji-1f9d8-1f3fc-200d-2640-fe0f{background-position:-3234px -3102px}.emoji-1f9d8-1f3fd-200d-2640-fe0f{background-position:-3234px -3168px}.emoji-1f9d8-1f3fe-200d-2640-fe0f{background-position:-3234px -3234px}.emoji-1f9d8-1f3ff-200d-2640-fe0f{background-position:-3234px -3300px}.emoji-1f9d8-1f3fb-200d-2642-fe0f{background-position:-3234px -3432px}.emoji-1f9d8-1f3fc-200d-2642-fe0f{background-position:-3234px -3498px}.emoji-1f9d8-1f3fd-200d-2642-fe0f{background-position:-3234px -3564px}.emoji-1f9d8-1f3fe-200d-2642-fe0f{background-position:-3234px -3630px}.emoji-1f9d8-1f3ff-200d-2642-fe0f{background-position:-3234px -3696px}.emoji-1f9d8-1f3fb{background-position:-3300px 0}.emoji-1f9d8-1f3fc{background-position:-3300px -66px}.emoji-1f9d8-1f3fd{background-position:-3300px -132px}.emoji-1f9d8-1f3fe{background-position:-3300px -198px}.emoji-1f9d8-1f3ff{background-position:-3300px -264px}.emoji-1f9d9-1f3fb-200d-2640-fe0f{background-position:-3300px -396px}.emoji-1f9d9-1f3fc-200d-2640-fe0f{background-position:-3300px -462px}.emoji-1f9d9-1f3fd-200d-2640-fe0f{background-position:-3300px -528px}.emoji-1f9d9-1f3fe-200d-2640-fe0f{background-position:-3300px -594px}.emoji-1f9d9-1f3ff-200d-2640-fe0f{background-position:-3300px -660px}.emoji-1f9d9-1f3fb-200d-2642-fe0f{background-position:-3300px -792px}.emoji-1f9d9-1f3fc-200d-2642-fe0f{background-position:-3300px -858px}.emoji-1f9d9-1f3fd-200d-2642-fe0f{background-position:-3300px -924px}.emoji-1f9d9-1f3fe-200d-2642-fe0f{background-position:-3300px -990px}.emoji-1f9d9-1f3ff-200d-2642-fe0f{background-position:-3300px -1056px}.emoji-1f9d9-1f3fb{background-position:-3300px -1188px}.emoji-1f9d9-1f3fc{background-position:-3300px -1254px}.emoji-1f9d9-1f3fd{background-position:-3300px -1320px}.emoji-1f9d9-1f3fe{background-position:-3300px -1386px}.emoji-1f9d9-1f3ff{background-position:-3300px -1452px}.emoji-1f9da-1f3fb-200d-2640-fe0f{background-position:-3300px -1584px}.emoji-1f9da-1f3fc-200d-2640-fe0f{background-position:-3300px -1650px}.emoji-1f9da-1f3fd-200d-2640-fe0f{background-position:-3300px -1716px}.emoji-1f9da-1f3fe-200d-2640-fe0f{background-position:-3300px -1782px}.emoji-1f9da-1f3ff-200d-2640-fe0f{background-position:-3300px -1848px}.emoji-1f9da-1f3fb-200d-2642-fe0f{background-position:-3300px -1980px}.emoji-1f9da-1f3fc-200d-2642-fe0f{background-position:-3300px -2046px}.emoji-1f9da-1f3fd-200d-2642-fe0f{background-position:-3300px -2112px}.emoji-1f9da-1f3fe-200d-2642-fe0f{background-position:-3300px -2178px}.emoji-1f9da-1f3ff-200d-2642-fe0f{background-position:-3300px -2244px}.emoji-1f9da-1f3fb{background-position:-3300px -2376px}.emoji-1f9da-1f3fc{background-position:-3300px -2442px}.emoji-1f9da-1f3fd{background-position:-3300px -2508px}.emoji-1f9da-1f3fe{background-position:-3300px -2574px}.emoji-1f9da-1f3ff{background-position:-3300px -2640px}.emoji-1f9db-1f3fb-200d-2640-fe0f{background-position:-3300px -2772px}.emoji-1f9db-1f3fc-200d-2640-fe0f{background-position:-3300px -2838px}.emoji-1f9db-1f3fd-200d-2640-fe0f{background-position:-3300px -2904px}.emoji-1f9db-1f3fe-200d-2640-fe0f{background-position:-3300px -2970px}.emoji-1f9db-1f3ff-200d-2640-fe0f{background-position:-3300px -3036px}.emoji-1f9db-1f3fb-200d-2642-fe0f{background-position:-3300px -3168px}.emoji-1f9db-1f3fc-200d-2642-fe0f{background-position:-3300px -3234px}.emoji-1f9db-1f3fd-200d-2642-fe0f{background-position:-3300px -3300px}.emoji-1f9db-1f3fe-200d-2642-fe0f{background-position:-3300px -3366px}.emoji-1f9db-1f3ff-200d-2642-fe0f{background-position:-3300px -3432px}.emoji-1f9db-1f3fb{background-position:-3300px -3564px}.emoji-1f9db-1f3fc{background-position:-3300px -3630px}.emoji-1f9db-1f3fd{background-position:-3300px -3696px}.emoji-1f9db-1f3fe{background-position:-3300px -3762px}.emoji-1f9db-1f3ff{background-position:-3366px 0}.emoji-1f9dc-1f3fb-200d-2640-fe0f{background-position:-3366px -132px}.emoji-1f9dc-1f3fc-200d-2640-fe0f{background-position:-3366px -198px}.emoji-1f9dc-1f3fd-200d-2640-fe0f{background-position:-3366px -264px}.emoji-1f9dc-1f3fe-200d-2640-fe0f{background-position:-3366px -330px}.emoji-1f9dc-1f3ff-200d-2640-fe0f{background-position:-3366px -396px}.emoji-1f9dc-1f3fb-200d-2642-fe0f{background-position:-3366px -528px}.emoji-1f9dc-1f3fc-200d-2642-fe0f{background-position:-3366px -594px}.emoji-1f9dc-1f3fd-200d-2642-fe0f{background-position:-3366px -660px}.emoji-1f9dc-1f3fe-200d-2642-fe0f{background-position:-3366px -726px}.emoji-1f9dc-1f3ff-200d-2642-fe0f{background-position:-3366px -792px}.emoji-1f9dc-1f3fb{background-position:-3366px -924px}.emoji-1f9dc-1f3fc{background-position:-3366px -990px}.emoji-1f9dc-1f3fd{background-position:-3366px -1056px}.emoji-1f9dc-1f3fe{background-position:-3366px -1122px}.emoji-1f9dc-1f3ff{background-position:-3366px -1188px}.emoji-1f9dd-1f3fb-200d-2640-fe0f{background-position:-3366px -1320px}.emoji-1f9dd-1f3fc-200d-2640-fe0f{background-position:-3366px -1386px}.emoji-1f9dd-1f3fd-200d-2640-fe0f{background-position:-3366px -1452px}.emoji-1f9dd-1f3fe-200d-2640-fe0f{background-position:-3366px -1518px}.emoji-1f9dd-1f3ff-200d-2640-fe0f{background-position:-3366px -1584px}.emoji-1f9dd-1f3fb-200d-2642-fe0f{background-position:-3366px -1716px}.emoji-1f9dd-1f3fc-200d-2642-fe0f{background-position:-3366px -1782px}.emoji-1f9dd-1f3fd-200d-2642-fe0f{background-position:-3366px -1848px}.emoji-1f9dd-1f3fe-200d-2642-fe0f{background-position:-3366px -1914px}.emoji-1f9dd-1f3ff-200d-2642-fe0f{background-position:-3366px -1980px}.emoji-1f9dd-1f3fb{background-position:-3366px -2112px}.emoji-1f9dd-1f3fc{background-position:-3366px -2178px}.emoji-1f9dd-1f3fd{background-position:-3366px -2244px}.emoji-1f9dd-1f3fe{background-position:-3366px -2310px}.emoji-1f9dd-1f3ff{background-position:-3366px -2376px}.emoji-261d-1f3fb{background-position:-3564px -528px}.emoji-261d-1f3fc{background-position:-3564px -594px}.emoji-261d-1f3fd{background-position:-3564px -660px}.emoji-261d-1f3fe{background-position:-3564px -726px}.emoji-261d-1f3ff{background-position:-3564px -792px}.emoji-26f9-1f3fb-200d-2640-fe0f{background-position:-3630px -1650px}.emoji-26f9-1f3fc-200d-2640-fe0f{background-position:-3630px -1716px}.emoji-26f9-1f3fd-200d-2640-fe0f{background-position:-3630px -1782px}.emoji-26f9-1f3fe-200d-2640-fe0f{background-position:-3630px -1848px}.emoji-26f9-1f3ff-200d-2640-fe0f{background-position:-3630px -1914px}.emoji-26f9-1f3fb-200d-2642-fe0f{background-position:-3630px -2046px}.emoji-26f9-1f3fc-200d-2642-fe0f{background-position:-3630px -2112px}.emoji-26f9-1f3fd-200d-2642-fe0f{background-position:-3630px -2178px}.emoji-26f9-1f3fe-200d-2642-fe0f{background-position:-3630px -2244px}.emoji-26f9-1f3ff-200d-2642-fe0f{background-position:-3630px -2310px}.emoji-26f9-1f3fb{background-position:-3630px -2442px}.emoji-26f9-1f3fc{background-position:-3630px -2508px}.emoji-26f9-1f3fd{background-position:-3630px -2574px}.emoji-26f9-1f3fe{background-position:-3630px -2640px}.emoji-26f9-1f3ff{background-position:-3630px -2706px}.emoji-270a-1f3fb{background-position:-3630px -3234px}.emoji-270a-1f3fc{background-position:-3630px -3300px}.emoji-270a-1f3fd{background-position:-3630px -3366px}.emoji-270a-1f3fe{background-position:-3630px -3432px}.emoji-270a-1f3ff{background-position:-3630px -3498px}.emoji-270b-1f3fb{background-position:-3630px -3630px}.emoji-270b-1f3fc{background-position:-3630px -3696px}.emoji-270b-1f3fd{background-position:-3630px -3762px}.emoji-270b-1f3fe{background-position:-3696px 0}.emoji-270b-1f3ff{background-position:-3696px -66px}.emoji-270c-1f3fb{background-position:-3696px -198px}.emoji-270c-1f3fc{background-position:-3696px -264px}.emoji-270c-1f3fd{background-position:-3696px -330px}.emoji-270c-1f3fe{background-position:-3696px -396px}.emoji-270c-1f3ff{background-position:-3696px -462px}.emoji-270d-1f3fb{background-position:-3696px -594px}.emoji-270d-1f3fc{background-position:-3696px -660px}.emoji-270d-1f3fd{background-position:-3696px -726px}.emoji-270d-1f3fe{background-position:-3696px -792px}.emoji-270d-1f3ff{background-position:-3696px -858px}.emoji-picker{pointer-events:auto}.emoji-picker li.custom-emoji-tab:not(.active) a{width:max-content;padding-top:7px !important}.emoji-picker li.custom-emoji-tab:not(.active) a svg,.emoji-picker li.custom-emoji-tab:not(.active) a div{color:rgba(var(--center-channel-color-rgb), 0.56);fill:rgba(var(--center-channel-color-rgb), 0.56)}.emoji-picker li.custom-emoji-tab:not(.active) a:hover svg,.emoji-picker li.custom-emoji-tab:not(.active) a:hover div{color:rgba(var(--center-channel-color-rgb), 0.72);fill:rgba(var(--center-channel-color-rgb), 0.72)}.emoji-picker li.custom-emoji-tab.active a{width:max-content;padding-top:7px !important}.emoji-picker li.custom-emoji-tab.active a svg,.emoji-picker li.custom-emoji-tab.active a div{color:var(--button-bg);fill:var(--mention-bg-rgb)}.emoji-picker li.custom-emoji-tab.active a:hover svg,.emoji-picker li.custom-emoji-tab.active a:hover div{color:var(--button-bg);fill:var(--mention-bg-rgb)}.emoji-picker .nav.nav-tabs{width:fit-content;width:-moz-fit-content}.custom-emoji-tab__icon__text{display:flex;flex-direction:row}.custom-emoji-tab{display:flex}.custom-emoji-tab__icon{margin-right:7px}.file-preview__container{position:relative;display:flex;width:100%;height:8rem;flex-shrink:0;flex-wrap:nowrap;align-items:center;padding-left:8px;margin:0;overflow-x:auto;overflow-y:hidden;white-space:nowrap}.file-preview{overflow:hidden;*zoom:1;position:relative;display:inline-block;width:120px;height:100px;flex-shrink:0;flex-wrap:nowrap;border:1px solid rgba(0,0,0,.15);margin-right:10px}.file-preview .spinner{position:absolute;top:50%;left:50%;width:32px;height:32px;margin-top:-16px;margin-left:-16px}.app__body .file-preview__remove{position:absolute;top:4px;right:4px;display:flex;width:2.8rem;height:2.8rem;align-items:center;justify-content:center;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:1.4rem;text-align:center;text-decoration:none}.app__body .file-preview__remove:focus{color:rgba(var(--center-channel-color-rgb), 0.56)}.app__body .file-preview__remove:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.app__body .file-preview__remove:active{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.image-comment{width:300px;height:300px;background-position:left top;background-repeat:no-repeat}.file-icon{width:100%;height:100%}.file-icon.text{background-image:url(/static/files/5790e7bccf341e7afc4d49e681831840.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.file-icon.audio{background-image:url(/static/files/94d3e062b894b482ba56298e41722320.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.file-icon.video{background-image:url(/static/files/c7abbdc345c701433289e6898aad9799.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.file-icon.ppt{background-image:url(/static/files/8b4138fc5724da59a6c2ccf2315b593b.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.file-icon.generic,.file-icon.other{background-image:url(/static/files/48c8ed225ff4a2f7a4c1a1f1a1c06c69.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.file-icon.code{background-image:url(/static/files/f8f0b8752f8c2f772bc7944317f036b8.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.file-icon.excel{background-image:url(/static/files/925aafc8b6d54b579a4e1f0d71d6bfb0.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.file-icon.word{background-image:url(/static/files/82de93c379543742504413eb6abd50c0.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.file-icon.pdf{background-image:url(/static/files/00301d72e07c55d59df566ee59780e52.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.file-icon.patch{background-image:url(/static/files/5b38cef34af0acb354afbfe685544c53.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.file-icon.image{background-image:url(/static/files/3b8734f0d193b817f2b3c7663df97c3f.svg);background-position:center;background-repeat:no-repeat;background-size:32px 40px}.pdf-preview-spacer{height:5px}.pdf-max-pages{position:relative;bottom:8px;left:0;display:block;width:100%}.pdf-download-btn-spacer{margin-right:4px}.file-view--single{position:relative;margin:5px 0}.file-view--single:not(.image-permalink){margin:5px 0 0}.file-view--single .file__image{*zoom:1}.file-view--single .file__image::after{display:table;clear:both;content:""}.file-view--single .file__image .image-header{display:flex;align-items:baseline}.file-view--single .file__image .image-name{display:inline-block;overflow:hidden;margin:-4px 0 0 0;color:rgba(var(--center-channel-color-rgb), 0.72);cursor:pointer;font-size:12px;text-overflow:ellipsis;white-space:nowrap}.file-view--single .file__image .image-name div{display:inline}.file-view--single .file__image .image-container{*zoom:1;position:relative;width:100%;max-width:1024px;height:100%}.file-view--single .file__image .image-container::after{display:table;clear:both;content:""}.file-view--single .file__image .image-preload{position:absolute;z-index:1;top:0;right:0;bottom:0;left:0;display:flex;align-items:center;justify-content:center}.file-view--single .file__image .image-preload .fa{font-size:20px;opacity:.6}.file-view--single .file__image .image-loaded{bottom:0;min-width:40px;max-width:100%;min-height:40px;max-height:350px;border-radius:4px;transition:all .1s linear}.file-view--single .file__image .image-loaded .file-preview__button{display:block}.file-view--single .file__image .image-loaded .image-permalink{max-width:320px;max-height:180px}.file-view--single .file__image .image-loaded img{position:relative;z-index:2;overflow:hidden;max-height:350px;align-self:center;border-radius:4px;cursor:pointer;transition:all .1s linear}.file-view--single .file__image .image-loaded img.image-permalink{max-width:100%;height:auto}.file-view--single .file__image .image-loaded img.compact-display{max-height:175px}.file-view--single .file__image .image-loaded img:hover{box-shadow:0 2px 5px 0 rgba(0,0,0,.1),0 2px 10px 0 rgba(0,0,0,.1)}.file-view--single .file__image .image-loaded img.min-preview{max-width:100%;max-height:50px}.file-view--single .file__image .image-loaded img.min-preview--portrait{max-width:50px;max-height:inherit}.file-view--single .file__image .image-loaded img.small-image--inside-container{width:unset;max-height:inherit;border-width:0;margin:0;border-radius:0;box-shadow:none}.file-view--single .file__image .image-loaded.svg{display:block;width:100%;height:inherit}.file-view--single .file__image .image-loaded.svg img{height:inherit}.file-view--single .file__image .image-loaded.svg img:hover{box-shadow:0 2px 5px 0 rgba(0,0,0,.1),0 2px 10px 0 rgba(0,0,0,.1)}.file-view--single .file__image .image-loaded>.file-preview__button{min-width:40px;min-height:40px;text-align:left}.file-view--single .file__image .image-fade-in{opacity:1}.file-view--single .file-details__name{display:block;font-size:14px;font-weight:bold}.file-view--single .file-details__name:hover{cursor:pointer;text-decoration:underline}.post-image__columns{position:relative;display:flex;flex-flow:wrap}.post-image__column{position:relative;display:flex;overflow:hidden;width:320px;max-width:100%;height:6.4rem;align-items:center;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin:4px 12px 4px 0;background:var(--center-channel-bg);border-radius:4px;color:var(--center-channel-color);cursor:pointer;transition:box-shadow .15s ease}.post-image__column:hover,.post-image__column:focus-within,.post-image__column.keep-open{overflow:visible;box-shadow:0 2px 3px 0 rgba(0,0,0,.1),0 2px 3px 0 rgba(0,0,0,.1)}.post-image__column:hover .file-dropdown-icon,.post-image__column:focus-within .file-dropdown-icon,.post-image__column.keep-open .file-dropdown-icon{display:flex}.post-image__column:hover>.post-image__details,.post-image__column:focus-within>.post-image__details,.post-image__column.keep-open>.post-image__details{overflow:visible}.post-image__column:hover{box-shadow:var(--elevation-1)}.post-image__column:hover .post-image__download{opacity:1}.post-image__column:focus-within .post-image__download{opacity:1}.post-image__column--placeholder{visibility:hidden}.post-image__column.file-preview{flex-shrink:0;flex-wrap:nowrap;margin:0 10px 0 0;cursor:auto}.post-image__column.file-preview .post-image__details{padding-right:3.2rem}.post-image__column.file-preview .post-image__details .post-image__name{white-space:normal}.post-image__load{width:100%;height:100%;background-position:center;background-repeat:no-repeat;background-size:20px 20px}.post-image{position:relative;overflow:hidden;width:4rem;height:4rem;background-color:#fff;background-repeat:no-repeat;background-size:cover;border-radius:4px;text-align:center}.post-image.small{background-position:center}.post-image.normal{background-position:top left}.post-image .spinner .file__loading{position:absolute;top:50%;left:50%;margin-top:-16px;margin-left:-16px}.post-image .file__loaded{max-width:initial}.post-image .file__loaded.landscape,.post-image .file__loaded.quadrat{height:100px}.post-image .file__loaded.portrait{width:120px}.post-image__thumbnail{cursor:-webkit- zoom-in;cursor:zoom- zoom-in;z-index:1;display:flex;width:6.3rem;height:100%;flex:none;align-items:center;justify-content:center}.file-dropdown-icon{display:none;width:32px;min-width:32px;height:32px;align-items:center;justify-content:center;border:0;margin-left:8px;background-color:var(--center-channel-bg);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.72);cursor:pointer;fill:rgba(var(--center-channel-color-rgb), 0.72);text-decoration:none;transition:opacity .15s ease}.file-dropdown-icon svg{display:flex}.file-dropdown-icon:hover{display:flex;background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.file-dropdown-icon:focus{display:flex}.post-image__details{position:relative;display:flex;overflow:hidden;height:100%;flex:1;align-items:center;font-size:12px;text-align:left}.post-image__details .post-image__detail_wrapper{display:flex;flex:1;padding:0}.post--compact .post-image__details .post-image__detail_wrapper{padding-left:8px}.post-image__details .post-image__detail_wrapper .post-image__detail{width:100%;height:100%;line-height:normal}.post-image__details .post-image__detail_wrapper .post-image__detail .post-image__name{display:block;overflow:hidden;max-width:151px;margin-bottom:3px;font-weight:600;outline:none;text-decoration:none;text-overflow:ellipsis;white-space:nowrap;word-break:break-word}.post-image__details .post-image__detail_wrapper .post-image__detail .post-image__name a{border-radius:100px}.post-image__details .post-image__detail_wrapper .post-image__detail .post-image__type{display:inline-block;overflow:hidden;max-width:134px;float:left;opacity:.6;text-overflow:ellipsis;white-space:nowrap}.post-image__details .post-image__detail_wrapper .post-image__detail .post-image__size{margin-left:4px;opacity:.6}.post-image__details .post-image__download{top:0;right:0;display:flex;height:100%;align-items:center;justify-content:center;padding:0 1.6rem;line-height:0;opacity:1;text-align:center;transition:opacity .15s ease}.post-image__details .post-image__download a{display:flex;width:3.2rem;height:3.2rem;align-items:center;justify-content:center;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:1.6rem;text-decoration:none}.post-image__details .post-image__download a:focus{color:rgba(var(--center-channel-color-rgb), 0.56)}.post-image__details .post-image__download a:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.post-image__details .post-image__download a:active{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.post-image__details .post-image__download span{display:inline-block}.post-image__details .post-image__download svg{display:inline-block;width:30px;height:30px;border:1px solid;border-radius:50%;opacity:.7;transition:all .1s linear}.post-image__details .post-image__download svg:hover{opacity:1}.post-image__details div.MenuWrapper+.post-image__download{padding-left:8px}.post-image__details .post-image__progressBar{position:absolute;bottom:0;width:100%;height:7px;margin-bottom:0;border-radius:0}.post-image__details .progress-bar{background-color:#285ab9}.post-image__details .post-image__uploadingTxt{color:rgba(var(--center-channel-color-rgb), 0.56)}.file-details__container{display:flex;background:#fff}.file-details__container .file-details{width:320px;height:270px;padding:14px;text-align:left;vertical-align:top}.file-details__container .file-details .file-details__name{margin:5px 0;color:rgba(0,0,0,.9);font-size:16px;word-break:break-word}.file-details__container .file-details .file-details__info{color:rgba(0,0,0,.5)}.file-details__container .file-details__preview{width:320px;height:270px;border-right:1px solid rgba(0,0,0,.15);vertical-align:center}.file-details__container .file-details__preview img{width:80px}.file-details__container .file-details__preview .file-details__preview-helper{display:inline-block;height:100%;vertical-align:middle}.file-playback__controls{position:absolute;z-index:2;right:5px;bottom:0;cursor:pointer;font-size:22px;transition:opacity .6s}.file-playback__controls.stop{opacity:0}.view-image__loading{display:flex;width:100%;height:100%;min-height:140px;flex-direction:column;align-items:center;justify-content:center;padding-top:28px;background:#000}.view-image__loading .fa{color:#fff;font-size:20px;opacity:.6}.image-loading__container{position:relative;overflow:hidden;max-height:inherit}.file-preview__button{display:inline-block;max-height:inherit;vertical-align:top}.small-image__container{display:flex;min-width:48px;max-width:calc(100% - 5px);min-height:48px;max-height:inherit;align-items:center;justify-content:center;border:1px solid rgba(var(--center-channel-color-rgb), 0.32);margin:5px 2px;background:var(--center-channel-bg);border-radius:4px}.small-image__container:hover{z-index:2;box-shadow:0 2px 5px 0 rgba(0,0,0,.1),0 2px 5px 0 rgba(0,0,0,.1);transition:all .1s linear}.small-image__container:hover .image-preview-utility-buttons-container{display:inline-block}.small-image__container--min-width{width:48px}.icon{display:inline-flex;align-items:center;justify-content:center;font-size:18px}.icon--no-spacing::before{margin:0}.icon--small{width:16px;height:16px}.icon--small-filled{width:14px;height:14px}.icon--standard{width:20px;height:20px;font-size:1.6rem}.icon-10{font-size:12px}.icon-12{font-size:14.4px}.icon-16{font-size:18px}.icon-20{font-size:24px}.icon-28{font-size:31.2px}.icon-32{font-size:36px}.icon-40{font-size:48px}.icon-52{font-size:60px}.icon-64{font-size:72px}.help-text{display:block;margin:10px 0 0;color:rgba(0,0,0,.5)}.help-text ul,.help-text ol{padding-left:23px}.help-text a{opacity:.5}.help-text .help-link{margin-right:5px}.help-text .btn{font-size:13px}.help-text.remove-filename{position:relative;top:-2px;margin-bottom:5px}.form-control{border-radius:2px;text-align:left}.form-control:focus{box-shadow:none}.form-control.no-padding{padding:0;line-height:32px}.form-control.no-resize{resize:none}.form-control[disabled],.form-control [readonly]{background:rgba(255,255,255,.1);color:inherit;cursor:auto}fieldset[disabled] .form-control{background:rgba(255,255,255,.1);color:inherit;cursor:auto}.admin-textarea{resize:none}input[type=radio],input[type=checkbox]{margin-top:3px;font-size:14px}input::-webkit-file-upload-button{display:none}::-webkit-input-placeholder{color:inherit;opacity:.5}::-moz-placeholder{color:inherit;opacity:.5}:-ms-input-placeholder{color:inherit;opacity:.5}:-moz-placeholder{color:inherit;opacity:.5}a{color:#166de0;cursor:pointer;text-decoration:none;word-break:break-word}a:hover,a:focus{color:#1156b2;outline:0}.text-danger{color:#bf5f5d}.text-danger:hover,.text-danger:focus{color:#bf5f5d}.mention{position:relative;z-index:10;padding-bottom:2px;background:#166de0;border-radius:3px;color:#fff}.badge{display:inline-block;min-width:10px;padding:3px 7px;background-color:#777;border-radius:10px;color:#fff;font-size:12px;font-weight:bold;line-height:1;text-align:center;vertical-align:middle;white-space:nowrap}.mention--highlight{padding:0 1px;background-color:#ff0;border-radius:4px}.mention--highlight .mention--highlight{padding:0}.group-mention-link{color:var(--link-color)}.browser--ie .modal .modal-dialog{transform:translateY(0)}.modal-backdrop.in{opacity:.64}.modal-body{overflow:auto;max-height:calc(90vh - 80px);padding:20px 15px}.modal-body.overflow--visible{overflow:visible}.modal-body .manage-teams__teams .MenuWrapper{position:static}.modal-body .manage-teams__teams .Menu{top:inherit;margin-right:20px}.no-scroll{overflow:hidden !important}.app__body .modal .modal-content{border-color:rgba(var(--center-channel-color-rgb), 0.16);background:var(--center-channel-bg);color:var(--center-channel-color)}.app__body .modal .modal-header{background:var(--sidebar-header-bg)}.app__body .modal .modal-header .close{color:var(--sidebar-header-text-color)}.app__body .edit-modal-body{overflow:visible}.app__body .edit-modal-body .custom-textarea{height:auto;min-height:8em;max-height:60vh;-webkit-overflow-scrolling:touch;-ms-overflow-style:auto;overflow-y:auto}.app__body .edit-modal-body .custom-textarea.custom-textarea--preview{display:none}.app__body .edit-modal-body .custom-textarea.textbox-preview-area{position:relative}.app__body .edit-modal-body .edit-post-footer{position:relative;display:inline-block;font-size:13px}.app__body .edit-modal-body .edit-post-footer .post-error{position:relative;top:3px;margin-bottom:0;font-size:.85em;font-weight:normal;opacity:.55}.row--invite .col-sm-6:first-child{padding-right:0}.modal__hint{display:block;margin:0 0 10px;font-size:.9em;opacity:.8}.modal__error{margin-top:6px;color:#d64946;float:left;font-size:.95em;font-weight:normal}.more-table{margin:0;table-layout:fixed}.modal{width:100%;color:rgba(0,0,0,.9)}.modal .modal--overflow .modal-body{overflow:visible}.modal textarea{overflow-x:hidden}.modal .modal-footer{background:var(--center-channel-bg)}.modal .modal-footer.modal-footer--invisible{overflow:hidden;height:0;padding:0}.modal .modal-footer .error-text{margin:10px;float:left;font-weight:bold;text-align:left}.modal.modal-image{overflow:hidden}.modal.modal-image .modal-code .modal-image__content{background:transparent}.modal .custom-textarea{padding:12px 30px 12px 15px}.modal .btn{font-size:13px}.modal .info__label{margin-bottom:3px;font-size:.9em;font-weight:600;opacity:.5}.modal .info__value{padding-left:10px;word-break:break-word}.modal .info__value p{white-space:pre-wrap}.modal .team-member-list{width:100%}.modal .remove__member{padding:6px;color:inherit;float:right;font-size:20px;line-height:0}.modal .remove__member:hover{color:#d64946}.modal .modal-dialog{max-width:95%;margin-right:auto;margin-bottom:0;margin-left:auto}.modal .modal-dialog.modal--overflow-visible .modal-body{position:static}.modal .modal-dialog.modal--overflow-visible .modal-body .dropdown{position:static}.modal .modal-dialog.modal--overflow-visible .modal-body .dropdown-menu{right:20px;left:auto}.modal .modal-dialog.modal-xl{width:800px}.modal .modal-push-down{margin-top:60px}.modal .modal-next-bar{position:absolute;top:0;right:0;height:100%}.modal .modal-header{display:flex;min-height:56px;padding:14px 48px 11px 15px;border:1px solid rgba(0,0,0,.15);background:#333;border-radius:0;border-radius:3px 3px 0 0;color:#fff;overflow:hidden;*zoom:1}.modal .modal-header .modal-title{overflow:hidden;max-width:calc(100% - 80px);flex:1;color:var(--sidebar-header-text-color);font-size:17px;line-height:27px;text-overflow:ellipsis;white-space:nowrap}.modal .modal-header .modal-title .name{font-weight:600}.modal .modal-header .modal-title .shared-channel-icon{width:16px;height:16px;margin:0 8px;color:#3d3c40;font-size:16px;line-height:16px}.modal .modal-header .modal-title .shared-channel-icon::before{margin:0}.modal .modal-header .modal-action{padding:0;margin:0}.modal .modal-header .close{position:absolute;z-index:5;right:10px;width:30px;height:30px;color:#fff;font-size:24px;line-height:30px;opacity:.7;text-shadow:none;transition:all .1s ease-in}.modal .modal-header .close:hover{opacity:1;background:rgba(0,0,0,.1)}.modal .modal-header .close .sr-only{display:none}.modal .modal-header .close span{font-family:"Open Sans",sans-serif;line-height:10px}.modal .modal-header .btn.btn-primary{position:relative;margin-top:-4px}.modal .modal-header .btn.btn-primary i{margin-right:5px}.modal .no-channel-message{padding:2em 1em;text-align:center}.modal .no-channel-message .secondary-message{margin:1em 0 0;opacity:.8}.modal .modal-content{border:1px solid #777;background:#fff;border-radius:4px;box-shadow:0 8px 24px rgba(0,0,0,.12)}.modal .modal-chevron-icon{top:50%;font-size:120%}.modal .modal-prev-bar{position:absolute;top:0;left:0;height:100%}.modal .modal-image{position:relative;width:100%;max-width:100%;height:100%;margin:0 auto}.modal .modal-image .modal-body{overflow:hidden;*zoom:1;display:table;width:100%;height:100%;max-height:100%;background:transparent;table-layout:fixed}.modal .modal-image .modal-image__background{background:#f3f3f3}.modal .modal-image .modal-image__content{min-width:440px;max-width:90vw;max-height:91.5vh;overflow-x:hidden;overflow-y:visible}.modal .modal-image .modal-image__content.modal-auto__content{overflow:auto;width:90vw}.modal .modal-image .modal-image__content.modal-auto__content::-webkit-scrollbar-thumb{background:#aaa}.modal .modal-image .modal-image__content.modal-auto__content .view-image__loading{width:90vw}.modal .modal-image .modal-image__content .pdf{width:max-content;height:91.5vh;margin:0 auto}.modal .modal-image .modal-image__content .pdf .post-code{width:max-content}.modal .modal-image .post-code__container{overflow:auto}.modal .modal-image .modal-image__wrapper{position:relative;display:table-cell;width:100%;max-width:90%;border-radius:3px;text-align:center;vertical-align:middle}.modal .modal-image .modal-image__wrapper:hover{border-radius:3px 3px 0 0}.modal .modal-image .modal-image__wrapper.default{width:100%;height:80%}.modal .modal-image .modal-image__wrapper .post-code{background:transparent}.modal .modal-image .modal-image__wrapper .post-code .post-code__line-numbers{padding:5px 0}.modal .modal-image .modal-image__wrapper .post-code code{width:100%;padding:5px 0;margin:0}.modal .modal-image .modal-image__wrapper .code-preview{display:flex;height:calc(100vh - 168px);flex-direction:column;border-radius:8px}@media screen and (max-width: 768px){.modal .modal-image .modal-image__wrapper .code-preview{height:calc(100vh - 108px);border-radius:0}.modal .modal-image .modal-image__wrapper .code-preview .post-code__language{top:0}}.modal .modal-image .modal-image__wrapper .code-preview .hljs{margin:0}.modal .modal-image .modal-image__wrapper audio,.modal .modal-image .modal-image__wrapper canvas,.modal .modal-image .modal-image__wrapper progress,.modal .modal-image .modal-image__wrapper video{display:block;width:auto;height:auto;max-height:85vh;margin:0 auto;border-radius:8px}.modal .modal-image .modal-image__wrapper video{width:100%}.modal .modal-image .modal-image__wrapper canvas{max-height:100%}.modal .modal-image .modal-image__wrapper .modal-close{position:absolute;z-index:9999;top:-13px;right:-13px;width:37px;height:37px;background-image:url(/static/files/f2b29bd9b1060d4e066bb26e89d4de15.png);background-size:100% 100%;cursor:pointer;opacity:1;transition:opacity .6s}.modal .modal-image .modal-image__wrapper .modal-zoom-btn{margin-right:6px;margin-left:6px}.modal .modal-image .modal-image__wrapper a{color:#fff;text-decoration:none}.modal .modal-image .modal-image__wrapper .btn-inactive{margin-right:6px;margin-left:6px;color:gray}.modal .modal-image .modal-image__wrapper>div{position:relative;display:inline-block;min-width:300px;max-width:100%;min-height:100px}.modal .modal-image .modal-image__wrapper code{min-width:330px;min-height:130px}.modal .modal-image .modal-image__wrapper pre,.modal .modal-image .modal-image__wrapper code{display:inline-block}.modal .modal-image .modal-image__wrapper .post-body--code{overflow:auto;max-width:calc(100vw - 80px);max-height:calc(100vh - 80px)}.modal .modal-image .modal-image__wrapper img{max-width:100%;max-height:calc(100vh - 168px)}.modal .modal-image .modal-image__wrapper .spinner .file__loading{position:absolute;z-index:2;top:50%;left:50%;margin-top:-16px;margin-left:-16px}.modal .modal-image .modal-content{width:100%;height:100%;padding:0;border:none;background:rgba(0,0,0,0);box-shadow:none}.modal .modal-image .image-control{position:relative;top:50%;width:50px;height:45px;margin-top:-23px;background:url(/static/files/47828bbc15464edb98e984a0d3bffb72.png) left no-repeat;float:left}.modal .modal-image .image-control.image-next{background:url(/static/files/0098d1355858d44623fc00082b789af0.png) left no-repeat;float:right}.modal .modal-image .loader-image{position:absolute;top:0;right:0;bottom:0;left:0;margin:auto}.modal .modal-image .loader-percent{display:block;height:20px;margin-top:12px;color:rgba(255,255,255,.8)}.modal .modal-image .modal-button-bar{display:flex;overflow:hidden;max-width:100%;justify-content:center;padding:0 10px;background-color:#000;line-height:40px}.modal .modal-image .modal-button-bar .modal-bar-file-count{float:left}.modal .modal-image .modal-button-bar .modal-bar-links{float:right}.modal .modal-image .modal-button-bar .text{bottom:0;margin-left:5px;color:#fff;vertical-align:middle}.modal .modal-image .modal-button-bar .modal-column{flex:1}.modal.more-channel__modal .modal-body{padding:10px 0 15px;overflow-x:hidden}.modal.more-channel__modal .channel-count{margin-top:5px;float:right;opacity:.8}.modal .suggestion-list--top{position:absolute;bottom:initial}.modal .suggestion-list--bottom{position:absolute}.modal .suggestion-list__content--top{position:absolute;bottom:0}.modal .suggestion-list__content--bottom{position:absolute;top:0}.more-modal .loading-screen{height:auto;padding:1.9em 1em;font-size:1.25em}.more-modal .Select-input>input{padding:8px 0}.more-modal .status-wrapper{flex:32px 0 0}.more-modal .more-modal__gm-icon{display:flex;width:32px;height:32px;flex:32px 0 0;align-items:center;justify-content:center;border-radius:50%}.more-modal .user-list{position:relative;margin-top:10px;overflow-x:hidden;overflow-y:auto}.more-modal .modal-body{padding:10px 0 15px;overflow-x:hidden}.more-modal .filter-row{width:300px;margin:5px 0 10px}.more-modal .filter-row.filter-row--full{width:100%}.more-modal .member-count{margin-top:5px;float:right;opacity:.8}.more-modal .member-show{margin-top:8px;margin-right:3px;float:right;opacity:.8}.more-modal .member-select__container .member-count{margin:12px 0 0 3px}.more-modal .member-select__container select{width:auto;margin:1px 5px 0 2px;float:right;opacity:.8}.more-modal .more-purpose{opacity:.7}.modal-tabs{display:flex;width:100%;flex-direction:column}.modal-tabs .tab-content{display:flex;height:auto;flex:1 1 auto;flex-direction:column}.modal-tabs .tab-pane{display:none;height:auto;flex:1 1 auto}.modal-tabs .tab-pane.active{display:flex}.modal-tabs .nav-tabs{margin:0 0 16px}.modal-tabs .nav-tabs>li{width:50%;border:none;border-bottom:2px rgba(0,0,0,.15) solid;margin-right:0;text-align:center}.modal-tabs .nav-tabs>li.active{border-bottom:2px #166de0 solid}.modal-tabs .nav-tabs>li.active a{opacity:1}.modal-tabs .nav-tabs>li>a{display:flex;height:40px;align-items:center;justify-content:center;padding-bottom:12px;border:none;background:var(--center-channel-bg);color:inherit;font-weight:900;opacity:.5;outline:none}.modal-tabs .nav-tabs>li>a:active{opacity:1}.more-modal__button .btn{width:100%;height:39px;font-size:.9em;font-weight:600}.more-modal__dropdown{display:inline-flex;padding:0 16px;font-weight:600}.more-modal__dropdown span{color:var(--center-channel-color);font-size:.9em}.more-modal__dropdown a:hover{color:var(--center-channel-color);text-decoration:none}.more-modal__icon-container{margin-right:6px}.more-modal__list{display:flex;flex-direction:column}.browser--ie .more-modal__list{flex:20}.more-modal__list>div{overflow:auto;min-height:100%}.popover .more-modal__list{font-size:.95em}.popover .more-modal__list .more-modal__row{padding:5px 10px}.more-modal__list .more-modal__image{max-width:none;flex-grow:0;flex-shrink:0;margin-top:2px;border-radius:60px}.more-modal__list .more-modal__details{overflow:hidden;flex-grow:1;flex-shrink:1;align-self:center;padding-left:10px;text-overflow:ellipsis}.more-modal__list .more-modal__details .shared-channel-icon{width:16px;height:16px;margin-top:0;margin-left:8px;color:rgba(61,60,64,.72);font-size:16px;line-height:16px}.more-modal__list .more-modal__details .shared-channel-icon::before{margin:0}.more-modal__list .more-modal__details .more-modal__name{display:flex;overflow:hidden;min-width:0;margin:5px 0;text-overflow:ellipsis;white-space:nowrap}.more-modal__list .more-modal__details .more-modal__name .more-modal__name_sub{font-weight:500;opacity:.5}.more-modal__list .more-modal__details .more-modal__name .more-modal__name_count{font-weight:400;opacity:.6}.more-modal__list .more-modal__actions{flex-grow:0;flex-shrink:0;padding-left:8px;margin:5px 0}.more-modal__list .more-modal__name{display:flex;font-weight:600;white-space:nowrap}.more-modal__list .more-modal__name span{overflow:hidden;max-width:100%;text-overflow:ellipsis}.more-modal__list .more-modal__row--link{color:inherit;text-decoration:none}.more-modal__list .more-modal__row--link:hover,.more-modal__list .more-modal__row--link:focus{color:inherit}.more-modal__list .more-modal__description{display:block;overflow:hidden;opacity:.6;text-overflow:ellipsis;white-space:nowrap}.more-modal__list .more-modal__description:empty{display:none}.more-modal__list .more-modal__row{display:flex;min-height:65px;align-items:center;padding:10px 15px;border-bottom:1px solid rgba(0,0,0,.15)}.more-modal__list .more-modal__row.clickable{cursor:pointer}.more-modal__list .more-modal__row.more-modal__row--selected{background:rgba(var(--sys-center-channel-color-rgb), 0.08)}.app__body .more-modal__list .more-modal__row.more-modal__row--selected{background:rgba(var(--center-channel-color-rgb), 0.08)}.more-modal__list .more-modal__row.more-modal__row--selected .more-modal__actions--round{display:block}.more-modal__list .more-modal__row.more-modal__row--selected .more-modal__lastPostAt{display:none}.more-modal__list .more-modal__row .more-modal__shared-actions{color:rgba(61,60,64,.72)}.more-modal__list .more-modal__row .more-modal__shared-actions .shared-user-icon{width:16px;height:16px;margin-left:4px;font-size:16px;line-height:16px}.more-modal__list .more-modal__row .more-modal__shared-actions .shared-user-icon::before{margin:0}#member-list-popover .more-modal__list .more-modal__row{min-height:0}.more-modal__list .more-modal__lastPostAt{display:block;margin-left:5px;opacity:.6}.more-modal__list .more-modal__lastPostAt time{font-weight:bold;white-space:nowrap}.more-modal__list .more-modal__placeholder-row{padding:10px 15px}.more-modal__list .more-modal__actions--round{display:none;width:32px;height:32px;line-height:32px;opacity:.5;text-align:center}.more-modal__list .more-modal__right{display:flex;width:100%;flex-direction:column}.more-modal__list .more-modal__right .control-label{padding:5px 0 0 5px;font-weight:normal}.more-modal__list .more-modal__top{display:flex}.more-modal__list .more-modal__bottom>.has-error{padding-left:5px}.more-modal__list p{overflow:hidden;margin:5px 0;text-overflow:ellipsis}.member-select__container{position:absolute;top:15px;right:15px}.filtered-user-list{display:flex;width:100%;height:calc(90vh - 120px);flex-direction:column}.filtered-user-list>div{flex:1 1 auto}.filtered-user-list .multi-select__wrapper{display:flex;height:1px;flex-direction:column;flex-grow:500}.filtered-user-list .more-modal__list{height:1px;flex-grow:500}.filtered-user-list .filter-button{padding-left:0;margin-left:0}.filtered-user-list .filter-button .btn{height:34px}.filtered-user-list .filter-controls{padding:1em 1.5em 0}.filtered-user-list .filter-controls .filter-control__next{float:right}.team-selector-modal .more-modal__row,.channel-selector-modal .more-modal__row{border:0}.team-selector-modal .more-modal__row:nth-child(odd),.channel-selector-modal .more-modal__row:nth-child(odd){background:rgba(0,0,0,.03)}.team-selector-modal .more-modal__row .team-name,.channel-selector-modal .more-modal__row .team-name{padding-left:5px;color:rgba(0,0,0,.3)}.team-selector-modal .more-modal__row .icon__lock,.team-selector-modal .more-modal__row .icon__globe,.channel-selector-modal .more-modal__row .icon__lock,.channel-selector-modal .more-modal__row .icon__globe{margin-right:5px}.team-selector-modal .modal-header,.channel-selector-modal .modal-header{background:#000;color:#fff}.team-selector-modal .modal-header .close,.channel-selector-modal .modal-header .close{color:#fff;opacity:1}.team-selector-modal .modal-header .close:hover,.channel-selector-modal .modal-header .close:hover{opacity:1}.team-selector-modal .modal-body,.channel-selector-modal .modal-body{padding:15px 0}.team-selector-modal .modal-body .filter-row,.channel-selector-modal .modal-body .filter-row{padding:0 15px}.team-selector-modal .modal-body .more-modal__row--selected,.channel-selector-modal .modal-body .more-modal__row--selected{background-color:#c8defa}.team-selector-modal .modal-body .more-modal__row--selected .more-modal__actions--round,.channel-selector-modal .modal-body .more-modal__row--selected .more-modal__actions--round{display:block}.team-selector-modal .modal-body .no-channel-message,.channel-selector-modal .modal-body .no-channel-message{width:100%;margin-top:40px;color:rgba(0,0,0,.3);font-size:1.25em;text-align:center}.team-selector-modal .modal-body .filter-row--full,.channel-selector-modal .modal-body .filter-row--full{flex-grow:0}.team-selector-modal .filter-control,.channel-selector-modal .filter-control{border:none;background:none;color:#166de0}.team-selector-modal .filter-control:hover,.team-selector-modal .filter-control:focus,.team-selector-modal .filter-control:active,.channel-selector-modal .filter-control:hover,.channel-selector-modal .filter-control:focus,.channel-selector-modal .filter-control:active{border:none;background:none;box-shadow:none;color:#166de0}.modal-invite-member .btn:hover{text-decoration:underline}.more-public-direct-channels .filtered-user-list{height:calc(90vh - 180px)}.insights-modal .modal-content,.user-groups-modal-create .modal-content,.user-groups-modal-update .modal-content,.view-user-groups-modal .modal-content,.user-groups-modal .modal-content{border-radius:8px}.insights-modal .modal-content .modal-header,.user-groups-modal-create .modal-content .modal-header,.user-groups-modal-update .modal-content .modal-header,.view-user-groups-modal .modal-content .modal-header,.user-groups-modal .modal-content .modal-header{display:flex;min-height:0;align-items:center;padding:24px 24px;border:none;background:transparent;color:inherit}.insights-modal .modal-content .modal-header button.modal-header-back-button,.user-groups-modal-create .modal-content .modal-header button.modal-header-back-button,.user-groups-modal-update .modal-content .modal-header button.modal-header-back-button,.view-user-groups-modal .modal-content .modal-header button.modal-header-back-button,.user-groups-modal .modal-content .modal-header button.modal-header-back-button{position:absolute;left:18px;width:4rem;height:4rem;color:rgba(var(--center-channel-color-rgb), 0.56);float:left}.insights-modal .modal-content .modal-header button.modal-header-back-button:hover,.user-groups-modal-create .modal-content .modal-header button.modal-header-back-button:hover,.user-groups-modal-update .modal-content .modal-header button.modal-header-back-button:hover,.view-user-groups-modal .modal-content .modal-header button.modal-header-back-button:hover,.user-groups-modal .modal-content .modal-header button.modal-header-back-button:hover{color:rgba(var(--center-channel-color-rgb), 0.72)}.insights-modal .modal-content .modal-header button.modal-header-back-button:active,.user-groups-modal-create .modal-content .modal-header button.modal-header-back-button:active,.user-groups-modal-update .modal-content .modal-header button.modal-header-back-button:active,.view-user-groups-modal .modal-content .modal-header button.modal-header-back-button:active,.user-groups-modal .modal-content .modal-header button.modal-header-back-button:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.insights-modal .modal-content .modal-header button.modal-header-back-button i,.user-groups-modal-create .modal-content .modal-header button.modal-header-back-button i,.user-groups-modal-update .modal-content .modal-header button.modal-header-back-button i,.view-user-groups-modal .modal-content .modal-header button.modal-header-back-button i,.user-groups-modal .modal-content .modal-header button.modal-header-back-button i{display:inline;font-size:24px;line-height:24px}.insights-modal .modal-content .modal-header .close,.user-groups-modal-create .modal-content .modal-header .close,.user-groups-modal-update .modal-content .modal-header .close,.view-user-groups-modal .modal-content .modal-header .close,.user-groups-modal .modal-content .modal-header .close{right:18px;width:4rem;height:4rem;margin-top:0;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:32px;font-weight:normal;line-height:30px}.insights-modal .modal-content .modal-header .close:hover,.user-groups-modal-create .modal-content .modal-header .close:hover,.user-groups-modal-update .modal-content .modal-header .close:hover,.view-user-groups-modal .modal-content .modal-header .close:hover,.user-groups-modal .modal-content .modal-header .close:hover{background:rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.72);fill:rgba(var(--center-channel-color-rgb), 0.72)}.insights-modal .modal-content .modal-header .close:active,.user-groups-modal-create .modal-content .modal-header .close:active,.user-groups-modal-update .modal-content .modal-header .close:active,.view-user-groups-modal .modal-content .modal-header .close:active,.user-groups-modal .modal-content .modal-header .close:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.insights-modal .modal-content .modal-header .modal-title,.user-groups-modal-create .modal-content .modal-header .modal-title,.user-groups-modal-update .modal-content .modal-header .modal-title,.view-user-groups-modal .modal-content .modal-header .modal-title,.user-groups-modal .modal-content .modal-header .modal-title{color:inherit;font-size:22px;line-height:28px}.multi-select__container{display:flex;width:100%;justify-content:space-between;padding:0 15px}.multi-select__container .btn{height:36px;margin-left:16px}.multi-select__focused>div{border-radius:4px;box-shadow:0 0 1px 3px rgba(var(--link-color-rgb), 0.5),0 0 0 1px var(--link-color)}.multi-select__focused input{box-shadow:none !important}.multi-select__help{display:flex;justify-content:space-between;padding:10px 15px 0}.multi-select__help:empty{display:none}.multi-select__help>div:not(.multi-select__note),.multi-select__help>span{opacity:.6}.multi-select__note{display:table;width:100%;padding:8px 13px;border-radius:3px}.multi-select__note>div{display:table-cell}.multi-select__note>div.note__icon{width:15px}.prompt{width:600px;max-width:90%;padding:1em 2em 0;border:1px solid rgba(0,0,0,.15);margin:50px auto;background:#fff}.prompt .prompt__heading{display:table;width:100%;margin:1em 0;font-size:1.2857142857em;line-height:normal;table-layout:fixed}.prompt .prompt__heading>div{display:table-cell;vertical-align:top}.prompt .prompt__heading>div:first-child{width:70px}.prompt .prompt__heading img{margin-right:15px}.prompt .prompt__allow{margin:1em 0;font-size:1.4285714286em}.prompt .prompt__buttons{padding:1.5em 0;border-top:1px solid rgba(0,0,0,.15);text-align:right}.prompt .prompt__error{display:inline-block}.app__body .popover.channel-header__popover{box-shadow:none}.header-popover-text-measurer{position:absolute;width:auto;height:auto;visibility:hidden;white-space:nowrap}.popover{padding:0;background:var(--center-channel-bg);border-radius:4px;box-shadow:0 8px 24px rgba(0,0,0,.12);color:#404040;font-family:inherit}.app__body .popover{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:0 8px 24px rgba(0,0,0,.12)}.app__body .popover .user-profile-popover{border:1px solid rgba(var(--center-channel-color-rgb), 0.2);background:transparent !important;box-shadow:none !important}.app__body .popover .user-profile-popover .popover-title{position:relative;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.2);background:var(--center-channel-bg);border-radius:2px 2px 0 0}.app__body .popover .user-profile-popover .popover-title::before{position:absolute;top:0;left:0;width:100%;height:100%;background:rgba(var(--center-channel-color-rgb), 0.04) !important;content:""}.app__body .popover .user-profile-popover .popover-title span{position:relative;z-index:1}.app__body .popover .user-profile-popover .popover-content{border-top:none;background:var(--center-channel-bg);border-radius:0 0 3px 3px;box-shadow:rgba(var(--center-channel-color-rgb), 0.08) 0 17px 50px 0,rgba(var(--center-channel-color-rgb), 0.08) 0 12px 15px 0}.app__body .popover .user-profile-popover .popover-content .shared-user-icon{width:16px;height:16px;margin-left:8px;color:rgba(61,60,64,.72);font-size:16px;line-height:20px}.app__body .popover .user-profile-popover .popover-content .shared-user-icon::before{margin:0}.popover.channel-header__popover{z-index:999;margin-left:8px;font-size:12px}.popover.channel-header__popover.chanel-header__popover--lhs_offset{margin-left:73px}.popover.channel-header__popover .popover-content{padding:2px 3px}.popover.channel-header__popover .popover-content .markdown__list{margin:0}.popover.channel-header__popover .popover-content p{white-space:normal;word-break:normal}.popover.channel-header__popover .popover-content p:last-child{margin-bottom:0}.popover.channel-header__popover.bottom{margin-top:-10px}.popover.bottom>.arrow,.popover.right>.arrow,.popover.top>.arrow,.popover.left>.arrow{display:none}.popover.bottom>.arrow::after,.popover.right>.arrow::after,.popover.top>.arrow::after,.popover.left>.arrow::after{border-color:transparent}.popover.bottom{margin-top:10px}.popover.bottom>.arrow::after{border-bottom-color:var(--center-channel-bg)}.popover.left>.arrow::after{border-left-color:var(--center-channel-bg)}.popover.right>.arrow::after{border-right-color:var(--center-channel-bg)}.popover.top>.arrow::after{border-top-color:var(--center-channel-bg)}.popover ul+p,.popover ol+p{margin-top:.6em}.popover p+ul,.popover p+ol{margin-top:.6em}.popover blockquote{overflow:hidden;padding:0 0 0 20px;font-size:13px;text-overflow:ellipsis}.popover blockquote::before{top:0;left:2px;font-size:15px}.popover .popover-title{overflow:hidden;max-width:100%;padding:8px 10px;border-color:rgba(var(--center-channel-color-rgb), 0.08);background:rgba(0,0,0,.05);border-radius:0;text-overflow:ellipsis}.popover .popover-title>span{display:flex;justify-content:space-between}.popover .popover-title .user-popover__username{font-family:"Open Sans",sans-serif}.popover hr.divider{margin:8px 0}.popover hr.divider--expanded{margin:8px -15px}.popover .popover-content{word-break:break-word}.popover .popover-content p:last-child{margin-bottom:5px}.popover .popover__row{padding:9px 15px 0;margin:0 -15px 0}.popover .popover__row.first{border-top:1px solid transparent;margin-top:4px}.popover .popover__row>a i{margin-right:5px}.channel-header__info .popover-content{overflow:auto;max-height:250px}.user-popover{display:inline-block;cursor:pointer}.code-popover .popover-content{padding:5px}.user-popover-image{position:relative;display:block;width:128px;margin:0 auto}.user-popover-image .user-popover-status{position:absolute;top:auto;right:8px;bottom:0;display:flex;width:28px;height:28px;padding:4px;background:rgba(var(--center-channel-bg-rgb), 1);border-radius:50px}.user-popover-image .user-popover-status svg{width:100%;min-height:100%}.user-popover__username,.user-popover__username>a{display:inline-block;overflow:hidden;max-width:150px;height:17px;text-overflow:ellipsis;white-space:nowrap}.user-profile-popover .user-popover__username:only-child,.user-profile-popover .user-popover__username:only-child>a{max-width:100%}.user-profile-popover .Avatar{display:block;margin:5px auto}.user-popover__role{padding:3px 5px;margin-left:10px;background-color:rgba(0,0,0,.3);border-radius:4px;color:#fff;font-size:.8em;font-weight:bold}.user-popover__email{display:block;overflow:hidden;max-width:300px;text-overflow:ellipsis}.hidden-label+.search-autocomplete__divider::before{display:none}.search-autocomplete__divider{position:relative;display:flex;height:2.8rem;align-items:center;justify-content:flex-start;padding:0 0 0 2.4rem;margin:1.2rem 0 0;color:rgba(var(--center-channel-color-rgb), 0.6);font-size:12px;font-weight:600;text-transform:uppercase}.search-autocomplete__divider span{background:var(--center-channel-bg)}.search-autocomplete__divider:first-child::before{display:none}.search-autocomplete__divider::before{position:absolute;top:-7px;left:0;width:100%;height:1px;background:rgba(var(--center-channel-color-rgb), 0.08);content:""}.search-autocomplete__name{overflow:hidden;text-overflow:ellipsis}.search-help-popover{top:25px;right:-2px;left:auto;width:296px;max-width:350px;opacity:0;visibility:hidden}.search-help-popover.autocomplete{display:block}.search-help-popover.autocomplete .popover-content{position:relative;max-height:60vh;padding:0 0 12px;-webkit-overflow-scrolling:touch;overflow-x:hidden}.search-help-popover.autocomplete .popover-content::-webkit-scrollbar-track{width:0}.search-help-popover.autocomplete .popover-content::-webkit-scrollbar-thumb{border:1px solid var(--center-channel-bg);background-color:rgba(var(--center-channel-color-rgb), 0.24) !important;border-radius:4px}.search-help-popover.bottom>.arrow{top:-18px;left:30px;border-width:9px}.search-help-popover .popover-content{overflow:auto;max-height:500px;padding:0}.search-help-popover h4{margin-top:0;font-size:1.4rem}.search-help-popover ul span{opacity:.8}.search-help-popover ul strong,.search-help-popover ul b{opacity:1}.search-help-popover .tooltip-inner{max-width:100%}body.enable-animations .search-help-popover{transition-delay:0s;transition-duration:.1s;transition-property:opacity,visibility;transition-timing-function:ease-in,step-end}.search-help-popover.visible{opacity:1;visibility:visible}body.enable-animations .search-help-popover.visible{transition-delay:.2s;transition-duration:.3s;transition-property:opacity,visibility;transition-timing-function:ease-out,step-start}body.enable-animations .sidebar--right .search-help-popover.visible{transition-delay:0s;transition-duration:.3s;transition-property:opacity,visibility;transition-timing-function:ease-out,step-start}.member-list__popover{max-width:initial;margin-left:110px}.member-list__popover.popover.bottom{margin-top:2px}.member-list__popover .more-modal__body{position:relative;overflow:auto;max-height:275px;border-top:1px solid transparent;border-bottom:1px solid transparent}.member-list__popover .more-modal__header{display:flex;padding:14px 20px}.member-list__popover .more-modal__header .icon{position:relative;margin:0 38px 0 24px;opacity:.8}.member-list__popover .more-modal__header span{align-self:center;font-weight:600}.member-list__popover .more-modal__header button{width:fit-content;margin-left:auto}.member-list__popover .more-modal__header button i{margin:0 5px !important}.member-list__popover .more-modal__header .subhead{font-size:12px;opacity:.6}.member-list__popover .more-modal__header .subhead span{font-weight:normal}.member-list__popover .more-modal__button{display:flex}.member-list__popover .more-modal__button .btn{width:100%;height:42px;padding:0;margin:0 auto}.member-list__popover .more-modal__list .more-modal__row{overflow:hidden;height:50px;padding:0 12px 0 20px;border:none;margin:1px 0;cursor:pointer}.member-list__popover .more-modal__list .more-modal__row .more-modal__actions{padding:0;margin-left:12px;opacity:1}.member-list__popover .more-modal__list .more-modal__row .more-modal__actions button{width:2em;height:2em;border-radius:4px;line-height:0;opacity:0}.member-list__popover .more-modal__list .more-modal__row .more-modal__actions button:hover{background-color:rgba(var(--button-bg-rgb), 0.24)}.member-list__popover .more-modal__list .more-modal__row .more-modal__actions button:active{background-color:rgba(var(--button-bg-rgb), 0.32)}.member-list__popover .more-modal__list .more-modal__row .more-modal__actions button.a11y--focused{opacity:1}.member-list__popover .more-modal__list .more-modal__row:hover{padding-left:17px;border-left:3px solid transparent}.member-list__popover .more-modal__list .more-modal__row:hover .more-modal__actions button{opacity:1}.member-list__popover .more-modal__list .more-modal__row:hover .more-modal__name{font-weight:600}.member-list__popover .more-modal__list .more-modal__row.more-modal__row--button{position:relative;height:40px;border-left:none}.member-list__popover .more-modal__list .more-modal__row.more-modal__row--button button{position:absolute;top:0;left:0;width:100%;height:100%;font-weight:500}.member-list__popover .more-modal__list .more-modal__row .shared-user-icon{margin-top:5px;color:rgba(61,60,64,.56);font-size:16px}.member-list__popover .more-modal__list .more-modal__name{display:block;font-size:13.5px;font-weight:normal}.member-list__popover .more-modal__list .more-modal__image{position:relative;top:-1px;margin:0}.member-list__popover .more-modal__list .more-modal__details{padding-left:16px;line-height:39px}.member-list__popover .more-modal__list .more-modal__details .shared-user-icon{width:16px;height:16px;margin-top:16px;margin-left:8px;color:rgba(61,60,64,.72);font-size:16px;line-height:16px}.member-list__popover .more-modal__list .more-modal__details .shared-user-icon::before{margin:0}.member-list__popover .more-modal__list .more-modal__actions{margin:0;line-height:42px;opacity:0}.member-list__popover .more-modal__list .more-modal__actions .icon{position:relative;top:2px}.member-list__popover .popover-content{position:relative;width:260px;max-height:380px;padding:0}.member-list__popover .popover-content .text-nowrap{overflow:hidden;width:100%;padding:6px 10px;font-size:13px;line-height:26px}.member-list__popover .popover-content .more__name{overflow:hidden;max-width:140px;margin-left:6px;text-overflow:ellipsis}.channel_search{display:flex}.channel_search .search_input{flex:1;margin-right:16px;margin-left:16px}.channel_search .create_button{margin-right:16px}.app__body .custom-textarea{overflow:hidden;height:100%;min-height:46px;max-height:560px;border:none;background:transparent;border-radius:4px;box-shadow:inset 0 0 0 1px rgba(var(--center-channel-color-rgb), 0.24);line-height:20px;resize:none;transition:none;white-space:pre-wrap;word-wrap:break-word}.app__body .custom-textarea:focus{box-shadow:inset 0 0 0 2px rgba(var(--center-channel-color-rgb), 0.32)}.app__body .custom-textarea.bad-connection{background:#ffffac !important;color:#d04444 !important}.textarea-wrapper{position:relative;min-height:37px}.textarea-wrapper.textarea-wrapper--preview>div:first-child{display:none}.textarea-wrapper .textbox-preview-area{position:relative;z-index:2;top:0;left:0}.textarea-wrapper .textbox-preview-area ul{white-space:normal}.textarea-wrapper .textbox-preview-area:focus{border-color:rgba(var(--center-channel-color-rgb), 0.4)}.textarea-wrapper .textbox-preview-area p{margin:0;white-space:pre-wrap}.textarea-wrapper .textbox-preview-area ul+p,.textarea-wrapper .textbox-preview-area ol+p{margin-top:.6em}.textarea-wrapper .textbox-preview-area p+ul,.textarea-wrapper .textbox-preview-area p+ol{margin-top:.6em}.textarea-wrapper .textbox-preview-link{margin-right:8px}.help__format-text{display:inline-block;font-size:.85em;opacity:0;transition:all .3s ease-in .3s;vertical-align:bottom;white-space:nowrap}.modal .help__format-text{white-space:normal}.help__format-text b,.help__format-text i,.help__format-text span{position:relative;top:-1px;margin:0 2px}.help__format-text b{opacity:.9}.help__format-text code{padding:0;background:transparent}.help__format-text .textbox-preview-link{margin-left:15px;cursor:pointer;font-size:13px}.file-overlay{position:absolute;z-index:13;top:0;left:0;width:100%;height:100%;color:#fff;font-size:1.4285714286em;font-weight:600;pointer-events:none;text-align:center}.file-overlay .overlay__indent{overflow:hidden;*zoom:1;background-color:rgba(0,0,0,.6);position:relative;height:100%}.file-overlay.right-file-overlay{font-size:1.2857142857em}.file-overlay.right-file-overlay .overlay__circle{width:300px;height:300px;margin:-150px 0 0 -150px}.file-overlay.right-file-overlay .overlay__files{width:150px;margin:60px auto 15px}.file-overlay .overlay__circle{position:absolute;top:50%;left:50%;width:370px;height:370px;margin:-185px 0 0 -185px;border-radius:500px;pointer-events:none;background:rgba(0,0,0,.7)}.file-overlay .overlay__files{display:block;margin:75px auto 20px}.file-overlay .overlay__logo{position:absolute;bottom:30px;left:50%;margin-left:-50px;opacity:.3}.file-overlay .fa{display:inline-block;margin-right:8px;font-size:1.1em}#post-list{position:relative;height:100%;flex:1 1 auto;overflow-y:hidden}#post-list .inactive{display:none}#post-list .post-list__loading{padding:1em 0;font-size:.9em;font-style:italic;opacity:.5;text-align:center}#post-list .post-list__loading i{margin-right:2px}#post-list .post-list__loading.post-list__loading-search{cursor:pointer}#post-list .post-list__loading.post-list__loading-search:hover{text-decoration:underline}#post-list .post-list-holder-by-time{position:absolute;width:100%;height:100%;background:var(--center-channel-bg)}#post-list .post-list-holder-by-time.active{display:inline}#post-list .post-list-holder-by-time.normal_post_list{padding:1em 0 0;overflow-y:scroll}#post-list .post-list-holder-by-time.normal_post_list .post-list__table{display:table}#post-list .post-list-holder-by-time.normal_post_list .post-list__content{display:table-cell;height:unset;padding:14px 0 7px;vertical-align:bottom}#post-list .more-messages-text{display:block;width:100%;border:none;margin:5px 0 10px;font-size:13px;outline:none;text-align:center}#post-list .new-messages__button{position:absolute;z-index:3;bottom:0;left:50%;margin:5px auto;font-size:13.5px;opacity:0;text-align:center;transform:translateX(-50%);visibility:hidden}#post-list .new-messages__button .fa{position:relative;top:1px;margin-right:.5rem;font-size:1.2em;font-weight:bold}#post-list .new-messages__button .icon{display:inline-flex;align-items:center;justify-content:center;margin-left:5px}#post-list .new-messages__button div{display:flex;height:28px;align-items:center;padding:0 20px;border-radius:50px;cursor:pointer}body.enable-animations #post-list .new-messages__button{transition-delay:0s;transition-duration:.12s;transition-property:opacity,visibility;transition-timing-function:ease-in,step-end}#post-list .new-messages__button.visible{opacity:1;visibility:visible}body.enable-animations #post-list .new-messages__button.visible{transition-delay:0s;transition-duration:.12s;transition-property:opacity,visibility;transition-timing-function:ease-out,step-start}.post-list__timestamp{position:absolute;z-index:50;top:8px;left:0;display:none;width:100%;opacity:0;pointer-events:none;text-align:center;transform:translateY(-45px);transition:all .6s ease}.post-list__timestamp.scrolling{opacity:.9;transform:translateY(0)}.post-list__timestamp.toastAdjustment{top:50px}.post-list__timestamp>div{display:inline-block;padding:0 8px;border:1px solid rgba(var(--sidebar-header-text-color-rgb), 0.5);background:var(--sidebar-header-bg);border-radius:3px;color:var(--sidebar-header-text-color);font-size:12px;line-height:25px;text-align:center;-webkit-font-smoothing:subpixel-antialiased;-moz-osx-font-smoothing:auto}.post-list__arrows{position:absolute;z-index:50;bottom:0;left:9px;display:none;width:40px;height:40px;background-repeat:no-repeat;fill:#444;opacity:0;text-align:center;transition:all .6s}.post-list__arrows svg{width:28px;height:28px;color:inherit}.post-list__arrows.scrolling{display:block;opacity:1}.post-create-message{padding:15px}.post-create__container{z-index:12;width:100%;flex:0 0 auto;background:var(--center-channel-bg)}.post-create__container label{font-weight:normal}.post-create__container form{width:100%;padding:0 15px 0;margin:0 auto}.post-create__container .center{max-width:1028px}.post-create__container .custom-textarea{bottom:0;max-height:calc(50vh - 40px);padding:13px 0 12px 16px;cursor:auto;resize:none}.post-create__container .custom-textarea:not(.custom-textarea--emoji-picker){padding-right:40px}.post-create__container .custom-textarea.custom-textarea--emoji-picker{padding-right:90px}.post-create__container .custom-textarea.textbox-preview-area{overflow-y:auto}.post-create__container .custom-textarea ::placeholder{color:inherit}.post-create__container .emoji-picker{position:absolute;top:-361px;right:0}.post-create__container .scroll .custom-textarea{overflow:auto;-webkit-overflow-scrolling:touch;-ms-overflow-style:auto}.post-create__container .scroll .custom-textarea:not(.custom-textarea--emoji-picker){padding-right:50px}.post-create__container .scroll .custom-textarea.custom-textarea--emoji-picker{padding-right:90px}.post-create__container .post-create-body{position:relative;padding:0 0 2px}.post-create__container .post-create-body .post-body__cell{position:relative;vertical-align:top}.post-create__container .post-create-body .send-button{display:none;width:45px;height:100%;padding-right:4px;border-left:1px solid transparent;cursor:pointer;font-size:17px;line-height:49px;text-align:center;transition:all .15s;vertical-align:bottom}.post-create__container .post-create-body .send-button:active{opacity:.75}.post-create__container .post-create-body .send-button.disabled i{color:inherit}.android .post-create__container .post-create-body .send-button,.ios .post-create__container .post-create-body .send-button{display:block}.post-create__container .post-create-body .icon--emoji-picker{cursor:pointer;opacity:.5;transition:all .15s}.post-create__container .post-create-body .icon--emoji-picker:hover,.post-create__container .post-create-body .icon--emoji-picker:active{box-shadow:none;opacity:.9}.post-create__container .msg-typing{display:block;overflow:hidden;height:20px;margin-bottom:5px;font-size:.95em;opacity:.7;text-overflow:ellipsis;white-space:nowrap}.post-create__container .channel-archived__message{padding:25px;border-top-width:1px;border-top-style:solid;text-align:center}.post-create__container .channel-archived__close-btn{margin:10px}.post-body__actions{position:absolute;top:0;right:0;display:flex;margin:0 1px 0 0}.post-body__actions>div{margin:0 4px 0 0}.post-body__actions .post-action{display:flex;width:36px;height:36px;align-items:center;justify-content:center;border:none;margin:5px 0;background:transparent;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);fill:rgba(var(--center-channel-color-rgb), 0.56)}.post-body__actions .post-action:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);fill:rgba(var(--center-channel-color-rgb), 0.72)}.post-body__actions .post-action:active,.post-body__actions .post-action--active,.post-body__actions .post-action--active:hover{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.post-body__actions .post-action+input{position:absolute;top:0;right:0;width:100%;height:100%;margin:0;cursor:pointer;direction:ltr;font-size:23px;opacity:0;pointer-events:none}.post-body__actions.btn-file__disabled{opacity:.1}.post-body__actions.btn-file__disabled:hover,.post-body__actions.btn-file__disabled:active{opacity:.1}.post-body__helper-text{display:inline-block;margin:8px 0 4px;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif}.post-create-footer{position:relative;padding:6px 0 0;font-size:13px}.post-create-footer .help__text{text-align:right}.post-create-footer .help__text a,.post-create-footer .help__text button{margin-left:10px}.post-create-footer .post-error{position:absolute;top:4px;display:inline-block;margin-bottom:0;font-size:.85em;font-weight:normal;opacity:.55}.post-list__table{width:100%;height:100%}.post-list__table .post-list__content{overflow:hidden;height:100%}.post-list__table .post-list__content .dropdown-menu.bottom{top:auto;bottom:19px}.post-list__table .loading-screen{position:relative;height:calc(40px + 1em);padding:0}.post{position:relative;overflow:hidden;max-width:100%;padding:8px .5em 0 1.5em;transition:height 200ms,background-color 200ms;word-wrap:break-word}.post:not(.post--editing):not(.post--editing):hover{background-color:rgba(var(--center-channel-color-rgb), 0.04)}.post:not(.post--editing):not(.post--editing):hover .PostAttachmentOpenGraph .remove-button{display:flex}.post .hide-element{display:none}.post.post--editing{overflow:visible;background-color:rgba(var(--button-bg-rgb), 0.08)}.post.post--editing .post--editing__wrapper{position:relative;margin:8px 0 0}.post.post--editing .post--editing__wrapper.scroll .custom-textarea{overflow:auto;-webkit-overflow-scrolling:touch;-ms-overflow-style:auto}.post.post--editing .post--editing__wrapper.scroll .post-body__actions{right:10px}.post.post--editing .custom-textarea{max-height:calc(50vh - 40px);padding:13px 0 12px 16px;background-color:var(--center-channel-bg)}.post.post--editing .custom-textarea.custom-textarea--emoji-picker{padding-right:50px}.post.post--editing .post__body{position:relative;overflow:visible;background:transparent}.browser--ie .post .post__header .col__reply .comment-icon__container{flex:0 1 auto;align-items:center}.browser--ie .post .post__header .col__reply>.open,.browser--ie .post .post__header .col__reply>div{flex:0 1 30px;align-items:center}.browser--ie .post .post__header .col__reply>.open:first-child,.browser--ie .post .post__header .col__reply>div:first-child{flex:0 1 25px}.post.post--system .post__header .post-menu{min-width:0}.post:hover,.post.a11y--active{overflow:visible}.post:hover .dropdown,.post:hover .comment-icon__container,.post:hover .card-icon__container,.post:hover .reacticon,.post:hover .post-menu__item,.post:hover .post__reply,.post:hover .post-reaction,.post:hover .post__remove,.post.a11y--active .dropdown,.post.a11y--active .comment-icon__container,.post.a11y--active .card-icon__container,.post.a11y--active .reacticon,.post.a11y--active .post-menu__item,.post.a11y--active .post__reply,.post.a11y--active .post-reaction,.post.a11y--active .post__remove{visibility:visible}.post:hover .permalink-icon,.post.a11y--active .permalink-icon{visibility:visible}.post:hover .post-add-reaction .Reaction,.post.a11y--active .post-add-reaction .Reaction{opacity:1;visibility:visible}.post.post--hovered,.post.a11y--active{overflow:visible}.post.post--hovered .dropdown,.post.post--hovered .comment-icon__container,.post.post--hovered .card-icon__container,.post.post--hovered .post__reply,.post.post--hovered .post__remove,.post.post--hovered .post__dropdown,.post.post--hovered .reacticon__container,.post.post--hovered .permalink-icon,.post.a11y--active .dropdown,.post.a11y--active .comment-icon__container,.post.a11y--active .card-icon__container,.post.a11y--active .post__reply,.post.a11y--active .post__remove,.post.a11y--active .post__dropdown,.post.a11y--active .reacticon__container,.post.a11y--active .permalink-icon{visibility:visible}.post.post--hovered .post__body,.post.a11y--active .post__body{background:transparent !important}.post.post--hovered .search-item-snippet,.post.a11y--active .search-item-snippet{overflow:visible}.post.post--hide-controls .post__header .post-menu{display:none}.post.post--thread.same--user{padding:0 .5em 0 1em}.post.post--thread.same--user .post__header,.post.post--thread.same--user .post-preview__header{margin-bottom:0}.post.post--thread.same--user .post__header .post__header--info,.post.post--thread.same--user .post-preview__header .post__header--info{position:absolute;left:-5px}.post.post--thread.same--user .post__header .post__header--info .post__time,.post.post--thread.same--user .post-preview__header .post__header--info .post__time{position:absolute;top:4px;left:-14px;display:inline-block;width:51px;font-size:.7em;line-height:20px;text-align:right;text-rendering:auto}.post.post--compact.post--thread .post__header{padding-top:3px}.post.post--compact.post--system .status{visibility:hidden}.post.post--compact.post--system>div{margin-bottom:0}.post.post--compact .card-icon__container{margin:0 7px 0 -4px}.post.post--compact .post-message{overflow:inherit}.post.post--compact .post-message--collapsed+.post-image__columns::before{position:absolute;top:0;left:0;width:100%;height:100%;content:""}.post.post--compact .post__img{width:16px;padding-top:1px}.post.post--compact .post__img img{display:none}.post.post--compact .attachment{padding-top:1px;clear:both;cursor:default}.post.post--compact .attachment.attachment--pretext{padding:0;clear:none}.post.post--compact .attachment .attachment__body__wrap .btn-close{left:-2px}.post.post--compact.post--comment .attachment .attachment__body__wrap .btn-close{left:-13px}.post.post--compact .auto-responder{background:rgba(255,255,255,.7)}.post.post--compact .post__img .status-wrapper{cursor:auto;pointer-events:none}.post.post--compact .ThreadFooter .status-wrapper{height:24px}.post.post--compact .status-wrapper{height:14px}.post.post--compact .status-wrapper .status{position:relative;top:auto;right:auto;bottom:auto;left:-2px;width:13px;height:13px}.post.post--compact .status-wrapper svg{top:1px}.post.post--compact .status-wrapper::after{bottom:0}.post.post--compact blockquote{display:flex;flex-direction:column;padding:3px 0 3px 20px}.post.post--compact blockquote::before{top:0;left:0;font-size:15px}.post.post--compact .search-item-snippet blockquote{margin-top:0}.post.post--compact .markdown__heading{margin:0;clear:both;font-size:1em}.post.post--compact .post__header,.post.post--compact .post-preview__header{display:flex;width:auto;max-height:22px;padding:0;margin-bottom:0}.post.post--compact .post__body{padding:2px 0 0;background:transparent !important;line-height:1.5}.post.post--compact .post__body .img-div{max-width:150px;max-height:150px}.post.post--compact .post__body p{line-height:inherit}.post.post--compact .post__body ol,.post.post--compact .post__body ul{padding-left:20px;clear:both}.post.post--compact .post__body div:not(.image-loading__container){margin-bottom:0}.post.post--compact .post__body .post-image__column{padding:0;margin:3px 10px 3px 0}.post.post--compact .post-image__column{min-width:150px;max-width:250px;height:26px;padding:0 7px;border-radius:2px;font-size:.9em;line-height:25px}.post.post--compact .post-image__column .post-image__thumbnail{display:none}.post.post--compact .post-image__column .post-image__details{width:100%;padding:0;border:none;background:transparent}.post.post--compact .post-image__column .post-image__details span{display:none}.post.post--compact .post-image__column .post-image__details svg{position:relative;top:2px}.post.post--compact .post-image__column .post-image__details .icon{display:block;margin-right:5px;float:left;opacity:.6}.post.post--compact .post-image__column .post-image__download{position:relative;width:auto;padding:0;opacity:1}.post.post--compact .post-image__column .post-image__name{overflow:hidden;*zoom:1;display:block;width:100%;padding:0 5px;margin:0;text-overflow:ellipsis;white-space:nowrap}.post.post--compact .post-image__column .post-image__name i{margin-right:5px;font-size:.9em;opacity:.5}.post.post--compact .post-image__column a:hover{text-decoration:none}.post .post__img>:hover{cursor:pointer}.post .post--fail{position:relative}.post .post-edited__indicator{display:inline-block;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:11px;font-style:italic;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.post .post-edited__indicator>i{margin-right:2px}.post .emoticon,.post .emoticon--post-menu{vertical-align:top}.post p{width:100%;margin:0;font-size:13.5px;line-height:1.6em;white-space:pre-wrap;word-break:break-word}.post .post__header--info{padding:0}.post.post--root .comment-icon__container{visibility:visible}.post.post--comment .post__body{padding-left:7px;border-left:4px solid rgba(0,0,0,.3)}.post.post--comment .post__body.mention-comment{border-color:#ff0;border-left:4px solid #ff0}.post.post--comment .attachment .attachment__body__wrap .btn-close{left:-11px}.post.same--root.same--user{padding:0 .5em 0 1.5em}.post.same--root.same--user:hover .post__time,.post.same--root.same--user.post--hovered .post__time,.post.same--root.same--user.a11y--active .post__time{opacity:.5}.post.same--root.same--user .post__img .status-wrapper{display:none}.post.same--root.same--user .post__header{height:0;margin:0}.post.same--root.same--user .post__header .col__name{display:none}.post.same--root.same--user .post__header .post-menu{top:-1px}.post.same--root.same--user .post-pre-header{padding-top:5px;padding-bottom:5px}.post.same--root.post--comment .post__link{display:none}.post.same--root.post--comment.same--user .post__img .status-wrapper{display:none}.post.same--root.post--comment.same--user.post--bot .post__header{height:auto;float:none}.post.same--root.post--comment.same--user.post--bot.post--compact .post__header{float:left}.post.same--root.post--comment.same--user.post--bot .col__name{display:flex}.post.same--root.post--comment.same--user.post--bot .post__permalink{position:relative;top:auto;left:auto;width:auto}.post.same--root.post--comment.same--user.post--bot .post__time{opacity:.6}.post.same--root.post--comment.same--user.post--bot .post__img .status-wrapper{display:inline}.post.other--root .comment-icon__container.icon--show{visibility:visible}.post.other--root.post--comment .popover{margin-top:84px}.post.other--root.post--comment .popover>.arrow{top:21px !important}.post.other--root.post--comment .post__header .post-menu{top:-4px}.post .post-pre-header{display:flex;height:25px;padding-bottom:10px}.post .post-pre-header .post-pre-header__icons-container{display:flex;width:52px;align-items:center;justify-content:flex-end;padding-right:9px;margin-left:5px}.post .post-pre-header .post-pre-header__icons-container .icon--post-pre-header{width:10px;height:10px;color:var(--link-color);fill:var(--link-color);font-size:12px}.post .post-pre-header .post-pre-header__icons-container .icon--post-pre-header:nth-of-type(even){margin-left:9px}.post .post-pre-header .post-pre-header__icons-container .icon--post-pre-header.icon-pin::before{line-height:10px}.post .post-pre-header .post-pre-header__text-container{color:var(--link-color);font-size:12px;line-height:15px}.post .post-pre-header .post-pre-header__text-container .post-pre-header__link-separator{margin:0 5px;color:rgba(var(--center-channel-color-rgb), 0.32);font-size:4px;vertical-align:top}.post .post__content{position:relative;display:table;width:100%;padding:0 8px 0 5px;margin:0 auto;table-layout:fixed}.post .post__content>div{display:table-cell;vertical-align:top}.post .center{max-width:1000px}.post .post__header,.post .post-preview__header{display:flex;width:100%;margin-bottom:2px;white-space:nowrap}.post .post__header .col__name,.post .post-preview__header .col__name{display:flex;min-width:0;flex:0 auto;margin-right:8px;font-weight:600;text-overflow:ellipsis}.post .post__header .col__name.permalink--username,.post .post-preview__header .col__name.permalink--username{margin-right:6px}.post .post__header .col__name .user-popover,.post .post-preview__header .col__name .user-popover{overflow:hidden;*zoom:1;text-align:left;text-overflow:ellipsis;-moz-user-select:all;vertical-align:top;white-space:nowrap}.post .post__header .col__name .colon,.post .post-preview__header .col__name .colon{display:none;margin-left:2px;font-weight:900}.post .post__header .col__remove,.post .post-preview__header .col__remove{position:absolute;right:10px}.post .post__header .permalink-popover,.post .post-preview__header .permalink-popover{min-width:0}.post .post__header .permalink-popover .popover-content,.post .post-preview__header .permalink-popover .popover-content{padding:5px}.post .post__header .permalink-popover .form-control,.post .post__header .permalink-popover .btn,.post .post-preview__header .permalink-popover .form-control,.post .post-preview__header .permalink-popover .btn{height:30px;padding:0 8px;font-size:13px;line-height:30px}.post .post__header .shared-user-icon,.post .post-preview__header .shared-user-icon{width:16px;height:20px;margin:0 0 0 4px;color:rgba(61,60,64,.72);font-size:16px;line-height:20px}.post .post__header .shared-user-icon::before,.post .post-preview__header .shared-user-icon::before{margin:0}.post .post__img{width:53px;padding-right:10px;text-align:right}.post .post__img .icon{fill:var(--center-channel-color)}.post .post__img .icon svg{width:32px;height:32px}.post .post__img path{fill:currentColor}.post .post__img .profile-icon{display:inline-flex;overflow:hidden;align-items:center;justify-content:center}.post .post__img .profile-icon.emoji img{width:28px;min-width:28px;height:28px;border-radius:unset;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.post .post__embed-container{display:block;overflow:hidden;max-height:1000px;padding-top:5px;transition:max-height 500ms ease}.post .post__embed-container[hidden]{max-height:0}.post .dropdown{top:-1px;display:inline-block;vertical-align:middle;visibility:hidden}.post .dropdown:last-child{margin-right:0}.post .dropdown .dropdown-menu{top:20px;right:0;left:auto;min-width:130px;padding:2px 0}.post .dropdown .dropdown-menu li{display:block}.post .dropdown .dropdown-menu a{padding:5px 15px}.post .post__remove{position:relative;right:-10px;color:inherit;font-size:20px;font-weight:600;line-height:20px;opacity:.5;visibility:hidden}.post .post__remove:hover{opacity:.8}.post .post-add-reaction{display:inline-block}.post .post-add-reaction .Reaction{opacity:0;visibility:hidden}.post .post__body{width:100%;padding:0 0 .2em;word-wrap:break-word}.post .post__body.post--ephemeral{padding-right:20px !important}.post .post__body p+p{margin:.5em 0 0}.post .post__body ul,.post .post__body ol{font-size:13.5px}.post .post__body ul p,.post .post__body ol p{margin-bottom:0}.post .post__body ul li p,.post .post__body ol li p{display:inline}.post .post__body ul li ul,.post .post__body ol li ul{padding:0 0 0 20px;margin:0;font-size:1em}.post .post__body ul li.list-item--task-list ul,.post .post__body ul li.list-item--task-list ol,.post .post__body ol li.list-item--task-list ul,.post .post__body ol li.list-item--task-list ol{margin-left:20px}.post .post__body ul li.list-item--task-list ul,.post .post__body ol li.list-item--task-list ul{padding-left:0}.post .post__body ul li:not(.list-item--task-list) li.list-item--task-list,.post .post__body ul li:not(.list-item--task-list) li.list-item--task-list~li,.post .post__body ol li:not(.list-item--task-list) li.list-item--task-list,.post .post__body ol li:not(.list-item--task-list) li.list-item--task-list~li{margin-left:-20px}.post .post__body ul li input[type=checkbox]:disabled,.post .post__body ol li input[type=checkbox]:disabled{cursor:default;vertical-align:top}.post .post__body ul li.list-item--task-list,.post .post__body ul li.list-item--task-list~li{list-style-type:none}.post .post__body ul li.list-item--task-list~li:not(.list-item--task-list){text-indent:3px}.post .post__body ul li.list-item--task-list~li:not(.list-item--task-list)::before{margin-right:8px;content:"•"}.post .post__body ul+p,.post .post__body ol+p{margin-top:.6em}.post .post__body p+ul,.post .post__body p+ol{margin-top:.6em}.post .post__body .pending-post-actions{position:absolute;z-index:100;top:0;right:0;padding:5px 7px;background:rgba(0,0,0,.7);color:#fff;font-size:.9em}.post .post__body .pending-post-actions a{color:#fff}.post .post-reaction-list{position:relative;z-index:5;display:flex;min-height:30px;flex-wrap:wrap;align-items:center;padding:4px 0 0}.post .post-reaction-list .post-add-reaction-emoji-picker-open{display:inline-block}.post .post-reaction-list .post-add-reaction-emoji-picker-open .Reaction{opacity:1;visibility:visible}.post .post-add-reaction-emoji-picker-open .Reaction{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.post .post__link{overflow:hidden;margin:2px 0 5px;font-size:13px;text-overflow:ellipsis;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;white-space:nowrap}.post .post__link a{font-weight:bold}.post .post__link a.user_name:hover{text-decoration:none}.post .post__embed-visibility{position:relative;z-index:2;display:inline-block;width:2.4rem;height:1.6rem;margin:0;cursor:pointer;font:normal normal normal 14px/1 FontAwesome;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;text-rendering:auto}.post .post__embed-visibility.pull-left{margin:2px 0 0 -4px}.post .post__embed-visibility:hover{text-decoration:none}.post .post__embed-visibility::before{content:""}.post .post__embed-visibility[data-expanded=true]::before{content:""}.post .post__visibility{padding:4px;font-size:.9em;opacity:.6}.post .image-preview-utility-buttons-container{position:absolute;z-index:3;top:8px;right:8px;display:none;padding:4px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg);border-radius:4px;box-shadow:var(--elevation-1)}.post .image-preview-utility-buttons-container button.size-aware-image__copy_link,.post .image-preview-utility-buttons-container a.size-aware-image__download{display:inline-block;width:28px;height:28px;padding:2px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);text-align:center}.post .image-preview-utility-buttons-container button.size-aware-image__copy_link:hover,.post .image-preview-utility-buttons-container a.size-aware-image__download:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);text-decoration:none}.post .image-preview-utility-buttons-container button.size-aware-image__copy_link svg,.post .image-preview-utility-buttons-container a.size-aware-image__download svg{padding-top:2px;fill:rgba(var(--center-channel-color-rgb), 0.56)}.post .image-preview-utility-buttons-container button.size-aware-image__copy_link .svg-check,.post .image-preview-utility-buttons-container a.size-aware-image__download .svg-check{fill:var(--online-indicator)}.post .image-preview-utility-buttons-container button.size-aware-image__copy_link:active,.post .image-preview-utility-buttons-container a.size-aware-image__download:active{background:rgba(var(--button-bg-rgb), 0.08)}.post .image-preview-utility-buttons-container button.size-aware-image__copy_link:active svg,.post .image-preview-utility-buttons-container a.size-aware-image__download:active svg{fill:var(--button-bg)}.post .image-preview-utility-buttons-container button.size-aware-image__copy_link--recently_copied{background:rgba(var(--online-indicator-rgb), 0.16)}.post .image-preview-utility-buttons-container button.size-aware-image__copy_link--recently_copied:hover{background:rgba(var(--online-indicator-rgb), 0.16)}.post .image-preview-utility-buttons-container--small-image{position:absolute;top:-8px;left:24px;width:68px}.post .image-preview-utility-buttons-container--small-image-no-copy-button{left:32px;width:38px}.post .image-preview-utility-buttons-container:hover button.size-aware-image__copy_link,.post .image-preview-utility-buttons-container:hover a.size-aware-image__download{color:rgba(var(--center-channel-color-rgb), 0.72)}.post .image-loaded-container{position:relative;display:inline-block}.post .image-loaded-container:hover .image-preview-utility-buttons-container{display:inline-block}.post .small-image-utility-buttons-wrapper:hover .image-preview-utility-buttons-container{display:inline-block}.post .post__time,.post .post-preview__time{margin-right:4px;font-size:.9em;opacity:.6}.post .post__permalink{display:inline-block;color:inherit}.post .post__permalink:hover,.post .post__permalink:focus{color:inherit}.post .post__permalink:focus{text-decoration:none}.post .post__permalink:hover{text-decoration:underline}.post .post_permalink_mobile_view{display:inline-block;color:inherit}.post .post_permalink_mobile_view:hover,.post .post_permalink_mobile_view:focus{color:inherit;text-decoration:none}.post .post-loading-gif{width:10px;height:10px;margin-top:6px}.post .post-fail{color:#d58a8a}.post .post-waiting{position:relative;color:#999}.post .post-waiting .spinner{position:absolute;top:4px;right:8px;width:20px}.post .post-waiting .post-message{padding-right:24px}.post .permalink-icon{display:inline-block;color:#166de0;visibility:hidden}.post .post__reply{display:inline-block;margin-right:6px;visibility:hidden}.post .post__reply svg{position:relative;top:3px;width:18px;fill:currentColor}.post .comment-icon__container{position:relative;top:1px;display:inline-block;fill:#166de0;text-decoration:none;visibility:hidden}.post .comment-icon__container:focus{outline:none}.post .comment-icon__container.icon--visible{visibility:visible}.post .comment-icon__container svg{width:17px;height:17px}.post .comment-icon__container .comment-count{margin-left:2px}.post .comment-icon__container .comment-icon{position:relative;top:1px;display:inline-block;margin:0 1px 0 5px;fill:currentColor;vertical-align:top}.post .comment-icon__container path{fill:currentColor}.post .reacticon__container{display:inline-block;fill:#166de0;font-size:16px;vertical-align:top;visibility:hidden}.post .reacticon__container svg{position:relative;top:1px;width:14px;height:14px}.post .card-icon__container{position:relative;z-index:1;top:2px;margin:0 6px 0 4px;opacity:.24;vertical-align:top}.post .card-icon__container:hover{opacity:.4}.post .card-icon__container.active{opacity:1}.post .card-icon__container svg{width:14px;height:14px}.post .web-embed-data{overflow:hidden;height:50px;padding:2px 0 0 10px;border-radius:2px;text-overflow:ellipsis;background:rgba(0,0,0,.05)}.post .web-embed-data .embed-title{overflow:hidden;margin:3px 0 1px;color:#555;font-weight:600;text-overflow:ellipsis;white-space:nowrap}.post .web-embed-data .embed-description{overflow:hidden;margin:0;color:#888;text-overflow:ellipsis;white-space:nowrap}.post .web-embed-data .embed-link{display:none}.post .post-preview .post__img{width:24px;padding:0;text-align:left}.post .post-preview .post__img img.avatar-post-preview{display:block}.post .post-preview .post-message__text-container{overflow:hidden}.post .post-preview .post-message--collapsed.post-message-preview--overflow .post-message__text{display:-webkit-box;overflow:hidden;-webkit-box-orient:vertical;-webkit-line-clamp:4;text-overflow:ellipsis;white-space:nowrap}.post .post-preview .post-preview-collapse__show-more-button{padding:0;border:none;background:none;font-size:12px}.post .post-preview .post-image__columns div.post-image__column{margin:12px 12px 0 0}.post .post-preview .post__preview-footer{display:block;padding-top:8px}.post .post-preview .post__preview-footer p{display:inline-block;width:auto;margin-right:8px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:12px;line-height:16px}.post .post-preview .post__preview-footer a{display:inline-block;font-size:12px;line-height:16px}.post .Menu .MenuItem{background:var(--center-channel-bg)}.Badge .badge-autocomplete{display:inline;padding:0 5px;margin:0 4px}.Badge .badge-popoverlist{display:inline;margin:0 4px}.Badge .badge-admin{display:inline;margin:0 4px;background:rgba(61,60,64,.15)}.permalink-text{overflow:hidden}.permalink-popover{min-width:320px;margin-left:50px !important}.post-message{position:relative;overflow:hidden;overflow:clip}.post-collapse{position:absolute;bottom:0;width:100%;pointer-events:none}.post-collapse .post-collapse__gradient,.post-collapse .post-attachment-collapse__gradient{position:relative;background:linear-gradient(rgba(var(--center-channel-bg-rgb), 0), var(--center-channel-bg))}.post-collapse .post-collapse__show-more,.post-collapse .post-attachment-collapse__show-more{background:var(--center-channel-bg);pointer-events:auto}.post-collapse__show-more{padding-bottom:10px;background:var(--center-channel-bg)}.post-collapse__show-more,.post-attachment-collapse__show-more{z-index:5;display:flex;width:100%;justify-content:center}.post-collapse__show-more .post-collapse__show-more-button,.post-attachment-collapse__show-more .post-collapse__show-more-button{position:relative;display:inline-block;flex-shrink:0;padding:0 8px;border:1px solid transparent;margin:0 8px;background:var(--center-channel-bg);border-radius:2px;font-size:13px;font-weight:bold;line-height:24px;transition:all .15s ease}.post-collapse__show-more .post-collapse__show-more-button:hover,.post-attachment-collapse__show-more .post-collapse__show-more-button:hover{color:var(--center-channel-bg)}.post-collapse__show-more .post-collapse__show-more-button .fa,.post-attachment-collapse__show-more .post-collapse__show-more-button .fa{position:relative;top:2px;margin-right:5px;font-size:1.4em;font-weight:bold}.post-collapse__show-more .post-collapse__show-more-button .fa.fa-angle-up,.post-attachment-collapse__show-more .post-collapse__show-more-button .fa.fa-angle-up{top:1px}.post-collapse__show-more .post-collapse__show-more-button:focus,.post-attachment-collapse__show-more .post-collapse__show-more-button:focus{outline:none}.post-collapse__show-more .post-collapse__show-more-line,.post-attachment-collapse__show-more .post-collapse__show-more-line{display:inline-block;height:1px;flex-basis:200px;margin-top:12px}.sidebar-right__card .post-message--collapsed{max-height:150px}.post-message--collapsed .post-message__text-container{max-height:600px}.post-message--collapsed .post-message__text-container .all-emoji .emoticon,.post-message--collapsed .post-message__text-container .all-emoji .emoticon--post-menu{min-width:32px;min-height:32px;vertical-align:top}.post-message--collapsed .post-message__text-container .all-emoji .emoticon--unicode{font-size:32px;line-height:1.1}.os--windows .post-message--collapsed .post-message__text-container .all-emoji .emoticon--unicode{position:relative;left:-4px;font-size:29px}.post-message--collapsed .post-collapse__gradient,.post-message--collapsed .post-attachment-collapse__gradient{height:90px}.post-message--collapsed .post-collapse__show-more{bottom:10px}.post-message--expanded .post-collapse{position:relative}.post-message--expanded .post-collapse__show-more,.post-message--expanded .post-attachment-collapse__show-more{position:relative;padding-top:10px}.post-message--expanded .post-collapse__gradient,.post-message--expanded .post-attachment-collapse__gradient{height:0}.post-message__text{text-align:left}.post-message__text>ul,.post-code,.table-responsive{direction:ltr}.file-attachment-menu-item-input{position:absolute;top:0;right:0;width:0;height:35px;margin:0;cursor:pointer;direction:ltr;font-size:23px;opacity:0;pointer-events:none}.post-row__padding.bottom>div:not(.post){padding-bottom:1em}.post-row__padding.top>div:not(.post){padding-top:1em}.post-row__padding.top .post{padding-top:22px}.post-row__padding.top .post.same--root.same--user{padding-top:1em}.post-row__padding.bottom .post{padding-bottom:1em}.post-row__padding.bottom .post.same--root.same--user{padding-bottom:1em}.post-list__dynamic{overflow-x:hidden}.emoji-picker--active .post-list__dynamic{pointer-events:none}@keyframes postHighlight{100%{background:initial}}.app__body .app__content .post.post--highlight{animation-delay:5s;animation-duration:2s;animation-fill-mode:forwards;animation-name:postHighlight}.app__body .post-list__table .post:not(.current--user).post--highlight .post-collapse__gradient,.app__body .post-list__table .post.post--compact.post--highlight .post-collapse__gradient{background:linear-gradient(rgba(var(--mention-highlight-bg-mixed-rgb), 0.5), rgba(var(--mention-highlight-bg-mixed-rgb), 0.5))}.app__body .post-list__table .post.current--user.post--highlight:not(.post--compact) .post-collapse__gradient{background:linear-gradient(rgba(var(--center-channel-bg-rgb), 0), rgba(var(--mention-highlight-bg-mixed-rgb), 1))}.app__body .post-list__table .post.current--user.post--highlight:not(.post--compact) .post-collapse__show-more{background:rgba(var(--mention-highlight-bg-mixed-rgb), 1)}.app__body .post-list__table .post.current--user.post--highlight:hover .post-collapse__gradient,.app__body .post-list__table .post.current--user.post--highlight.post--hovered .post-collapse__gradient{background:linear-gradient(rgba(var(--mention-highlight-bg-mixed-rgb), 0.5), rgba(var(--mention-highlight-bg-mixed-rgb), 1))}.post--pinned-or-flagged{background-color:rgb(var(--pinned-highlight-bg-mixed-rgb))}.post--pinned-or-flagged .post-collapse .post-collapse__gradient,.post--pinned-or-flagged .post-collapse .post-attachment-collapse__gradient{position:relative;background:linear-gradient(transparent, rgb(var(--pinned-highlight-bg-mixed-rgb)))}.post--pinned-or-flagged .post-collapse .post-collapse__show-more,.post--pinned-or-flagged .post-collapse .post-attachment-collapse__show-more{background:rgb(var(--pinned-highlight-bg-mixed-rgb));pointer-events:auto}.post-menu{position:absolute;z-index:6;top:-12px;right:0;display:flex;justify-content:flex-end;padding:4px;border:1px solid transparent;border-radius:4px;white-space:normal}.post-menu__item{display:inline-flex;width:28px;height:28px;align-items:center;justify-content:center;border:none;background:transparent;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.4);fill:rgba(var(--center-channel-color-rgb), 0.4)}.post-menu__item:active,.post-menu__item--active,.post-menu__item--active:hover{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.post-menu__item span{display:flex}.post-menu__item--show{display:block}.post-menu__item--wide{width:auto;padding:0 6px}.post-menu__item--selected{color:var(--link-color);fill:var(--link-color)}.post-menu__comment-count{margin:0 0 0 2px;font-weight:600;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.post-menu__emoticon{cursor:pointer}@media(min-width: 768px){.post-menu__item{display:none}.post-menu__item--show{display:block}.post:hover .post-menu,.post.post--hovered .post-menu,.post.a11y--active .post-menu{border-color:rgba(var(--center-channel-color-rgb), 0.08);background-color:var(--center-channel-bg);box-shadow:var(--elevation-1)}.post:hover .search-item__jump,.post.post--hovered .search-item__jump,.post.a11y--active .search-item__jump{color:rgba(var(--center-channel-color-rgb), 0.56)}.post:hover .search-item__jump:hover,.post.post--hovered .search-item__jump:hover,.post.a11y--active .search-item__jump:hover{color:var(--link-color)}.post:hover .post-menu__item,.post.post--hovered .post-menu__item,.post.a11y--active .post-menu__item{display:inline-flex;color:rgba(var(--center-channel-color-rgb), 0.56);fill:rgba(var(--center-channel-color-rgb), 0.56)}.post:hover .post-menu__item:hover,.post.post--hovered .post-menu__item:hover,.post.a11y--active .post-menu__item:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72);fill:rgba(var(--center-channel-color-rgb), 0.72)}.post:hover .post-menu__item:active,.post:hover .post-menu__item--active,.post:hover .post-menu__item--active:hover,.post.post--hovered .post-menu__item:active,.post.post--hovered .post-menu__item--active,.post.post--hovered .post-menu__item--active:hover,.post.a11y--active .post-menu__item:active,.post.a11y--active .post-menu__item--active,.post.a11y--active .post-menu__item--active:hover{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}}.post-right__container,.ThreadViewer{display:flex;flex-direction:column}.post-right__container .post-right-root-message,.ThreadViewer .post-right-root-message{padding:1em 1em 0}.post-right__container .post-right-comments-container,.ThreadViewer .post-right-comments-container{position:relative}.post-right__container .post-right-comments-container .post:hover+.Separator .separator__hr,.ThreadViewer .post-right-comments-container .post:hover+.Separator .separator__hr{overflow:visible}.post-right__container .post-right-comments-container .post:hover+.Separator .separator__hr::before,.ThreadViewer .post-right-comments-container .post:hover+.Separator .separator__hr::before{position:absolute;top:-16px;left:0;width:100%;height:16px;background:rgba(var(--center-channel-color-rgb), 0.04);content:""}.post-right__container .help__format-text,.ThreadViewer .help__format-text{display:none}.post-right__container .post.post--root,.ThreadViewer .post.post--root{padding-top:2rem}.post-right__container .post.post--root .post__body,.ThreadViewer .post.post--root .post__body{background:transparent !important}.post-right__container .post.post--root.post--compact,.ThreadViewer .post.post--root.post--compact{padding-left:1em}.post-right__container .post .post-pre-header__icons-container,.ThreadViewer .post .post-pre-header__icons-container{width:60px;padding-right:12px;margin-left:0}.post-right__container .post .post__header .post-menu,.ThreadViewer .post .post__header .post-menu{text-align:right}.post-right__container .post .post__header .col__name.Badge,.ThreadViewer .post .post__header .col__name.Badge{flex:none}.post-right__container .post.post--comment .post__body,.ThreadViewer .post.post--comment .post__body{border-left:none}.post-right__container .post .post__content,.ThreadViewer .post .post__content{padding:0 10px 0 0}.post-right__container .post .post__body,.ThreadViewer .post .post__body{width:100%;padding-left:0}.post-right__container .post.post--compact .post__body,.ThreadViewer .post.post--compact .post__body{padding-left:0}.post-right__container .post.post--compact.same--root.post--comment,.ThreadViewer .post.post--compact.same--root.post--comment{padding-left:1em}.post-right__container .post.post--compact.same--root.post--comment .post__header,.ThreadViewer .post.post--compact.same--root.post--comment .post__header{height:auto;margin-left:0;float:none}.post-right__container .post.post--compact.same--root.post--comment .post__header .post__time,.ThreadViewer .post.post--compact.same--root.post--comment .post__header .post__time{opacity:.6}.post-right__container .post.post--compact.same--user .post__header .col__name,.ThreadViewer .post.post--compact.same--user .post__header .col__name{display:inline-block}.post-right__container .post.post--compact .post__img,.ThreadViewer .post.post--compact .post__img{width:16px}.post-right__container .post.post--compact .card-icon__container,.ThreadViewer .post.post--compact .card-icon__container{margin:0 0 0 6px}.post-right__container .post .post__img,.ThreadViewer .post .post__img{width:60px;padding:2px 12px 0 0}.post-right__container .post .post-body img,.ThreadViewer .post .post-body img{max-height:200px}.post-right__container .post .post-preview .post__img,.ThreadViewer .post .post-preview .post__img{width:24px}.post-right__container hr,.ThreadViewer hr{border:none}.post-right__container .post-create__container,.ThreadViewer .post-create__container{width:100%}.post-right__container .post-create__container .btn,.ThreadViewer .post-create__container .btn{margin-bottom:10px}.post-right__container .post-create__container .btn.disabled,.ThreadViewer .post-create__container .btn.disabled{border-color:transparent !important;background:gray !important}.post-right__container .post-create__container .custom-textarea,.ThreadViewer .post-create__container .custom-textarea{min-height:100px;max-height:calc(50vh - 80px)}.post-right__container .post-create__container .msg-typing,.ThreadViewer .post-create__container .msg-typing{display:block;min-width:1px;max-width:230px;height:20px;margin-top:3px;margin-bottom:0;float:left;font-size:13px;line-height:20px;opacity:.7}.post-right__container .post-create__container .post-right-comments-upload-in-progress,.ThreadViewer .post-create__container .post-right-comments-upload-in-progress{padding:6px 0;margin-right:10px;opacity:.7}.post-right__container .post-create__container .emoji-picker,.ThreadViewer .post-create__container .emoji-picker{position:absolute;top:-361px;right:0}.post-right__container .post-create__container form,.ThreadViewer .post-create__container form{padding:0}.post-right__container .post-create__container .post-create,.ThreadViewer .post-create__container .post-create{padding:.5em 15px 0}.post-right__container .post-create__container .post-create-footer .post-error,.ThreadViewer .post-create__container .post-create-footer .post-error{position:relative;top:0;display:inline-block;margin-bottom:0;font-size:.85em;font-weight:normal;opacity:.55}.post-right__container{flex:1}.post-right__container .ThreadViewer{flex:1}.post-right-header{height:39px;padding:10px 10px 0 15px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.12);color:#999;font-size:1em;font-weight:400;text-transform:uppercase}.post-right-root-container{padding:5px 10px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.12)}.post-right-root-container ul{padding-left:0;margin-bottom:2px}.post-right-channel__name{margin:8px 0 12px;font-weight:600}.card-info-channel__name{margin:0 0 15px 14px;font-weight:600}.post-right-root-container li{display:inline;padding-right:3px;list-style-type:none}.post-right-root-time{color:#a8adb7}.post-right-create-comment-container{position:absolute;bottom:0;left:0;width:100%;padding:5px;margin-bottom:18px}.post-right__scroll{position:relative;flex:1 1 auto;padding-top:28px;-webkit-overflow-scrolling:touch}.post-right__scroll .file-preview__container{margin-top:5px}.post-right-comment-time{color:#a8adb7}.react-select .a11y--focused{box-shadow:none}.react-select .react-select__value-container{padding:0 8px}.react-select .react-select__multi-value{align-items:center;margin:4px 4px 4px 0;background:rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:32px;color:var(--sys-center-channel-color)}.app__body .react-select .react-select__multi-value{background:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color)}.react-select .react-select__multi-value__remove{cursor:pointer}.react-select .react-select__multi-value__remove span{display:flex;width:16px;height:16px}.react-select .react-select__multi-value__remove:hover{background:none}.react-select .react-select__multi-value__remove svg{width:16px;height:16px;fill:rgba(var(--sys-center-channel-color-rgb), 0.64);opacity:.6}.react-select .react-select__multi-value__remove svg:hover{fill:rgba(var(--sys-center-channel-color-rgb), 0.8)}.app__body .react-select .react-select__multi-value__remove svg{fill:rgba(var(--center-channel-color-rgb), 0.64)}.app__body .react-select .react-select__multi-value__remove svg:hover{fill:rgba(var(--center-channel-color-rgb), 0.8)}.react-select .react-select__control{height:36px;min-height:36px;border-color:rgba(var(--sys-center-channel-color-rgb), 0.2);background:rgba(var(--sys-center-channel-bg-rgb), 1)}.app__body .react-select .react-select__control{border-color:rgba(var(--center-channel-color-rgb), 0.2);background:var(--center-channel-bg)}.react-select .react-select__control.react-select-auto{width:100%;height:auto}.react-select .react-select__control:hover .react-select__indicator{opacity:.8}.react-select .react-select__control.react-select__control--is-disabled{background:rgba(var(--sys-center-channel-color-rgb), 0.04)}.app__body .react-select .react-select__control.react-select__control--is-disabled{background:rgba(var(--center-channel-color-rgb), 0.04)}.react-select .react-select__padded-component{padding:4px 2px 4px 8px}.react-select .react-select__control--is-focused{border-color:rgba(var(--sys-button-bg-rgb), 1) !important;box-shadow:inset 0 0 0 1px rgba(var(--sys-button-bg-rgb), 1)}.app__body .react-select .react-select__control--is-focused{border-color:rgba(var(--button-bg-rgb), 1) !important;box-shadow:inset 0 0 0 1px rgba(var(--button-bg-rgb), 1)}.react-select .react-select__indicator-separator{background-color:rgba(var(--sys-center-channel-color-rgb), 0.4)}.app__body .react-select .react-select__indicator-separator{background-color:rgba(var(--center-channel-color-rgb), 0.4)}.react-select .react-select__indicator{padding:7px 8px;color:inherit;opacity:.4;transition:opacity .2s ease}.react-select .react-select__single-value{color:inherit}.react-select__input,.react-select .react-select__input{color:var(--sys-center-channel-color)}.app__body .react-select__input,.app__body .react-select .react-select__input{color:var(--center-channel-color)}.react-select__menu,.react-select .react-select__menu{background:var(--sys-center-channel-bg)}.app__body .react-select__menu,.app__body .react-select .react-select__menu{background:var(--center-channel-bg)}.react-select__menu-list,.react-select .react-select__menu-list{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.2);border-radius:4px}.app__body .react-select__menu-list,.app__body .react-select .react-select__menu-list{border:1px solid rgba(var(--center-channel-color-rgb), 0.2)}.react-select__option--is-focused,.react-select .react-select__option--is-focused{background:rgba(var(--sys-button-bg-rgb), 0.08)}.app__body .react-select__option--is-focused,.app__body .react-select .react-select__option--is-focused{background:rgba(var(--center-channel-color-rgb), 0.08)}.react-select__option--is-selected,.react-select .react-select__option--is-selected{background:var(--sys-button-bg);color:var(--sys-button-color)}.app__body .react-select__option--is-selected,.app__body .react-select .react-select__option--is-selected{background:var(--button-bg);color:var(--button-color)}.react-select__option--is-selected:hover,.react-select .react-select__option--is-selected:hover{background:rgba(var(--sys-button-bg-rgb), 0.88)}.app__body .react-select__option--is-selected:hover,.app__body .react-select .react-select__option--is-selected:hover{background:rgba(var(--button-bg-rgb), 0.88)}.react-select__option:active,.react-select .react-select__option:active{background:rgba(var(--sys-button-bg-rgb), 0.16)}.app__body .react-select__option:active,.app__body .react-select .react-select__option:active{background:rgba(var(--button-bg-rgb), 0.16)}.react-select .react-select-top .react-select__menu{top:auto;bottom:100%}.remove-image{position:relative;display:inline-block}.remove-image__img{display:flex;overflow:hidden;width:128px;height:128px;align-items:center;justify-content:center;border:1px solid rgba(0,0,0,.15);background:#fff;border-radius:4px}.remove-image__img img{max-width:100%;max-height:100%}.remove-image__btn{position:absolute;top:-8px;right:-9px;display:flex;width:24px;height:24px;align-items:center;justify-content:center;border:none;background:rgba(0,0,0,.8);border-radius:40px;color:#fff;font-size:20px}.remove-image__btn:hover{background:#000}.remove-image__btn span{margin-left:1px;line-height:0}.save-button .icon{margin-right:10px}::-webkit-scrollbar{width:8px;height:8px}::-webkit-scrollbar-track{background:rgba(0,0,0,.1)}::-webkit-scrollbar-thumb{background:rgba(0,0,0,.2);border-radius:4px}body.app__body{scrollbar-3dlight-color:#7d7e94;scrollbar-arrow-color:#c1c1d1;scrollbar-darkshadow-color:#2d2c4d;scrollbar-face-color:rgba(var(--center-channel-bg-rgb), 0.1);scrollbar-highlight-color:#7d7e94;scrollbar-shadow-color:#2d2c4d;scrollbar-track-color:rgba(var(--center-channel-bg-rgb), 0.1)}body .ps>.ps__scrollbar-y-rail>.ps__scrollbar-y{width:6px !important}body .ps:hover>.ps__scrollbar-y-rail:hover{background:transparent}.scrollbar--horizontal,.scrollbar--vertical{background-color:rgba(var(--sidebar-text-rgb), 0.32);border-radius:2px}.browser--ie .scrollbar--view{margin:0 !important;-ms-overflow-style:none;overflow-x:hidden !important}.browser--ie .scrollbar--view .scrollbar--vertical{visibility:hidden}.search-bar-container--global{width:100%}.search-bar__container{padding:0 4px 0 8px}.sidebar--right .search-bar__container .channel-header__links{line-height:25px}.icon--rotate{animation:spin .7s infinite linear}.search-item-snippet{overflow:hidden;*zoom:1;text-overflow:ellipsis}.search-item-snippet ul,.search-item-snippet ol{padding-left:20px}.search__font-icon{position:absolute;top:0;left:4px;display:flex;height:100%;align-items:center;color:rgba(var(--center-channel-color-rgb), 0.56);pointer-events:none}.search__icon{position:absolute;top:6px;left:9px;fill:rgba(var(--center-channel-color-rgb), 0.56);pointer-events:none}.search__icon svg{width:14px;height:14px}body.enable-animations .search__icon svg{transition:opacity .12s ease-out}.input-clear{position:absolute;top:0;right:0;display:flex;width:2.4rem;height:100%;align-items:center;justify-content:center;margin:0;color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;font-size:16px;visibility:hidden}.input-clear:hover{color:rgba(var(--center-channel-color-rgb), 0.72)}.input-clear:active{color:var(--center-channel-color)}.input-clear.visible{visibility:visible}body.enable-animations .input-clear{transition:opacity .12s ease-out}.search__form{position:relative;display:flex;align-items:center;padding:0;background:rgba(var(--sidebar-text-rgb), 0.08);border-radius:4px}.search__form .searchTypeBadge{position:relative;left:26px;display:flex;align-items:center;justify-content:center;padding:2px 2px 2px 7px;margin:0 6px;background:rgba(var(--sidebar-text-rgb), 0.08);border-radius:4px;color:var(--sidebar-text);font-size:10px;font-weight:700}.search__form .searchTypeBadge .icon-close{padding:2px;cursor:pointer}.search__form .searchTypeBadge:hover{background:rgba(var(--button-bg-rgb), 0.16)}.search__form .search-bar{width:100%;height:28px;padding:3px 2.8rem 2px 3rem;border:none;background:transparent;box-shadow:none;color:rgba(var(--global-header-text-rgb), 0.64);font-size:12px;outline:none}.search__form .search-bar::placeholder{color:rgba(var(--global-header-text-rgb), 0.64);opacity:1}.search__form .search-bar.a11y--focused{box-shadow:none}.search-bar__container .search__form{width:180px;height:32px;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);margin:16px 0 0;border-radius:4px}.search-bar__container .search__form .input-clear{right:4px}.search-bar__container .search__form:hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.4)}.search-bar__container .search__form--focused,.search-bar__container .search__form--focused:hover{padding:0;border:2px solid var(--button-bg)}.search-bar__container .search__form--focused .search__icon,.search-bar__container .search__form--focused:hover .search__icon{top:6px;left:8px}.search-bar__container .search__form--focused .input-clear,.search-bar__container .search__form--focused:hover .input-clear{right:3px}body.enable-animations .search-bar__container .search__form{transition-delay:0s;transition-duration:.12s,.3s;transition-property:border-color,width;transition-timing-function:ease-in-out,ease-out}.inner-wrap.move--left .search__form{width:272px}.search__form .LoadingSpinner{position:absolute;top:4px;right:25px;font-size:1em;opacity:.5}.search__form:hover{background:rgba(var(--sidebar-text-rgb), 0.16)}.search__form.active{background:rgba(var(--sidebar-text-rgb), 0.32)}.search__form:focus-within{background:var(--center-channel-bg)}.search__form:focus-within .search__font-icon,.search__form:focus-within .input-clear-x{color:rgba(var(--center-channel-color-rgb), 0.56)}.search__form:focus-within .searchTypeBadge{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.search__form:focus-within .search-bar{color:rgb(var(--center-channel-color-rgb))}.search__form .search-help-popover{width:432px;max-width:432px}.search__form .search__font-icon,.search__form .input-clear-x{color:rgba(var(--global-header-text-rgb), 0.56)}.search-items-container{position:relative;height:calc(100% - 56px);flex:1 1 auto;padding-top:16px;-webkit-overflow-scrolling:touch}.search-items-container.no-results{display:flex;padding-top:0}.search-items-container div.loading{text-align:center}.search-items-container img{display:inline-block}.search-results-header{height:44px;padding:0 10px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.12);color:#999;font-size:1em;font-weight:400;line-height:44px;text-transform:uppercase}.search-item__container{display:flex;flex-direction:column}.search-item__container .post{padding:0 1em 16px;margin:0}.search-item__container .post:first-child{border:none}.search-item__container .post:hover .post__header{padding-right:105px}.search-item__container .post .post__header{padding-right:70px}.search-item__container .post .search-channel__name__container{display:flex;flex-direction:row;align-items:baseline;padding:16px 0 12px}.search-item__container .post .search-channel__name{overflow:hidden;flex-shrink:1;font-weight:600;opacity:.72;text-overflow:ellipsis;white-space:nowrap}.search-item__container .post .search-channel__archived{flex-shrink:0;float:right;opacity:.5}.search-item__container .post .search-team__name{overflow:hidden;flex-shrink:1;padding:0 8px;border-left:1px solid rgba(var(--center-channel-color-rgb), 0.5);margin:0 0 0 8px;font-size:12px;font-weight:400;opacity:.5;text-overflow:ellipsis;white-space:nowrap}.search-item__container .post .post-pre-header__icons-container{width:53px;padding-right:10px;margin-left:0}.col__controls{position:absolute;top:-9px;right:0;font-size:13px}.col__controls a{vertical-align:top}.col__controls .search-item__jump{position:relative;padding:5px 4px 0;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.4);font-size:12px;font-weight:600;text-decoration:none}.search-item-time{font-size:.9em;opacity:.7}.search-results-none{padding:10px}.search-highlight{background-color:#ff0}.search-hint__title{padding:22px 24px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin:0;font-weight:bold}.search-hint__suggestions-list{padding:8px 0;margin:0;list-style-type:none}.search-hint__suggestions-list__option{display:flex;box-sizing:border-box;justify-content:left;padding:10px 24px;color:var(--center-channel-color);cursor:pointer;text-align:left}.search-hint__suggestions-list__option.highlighted{background:rgba(var(--center-channel-color-rgb), 0.08)}.search-hint__suggestion-list__flex-wrap{width:51px}.search-hint__suggestion-list__label{padding:1px 5px;background:rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;font-size:10px;font-weight:600;letter-spacing:.01em;text-transform:uppercase}.search-hint__suggestion-list__value{margin-left:16px}.search-hint__search-type-selector{padding:18px 24px 8px 24px;font-size:14px;font-weight:600}.search-hint__search-type-selector .button-container{display:flex}.search-hint__search-type-selector button{display:flex;align-items:center;justify-content:center;padding:8px 16px;border:1px solid var(--button-bg);margin:18px 8px 16px 0;background:var(--center-channel-bg);border-radius:4px;color:var(--button-bg);font-size:12px;line-height:1}.search-hint__search-type-selector button .icon{margin-right:6px;font-size:14px}.search-hint__search-type-selector button:hover,.search-hint__search-type-selector button.highlighted{background:rgba(var(--button-bg-rgb), 0.04)}.sidebar--right__subheader ul.search-hint__suggestions-list{padding:10px 0}.sidebar--right__subheader .search-hint__suggestions-list__option:first-child{padding-top:10px}.sidebar--right__subheader .search-hint__suggestions-list__option:hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.status-wrapper{position:relative;display:inline-block;height:32px;align-self:center}.sidebar--left .status-wrapper{width:36px;height:36px}.sidebar--left .status-wrapper .status{right:-6px;bottom:-5px;width:19px;height:19px}.sidebar--left .status-wrapper .status.status-edit .fa{top:4px}.sidebar--left .status-wrapper .status .fa{position:relative;top:2px}.sidebar--left .status-wrapper .status .icon__container::after{position:absolute;top:4px;left:4px;width:10px;height:10px;border-radius:20px;content:""}.sidebar--left .status-wrapper .status svg{position:relative;z-index:1;top:0;left:0;width:13px;height:13px;max-height:initial}.sidebar--left .status-wrapper .status svg.offline--icon,.sidebar--left .status-wrapper .status svg .offline--icon{fill:var(--offline-indicator)}.status-wrapper .status{position:absolute;top:auto;right:-3px;bottom:-4px;width:15px;height:15px;margin:0;background:var(--center-channel-bg);border-radius:100px;line-height:0;visibility:visible}.modal .status-wrapper .status{bottom:-6px}.status-wrapper .status.status-edit{text-align:center;visibility:hidden}.status-wrapper .status.status-edit i{position:relative;top:4px;font-size:10px;opacity:1}.status-wrapper .status svg{position:relative;top:2px;max-height:11px}.status-wrapper .status .dnd--icon{fill:var(--dnd-indicator)}.status-wrapper .status .online--icon{fill:var(--online-indicator)}.status-wrapper .status .away--icon{fill:var(--away-indicator)}.status-wrapper .status .offline--icon{fill:var(--offline-indicator)}.status-selector .status{opacity:1;visibility:visible}body.enable-animations .status-selector .status{transition-delay:0s;transition-duration:.12s;transition-property:opacity,visibility;transition-timing-function:ease-out,step-start}.status-selector .status-edit{opacity:0;visibility:hidden}.status-selector:hover .status{opacity:0;visibility:hidden}.status-selector:hover .status-edit{opacity:1;visibility:visible}.status{position:relative;top:2px;display:inline-block;width:15px;margin:0 7px 0 1px}.status.status--group{top:0;width:15px;height:15px;margin:0 9px 0 -1px;border-radius:2px;font-size:10px;font-weight:600;line-height:14px;text-align:center}.status svg{max-height:14px;backface-visibility:hidden}.status i.online--icon,.status i.away--icon,.status i.dnd--icon,.status path.online--icon,.status path.away--icon,.status path.dnd--icon,.status ellipse.online--icon,.status ellipse.away--icon,.status ellipse.dnd--icon{opacity:1}.status .fa-lock{margin-left:1px}.status .fa-globe{position:relative;top:-1px}.status-dropdown-menu .online--icon>svg{fill:var(--online-indicator)}.status-dropdown-menu .away--icon>svg{fill:var(--away-indicator)}.status-dropdown-menu .dnd--icon>svg{fill:var(--dnd-indicator)}.status-dropdown-menu .offline--icon{fill:var(--offline-indicator)}.app__body .status.status--online{color:var(--online-indicator)}.app__body .status.status--away{color:var(--away-indicator)}.app__body .status .dnd--icon{fill:var(--dnd-indicator)}.app__body .status .online--icon{fill:var(--online-indicator)}.app__body .status .away--icon{fill:var(--away-indicator)}.app__body .status .offline--icon{fill:var(--offline-indicator)}.app__body .sidebar--left .status .offline--icon{fill:var(--offline-indicator)}.app__body .suggestion--selected{background-color:rgba(var(--center-channel-color-rgb), 0.08)}.suggestion-list{z-index:100;width:100%}.post-right__scroll .suggestion-list{margin:0}.suggestion-list .badge{position:absolute;top:8px;right:10px;background:rgba(var(--center-channel-color-rgb), 0.48);color:var(--center-channel-bg);font-size:10px;font-weight:700}.suggestion-list .LoadingSpinner{position:relative;display:flex;height:40px;align-items:center;justify-content:center;margin:0 24px}.suggestion-list .shared-channel-icon{width:16px;height:16px;margin-left:8px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:16px;line-height:16px}.suggestion-list .shared-channel-icon::before{margin:0}.suggestion-list--top{position:absolute;bottom:100%}.suggestion-list--bottom{position:absolute;top:0}.suggestion-list__content{width:496px;max-width:100%;max-height:292px;padding-bottom:12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg);border-radius:4px;box-shadow:0 8px 24px rgba(0,0,0,.12);-webkit-overflow-scrolling:touch;overflow-x:auto;overflow-y:auto}.suggestion-list__content::-webkit-scrollbar-track{width:0;background:transparent}.suggestion-list__content::-webkit-scrollbar-thumb{border:1px solid var(--center-channel-bg);background-color:rgba(var(--center-channel-color-rgb), 0.24) !important;border-radius:4px}.modal .suggestion-list__content{width:100%;max-height:205px}.slash-command{display:flex;align-items:flex-start;padding:1rem 2.4rem}.slash-command:first-child{margin:12px 0 0 0}.slash-command__icon{display:flex;width:3.2rem;height:3.2rem;flex:0 0 3.2rem;align-items:center;justify-content:center;background:rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;font-size:20px;font-weight:600}.slash-command__icon span{opacity:.56}.slash-command__info{margin-left:12px;line-height:1}.slash-command__desc{margin:2px 0 0;font-size:12px;line-height:1.6;opacity:.56}.suggestion-list__content--top{position:absolute;bottom:0}.suggestion-list__content--bottom{position:absolute;top:0}.suggestion-list__divider{position:relative;display:flex;height:2.8rem;align-items:center;justify-content:flex-start;padding:0 0 0 2.4rem;margin:1.2rem 0 0 0;color:rgba(var(--center-channel-color-rgb), 0.6);font-size:1.2rem;font-weight:600;text-transform:uppercase}.suggestion-list__divider:first-child::before{display:none}.suggestion-list__divider::before{position:absolute;top:-7px;left:0;width:100%;height:1px;background:rgba(var(--center-channel-color-rgb), 0.08);content:""}.suggestion-list__no-results{position:relative;margin:7px 10px 2px;line-height:21px}.suggestion-list__no-results>span{position:relative;z-index:5;display:inline-block;padding:0 10px 0 5px;font-size:.9em}.suggestion-list__item{position:relative;z-index:101;display:flex;width:100%;height:4rem;align-items:center;padding:0 2.4rem;margin:0;cursor:pointer;font-size:inherit;line-height:20px;white-space:nowrap}.suggestion-list__item .suggestion-list__ellipsis{overflow:hidden;max-width:89%;color:rgba(var(--center-channel-color-rgb), 0.56);text-overflow:ellipsis;white-space:nowrap}.suggestion-list__item .suggestion-list__ellipsis .suggestion-list__main{overflow:hidden;max-width:89%;color:rgba(var(--center-channel-color-rgb), 1);text-overflow:ellipsis;white-space:nowrap}.suggestion-list__item .suggestion-list__ellipsis .suggestion-list__main .suggestion-list__desc{color:rgba(var(--center-channel-color-rgb), 0.56)}.suggestion-list__item .suggestion-list__flex{display:flex;width:100%;max-width:100%;align-items:center}.suggestion-list__item .suggestion-list__flex .suggestion-list__main{max-width:70%}.suggestion-list__item .suggestion-list__flex .badge{position:unset;display:flex;width:20px;height:16px;margin-left:8px}.suggestion-list__item .suggestion-list__flex .badge-autocomplete,.suggestion-list__item .suggestion-list__flex .shared-channel-icon{margin:0 0 0 8px}.suggestion-list__item .suggestion-list__flex .Badge{margin:0}.suggestion-list__item .suggestion-list_unread-mentions{display:flex;flex:1 1 auto;align-items:center;justify-content:flex-start}.suggestion-list__item .suggestion-list_unread-mentions.position-end{justify-content:flex-end}.suggestion-list__item .suggestion-list__unread{font-weight:bold}.suggestion-list__item .suggestion-list__icon{display:inline-flex;flex:0 0 1.6rem;align-items:center;justify-content:center;fill:var(--center-channel-color);opacity:.56}.suggestion-list__item .suggestion-list__icon--standard{width:2rem;height:2rem;flex:0 0 2.4rem;margin:0 12px 0 0;font-size:1.2rem}.suggestion-list__item .suggestion-list__icon--large{width:2.4rem;height:2.4rem;flex:0 0 2.4rem;margin:0 12px 0 0;font-size:2rem}.suggestion-list__item .suggestion-list__icon .status--group{display:flex;width:1.8rem;height:1.8rem;align-items:center;justify-content:center;margin:0;background-color:rgba(var(--center-channel-color-rgb), 0.2)}.suggestion-list__item .shared-user-icon{width:16px;height:16px;margin-left:8px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:16px;line-height:16px}.suggestion-list__item .shared-user-icon::before{margin:0}.suggestion-list__item .Avatar{display:block;margin-right:12px;text-align:center}.suggestion-list__item .status-wrapper{overflow:visible;height:24px;margin-top:4px;margin-right:12px}.suggestion-list__item .status-wrapper .Avatar.Avatar-sm{margin:0}.suggestion-list__item .status-wrapper .status{right:-4px;bottom:-4px}.suggestion-list__item .status-wrapper .status svg{left:2px;max-width:11px}.suggestion-list__item .suggestion-list__team-name{position:absolute;right:20px;overflow:hidden;max-width:20%;text-overflow:ellipsis;white-space:nowrap}.tooltip{max-width:220px;font-family:inherit;pointer-events:none;word-wrap:break-word}.tooltip#announcement-bar__tooltip{pointer-events:auto}.tooltip .tooltip-inner{max-width:100%;padding:4px 8px;box-shadow:0 6px 14px rgba(0,0,0,.12);font-size:12px;font-weight:600;line-height:18px;text-align:center;word-break:break-word}.tooltip.text-nowrap .tooltip-inner{white-space:nowrap}.tooltip .tooltip-help{color:rgba(255,255,255,.64)}.integration-option:hover{box-shadow:rgba(0,0,0,.1) 0 1px 16px}.signup-team__container .has-error .control-label::before{display:inline-block;font:normal normal normal 14px/1 FontAwesome;font-size:inherit;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:auto;transform:translate(0, 0)}.tutorial-tip__header{display:flex;align-items:center;justify-content:flex-start}.tutorial-tip__header__title{flex:auto;order:0;margin:0;font-family:inherit;font-size:1.4rem;font-style:normal;font-weight:600;line-height:2rem}.tutorial-tip__header__close{display:flex;overflow:hidden;width:3.2rem;height:3.2rem;flex-shrink:0;align-items:center;justify-content:center;border:unset;margin-left:1.2rem;background:transparent;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.56);font-weight:600}.tutorial-tip__header__close:hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.tutorial-tip__header__close.active{background:rgba(var(--center-channel-color-rgb), 0.08)}.tutorial-tip__header__close i{font-size:1.8rem;line-height:1.8rem}.tutorial-tip__header__close i ::before{margin-right:0}.tutorial-tip__body{display:flex;flex-direction:column;margin-top:.6rem}.tutorial-tip__body p{margin:0 0 .8rem;font-size:1.4rem;line-height:2rem}.tutorial-tip__body p:last-of-type{margin-bottom:0}.tutorial-tip__btn-ctr{display:flex;flex-grow:1;justify-content:flex-end}.tutorial-tip__btn{display:inline-flex;height:3.2rem;align-items:center;padding:10px 16px;border:none;border-radius:4px;font-size:12px;font-weight:600;line-height:12px}.tutorial-tip__confirm-btn{background:var(--button-bg);color:var(--button-color)}.tutorial-tip__confirm-btn:hover:not(.disabled){background:linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.16), rgba(var(--center-channel-color-rgb), 0.16)),var(--button-bg)}.tutorial-tip__confirm-btn:active{background:linear-gradient(0deg, rgba(var(--center-channel-color-rgb), 0.32), rgba(var(--center-channel-color-rgb), 0.32)),var(--button-bg)}.tutorial-tip__confirm-btn:focus{box-shadow:inset 0 0 0 2px var(--sidebar-text-active-border)}.tutorial-tip__confirm-btn .icon-chevron-right::before{margin-right:-7px}.tutorial-tip__cancel-btn{display:inline-flex;align-items:center;margin-right:4px;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);text-decoration:none}.tutorial-tip__cancel-btn:hover{background:rgba(var(--button-bg-rgb), 0.04)}.tutorial-tip__cancel-btn:active{background:rgba(var(--button-bg-rgb), 0.08)}.tutorial-tip__cancel-btn:focus{box-shadow:inset 0 0 0 2px var(--sidebar-text-active-border)}.tutorial-tip__cancel-btn .icon-chevron-left::before{margin-left:-7px}.tutorial-tip__circles-ctr{display:flex;align-items:center;justify-content:flex-start}.tutorial-tip__circular-ring{position:relative;display:flex;width:12px;height:12px;align-items:center;justify-content:center;margin-right:4px;background:transparent;border-radius:50%}.tutorial-tip__circular-ring:last-child{margin-right:0}.tutorial-tip__circular-ring-active{background:rgba(var(--button-bg-rgb), 0.16)}.tutorial-tip__circle{position:absolute;top:3px;left:3px;width:6px;height:6px;background:rgba(var(--button-bg-rgb), 0.32);border-radius:6px}.tutorial-tip__circle.active{background:rgba(var(--button-bg-rgb), 1)}.tutorial-tip__footer{display:flex;flex-direction:column;margin-top:2.4rem}.tutorial-tip__footer-buttons{display:flex;align-items:center;justify-content:start}.tutorial-tip__opt{align-self:flex-end;margin-top:1.2rem;font-size:12px}.tutorial-tip__opt span{opacity:.9}.tip-backdrop{position:absolute;z-index:999;top:0;left:0;width:100%;height:100%;background:rgba(0,0,0,.5)}.tip-overlay{position:absolute;z-index:1000;width:32rem;padding:1.8rem 2.4rem 2.4rem;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background:var(--center-channel-bg);border-radius:4px;filter:drop-shadow(0 12px 32px rgba(0, 0, 0, 0.12))}.tip-overlay .arrow{position:absolute;left:24px;display:block;width:1.7rem;height:1.7rem;border-width:1px 0 0 1px;border-style:solid;border-color:rgba(var(--center-channel-color-rgb), 0.16);background:var(--center-channel-bg);transform:rotate(-45deg)}.tip-overlay .svg-wrapper{display:flex}.tip-overlay .svg-wrapper svg{margin:0 auto}.tip-overlay .handSvg.svg-wrapper{margin:20px 0 30px 0}.tip-overlay.tip-overlay--sidebar{margin:154px 0 0 6px}.tip-overlay.tip-overlay--sidebar .tutorial__footer{position:absolute;bottom:20px;left:0;width:100%;padding:0 20px}.tip-overlay.tip-overlay--sidebar .arrow{top:32px;left:-9px;margin-top:-10px}.tip-overlay.tip-overlay--sidebar.first-channel{margin-top:131px}.tip-overlay.tip-overlay--header--left{margin:10px 0 0 7px}.tip-overlay.tip-overlay--header--left .arrow{top:34px;left:-9px}.tip-overlay.tip-overlay--header--left.tip-overlay--header--heading .arrow{top:40px}.tip-overlay.tip-overlay--header--bottom{margin-top:-10px}.tip-overlay.tip-overlay--header--bottom .arrow{top:-9px;left:50%;margin-left:-10px}.tip-overlay.tip-overlay--start-trial{margin-top:100px;margin-left:5px;box-shadow:var(--elevation-2)}.tip-overlay.tip-overlay--start-trial .arrow{top:25px;left:-10px;border-right-color:var(--center-channel-bg);border-left-width:0}.tip-overlay.tip-overlay--chat{width:40.8rem;margin-top:-7px;box-shadow:var(--elevation-2)}.tip-overlay.tip-overlay--chat .arrow{bottom:-10px;left:calc(50% - 7px);transform:rotate(-135deg)}.tip-overlay.tip-overlay--add-channels{margin-left:6px}.tip-overlay.tip-overlay--add-channels .arrow{top:81px;left:-9px}.tip-overlay.tip-overlay--add-channels.tip-overlay--top-row-placement .arrow{top:41px}.tip-overlay.tip-overlay--threads-welcome{margin:85px 0 0 6px}.tip-overlay.tip-overlay--threads-welcome .arrow{top:24px;left:-9px}.tip-overlay.tip-overlay--threads-list{margin:99px 0 0 6px}.tip-overlay.tip-overlay--threads-list .arrow{top:24px;left:-9px}.tip-overlay.tip-overlay--threads-unread{margin:6px 0 0 126px}.tip-overlay.tip-overlay--threads-unread .arrow{top:-9px;left:24px;transform:rotate(45deg)}.tip-overlay.tip-overlay--threads-pane{margin:37px 0 0 -6px}.tip-overlay.tip-overlay--threads-pane .arrow{top:24px;right:-9px;left:unset;transform:rotate(135deg)}.tip-overlay.tip-overlay--product-switcher{margin-top:6px;margin-left:4px}.tip-overlay.tip-overlay--product-switcher .arrow{top:-9px;left:24px;transform:rotate(45deg)}.tip-overlay.tip-overlay--settings{margin:7px 0 0 -20px}.tip-overlay.tip-overlay--settings .arrow{top:-9px;right:24px;left:unset;transform:rotate(45deg)}.tip-button{position:relative;z-index:998;top:-10px;right:-10px;cursor:pointer}.tip-div{position:absolute;top:0;right:0}.tip-div.tip-overlay--chat{right:unset;left:0}.tip-div.tip-overlay--start-trial{top:15px;right:-15px;left:unset}.tip-div.tip-overlay--header{top:21px;right:2px}.tip-div.tip-overlay--header .tip-button{opacity:.8}.tip-div.tip-overlay--header--left{z-index:1;top:8px;right:14px;padding:0 0 12px 12px}.tip-div.tip-overlay--header--left.tip-overlay--header--heading{top:0;right:-6px;padding:0 0 12px 12px}.tip-div.tip-overlay--actions{margin-top:-7px;margin-right:8px}.tip-div.tip-overlay--sidebar{top:10px;right:10px}.tip-div.tip-overlay--add-channels{top:-6px;right:-13px;padding:0 8px 24px 24px;cursor:pointer}.tip-div.tip-overlay--threads-welcome{top:10px;right:5px;padding:0 8px 24px 24px;cursor:pointer}.tip-div.tip-overlay--threads-list{top:58px;right:-2px;padding:0 8px 24px 24px;cursor:pointer}.tip-div.tip-overlay--threads-unread{top:35px;right:24px;padding:0 8px 24px 24px;cursor:pointer}.tip-div.tip-overlay--threads-pane{top:25px;right:unset;left:4px;cursor:pointer}.tip-div.tip-overlay--product-switcher{z-index:1000;right:unset;padding:16px 0 0 20px;margin:0;cursor:pointer}.tip-div.tip-overlay--product-switcher .arrow{top:-13px;right:44px}.tip-div.tip-overlay--settings{z-index:1000;top:23px;right:38px;padding:10px;margin:0}body.announcement-bar--fixed .tip-overlay.tip-overlay--add-channels{margin-top:40px}body.announcement-bar--fixed .tip-overlay.tip-overlay--header--left{margin-top:50px}@media screen and (max-width: 768px){.tip-div.tip-overlay--chat{left:calc(50% - 4px)}.tip-div.tip-overlay--sidebar,.tip-div.tip-overlay--threads-welcome{top:17px}.tip-div.tip-overlay--threads-list{top:unset;right:unset;bottom:-16px;left:calc(50% - 16px)}.tip-overlay{top:unset !important;bottom:0 !important;left:calc(50% - 16rem) !important;margin:0 0 20px 0 !important}.tip-overlay .arrow{display:none}.tip-overlay.tip-overlay--chat{left:calc(50% - 204px) !important;margin-left:unset}}@media screen and (max-width: 425px){.tip-overlay.tip-overlay--chat{left:calc(50% - 16rem) !important;width:32rem}}.post .video-div{position:relative;overflow:hidden;max-width:480px;height:360px;margin-bottom:8px;border-radius:4px}.post .video-div iframe,.post .video-div video{display:block;max-width:100%}.post .video-div .video-thumbnail{max-width:100%;height:auto}.post .video-div .video-thumbnail__error{width:100%;height:100%;padding:110px 0;line-height:2;text-align:center}.post .video-div .video-thumbnail__error .fa{opacity:.5}.post .video-div .video-thumbnail__error div{font-size:1.2em}.post .video-div .block{position:absolute;top:50%;left:50%;width:200px;height:150px;margin:-75px 0 0 -100px;background-color:rgba(0,0,0,.5);border-radius:10px}.post .video-type{padding:0;margin:0;font-size:15px;opacity:.8}.post .video-title{margin-top:3px;font-size:15px}.post .play-button{position:absolute;top:26px;right:51px;width:100px;height:100px;border:4px solid rgba(255,255,255,.4);border-radius:14px}.post .play-button span{position:absolute;top:10px;left:20px;width:0;height:0;border-top:36px solid transparent;border-bottom:36px solid transparent;border-left:60px solid rgba(255,255,255,.4)}.post .img-div{position:relative;max-width:480px;max-height:350px;margin-bottom:8px;border-radius:4px;-moz-force-broken-image-icon:1;transition:all .1s linear}.post .img-div:hover{box-shadow:0 2px 5px 0 rgba(0,0,0,.1),0 2px 10px 0 rgba(0,0,0,.1)}.post .img-div.placeholder{height:350px}.sidebar--right .post .img-div{max-width:100%}.post .video-loading{height:368px}.post .video-div__placeholder{display:flex;height:360px;align-items:center;background-color:#000}.color-input{position:relative}.color-input input{height:36px}.color-icon{display:inline-block;width:24px;height:24px;border:1px solid rgba(var(--center-channel-color-rgb), 0.32);border-radius:2px;cursor:pointer}.color-pad{padding:5px;border-color:rgba(var(--center-channel-color-rgb), 0.32) !important;background:var(--center-channel-bg) !important;border-radius:0 2px 2px 0;line-height:0}.color-popover{position:absolute;z-index:12;top:100%;right:0;padding-top:8px}.chrome-picker .flexbox-fix:nth-child(2){display:none !important}.system-notice{position:absolute;z-index:9999;right:12px;bottom:12px;width:280px;padding:18px 20px 0;border:1px solid rgba(0,0,0,.15);background-color:var(--center-channel-bg);border-radius:4px;box-shadow:0 20px 30px rgba(0,0,0,.07),0 14px 20px rgba(0,0,0,.07)}.system-notice__header{display:flex;align-items:flex-start}.system-notice__logo{height:36px}.system-notice__logo svg{width:36px;height:36px;fill:#166de0}.system-notice__title{overflow:hidden;flex:10 1 auto;padding:3px 0 0 8px;line-height:16px;opacity:.7;text-overflow:ellipsis;white-space:nowrap}.system-notice__info{margin-bottom:12px;font-size:12px;opacity:.5}.system-notice__info .fa{margin-right:4px}.system-notice__body{padding:18px 0 16px;line-height:16px;opacity:.7}.system-notice__footer{display:flex;border-top:1px solid rgba(0,0,0,.2);margin:0 -20px}.system-notice__footer .btn{overflow:hidden;flex:1;text-overflow:ellipsis}.system-notice__footer .btn:hover{background:#166de0;color:#fff}.system-notice__footer .btn:first-child{border-radius:0 0 0 4px}.system-notice__footer .btn:last-child{border-left:1px solid rgba(0,0,0,.2);border-radius:0 0 4px 0}@keyframes rowhighlight{0%{background-color:rgba(0,0,0,0)}20%{background-color:beige}80%{background-color:beige}100%{background-color:rgba(0,0,0,0)}}.permissions-block .more-schemes{width:100%;padding:10px;text-align:center;text-decoration:none}.permissions-block.closed .permissions-tree{max-height:0;padding:0 1.5rem;overflow-y:hidden}.permissions-block .no-team-schemes{padding:20px;margin:20px;background:rgba(255,255,255,.5);color:rgba(0,0,0,.3);font-size:16px;text-align:center}.permissions-block .team-override-unavailable{padding:20px;color:#3333337d;opacity:50%}.permissions-block .team-override-unavailable .team-override-unavailable__inner{padding:20px;background-color:#fff}.permissions-block .teams-list{padding:20px}.permissions-block .teams-list .no-team-schemes{margin:0}.permissions-block .teams-list .team{display:flex;padding:10px}.permissions-block .teams-list .team:nth-child(even){background:rgba(255,255,255,.5)}.permissions-block .teams-list .team .remove{flex-grow:0}.permissions-tree{max-height:2000px;padding:.8em 1.5rem;transition:all .4s ease-in-out 0s}.permissions-tree.guest .permission-row{padding-left:15px}.permissions-tree.guest .permission-group .permission-group-row{padding-left:15px}.permissions-tree.guest .permission-group .permission-group-row .permission-name{min-width:300px}.permissions-tree .permissions-tree--header{display:flex;flex-direction:row;padding:.5em 0;border-bottom:1px solid #ccc;font-size:1.1em;font-weight:bold}.permissions-tree .permissions-tree--header .permission-name{min-width:300px;margin-left:16px}.permissions-tree .permissions-tree--header .permission-description{display:block;width:100%;color:#000;opacity:1}.permissions-tree .permissions-tree--body{background-color:#f5f5f5;background-image:linear-gradient(transparent 50%, rgba(255, 255, 255, 0.5) 50%);background-size:68px 68px;cursor:pointer}.permissions-tree .permission-arrow{display:flex;min-width:10px;min-height:10px;align-items:center;justify-content:space-around;margin:5px 7px 4px 6px;transition:transform 300ms}.permissions-tree .permission-arrow.open{margin-top:6px;transform:rotate(90deg);transform-origin:55% 50%;transition:transform 300ms}.permissions-tree .permission-check{display:flex;min-width:18px;min-height:18px;align-items:center;justify-content:space-around;border:2px solid rgba(0,0,0,.5);margin-right:5px;border-radius:3px}.permissions-tree .permission-check.checked,.permissions-tree .permission-check.intermediate{border:0}.permissions-tree .permission-check.checked svg,.permissions-tree .permission-check.intermediate svg{background:#fff;fill:#166de0}.permissions-tree .permission-name{display:inline-block;min-width:300px}.permissions-tree .permission-description{display:flex;overflow:hidden;width:100%;height:100%;align-items:center;opacity:.65}.permissions-tree .permission-description span{display:inline-block;overflow:hidden;width:100%;text-overflow:ellipsis;white-space:nowrap}.permissions-tree .permission-group .permission-group-row .permission-name{min-width:268px}.permissions-tree .permission-group .permission-group-permissions{overflow:hidden;max-height:0;transition:max-height 300ms}.permissions-tree .permission-group .permission-group-permissions.open{max-height:400px;transition:max-height 300ms}.permissions-tree .permission-group .permission-group-permissions .permission-row{padding:0 0 0 48px}.permissions-tree .permission-group .permission-group-permissions .permission-row .permission-name{min-width:242px}.permissions-tree .permission-group .permission-group-permissions .permission-group-row{padding:0 0 0 25px}.permissions-tree .permission-group .permission-group-permissions .permission-group-row.combined{padding:0 0 0 48px}.permissions-tree .permission-group .permission-group-permissions .permission-group-row .permission-name{min-width:244px}.permissions-tree .permission-group .permission-group-permissions .permission-group-permissions .permission-row{padding:0 0 0 78px}.permissions-tree .permission-group .permission-group-permissions .permission-group-permissions .permission-row .permission-name{min-width:213px}.permissions-tree .permission-group .permission-group-permissions .permission-group-permissions .permission-group-row{padding:0 0 0 60px}.permissions-tree .permission-group .permission-group-permissions .permission-group-permissions .permission-group-row.combined{padding:0 0 0 78px}.permissions-tree .permission-group .permission-group-permissions .permission-group-permissions .permission-group-row .permission-name{min-width:192px}.permissions-tree .permission-row,.permissions-tree .permission-group-row{display:flex;height:34px;flex-direction:row;align-items:center;border:2px solid rgba(0,0,0,0)}.permissions-tree .permission-row:hover,.permissions-tree .permission-group-row:hover{border-left:2px solid #166de0;background-color:#c8defa}.permissions-tree .permission-row:hover .permission-description,.permissions-tree .permission-group-row:hover .permission-description{opacity:1}.permissions-tree .permission-row.selected,.permissions-tree .permission-group-row.selected{animation-duration:3s;animation-name:rowhighlight}.permissions-tree .permission-row.read-only .permission-check,.permissions-tree .permission-group-row.read-only .permission-check{border:none;background-color:rgba(0,0,0,.3)}.permissions-tree .permission-row.read-only .permission-check.checked svg,.permissions-tree .permission-row.read-only .permission-check.intermediate svg,.permissions-tree .permission-group-row.read-only .permission-check.checked svg,.permissions-tree .permission-group-row.read-only .permission-check.intermediate svg{background:#fff;fill:rgba(0,0,0,.3)}.permissions-scheme-summary{padding:10px 20px 0 20px;border-left:2px solid rgba(0,0,0,0);margin:0 20px;cursor:pointer}.permissions-scheme-summary:nth-child(2){margin-top:20px}.permissions-scheme-summary:last-child{margin-bottom:20px}.permissions-scheme-summary:nth-child(odd){background:rgba(255,255,255,.5)}.permissions-scheme-summary:hover{border-left:2px solid #166de0;background-color:#c8defa}.permissions-scheme-summary .permissions-scheme-summary--header{display:flex;flex-direction:row;font-size:1.1em}.permissions-scheme-summary .permissions-scheme-summary--header .title{flex-grow:1;font-size:14px;font-weight:bold}.permissions-scheme-summary .permissions-scheme-summary--header .actions{flex-grow:0}.permissions-scheme-summary .permissions-scheme-summary--header .actions a{display:inline-block;padding:0 3px}.permissions-scheme-summary .permissions-scheme-summary--teams{padding:1.5em 0 .5em}.permissions-scheme-summary .permissions-scheme-summary--teams .team{display:inline-flex;height:25px;align-items:center;justify-content:center;padding:0 8px;margin-right:10px;margin-bottom:10px;background:rgba(0,0,0,.05);border-radius:13px;color:rgba(0,0,0,.6);font-size:11px}.team-scheme-extra-teams-overlay .tooltip-inner{display:flex;flex-direction:column}.permission-scheme-summary-error-message{color:#d64946}.team-scheme-details{padding:20px 20px 5px 20px}.team-scheme-details .form-group{display:flex}.team-scheme-details .form-group label{width:240px}.team-info-block{display:flex;flex-grow:1;align-items:center}.team-info-block .team-data{flex-grow:1;padding:0 0 0 10px}.team-info-block .team-data .title{font-weight:bold}.team-info-block .TeamIcon{background:rgba(0,0,0,.12)}.admin-modal .modal-header{margin:1px;background-color:#000;color:#fff}.edit-post-time-limit-button{height:26px;padding:0 8px;border-color:#5b6672;background:transparent;border-radius:4px;color:#5b6672;transition:all .15s ease}.edit-post-time-limit-button i{margin-right:4px}.edit-post-time-limit-button span{display:inline !important}.edit-post-time-limit-button:hover{border-color:#166de0;background:#166de0;color:#fff}.edit-post-time-limit-modal label{margin-right:7px;margin-left:7px;font-weight:normal}.edit-post-time-limit-modal .edit-post-time-limit-modal__error{display:inline-block;width:65%;color:red;text-align:left}.app__body .DayPicker{width:100%;margin-top:.3rem;font-size:inherit}.app__body .DayPicker .DayPicker-NavBar{position:relative}.app__body .DayPicker .DayPicker-Caption{padding:0 .5rem .7rem;border-bottom:1px solid transparent;margin:0 .5rem .7rem;text-align:center}.app__body .DayPicker .DayPicker-Caption>div{font-size:inherit}.app__body .DayPicker .DayPicker-Day{position:relative;z-index:1;min-width:32px;height:32px;padding:0;border-radius:100%;font-weight:600}.app__body .DayPicker .DayPicker-Day:hover{background:var(--center-channel-bg) !important}.app__body .DayPicker .DayPicker-Day::before{position:absolute;z-index:-1;top:0;left:50%;width:32px;height:32px;margin-left:-15px;border-radius:32px;content:" "}.app__body .DayPicker .DayPicker-Day--today{color:var(--button-bg)}.app__body .DayPicker .DayPicker-Day--today::before{background:rgba(var(--button-bg-rgb), 0.08)}.app__body .DayPicker .DayPicker-wrapper{padding:0}.app__body .DayPicker .DayPicker-NavButton{top:0;right:.5rem;margin-top:2px;outline:none}.app__body .DayPicker .DayPicker-Weekday{color:inherit;font-weight:bold}.app__body .DayPicker .DayPicker-Month{width:100%;margin:0}.app__body .DayPickerInput-Overlay{padding:20px 24px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);background:rgba(var(--center-channel-bg-rgb), 1);border-radius:4px;box-shadow:0 8px 24px 0 rgba(0,0,0,.12)}.app__body .DayPickerInput-Overlay .DayPicker{margin-top:8px}.app__body .DayPicker-Day--selected:not(.DayPicker-Day--disabled):not(.DayPicker-Day--outside){background-color:var(--button-bg)}#ldap_groups{overflow:visible}.groups-list{padding:2rem 2rem 2rem 2rem;transition:all .4s ease-in-out 0s}.groups-list.groups-list-less-padding{padding:0}.groups-list .groups-list--global-actions{position:relative;display:flex;padding:8px 20px;background:#fff}.groups-list .groups-list--global-actions .group-list-search{position:relative;display:flex;max-width:280px;height:30px;flex-grow:1;border:1px solid rgba(0,0,0,.1);margin-top:2px;border-radius:15px;stroke:rgba(0,0,0,.5)}.groups-list .groups-list--global-actions .group-list-search input{width:100%;border:0;margin-right:15px;margin-left:25px;font-size:.95em}.groups-list .groups-list--global-actions .group-list-search input:focus{outline:none}.groups-list .groups-list--global-actions .group-list-search .group-filter-action{padding:8px 10px 0 0}.groups-list .groups-list--global-actions .group-list-search .group-filter-action.hidden{visibility:hidden}.groups-list .groups-list--global-actions .group-list-link-unlink{display:flex;flex-grow:1;justify-content:flex-end}.groups-list .groups-list--global-actions .group-search-filters{position:absolute;top:40px;width:303px;padding:20px;border:1px solid rgba(0,0,0,.1);background-color:#fff}.groups-list .groups-list--global-actions .group-search-filters .search-groups-btn{right:20px;bottom:20px;float:right}.groups-list .groups-list--global-actions .group-search-filters .cancel-filters{float:right}.groups-list .groups-list--global-actions .group-search-filters .filter-row{height:30px;vertical-align:middle}.groups-list .groups-list--global-actions .group-search-filters .filter-check{display:inline-block;width:18px;height:18px;border:2px solid rgba(0,0,0,.5);margin-right:7px;border-radius:3px;vertical-align:middle}.groups-list .groups-list--global-actions .group-search-filters .filter-check.checked{border:0}.groups-list .groups-list--global-actions .group-search-filters .filter-check.checked svg{background:#fff;fill:#166de0}.groups-list .groups-list--header{display:flex;flex-direction:row;padding:.5em 0;border-bottom:solid 1px rgba(0,0,0,.1);font-size:1.1em;font-weight:bold}.groups-list .groups-list--header .group-name{margin-left:16px}.groups-list .groups-list--header .group-description{display:block;width:150px;color:#000;opacity:1}.groups-list .groups-list--header .group-description.adjusted{width:100px}.groups-list .groups-list--header .group-actions{width:130px}.groups-list .groups-list--body{background:#f5f5f5;cursor:pointer}.groups-list .groups-list--body .groups-list-loading{padding:40px;text-align:center}.groups-list .groups-list--body .groups-list-empty{margin-top:1rem;background:rgba(255,255,255,.5);color:rgba(0,0,0,.3);font-size:1.6rem;text-align:center}.groups-list .groups-list--body .groups-list-empty span{display:inline-block;width:100%;height:100%;padding-top:20px;padding-bottom:20px}.groups-list .groups-list--footer{display:flex;height:auto;align-items:center;justify-content:flex-end;padding:5px;border-top:solid 1px rgba(0,0,0,.1);background:#fff}.groups-list .groups-list--footer .btn-link{color:rgba(0,0,0,.5)}.groups-list .groups-list--footer .btn-link.disabled{opacity:.5}.groups-list .groups-list--footer .counter{margin-bottom:2px;color:rgba(0,0,0,.5);font-size:1.1em}.groups-list .group-check{display:flex;min-width:18px;min-height:18px;align-items:center;justify-content:space-around;border:2px solid rgba(0,0,0,.5);margin:5px 5px 4px 14px;border-radius:3px}.groups-list .group-check.checked{border:0}.groups-list .group-check.checked svg{background:#fff;fill:#166de0}.groups-list .group-name{display:flex;flex:1.8;flex-grow:1;align-items:center}.groups-list .group-content{display:flex;flex:1;padding-left:20px}.groups-list .group-description{display:flex;overflow:hidden;width:150px;height:100%;align-items:center;opacity:.65}.groups-list .group-description.adjusted{width:120px}.groups-list .group-description.roles{overflow:visible}.groups-list .group-description i{margin-right:5px}.groups-list .group-description>a{padding:3px 5px;color:#000;text-decoration:none}.groups-list .group-description>a:hover{background-color:rgba(0,0,0,.15);border-radius:3px}.groups-list .group-description>a.warning{color:#d64946}.groups-list .group-description-link>a:hover{background-color:transparent;text-decoration:underline}.groups-list .group-actions{width:130px;padding-right:20px;text-align:right}.groups-list .group.checked{background-color:#c8defa}.groups-list .group.checked .group-description{opacity:1}.groups-list .group:nth-child(even){background:rgba(255,255,255,.5)}.groups-list .group.checked:nth-child(even){background-color:#c8defa}.groups-list .group .group-row .group-name{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.groups-list .group-row{display:flex;height:34px;flex-direction:row;align-items:center;border:2px solid rgba(0,0,0,0)}.groups-list .group-row:hover{border-left:2px solid #166de0;background-color:#e0ecfc}.groups-list .group-row:hover .group-description{opacity:1}.groups-list .group-row.selected{animation-duration:3s;animation-name:rowhighlight}.groups-list .group-row.group-row-large{height:80px}.groups-list .channel-icon{opacity:.8}#groupDisplayName.group-profile{padding-bottom:0}#groupMention .group-profile{padding-top:0}#groupMention .group-at-mention-input{padding-left:26px}.group-profile{padding:20px}.group-users .group-users--header{padding:10px 20px;background:#333;color:#fff}.group-users .group-users--header a{color:#fff;text-decoration:underline}.group-users .group-users--body{position:relative;margin:15px 15px 0 15px}.group-users .group-users--body .group-users-loading{position:absolute;display:none;width:100%;height:100%;background:rgba(0,0,0,.15);text-align:center}.group-users .group-users--body .group-users-loading.active{display:flex;align-items:center;justify-content:center}.group-users .group-users--body .group-users-loading.active .fa-spinner{max-width:10%}.group-users .group-users--body .group-users-empty{padding:20px;background:rgba(255,255,255,.5);color:rgba(0,0,0,.3);font-size:1.5em;text-align:center}.group-users .group-users--body .group-users-row{display:flex;align-items:center;padding:10px 15px}.group-users .group-users--body .group-users-row:nth-child(even){background:rgba(255,255,255,.5)}.group-users .group-users--body .group-users-row .profile-picture{width:32px;height:32px;margin:5px 10px;border-radius:100%}.group-users .group-users--body .group-users-row .user-data{margin-left:10px}.group-users .group-users--body .group-users-row .user-data .name-row{display:flex}.group-users .group-users--body .group-users-row .user-data .display-name,.group-users .group-users--body .group-users-row .user-data .email{color:rgba(0,0,0,.3)}.group-users .group-users--body .group-users-row .email-label{margin-right:5px}.group-users .group-users--footer{display:flex;height:auto;align-items:center;justify-content:flex-end;padding:5px;margin:0 15px 15px 15px;background:#fff}.group-users .group-users--footer.empty{height:0;padding:0;border-top:0}.group-users .group-users--footer .btn-link{color:rgba(0,0,0,.5)}.group-users .group-users--footer .btn-link.disabled{opacity:.5}.group-users .group-users--footer .counter{margin-bottom:2px;color:rgba(0,0,0,.5);font-size:1.1em}.channel-moderation .channel-moderation--body{padding:20px}.channel-moderation .channel-moderation--body .channel-moderation--table{width:100%}.channel-moderation .channel-moderation--body .channel-moderation--table th{padding:6px 20px;border-bottom:solid 1px rgba(204,204,204,.75)}.channel-moderation .channel-moderation--body .channel-moderation--table th:first-child{width:100%;padding-left:0}.channel-moderation .channel-moderation--body .channel-moderation--table tr:not(:last-child){border-bottom:solid 1px rgba(204,204,204,.75)}.channel-moderation .channel-moderation--body .channel-moderation--table tr:last-child td{padding-bottom:0}.channel-moderation .channel-moderation--body .channel-moderation--table td{padding:20px 0}.channel-moderation .channel-moderation--body .channel-moderation--table td:first-child{padding-left:0}.channel-moderation .channel-moderation--body .channel-moderation--table td:not(:first-child){text-align:center;vertical-align:middle}.channel-moderation .channel-moderation--body .channel-moderation--table .checkbox{display:inline-block;width:18px;height:18px;padding:0;border:2px solid rgba(0,0,0,.5);background:none;border-radius:3px}.channel-moderation .channel-moderation--body .channel-moderation--table .checkbox>*{pointer-events:none}.channel-moderation .channel-moderation--body .channel-moderation--table .checkbox.disabled{border-color:rgba(0,0,0,.15)}.channel-moderation .channel-moderation--body .channel-moderation--table .checkbox.checked{border:0}.channel-moderation .channel-moderation--body .channel-moderation--table .checkbox.checked svg{fill:#145dbf}.group-teams-and-channels .group-teams-and-channels-loading{padding:40px;text-align:center}.group-teams-and-channels .group-teams-and-channels-empty{padding:20px;background:rgba(255,255,255,.5);color:rgba(0,0,0,.3);font-size:1.5em;text-align:center}.group-teams-and-channels .group-teams-and-channels--header{font-size:1.1em;font-weight:bold}.group-teams-and-channels .group-teams-and-channels--body{padding:20px}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row.has-children .type{margin-left:20px}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row:nth-child(even){background:rgba(255,255,255,.5)}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .team-icon,.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .channel-icon{width:16px;height:16px;margin:0 7px 0 4px;color:inherit;opacity:.7}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .arrow-icon .fa{padding:0 4px;cursor:pointer}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .channel-icon{margin:1px 2px 0 20px}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .team-icon-private{font-size:.35em}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .actions button{padding:5px}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .type{flex:1;margin-left:-29px;color:#454448;opacity:50%}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .name-no-arrow{margin-left:16px}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .name-content{display:flex;flex:1}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .name-content .name{flex:1}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .name-content .arrow-icon{margin-left:10px}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .name-content .arrow-icon .fa-caret-right{padding:5px;cursor:pointer}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .name-content .arrow-icon .open{transform:rotate(90deg);transform-origin:55% 50%;transition:transform 300ms}.group-teams-and-channels .group-teams-and-channels--body .group-teams-and-channels-row .remove{height:30px}.group-teams-and-channels .group-teams-and-channels--body .teams-list .teams-list--header{display:flex;justify-content:space-between;border-bottom:1px solid rgba(0,0,0,.5);font-size:1.1em;font-weight:bold}.group-settings .group-settings--body{padding:0 20px 20px 20px}.group-profile-add-menu{position:relative;margin-top:-36px;margin-left:10px}.group-profile-add-menu .fa-caret-down{margin-left:5px}.group-profile-add-menu .add-team-or-channel-menu{position:absolute;top:33px;width:100%;padding:5px 8px;border:1px solid rgba(0,0,0,.3);background:#fff;border-radius:2px}.group-profile-add-menu .add-team-or-channel-menu a{display:block;padding:7px;color:rgba(0,0,0,.5)}.group-user-profile-picture{width:32px;height:32px;margin:5px 10px;border-radius:100%}.group-users-to-remove-modal-description{padding:16px;background-color:#f5f5f5}.group-description.group-user-removal-column{height:40px}#team_groups .group-row .group-description,#channel_groups .group-row .group-description{width:170px}.section-separator{position:relative;z-index:0;height:4rem;margin:0;text-align:center}.section-separator hr{position:relative;z-index:5;top:2rem;border-color:#333;margin:0;opacity:.12}.email-group-row{overflow:hidden;width:90%;text-overflow:ellipsis}.group-users--header-padded{padding-left:24px}.icon-over-input{position:absolute;padding-top:9px;padding-left:12px;opacity:.8}.AdminChannelDetails_archiveContainer{position:relative;left:-22px;display:block;width:920px;padding-top:20px;padding-left:20px;border-top:1px solid rgba(0,0,0,.1);margin-top:20px}.AdminChannelDetails_archiveContainer .ArchiveButton{padding:9px 16px}.AdminChannelDetails_archiveContainer .channel-icon__archive,.AdminChannelDetails_archiveContainer .channel-icon__unarchive{width:16px;height:16px}.ArchiveButton___archived{border-color:#166de0;color:#166de0}.ArchiveButton___archived svg{fill:#166de0}.ArchiveButton___unarchived{border-color:#f74343;color:#f74343}.ArchiveButton___unarchived svg{fill:#f74343}.ArchiveButton{border-width:1px;border-style:solid;background-color:transparent;border-radius:4px}.ArchiveButton___unarchived:hover{background-color:rgba(247,67,67,.06);color:#f74343}.ArchiveButton___archived:hover{background-color:rgba(22,109,224,.06);color:#166de0}.ArchiveButton:focus,.ArchiveButton:focus:active,.ArchiveButton:active{outline:none}.ArchiveButton___archived:focus{color:#166de0}.ArchiveButton___unarchived:focus{color:#f74343}.ArchiveButton___archived:focus:active{background-color:rgba(22,109,224,.12)}.ArchiveButton___unarchived:focus:active{background-color:rgba(247,67,67,.12)}.ArchiveButton:active{box-shadow:none}.select-suggestion-container{position:relative;margin:8px 8px 0 0}.select-suggestion-container:hover::after{opacity:.6}.select-suggestion-container::after{position:absolute;top:8px;right:1rem;display:inline-block;content:"";font:normal normal normal 14px/1 FontAwesome;font-size:16px;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;opacity:.4;pointer-events:none;text-rendering:auto;transition:opacity .15s ease}.select-suggestion-container .form-control{max-width:100%;height:32px;padding-right:3rem;border-radius:3px;box-shadow:unset;cursor:pointer;font-size:13px}.select-suggestion-container .suggestion-list__content{border-radius:3px 3px 3px 0}.AdminSidebarHeader{background:#333}.AdminSidebarHeader>div:first-child{position:relative;display:flex;align-items:center;padding:10px;cursor:pointer}.AdminSidebarHeader>div>img{width:36px;height:36px;border-radius:36px}.AdminSidebarHeader>div .header__info{overflow:hidden;*zoom:1;position:relative;width:100%;flex-grow:1;padding:3px 15px 0 8px;color:#fff}.AdminSidebarHeader>div .header__info .team__name{overflow:hidden;max-width:100%;font-size:14px;font-weight:600;text-decoration:none;text-overflow:ellipsis;white-space:nowrap}.AdminSidebarHeader>div .header__info .user__name{font-weight:400;opacity:.8}.AdminSidebarHeader>div .menu-icon{margin-right:10px;fill:#fff;opacity:.8}.AdminSidebarHeader>div:hover .user__name,.AdminSidebarHeader>div:hover .menu-icon{opacity:1}.AdminSidebarHeader>div:hover>div>img{opacity:.8}.AdminSidebarHeader .Menu{margin-left:16px}.post-card--info{position:fixed;bottom:0;display:flex;width:100%;min-width:0;align-items:center;justify-content:space-between;padding:15px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.12);background:var(--center-channel-bg);white-space:nowrap}.post-card--info .post-card--post-by{padding-right:10px}.post-card--info .status-wrapper{height:auto}.post-card--info .more-modal__image{width:20px;height:20px;margin:0 2px 0 4px}.post-card--info .user-popover{font-weight:600}.SidebarHeaderDropdownButton{position:relative;display:flex;align-items:center}.SidebarHeaderDropdownButton .header__info{position:relative;width:100%;flex-grow:1;padding:3px 15px 0 8px;color:#fff}.SidebarHeaderDropdownButton .header__info .team__name{overflow:hidden;font-size:14px;font-weight:600;text-decoration:none;text-overflow:ellipsis;white-space:nowrap}.SidebarHeaderDropdownButton .header__info .user__name{font-weight:400}.SidebarHeaderDropdownButton .unread-badge{position:absolute;right:2px;bottom:2px;width:8px;height:8px;background:#f74343;border-radius:50%}.SidebarHeaderDropdownButton .unread-badge-addon{position:absolute;top:8px;right:4px;width:12px;height:12px;background-color:var(--sidebar-header-bg);border-radius:32px}.SidebarHeaderDropdownButton .menu-icon{fill:#fff;opacity:.8}.SidebarHeaderDropdownButton:hover .user__name,.SidebarHeaderDropdownButton:hover .menu-icon{opacity:1}.file-view--single{margin:0}.file-view--single .file__image{position:relative}.file-view--single .file__image .image-header .image-name,.file-view--single .file__image .image-header button.single-image-view__toggle{color:rgba(var(--center-channel-color-rgb), 0.56)}.file-view--single .file__image .image-header:hover .image-name,.file-view--single .file__image .image-header:hover button.single-image-view__toggle{color:rgba(var(--center-channel-color-rgb), 0.72)}.file-view--single .file__image .image-header button.single-image-view__toggle{display:inline-block;padding:0;border:none;background:transparent;border-radius:4px;font-size:18px;line-height:18px}.file-view--single .file__image .image-header button.single-image-view__toggle .icon{width:18px;height:18px}.file-view--single .file__image .image-header button.single-image-view__toggle .icon::before{margin-right:0;margin-left:0}.file-view--single .file__image .image-header--expanded{position:absolute;z-index:3;top:-6px;left:-2px}.file-view--single .file__image .image-header--expanded button.single-image-view__toggle{display:none;width:24px;height:24px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg);border-radius:16px;box-shadow:var(--elevation-1);line-height:20px}.file-view--single .file__image .image-header--expanded button.single-image-view__toggle:hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.24);box-shadow:var(--elevation-2)}.file-view--single .file__image:hover .image-header--expanded button.single-image-view__toggle{display:block;color:rgba(var(--center-channel-color-rgb), 0.56)}.file-view--single .file__image .image-container{margin:5px 0}.file-view--single .file__image .image-container.image-permalink{margin:5px 0 0}.SidebarHeader{display:flex;padding:0;cursor:pointer}.SidebarHeader .MenuWrapper{height:100%}.SidebarHeader .MenuWrapper:first-child{width:100%;height:100%}.SidebarHeader .status-selector{margin:3px 8px 0 6px}.SidebarHeader .sidebar-header-dropdown__icon svg{fill:var(--sidebar-header-text-color)}.btn-toggle{background:#bdc1c8;color:#6b7381}.btn-toggle.active{background-color:#2a9fd8}.btn-toggle.disabled{cursor:not-allowed;opacity:.5}.btn-toggle.btn-lg{position:relative;min-width:5.6rem;height:2.8rem;padding:0;border:none;border-radius:2.8rem;float:right}.btn-toggle.btn-lg:focus,.btn-toggle.btn-lg:focus.active,.btn-toggle.btn-lg.focus,.btn-toggle.btn-lg.focus.active{outline:none}.btn-toggle.btn-lg>.handle{position:absolute;top:.4rem;left:.4rem;width:2rem;height:2rem;background:#fff;border-radius:1rem;transition:left .25s}.btn-toggle.btn-lg.active{transition:background-color .25s}.btn-toggle.btn-lg.active>.handle{right:.4rem;left:inherit;transition:left .25s}.btn-toggle.btn-sm{position:relative;min-width:3rem;height:1.5rem;padding:0;border:none;border-radius:1.5rem;float:right}.btn-toggle.btn-sm:focus,.btn-toggle.btn-sm:focus.active,.btn-toggle.btn-sm.focus,.btn-toggle.btn-sm.focus.active{outline:none}.btn-toggle.btn-sm>.handle{position:absolute;top:.4rem;left:.4rem;width:2rem;height:2rem;background:#fff;border-radius:1rem;transition:left .25s}.btn-toggle.btn-sm.active{transition:background-color .25s}.btn-toggle.btn-sm.active>.handle{right:.4rem;left:inherit;transition:left .25s}.btn-toggle.btn-xs{position:relative;min-width:2rem;height:1rem;padding:0;border:none;border-radius:1rem;float:right}.btn-toggle.btn-xs:focus,.btn-toggle.btn-xs:focus.active,.btn-toggle.btn-xs.focus,.btn-toggle.btn-xs.focus.active{outline:none}.btn-toggle.btn-xs>.handle{position:absolute;top:.4rem;left:.4rem;width:2rem;height:2rem;background:#fff;border-radius:1rem;transition:left .25s}.btn-toggle.btn-xs.active{transition:background-color .25s}.btn-toggle.btn-xs.active>.handle{right:.4rem;left:inherit;transition:left .25s}.btn-toggle .bg-text{color:#fff;font-size:1.4rem;font-weight:600}.btn-toggle .bg-text.off{padding:0 1.6rem 0 3.4rem}.btn-toggle .bg-text.on{padding:0 3.4rem 0 1.6rem}span.greyed-out{opacity:.4}.row-content{opacity:.8}.groups-list-no-padding div.group-row{height:40px;padding-left:20px}.groups-list-no-padding div.groups-list--header div.group-name.adjusted{margin-left:20px}.groups-list-no-padding div.groups-list--header div.group-description.adjusted{margin-right:22px}.groups-list-no-padding div.groups-list--header div.group-description.group-description-adjusted{margin-right:22px}.groups-list-no-padding div.groups-list--header div.group-name.group-name-adjusted{margin-left:22px}.help-text-small.help-text-no-padding{margin-top:0}.help-text-small.help-text-single-line{height:17px}.team-descr-list-column{max-width:440px}.large-team-image-col{max-width:129px;padding-right:20px}.large-team-image-col .TeamIcon{margin-right:12px;background:rgba(0,0,0,.12)}.team-desc-col,.channel-desc-col{line-height:20px}.center-row>div{display:inline-block;float:none;vertical-align:middle}.row-bottom-padding{padding-bottom:12px}.csvDomains{padding-bottom:4px}.csvDomains span{font-size:12px;font-weight:600;line-height:17px}.help-text-small{max-width:668px;font-size:12px;line-height:17px;opacity:.6}#teams,#team_profile,#channels,#channel_profile{margin-top:0}.infinite-scroll{width:100%;overflow-x:hidden;overflow-y:hidden}.infinite-scroll:hover{overflow-y:scroll;overflow-y:overlay}.line-switch__label{margin:0}#appsModal .modal-footer .btn{margin-bottom:5px}@media screen and (max-width: 768px){#navbar_wrapper .navbar-default .navbar-brand{margin-left:0}#navbar_wrapper .navbar-default .navbar-header{margin:0 -15px;float:none}#navbar_wrapper .navbar-default .navbar-header .dropdown__icon{display:inline-block;width:4px;height:16px;background-size:100% 100%}#navbar_wrapper .navbar-default .navbar-toggle{display:block}#navbar_wrapper .navbar-default .navbar-toggle:not(.navbar-right__icon):hover{background:transparent}#navbar_wrapper .navbar-default .spacer{flex:1}#navbar_wrapper .navbar-default .Menu{position:fixed;top:48px;left:0;display:block;overflow:hidden;width:100%;height:100%;padding:2.5em 0 0;padding-bottom:50px;background:rgba(0,0,0,.9);transition:all .35s ease}body.announcement-bar--fixed #navbar_wrapper .navbar-default .Menu{top:calc(48px + 40px);height:calc(100% - 48px - 40px)}#navbar_wrapper .navbar-default .Menu__content{position:absolute;top:0;overflow:auto;width:100%;max-width:100%;height:100%;max-height:100%;padding:2rem 2rem 5rem;background:transparent}#navbar_wrapper .navbar-default .Menu__close{position:fixed;top:70px;right:20px;display:block;width:30px;height:30px;padding-top:13px;border:1px solid #fff;margin-left:-15px;border-radius:50%;color:#fff;font-family:"Open Sans",sans-serif;font-size:23px;font-weight:200;line-height:0;opacity:1;text-align:center;text-shadow:none}#navbar_wrapper .navbar-default .dropdown-menu .dropdown__divider+.dropdown__divider{display:none}#navbar_wrapper .navbar-default .dropdown-menu>li>a,#navbar_wrapper .navbar-default .dropdown-menu>li>button,#navbar_wrapper .navbar-default .dropdown-menu>li>.styleSelectableItemDiv{display:flex;width:100%;height:auto;justify-content:center;padding:.4rem 2rem;margin:0 auto;color:#fff;font-weight:600;line-height:32px;text-align:center}#navbar_wrapper .navbar-default .dropdown-menu>li>a:hover,#navbar_wrapper .navbar-default .dropdown-menu>li>button:hover,#navbar_wrapper .navbar-default .dropdown-menu>li>.styleSelectableItemDiv:hover{background:transparent}#navbar_wrapper .navbar-default .dropdown-menu>li>a .SubMenu__icon-right,#navbar_wrapper .navbar-default .dropdown-menu>li>button .SubMenu__icon-right,#navbar_wrapper .navbar-default .dropdown-menu>li>.styleSelectableItemDiv .SubMenu__icon-right{color:rgba(255,255,255,.56)}#navbar_wrapper .navbar-default .dropdown-menu>li .navbar-right__icon{margin:10px}#navbar_wrapper .navbar-default .dropdown-menu>li hr{border-bottom:1px solid rgba(255,255,255,.3);margin:8px auto}#navbar_wrapper .navbar-default .status{top:2px;width:16px;margin:0 8px 0 0}#navbar_wrapper .navbar-default .status svg{width:16px;max-height:20px}.browser--ie #navbar_wrapper .navbar-default .dropdown-menu .close{top:70px}.app__body .MenuWrapper .MenuItem__divider{border:none;margin:0}.app__body .modal .settings-modal:not(.settings-modal--tabless):not(.display--content) .modal-content{background:var(--sidebar-bg)}.app__body .modal .settings-modal .modal-body{min-height:100%}.app__body .modal .settings-modal .nav-pills>li:hover a{background:transparent !important}.app__body .modal .settings-modal.display--content .modal-header{display:none}.app__body .modal .settings-modal.display--content .settings-table{display:block}.app__body .modal .settings-modal.display--content .settings-table .settings-content .section-min__title{padding-right:15px}.app__body .modal .settings-modal.display--content .settings-table .settings-content .section-min__edit{position:relative;top:0;right:0;text-align:left}.app__body .modal .settings-modal.display--content .settings-table .settings-content .appearance-section .theme-elements .element{margin-right:10px}.app__body .modal .settings-modal.display--content .settings-table .settings-content .appearance-section .theme-elements .element:nth-child(2n){margin-right:10px}.app__body .modal .settings-modal.display--content .settings-table .settings-content.minimize-settings{display:block}.app__body .modal .settings-modal.display--content .settings-table .settings-content .section-min:hover{background:none}.app__body .modal .settings-modal.display--content .settings-table .settings-content .no-padding--left{padding-left:15px}.app__body .modal .settings-modal.display--content .settings-table .settings-links{display:none}.app__body .modal .settings-modal.display--content .settings-table .modal-header{position:absolute;z-index:5;top:0;display:block;width:100%}.app__body .modal .settings-modal.display--content .settings-table .modal-header .modal-title{width:100%;max-width:100%;padding:0 40px;text-align:center}.app__body .modal .settings-modal.display--content .settings-table .modal-header .modal-title>span{display:block;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.app__body .modal .settings-modal.display--content .settings-table .user-settings .tab-header{display:none}.app__body .modal .settings-modal.display--content .settings-table .user-settings .divider-dark.first{display:none}.app__body .modal .settings-modal .settings-table{padding:0}.app__body .modal .settings-modal .settings-table .nav{position:relative;top:auto;width:100%;margin:0}.app__body .modal .settings-modal .settings-table .nav.position--top{top:auto}.app__body .modal .settings-modal .settings-table .nav>li>a{font-size:1.1em;line-height:2.7}.app__body .modal .settings-modal .settings-table .nav>li>a .icon{margin:0 7px}.app__body .modal .settings-modal .settings-table .nav>li>button{color:var(--sidebar-text)}.app__body .modal .settings-modal .settings-table .nav>li.active>button{color:var(--sidebar-text)}.app__body .modal .settings-modal .settings-table .settings-content .section-min__edit{text-align:left}.app__body .modal .settings-modal .settings-table .settings-content .section-min__edit button{width:100%;text-align:left}.app__body .modal .settings-modal .settings-table .settings-content .section-min__edit .fa{display:inline-block}.app__body .modal .settings-modal .settings-table .settings-content.minimize-settings{display:none;padding:0}.app__body .modal .settings-modal .settings-table .settings-content.minimize-settings .user-settings{padding:70px 20px 30px}.app__body .modal .settings-modal .settings-table .settings-content .section-min:hover{background:none !important}.app__body .modal .modal--scroll .modal-body{overflow:auto;max-height:calc(100vh - 62px)}.app__body .modal .nav-pills>li.active button{background:transparent}.app__body .modal .nav-pills>li.active button::before{display:none}.app__body .modal .nav-pills>li button{padding:15px;border-bottom:1px solid}.app__body .modal .info__label{padding-bottom:5px;text-align:left}.app__body .modal .modal-header .modal-action{margin-top:10px}.app__body .modal .modal-header .close{overflow:hidden;margin-top:-2px;font-size:27px;font-weight:normal}.app__body .modal .modal-header .modal-title{max-width:90%}.app__body .modal .modal-header .btn.btn-primary{display:block;width:100%;margin:10px 0 6px}.app__body .more-modal .modal-header{flex-direction:column;padding-right:15px}.app__body .post .Menu,.app__body .SidebarMenu .Menu,.app__body .AddChannelDropdown .Menu,.app__body .GlobalThreads .Menu{position:fixed;z-index:9999;top:0;left:0;display:flex;overflow:auto;width:100%;height:100%;flex-wrap:wrap;align-items:center;padding:6em 2em 4em;border:0;margin:0;background:transparent;border-radius:0}.app__body .post .Menu .Menu__content,.app__body .SidebarMenu .Menu .Menu__content,.app__body .AddChannelDropdown .Menu .Menu__content,.app__body .GlobalThreads .Menu .Menu__content{position:relative;top:0;width:100%;max-width:inherit;max-height:inherit;padding:0}.app__body .post .Menu::after,.app__body .SidebarMenu .Menu::after,.app__body .AddChannelDropdown .Menu::after,.app__body .GlobalThreads .Menu::after{position:fixed;top:0;left:0;width:100%;height:100%;background:rgba(0,0,0,.3);content:""}.app__body .post .Menu .MenuItem,.app__body .SidebarMenu .Menu .MenuItem,.app__body .AddChannelDropdown .Menu .MenuItem,.app__body .GlobalThreads .Menu .MenuItem{z-index:9999;background:var(--center-channel-bg)}.app__body .post .Menu .MenuItem:last-child button,.app__body .SidebarMenu .Menu .MenuItem:last-child button,.app__body .AddChannelDropdown .Menu .MenuItem:last-child button,.app__body .GlobalThreads .Menu .MenuItem:last-child button{border-bottom:0}.app__body .edit-modal-body .custom-textarea{max-height:30vh}.app__body .row--invite .col-sm-6:first-child{padding-right:15px}.post-right__container{height:100%}.post-right__container .post.post--thread .post-pre-header__icons-container{width:60px;padding-right:12px;margin-left:0}.line-switch__toggle{margin:8px 0}.backstage-list__item .item-actions,.backstage-list__item .actions{margin:10px 0}.integration__icon.integration-list__icon{position:relative;top:0;width:50px;height:50px;margin:0 20px 15px}.emoji-picker{z-index:1070;top:0 !important;right:auto !important;bottom:auto !important;left:0 !important;width:100%;height:100%;border-radius:0}.emoji-picker>ul{margin-top:66px}.emoji-picker.bottom{margin-top:0}.emoji-picker .search-grid-container{height:calc(100vh - 170px)}.emoji-picker__inner{display:flex;height:calc(100vh - 100px);flex-direction:column}.emoji-picker--single .emoji-picker__inner{height:calc(100vh - 55px)}.emoji-picker__inner>*{flex-grow:0}.emoji-picker__header,.modal-body .emoji-picker .emoji-picker__header{display:block}.emoji-picker__categories .emoji-picker__category{width:30px;height:30px}.emoji-picker__search-container{height:40px}.emoji-picker__items{flex-grow:1}.emoji-picker__items .emoji-picker__category-header{padding-top:8px;font-size:14px}.emoji-picker__item{width:calc(100% / 15);height:auto;padding:0;padding-top:calc(100% / 15);margin:calc(100% / 45)}.emoji-picker__item>div{position:absolute;top:50%;left:50%;display:flex;width:30px;height:30px;align-items:center;justify-content:center;transform:translate(-50%, -50%)}.emoji-picker__preview{width:100%;height:60px}.MenuWrapper .Menu__content.dropdown-menu{max-width:100%}.MenuWrapper .Menu__content.mobile-channel-header-dropdown-enter{transform:translateY(100%)}.MenuWrapper .Menu__content.mobile-channel-header-dropdown-enter-active{transform:translateY(0%);transition:transform .35s ease-in}.MenuWrapper .Menu__content.mobile-channel-header-dropdown-enter-done{transform:translateY(0%)}.MenuWrapper .Menu__content.mobile-channel-header-dropdown-exit{transform:translateY(100%);transition:transform .35s ease-in}.mobile-main-menu .Menu__content.dropdown-menu{position:relative;width:100%;max-width:inherit;max-height:inherit;padding-top:0;padding-left:0;border:0;margin-bottom:0;background:transparent;box-shadow:none;color:inherit;list-style:none}.mobile-main-menu .Menu__content.dropdown-menu button,.mobile-main-menu .Menu__content.dropdown-menu a,.mobile-main-menu .Menu__content.dropdown-menu a:hover{opacity:.8}.mobile-main-menu .Menu__content.dropdown-menu .MenuItem>button,.mobile-main-menu .Menu__content.dropdown-menu .MenuItem>a{width:100%;height:auto;padding:3px 16px;font-size:15px;line-height:32px;text-align:left}.mobile-main-menu .Menu__content.dropdown-menu .MenuItem i.icon{width:auto;margin:0}.mobile-main-menu .Menu__content.dropdown-menu .MenuItem i.icon::before{margin:0}.mobile-main-menu .Menu__content.dropdown-menu .MenuGroup.menu-divider{background:var(--center-channel-bg)}.post__header .dropdown-menu>li>div,.GlobalThreads .dropdown-menu>li>div{border-top-color:rgba(var(--center-channel-color-rgb), 0.08) !important}.post__header .dropdown-menu>li>div .SubMenu__icon,.GlobalThreads .dropdown-menu>li>div .SubMenu__icon{padding:0 5px 0 8px !important}.post__header .dropdown-menu>li>div,.post__header .dropdown-menu>li>button,.GlobalThreads .dropdown-menu>li>div,.GlobalThreads .dropdown-menu>li>button{height:auto;padding:15px 20px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.12);border-radius:0}.post__header .dropdown-menu>li:first-child div,.post__header .dropdown-menu>li:first-child button,.GlobalThreads .dropdown-menu>li:first-child div,.GlobalThreads .dropdown-menu>li:first-child button{border:none}.integration-option{width:100%;height:auto;flex:0 0 100%;margin:0 0 30px;margin-left:0}.channel-header .channel-header__icon,.GlobalThreads .Header .channel-header__icon{display:none}.member-role .member-menu,.member-drop .member-menu{top:30px;right:0}.post-code{word-wrap:normal}.table-responsive{border:none}.multi-select__container .btn{display:block;min-width:50px}.multi-select__container .Select-value-label{max-width:190px;text-overflow:ellipsis}.more-modal__list .more-modal__actions--round{opacity:.5}.post-create__container{z-index:2}.post-create__container form{padding:0}.post-create__container .post-create-body{padding:0}.post-create__container .post-create-body .send-button{display:block}.post-create__container .post-create-body .custom-textarea.custom-textarea--emoji-picker{max-height:162px;padding-right:135px}.app-content .post-create__container .post-create-body textarea{border-right:none;border-left:none}.post-create__container .post-create-body .post-body__actions .Menu.dropdown-menu{max-height:80vh}.post-create__container .msg-typing{display:none}.post-create-footer{padding:0 16px}.post-create-footer .post-error{position:relative;top:0;margin:8px 0}.post-create-footer .help__text{display:none}.suggestion-list__content{max-height:145px}.filtered-user-list .filter-button .btn{width:100%}.settings-modal .modal-body{overflow:auto}#header-popover{position:fixed;top:40px !important;width:100%;max-width:100%;height:calc(100% - 50px);border:none;background:rgba(0,0,0,.9);box-shadow:none;transform:translate3d(0, 100%, 0);transition:all .35s ease}#header-popover.in{transform:translate3d(0, 0, 0)}#header-popover a{color:#0091ff}#header-popover .arrow{display:none}#header-popover .popover-content{padding:15px 20px 100px;color:#fff;font-size:15px}#header-popover .popover-content>div:first-child{overflow:auto;height:calc(100vh - 150px);-webkit-overflow-scrolling:touch}#header-popover .close{position:fixed;bottom:25px;left:50%;display:block;width:30px;height:30px;padding-top:13px;border:1px solid #fff;margin-left:-15px;border-radius:50%;color:#fff;font-family:"Open Sans",sans-serif;font-size:23px;font-weight:200;line-height:0;opacity:1;text-align:center;text-shadow:none}.video-div.embed-responsive-item iframe{position:absolute;top:0;left:0;width:100%;height:100%}.prompt .prompt__heading{display:block}.prompt .prompt__heading>div:first-child{display:block;margin:0 0 1em}.post-code__language{position:relative;display:block;opacity:1;transition:none}.backstage-form__footer .has-error{max-width:100%;margin-bottom:16px;float:none !important}.backstage-filters{display:block}.backstage-filters .backstage-filter__search{width:100%;margin:10px 0}.compliance-panel .row>.form-group,.audit-panel .row>.form-group{padding-left:15px}.user-popover{display:inline-block;cursor:pointer}.signup-team__container{padding:60px 10px 0;margin-bottom:30px;font-size:.9em}.signup-team__container .signup-team__name{font-size:2em}.signup-team__container .btn.btn-full{padding-left:10px}.signup-team__container .btn .icon,.signup-team__container .btn .fa{margin-right:6px}.sidebar--left .team__header .Avatar,#SidebarContainer .team__header .Avatar,.sidebar--menu .team__header .Avatar{display:none}.channel-intro{margin:0 0 35px}.post:not(.post--compact) .Badge{top:31px;left:6px}.post.post--system .post__header .post-menu{min-width:45px}.post .post-add-reaction .Reaction{opacity:1;visibility:visible}.browser--ie .post .post__header .post-menu .dropdown+div{display:none}.post .post-menu__item--reactions{display:none}.post .emoticon--post-menu{display:none}.post .post__dropdown{display:inline-block;width:28px;height:28px;line-height:21px;text-align:center;text-decoration:none;visibility:visible}.post .post__dropdown::after{top:-3px;content:"...";font-size:20px}.post .post__remove{margin-right:10px;visibility:visible}.post.post--compact{padding-left:1em}.post.post--compact .post__img{padding-top:0}.post-right__container .post.post--compact .post__img{padding-top:2px}.post.post--compact.same--root.same--user{padding-left:1em}.post.post--compact.same--root.same--user .post__header{height:auto}.post.post--compact .post-message--overflow{overflow:hidden;*zoom:1}.post.post--compact .status-wrapper::after{bottom:3px}.sidebar--right .post.post--compact .status-wrapper::after{bottom:0}.post.post--compact blockquote{margin-top:0}.post .post-pre-header .post-pre-header__icons-container{width:40px;padding-right:8px;margin-left:0}.post .post-pre-header .post-pre-header__icons-container .icon--post-pre-header:nth-of-type(even){margin-left:8px}.post .post__content{padding:0 10px 0 0}.post.current--user.post--comment .post__header{margin-bottom:3px}.post.current--user .post__link{margin:0 0 8px}.post .post__header{padding-right:70px;margin-bottom:0}.post .post__header .post-menu{z-index:auto;top:-6px;min-width:45px}.post .post__header .post-menu>div{width:auto}.post .post__header .post-menu .post-menu__item--reactions{display:none}.post .post__header .col__name .user-popover{max-width:105px}.post .comment-icon__container{display:none;visibility:visible}.sidebar--right .post .comment-icon__container{display:inline-block}.post .comment-icon__container.icon--show{display:inline-block}.post-list__content .post:not(.post--editing):hover{background:transparent}.post-list__content .post .comment-icon__container{visibility:visible}.post .dropdown,.post .post__reply{visibility:visible}.post .post__body{width:100%}.post .post__reply{margin-right:20px;float:right}.post .post__reply svg{top:1px}.post.post--comment .post__body{padding:0 0 0 7px;margin-top:5px}.post.other--root.post--comment .post__header .post-menu{top:-6px}.post.other--root .post__reply.post__reply--hide{visibility:hidden}.post .star-icon__container{position:relative;top:auto;left:auto}.post .star-icon__container:not(.visible){display:none}.post.same--root .star-icon__container{position:relative;top:auto;left:auto}.post.same--root.same--user.post--compact .status-wrapper::after{bottom:-2px}.post.same--root.same--user .post__img img{display:block}.post.same--root.same--user .post__header{height:auto;margin-top:5px}.post.same--root.same--user .post__header .col__name{display:inline-block}.post .post__img{width:40px}.post .post__img img{width:32px;height:32px}.post .attachment .attachment-actions .alert{position:relative;top:0;left:0;display:inline-block;margin:1rem 0 .4rem}.post .attachment .attachment__body__wrap .btn-close{top:7px;left:-15px;width:30px;height:30px;visibility:visible}.form-control.min-height{min-height:100px}.img-div{max-width:100%}.file-details__container{display:block}.file-details__container .file-details__preview{display:block;width:100%;height:150px;border-right:none;border-bottom:1px solid #ddd}.file-details__container .file-details__preview img{width:64px;height:64px}.file-details__container .file-details{width:100%;height:auto}.search-help-popover{left:0;max-width:100%}.modal-direct-channels .member-count,.more-channel__modal .member-count{display:block;margin-top:10px;float:none}.file-overlay{font-size:1.2857142857em}.file-overlay.center-file-overlay .overlay__indent{margin-left:0}.file-overlay .overlay__circle{width:300px;height:300px;margin:-150px 0 0 -150px}.file-overlay .overlay__files{width:150px;margin:60px auto 15px}.post-list__timestamp{display:block}.file-preview__container{margin:10px 0 5px}.file-preview{margin-top:0}.admin-sidebar .navbar-nav{margin-top:0}.admin-sidebar .navbar-nav>li{float:left}.admin-sidebar .navbar-nav .dropdown-menu{position:absolute;right:0;left:auto;background:var(--center-channel-bg)}body.white .inner-wrap>.row.content{margin-bottom:-185px}.footer,.footer-pane{height:187px}.footer-pane .footer-link{display:block;width:100%;padding:0;line-height:1.7;text-align:right}.footer-pane .footer-link.copyright{width:100%}.search-bar__container{flex:0 0 50px;padding:0;background:var(--sidebar-header-bg);color:var(--sidebar-header-text-color)}.search-bar__container .search-form__container{padding:0 20px 0 0}.search-bar__container .search__form{width:100%;border-color:transparent;margin-top:9px;background:var(--center-channel-bg);transform:translateX(0);transition:all .2s linear}.search-bar__container .search__form:hover,.search-bar__container .search__form--focused,.search-bar__container .search__form--focused:hover{border-width:1px;border-color:transparent}.search-bar__container .search__form .form-control{padding:0 31px;border:none;background:var(--center-channel-bg);border-radius:3px}.search-bar__container .channel-header__links{display:none}.sidebar--menu{width:290px;border:none;transform:translate3d(290px, 0, 0);transition:transform .35s ease;visibility:hidden}.sidebar--menu.visible{display:block;visibility:visible}.sidebar--menu.move--left{display:block;transform:translate3d(0, 0, 0);visibility:visible}.sidebar--menu .mentions{font-size:17px;font-weight:bold}.sidebar--menu .Menu .MenuItem.MenuItem--with-icon .MenuItem__help-text{padding-left:0}.sidebar--left{width:290px;border:none;transform:translate3d(-290px, 0, 0);transition:transform .35s ease}.sidebar--left.sidebar--padded{padding-top:0}.sidebar--left.move--right{transform:translate3d(0, 0, 0)}.sidebar--left .team__header{overflow:hidden;*zoom:1;padding:15px;pointer-events:none}.sidebar--left .team__header .team__name,.sidebar--left .team__header .user__name{max-width:100%}.sidebar--left .team__header .sidebar-header-dropdown{display:none}.sidebar--left .search__form{display:block}.sidebar--left .nav li.dropdown.open{padding-bottom:25px}.sidebar--left .nav li.dropdown.open ul{position:relative;top:5px;background:var(--center-channel-bg);border-radius:3px;clear:both}.sidebar--left .nav li.dropdown.open ul li a{line-height:30px}.sidebar--left .nav li .nav-more{padding:12px 0 12px 17px}.sidebar--left .nav li .sidebar-item{height:45px}.sidebar--left .nav li .sidebar-item.has-close .btn-close{display:block;width:30px;height:30px;margin-right:4px;font-size:25px;line-height:30px;opacity:.5}.sidebar--left .nav li h4{margin:1.5em 0 1em}.sidebar--left .nav li>a{margin:0;font-size:15px;line-height:2.5}.sidebar--left .nav li>a:hover,.sidebar--left .nav li>a:focus{background:transparent}#SidebarContainer{width:290px;border:none;transform:translate3d(-290px, 0, 0);transition:transform .35s ease}#SidebarContainer+.inner-wrap #app-content{margin-left:0}#SidebarContainer.move--right{transform:translate3d(0, 0, 0)}#SidebarContainer .team__header{overflow:hidden;*zoom:1;padding:15px;pointer-events:none}#SidebarContainer .team__header .team__name,#SidebarContainer .team__header .user__name{max-width:100%}#SidebarContainer .team__header .sidebar-header-dropdown{display:none}#SidebarContainer .search__form{display:block}#SidebarContainer .SidebarContainer_filterAddChannel{width:100%}#SidebarContainer .SidebarGlobalThreads,#SidebarContainer .SidebarGlobalThreads .SidebarLink{height:45px}#SidebarContainer .SidebarChannelGroup div.dropdown.open{padding-bottom:25px}#SidebarContainer .SidebarChannelGroup div.dropdown.open ul{position:relative;top:5px;background:var(--center-channel-bg);border-radius:3px;clear:both}#SidebarContainer .SidebarChannelGroup div.dropdown.open ul li a{line-height:30px}#SidebarContainer .SidebarChannelGroup div .nav-more{padding:12px 0 12px 17px}#SidebarContainer .SidebarChannelGroup div .SidebarChannel{height:45px}#SidebarContainer .SidebarChannelGroup div .SidebarChannel .SidebarLink{width:290px;height:45px;align-items:center}#SidebarContainer .SidebarChannelGroup div .SidebarChannel .SidebarLink::before{height:45px}#SidebarContainer .SidebarChannelGroup div .SidebarChannel .SidebarLink .badge+.SidebarMenu{display:none !important}#SidebarContainer .SidebarChannelGroup div .SidebarChannel .SidebarLink:hover .SidebarMenu{display:block !important}#SidebarContainer .SidebarChannelGroup div .SidebarChannel.has-close .btn-close{display:block;width:30px;height:30px;margin-right:4px;font-size:25px;line-height:30px;opacity:.5}#SidebarContainer .SidebarChannelGroup div .SidebarChannel .SidebarMenu_menuButton{margin-top:1px}#SidebarContainer .SidebarChannelGroup div h4{margin:1.5em 0 1em}#SidebarContainer .SidebarChannelGroup div>a{margin:0;font-size:15px;line-height:2.5}#SidebarContainer .SidebarChannelGroup div>a:hover,#SidebarContainer .SidebarChannelGroup div>a:focus{background:transparent}#SidebarContainer .SidebarMenu,#SidebarContainer .AddChannelDropdown{display:block !important}#SidebarContainer .SidebarMenu .Menu,#SidebarContainer .AddChannelDropdown .Menu{top:0 !important}.sidebar--right{right:0;width:100%;transform:translate3d(100%, 0, 0)}.browser--ie .sidebar--right{display:none;-webkit-transform:none !important;-moz-transform:none !important;-ms-transform:none !important;-o-transform:none !important;transform:none !important}.sidebar--right .sidebar--right__bg{display:none}.sidebar--right .sidebar--right__expand{display:none}.sidebar--right .post-create__container form{padding:.5em 1em}.sidebar--right .post-create__container .post-create{padding:0}.sidebar--right .post-create__container .emoji-rhs{position:relative;top:1px;right:-1px}.sidebar--right .post-create__container .msg-typing:empty{display:none}.sidebar--right .post-create__container .post-create-footer{padding:6px 0 0}.sidebar--right .post-create__container .post-create-footer .post-error{margin-bottom:8px}.sidebar--right .post-create__container .post-create-footer .control-label{top:0;margin:.5em 0}.sidebar--right .sidebar-collapse__container{display:table-cell;vertical-align:top}.sidebar--right .input-clear.visible{visibility:visible}.sidebar--right .sidebar--right__close{display:none}.sidebar--right .sidebar-right__body{height:calc(100% - 56px)}.search-items-container{height:calc(100% - 56px)}.inner-wrap{transition:all .35s ease}.app__body .inner-wrap::before{position:absolute;z-index:0;top:0;left:-15px;width:calc(100% + 30px);height:100%;background-color:transparent;content:"";transition:background-color .35s ease,z-index 0s ease .35s}.inner-wrap.move--right{transform:translate3d(0, 0, 0)}.inner-wrap.move--right::before{z-index:9999;background-color:rgba(0,0,0,.4);transition:all .35s ease}.inner-wrap.move--left-small{transform:translate3d(-290px, 0, 0)}.inner-wrap.move--left-small::before{z-index:9999;background-color:rgba(0,0,0,.4);transition:all .35s ease}.inner-wrap.move--left{margin:0;transform:translate3d(-100%, 0, 0)}.app__content{padding-top:50px;margin:0}.channel__wrap .app__content{padding-top:50px}.app__content #channel-header{display:none}.channel__wrap .row.header{display:block}.post-comments{padding:9px 21px 10px 10px !important}.multi-teams .app__content{margin-left:0}.multi-teams #SidebarContainer+.inner-wrap #app-content{margin-left:0}.multi-teams .sidebar--left,.multi-teams #SidebarContainer{left:0}.multi-teams .sidebar--left.move--right,.multi-teams #SidebarContainer.move--right{left:65px}.multi-teams .team-sidebar{display:none}.multi-teams .team-sidebar.move--right{display:flex;transform:translate3d(0, 0, 0)}.modal-body .MenuWrapper .Menu .dropdown-menu{top:35%;right:20%;left:unset}.signup-team-all{max-height:calc(75vh - (118px + 187px))}}@media screen and (max-width: 640px){body.browser--ie{min-width:600px}.section-min .d-flex{flex-direction:column}.multi-select__help{flex-direction:column}.multi-select__help>span:first-child{margin-bottom:1rem}.filtered-user-list{height:calc(100vh - 80px)}.more-modal--action .filtered-user-list{height:calc(100vh - 110px)}.app__body.announcement-bar--fixed .modal{padding-top:40px}.app__body .modal{overflow:hidden;padding:0}.app__body .modal .modal-dialog{max-width:100%;height:100%;margin:0}.app__body .modal .modal-footer{bottom:0;width:100%}.app__body .modal .about-modal .modal-content{display:flex;flex-direction:column}.app__body .modal .about-modal .modal-header{flex:0 0 70px;padding:0 25px}.app__body .modal .about-modal .modal-footer{position:relative}.app__body .modal .about-modal .modal-body{max-height:100%}.app__body .modal .about-modal .about-modal__content{display:block}.app__body .modal .about-modal .about-modal__hash p{word-break:break-all}.app__body .modal .about-modal .about-modal__hash p:first-child{float:none}.app__body .modal .about-modal .about-modal__logo{width:100%;padding:0;float:none;text-align:center}.app__body .modal .about-modal .about-modal__logo svg{width:100px;height:100px}.app__body .modal .about-modal .about-modal__logo+div{padding:2em 0 0}.app__body .modal .more-modal .modal-content{display:flex;flex-direction:column}.app__body .modal .more-modal .modal-body{display:flex;max-height:100%;flex:1 1 auto}.app__body .modal .more-modal .filtered-user-list{height:auto;flex:1 1 auto}.app__body .post .open>.dropdown-menu__content{display:table}.app__body .post .open>.dropdown-menu__content>.dropdown-menu{display:table-cell}.access-history__table>div{display:block}.access-history__table .access__report{margin:0 0 15px 15px}.access-history__table .access__date div{margin-bottom:15px}.activity-log__table>div{display:block}.activity-log__table .activity-log__report{width:100%}.activity-log__table .activity-log__action{margin-top:10px;text-align:left}}@media screen and (max-width: 550px){.file-view--single .file__image .image-loaded img{max-width:100%}.post .img-div{max-width:100%}.app__body .more-modal.more-system-members .filter-row{width:100%;min-height:80px}.app__body .more-modal.more-direct-channels .member-show{display:none}.app__body .more-modal.more-direct-channels select{width:100%;margin:0}.member-select__container{top:60px;left:15px;width:calc(100% - 30px)}}@media screen and (max-width: 480px){#user-profile-popover{left:50px !important}.emoji-picker__item{width:calc(100% / 9);padding-top:calc(100% / 9);margin:0}.post .attachment .attachment-actions button{width:100%}.nav-tabs{margin-top:1em}.nav-tabs>li{margin-right:0}.nav-tabs>li a{padding:6px 11px;font-size:.9em}.sidebar--right .post.post--compact .post__header{height:auto}.backstage-header h1{margin-bottom:15px;float:none}.backstage-header .add-integrations-link{float:none}.app__body .modal .settings-modal.display--content .modal-body{max-height:90%}.app__body .modal .settings-modal .modal-body{max-height:70%;padding-bottom:0}.app__body .modal .settings-modal .settings-table .security-links{display:block;margin-bottom:10px}.app__body .modal .settings-modal .settings-table .security-links:last-child{margin-bottom:0}.member-div{padding:8px 0}.member-div .member-drop,.member-div .member-role{position:relative;top:0;right:0;padding:5px 0;margin:0 0 0 44px}.member-div .open>.dropdown-menu{right:auto;left:0}.sidebar--left,#SidebarContainer{width:260px;transform:translate3d(-260px, 0, 0)}.inner-wrap.move--right{transform:translate3d(0, 0, 0)}.edit-modal-body--add-reaction{position:static}.edit-modal-body--add-reaction .emoji-picker{top:-1px !important;left:-1px !important;width:calc(100% + 2px);height:calc(100% + 2px)}}@media screen and (max-height: 640px){.signup-team__container{margin-bottom:30px;font-size:.9em}.signup-team__container .signup-team__name{font-size:2em}}@media screen and (max-width: 803px){.signup-team__container .terms-of-service-error__height--fill{height:calc(100vh - 121px - 4em);min-height:calc(100vh - 121px - 4em)}}@media screen and (max-width: 449px){.signup-team__container .terms-of-service-error__height--fill{height:calc(100vh - 138px - 4em);min-height:calc(100vh - 138px - 4em)}}@media screen and (max-width: 351px){.signup-team__container .terms-of-service-error__height--fill{height:calc(100vh - 145px - 4em);min-height:calc(100vh - 145px - 4em)}}@media screen and (max-width: 263px){.signup-team__container .terms-of-service-error__height--fill{height:calc(100vh - 173px - 4em);min-height:calc(100vh - 173px - 4em)}.signup-team__container .terms-of-service__height--fill{height:calc(100vh - 100px - 3em);min-height:calc(100vh - 100px - 3em)}}@media screen and (max-width: 350px){.post-attachment-dropdown::after{right:12px;left:auto}}@media screen and (max-width: 320px){.filter-row .Select--multi .Select-multi-value-wrapper{display:block;overflow:auto;max-height:50px}.filter-row .Select-input>input{padding:8px 0}.post.post--system .post__header{padding:0}.multi-teams .sidebar--left,.multi-teams #SidebarContainer{width:220px}.signup-team-all{max-height:calc(75vh - (111px + 187px))}}@media screen and (max-width: 380px)and (max-height: 580px){#navbar_wrapper .navbar-default .dropdown-menu{padding-top:1em}#navbar_wrapper .navbar-default .dropdown-menu>li>a{border:none;font-size:13px;line-height:27px}}label span{pointer-events:none}label span a{pointer-events:all}@media screen and (-webkit-min-device-pixel-ratio: 0){select,textarea,input{font-size:16px}}@media screen and (max-width: 960px){.system-users__filter-row{flex-direction:column}.system-users__filter-row .system-users__filter:first-child{flex:1 1 auto;padding-bottom:12px}.system-users__filter-row>label{margin-bottom:12px}.system-users__filter-row>label span{flex:0 0 auto;padding-left:0}.app__body .modal .modal-image .modal-image__wrapper img{max-height:calc(100vh - 108px)}.app__body .modal .modal-image .modal-image__wrapper>div{min-width:250px;font-size:12px}.app__body .modal .modal-image .modal-image__wrapper .modal-close{opacity:1}.app__body .modal .modal-image .modal-button-bar{bottom:20px;padding:5px 10px 5px 5px;line-height:30px}.post-create__container .channel-archived__close-btn{display:block;margin:10px auto 0}.help__format-text{display:none}.post-right__scroll .post-create__container .post-create-body .icon__emoji_picker{top:-7px;display:none}.signup-team__container.branded{display:block;max-width:380px;margin:0 auto}.signup-team__container.branded .signup__markdown{display:none}.backstage-content{max-width:100%;padding:0;margin:30px}.backstage-sidebar{position:relative;width:100%;height:auto;padding:30px 15px 0}.post .attachment .attachment__image.attachment__image--opengraph{max-width:100%;max-height:70px}.post .attachment .attachment__image.attachment__image--opengraph.loading{height:70px}}@media(min-width: 880px){.post-collapse__show-more{padding-right:60px}.post-attachment-collapse__show-more{padding-right:0}.sidebar--right .post-collapse__show-more,.sidebar--right .post-attachment-collapse__show-more{padding-right:0}}@media screen and (min-width: 769px){>header{z-index:2}>header+*{position:relative;z-index:1}.channel__wrap.move--left #channel-header{width:calc(100% - 400px)}.search-help-popover{width:274px}.channel-header__popover{top:44px !important;left:236px !important}.col-sm-auto{float:left}.second-bar{display:none}.channel-header .search-bar__container .search__form--focused{width:274px}.sidebar--right{top:63px}.announcement-bar--fixed .sidebar--right{top:95px}.sidebar--right.move--left{transform:translateX(0)}.sidebar--right.move--left .search-bar__container{display:none}.sidebar--right.sidebar--right--expanded{width:calc(100% - 220px - 48px)}.multi-teams .sidebar--right.sidebar--right--expanded{width:calc(100% - 285px - 48px)}.sidebar--right.sidebar--right--expanded .search-bar__container{padding-left:10px}.sidebar--right.sidebar--right--expanded .sidebar-right-container{position:relative;z-index:5}.sidebar--right.sidebar--right--expanded .sidebar--right__expand .icon-arrow-expand{display:none}.sidebar--right.sidebar--right--expanded .sidebar--right__expand .icon-arrow-collapse{display:inline-block}.move--left #post-list{margin-right:400px}.move--left .app__content>.post-create__container{width:calc(100% - 400px)}.post.post--compact .post-message--overflow{overflow:hidden;*zoom:1;margin-top:22px}.post.post--compact .attachment__body .post-message--overflow{margin-top:0}.post.post--compact.same--root.same--user{padding-top:0;padding-left:77px}.post.post--compact.same--root.same--user .post-message.post-message--overflow{margin-top:0}.post.post--compact.same--root.same--user .card-icon__container{position:absolute;top:4px;left:-16px}.post.post--compact.same--root.same--user .post__header .post-menu{top:-34px}.post.post--compact.same--root.same--user .post__img img{display:none}.post.post--compact.same--root.same--user.post--root .post__img img,.post.post--compact.same--root.same--user .post-preview .post__img img{display:block}.post.post--compact.same--root.same--user.post--root .post__time,.post.post--compact.same--root.same--user .post-preview .post__time{opacity:.6}.post.post--compact.same--root.post--comment.same--user .post__img img{display:none}.post.post--compact.same--root.post--comment .post__header{margin-left:12px}.post.post--compact.post--comment.other--root .post-message.post-message--overflow{margin-top:0}.post.post--compact.post--thread .post-message.post-message--overflow{margin-top:0}.channel__wrap #post-list .post.post--compact .post__permalink{position:absolute;top:1px;left:-76px;width:60px;text-align:right}.channel__wrap #post-list .post.post--compact .post__time{font-size:.85em}.channel__wrap #post-list .post.post--compact .star-icon__container{position:absolute;top:6px;left:-65px;width:60px;text-align:right}.post.post--compact:not(.post--thread){padding:0 .5em 0 77px}.post.post--compact:not(.post--thread) .post__link{margin:3px 0 7px;vertical-align:bottom}.post.post--compact:not(.post--thread) span p:last-child{margin-bottom:0}.post.post--compact:not(.post--thread) .post__header{padding-top:2px;padding-right:0;float:left}.post.post--compact:not(.post--thread) .post__header .col__name{position:relative;z-index:1;padding-right:5px;margin-right:2px;font-weight:bold}.post.post--compact:not(.post--thread) .post__header .colon{display:inline}.post.post--compact:not(.post--thread) .post__header .post-menu{top:-12px}.post.post--compact:not(.post--thread).other--root .post__link+.post__body{clear:both}.post.post--compact:not(.post--thread).other--root.post--comment .post__header .post-menu{top:-12px}.post.post--compact:not(.post--thread) .post-code{clear:both}.post.post--compact:not(.post--thread) .post__body{width:100%}.post.post--compact:not(.post--thread) .post__content{padding-right:45px}.sidebar--right .post.post--compact .card-icon__container{position:relative;top:2px;left:auto}.post.same--root.same--user .post__time{opacity:0}.post.same--root.same--user .post__header{float:left}.post.same--root.same--user .post__header .post-menu{top:-32px}.post.same--root.same--user:not(.post--compact) .post__permalink{position:absolute;top:2px;left:-18px}.sidebar--right .post.same--root.same--user:not(.post--compact) .post__permalink{top:1px;left:-18px}.post.same--root.same--user:not(.post--compact) .post__time{display:inline-block;width:51px;font-size:12px;line-height:20px;text-align:right;text-rendering:auto}.post.same--root.same--user:not(.post--compact) .post__time:hover{text-decoration:underline}.post-row__padding.top .post--compact{padding-top:1em}.post-row__padding.bottom .post--compact{padding-bottom:1em}}@media screen and (max-width: 1020px){.channel-header{z-index:5}.sidebar--right{z-index:13;top:0;transform:translateX(100%);transition:all .35s ease}.announcement-bar--fixed .sidebar--right{top:32px}.sidebar--right .sidebar-right-container{height:100%}.sidebar--right.move--left{-webkit-transform:translateX(0) !important;-moz-transform:translateX(0) !important;-ms-transform:translateX(0) !important;-o-transform:translateX(0) !important;transform:translateX(0) !important}.browser--ie .sidebar--right.move--left{display:block;-webkit-transform:none !important;-moz-transform:none !important;-ms-transform:none !important;-o-transform:none !important;transform:none !important}.sidebar--right.move--left .search-bar__container{z-index:5;display:block !important}.sidebar--right.move--left .search-bar__container .search__form{width:100% !important}.inner-wrap:not(.move--left) .app__content>#post-list{margin-right:0 !important}.inner-wrap:not(.move--left) .app__content>.post-create__container{width:100% !important}.inner-wrap.move--left .search-bar__container{display:none}.inner-wrap.move--left .app__content>#post-list{margin-right:0 !important}.inner-wrap.move--left .app__content>.post-create__container{width:100% !important}.inner-wrap.move--left .channel-header__links{position:relative;top:auto;right:auto}.inner-wrap.move--left .header-list__right,.inner-wrap.move--right .header-list__right{z-index:-1}}@media screen and (min-width: 1680px){.sidebar--right{width:500px}.sidebar--right .sidebar--right__title__channel{max-width:30rem}.channel-header .search-bar__container .search__form--focused,.GlobalThreads .Header .search-bar__container .search__form--focused{width:374px;max-width:374px}.inner-wrap.move--left .search__form{width:374px}.inner-wrap.move--left .ActivityAndInsights,.inner-wrap.move--left #post-list{margin-right:500px}.inner-wrap.move--left .app__content>.post-create__container{width:calc(100% - 500px)}.channel__wrap.move--left #channel-header{width:calc(100% - 500px)}}@media screen and (max-width: 1800px){.inner-wrap.move--left .date-separator.hovered--comment::before,.inner-wrap.move--left .date-separator.hovered--comment::after,.inner-wrap.move--left .new-separator.hovered--comment::before,.inner-wrap.move--left .new-separator.hovered--comment::after{background:none}}@media screen and (max-width: 1440px){.inner-wrap.move--left .help__format-text{display:none}.backstage-content{margin:46px 46px 46px 150px}}@media screen and (max-width: 1280px){.inner-wrap.move--left .post-collapse__show-more,.inner-wrap.move--left .post-attachment-collapse__show-more{margin-left:0}.inner-wrap.move--left .post-create__container .channel-archived__close-btn{display:block;margin:10px auto 0}.integration-option{flex:0 0 45%}}@media screen and (max-width: 1140px){.inner-wrap.move--left .file-overlay{font-size:1.2857142857em}.inner-wrap.move--left .file-overlay .overlay__circle{width:300px;height:300px;margin:-150px 0 0 -150px}.inner-wrap.move--left .file-overlay .overlay__files{width:150px;margin:60px auto 15px}}@media(max-width: 1024px){.inner-wrap:not(.move--left) .channel-header .search-bar__container .search__form,.inner-wrap:not(.move--left) .GlobalThreads .Header .search-bar__container .search__form{width:150px}.search-bar__container{padding:0 4px 0 0}}@media screen and (max-width: 1020px){.channel__wrap.move--left #channel-header{width:100%}}@media(min-width: 1280px){.sidebar--right.sidebar--right--expanded{width:96rem}.multi-teams .sidebar--right.sidebar--right--expanded{width:96rem}}@media(min-width: 1025px){.post-image__details .post-image__download{opacity:0}}@media(min-width: 992px){.modal-lg{width:700px}}.LoadingBars.with-text .spinner{margin-right:5px}.LoadingSpinner.with-text .spinner{margin-right:5px}:root{--sys-away-indicator: #ffbc1f;--sys-away-indicator-dark: #997113;--sys-button-bg: #166de0;--sys-button-color: #fff;--sys-center-channel-bg: #fff;--sys-center-channel-color: #3d3c40;--sys-dnd-indicator: #f74343;--sys-error-text: #d24b4e;--sys-link-color: #2389d7;--sys-mention-bg: #fff;--sys-mention-color: #145dbf;--sys-mention-highlight-bg: #ffe577;--sys-mention-highlight-link: #166de0;--sys-new-message-separator: #f80;--sys-online-indicator: #3db887;--sys-sidebar-bg: #145dbf;--sys-sidebar-header-bg: #1153ab;--sys-sidebar-header-text-color: #fff;--sys-sidebar-text: #fff;--sys-sidebar-text-60: #fff9;--sys-sidebar-text-80: #fffc;--sys-sidebar-text-active-border: #5d89ea;--sys-sidebar-text-active-color: #fff;--sys-sidebar-text-hover-bg: #4578bf;--sys-sidebar-unread-text: #fff;--sys-denim-button-bg: #1c58d9;--sys-denim-center-channel-text: #3f4350;--sys-away-indicator-rgb: 255, 188, 31;--sys-away-indicator-dark-rgb: 153, 113, 19;--sys-button-bg-rgb: 22, 109, 224;--sys-button-color-rgb: 255, 255, 255;--sys-center-channel-bg-rgb: 255, 255, 255;--sys-center-channel-color-rgb: 61, 60, 64;--sys-dnd-indicator-rgb: 247, 67, 67;--sys-error-text-color-rgb: 210, 75, 78;--sys-link-color-rgb: 35, 137, 215;--sys-mention-bg-rgb: 255, 255, 255;--sys-mention-color-rgb: 20, 93, 191;--sys-mention-highlight-bg-rgb: 255, 229, 119;--sys-mention-highlight-link-rgb: 22, 109, 224;--sys-new-message-separator-rgb: 255, 136, 0;--sys-online-indicator-rgb: 61, 184, 135;--sys-sidebar-bg-rgb: 20, 93, 191;--sys-sidebar-header-bg-rgb: 17, 83, 171;--sys-sidebar-header-text-color-rgb: 255, 255, 255;--sys-sidebar-text-rgb: 255, 255, 255;--sys-sidebar-text-active-border-rgb: 93, 137, 234;--sys-sidebar-text-active-color-rgb: 255, 255, 255;--sys-sidebar-text-hover-bg-rgb: 69, 120, 191;--sys-sidebar-unread-text-rgb: 255, 255, 255;--sys-denim-button-bg-rgb: 28, 88, 217;--sys-denim-center-channel-text-rgb: 63, 67, 80}
@font-face{font-family:KaTeX_AMS;font-style:normal;font-weight:400;src:url(/static/files/1de15e70fec550ef4554de45895cd073.woff2) format("woff2"),url(/static/files/96a57080955dae1ca302c76abb8af909.woff) format("woff"),url(/static/files/f453c078392f0c23335ea604c6765a12.ttf) format("truetype")}@font-face{font-family:KaTeX_Caligraphic;font-style:normal;font-weight:700;src:url(/static/files/5839401331dd0fbe22436cb27c8fcb73.woff2) format("woff2"),url(/static/files/c6297f9142925c50bd7828b90c103526.woff) format("woff"),url(/static/files/ec522b9ccc3e18028de1440991b38119.ttf) format("truetype")}@font-face{font-family:KaTeX_Caligraphic;font-style:normal;font-weight:400;src:url(/static/files/f96fac9755151d0fabd8ed9abdca9521.woff2) format("woff2"),url(/static/files/5079e051e18b6b617208b8cb5beb1082.woff) format("woff"),url(/static/files/703345f865eeee24c474248079a0ba93.ttf) format("truetype")}@font-face{font-family:KaTeX_Fraktur;font-style:normal;font-weight:700;src:url(/static/files/49cc6a3cab050d7c2ec2336cb804e1fc.woff2) format("woff2"),url(/static/files/0e5b99ca96d68358cdbbf0eb132e0bf3.woff) format("woff"),url(/static/files/459e524c11f9d9848bd73bfffdc62077.ttf) format("truetype")}@font-face{font-family:KaTeX_Fraktur;font-style:normal;font-weight:400;src:url(/static/files/77291f2c01508dbfa5a0e8fc8de4acb6.woff2) format("woff2"),url(/static/files/a33d4c9142212ef3479287135a87faac.woff) format("woff"),url(/static/files/1b0be9b9502d481bf047c11fd3afce41.ttf) format("truetype")}@font-face{font-family:KaTeX_Main;font-style:normal;font-weight:700;src:url(/static/files/fc4e48b59849688ac61c0d6daa6c3894.woff2) format("woff2"),url(/static/files/e8c40ca220bf98110e3d2a9bccc040b4.woff) format("woff"),url(/static/files/c0ad9a0fcd3872a71585a52543d02054.ttf) format("truetype")}@font-face{font-family:KaTeX_Main;font-style:italic;font-weight:700;src:url(/static/files/7e6803e0645cc02029a2b4b9b5c12dd0.woff2) format("woff2"),url(/static/files/4e9fb7097be319b4a3a323dca0626460.woff) format("woff"),url(/static/files/8b9b3524a9cd80e00610682ca9d48b7a.ttf) format("truetype")}@font-face{font-family:KaTeX_Main;font-style:italic;font-weight:400;src:url(/static/files/83915f6ea43188e031f15a41a2a13d0e.woff2) format("woff2"),url(/static/files/993cef711838adabce3a8b5b1c4a1901.woff) format("woff"),url(/static/files/7712cfa8ed8093a0c556b7ff8abf14f9.ttf) format("truetype")}@font-face{font-family:KaTeX_Main;font-style:normal;font-weight:400;src:url(/static/files/6f4b7338e13e491465211e73cc3d9ab2.woff2) format("woff2"),url(/static/files/3402ceebbaf069244380e282045d5615.woff) format("woff"),url(/static/files/9f78515e97ad0ff068507c103e83409d.ttf) format("truetype")}@font-face{font-family:KaTeX_Math;font-style:italic;font-weight:700;src:url(/static/files/2ffefb11f0c8412c11682bd0e1413b69.woff2) format("woff2"),url(/static/files/1d2e94d7e1264031867f942653f8139a.woff) format("woff"),url(/static/files/4ad93799ba7ea7199a6f27826a40b061.ttf) format("truetype")}@font-face{font-family:KaTeX_Math;font-style:italic;font-weight:400;src:url(/static/files/f9f7662953c4ef2ee65e1f3a935f9017.woff2) format("woff2"),url(/static/files/23820bbae1b543ae8cb70fe44d40809f.woff) format("woff"),url(/static/files/ac5aad6c4efef1a3d20b75397b7e6218.ttf) format("truetype")}@font-face{font-family:"KaTeX_SansSerif";font-style:normal;font-weight:700;src:url(/static/files/2bd0c2b5932c7e74bc69ff108c7746e3.woff2) format("woff2"),url(/static/files/31faa94a6e7e3e4dc3a777c1244a3d0b.woff) format("woff"),url(/static/files/04adc05e48582c893f35f05dfdc35cbc.ttf) format("truetype")}@font-face{font-family:"KaTeX_SansSerif";font-style:italic;font-weight:400;src:url(/static/files/fd4eccab43b2f46bac37538fc682154d.woff2) format("woff2"),url(/static/files/374a109b61e7c419be444a6ad27c8f8c.woff) format("woff"),url(/static/files/775f93f04f3a0bdcfecbc62e733847f1.ttf) format("truetype")}@font-face{font-family:"KaTeX_SansSerif";font-style:normal;font-weight:400;src:url(/static/files/7c3661bed01acdb90f0d0d6e8c2af175.woff2) format("woff2"),url(/static/files/8f5c4dcd24a0f3aa86380f0b3562eccd.woff) format("woff"),url(/static/files/1e909f1c2ba50ad8581dc75d86559eda.ttf) format("truetype")}@font-face{font-family:KaTeX_Script;font-style:normal;font-weight:400;src:url(/static/files/3c431f15b18a392c1711d7de01edf4f3.woff2) format("woff2"),url(/static/files/8cb4c7b5986d922a2dcdb6599a6106a9.woff) format("woff"),url(/static/files/36d2c2a98402f4c0cb1029a69f2b9806.ttf) format("truetype")}@font-face{font-family:KaTeX_Size1;font-style:normal;font-weight:400;src:url(/static/files/b3e926468f875c4b6a966d901c879696.woff2) format("woff2"),url(/static/files/b609c3dc1fbbb105ce2856c03d8db6e1.woff) format("woff"),url(/static/files/70d540a088e8e125414815b6afda0e3d.ttf) format("truetype")}@font-face{font-family:KaTeX_Size2;font-style:normal;font-weight:400;src:url(/static/files/a4aae3d505525c8eb88b9158c4649a7b.woff2) format("woff2"),url(/static/files/ca8ea1e72772a43ae46c4f7fb986b1fa.woff) format("woff"),url(/static/files/7534552259d59c1cba3e86a3c774b8e8.ttf) format("truetype")}@font-face{font-family:KaTeX_Size3;font-style:normal;font-weight:400;src:url(/static/files/08fca0137fd475f7852ab73e275e2208.woff2) format("woff2"),url(/static/files/cddcf234909da33bbfc0c37ecd11f60f.woff) format("woff"),url(/static/files/c7977d0148e0d53d73a8adda49f2fd8e.ttf) format("truetype")}@font-face{font-family:KaTeX_Size4;font-style:normal;font-weight:400;src:url(/static/files/1b0cff973201019de91c24530ab219c3.woff2) format("woff2"),url(/static/files/e84eaeda24afadafd7b6e246209d7a05.woff) format("woff"),url(/static/files/f93eac2f0543333d30a6abf9262ec864.ttf) format("truetype")}@font-face{font-family:KaTeX_Typewriter;font-style:normal;font-weight:400;src:url(/static/files/209b10f4e35040ca859c96177c458cc6.woff2) format("woff2"),url(/static/files/b6a56b14d09ea3eb5f01e0bbd2b20101.woff) format("woff"),url(/static/files/834915271cbece10d426ea41e479cfff.ttf) format("truetype")}.katex{font:normal 1.21em KaTeX_Main,Times New Roman,serif;line-height:1.2;text-indent:0;text-rendering:auto}.katex *{-ms-high-contrast-adjust:none!important;border-color:currentColor}.katex .katex-version:after{content:"0.13.11"}.katex .katex-mathml{clip:rect(1px,1px,1px,1px);border:0;height:1px;overflow:hidden;padding:0;position:absolute;width:1px}.katex .katex-html>.newline{display:block}.katex .base{position:relative;white-space:nowrap;width:-webkit-min-content;width:-moz-min-content;width:min-content}.katex .base,.katex .strut{display:inline-block}.katex .textbf{font-weight:700}.katex .textit{font-style:italic}.katex .textrm{font-family:KaTeX_Main}.katex .textsf{font-family:KaTeX_SansSerif}.katex .texttt{font-family:KaTeX_Typewriter}.katex .mathnormal{font-family:KaTeX_Math;font-style:italic}.katex .mathit{font-family:KaTeX_Main;font-style:italic}.katex .mathrm{font-style:normal}.katex .mathbf{font-family:KaTeX_Main;font-weight:700}.katex .boldsymbol{font-family:KaTeX_Math;font-style:italic;font-weight:700}.katex .amsrm,.katex .mathbb,.katex .textbb{font-family:KaTeX_AMS}.katex .mathcal{font-family:KaTeX_Caligraphic}.katex .mathfrak,.katex .textfrak{font-family:KaTeX_Fraktur}.katex .mathtt{font-family:KaTeX_Typewriter}.katex .mathscr,.katex .textscr{font-family:KaTeX_Script}.katex .mathsf,.katex .textsf{font-family:KaTeX_SansSerif}.katex .mathboldsf,.katex .textboldsf{font-family:KaTeX_SansSerif;font-weight:700}.katex .mathitsf,.katex .textitsf{font-family:KaTeX_SansSerif;font-style:italic}.katex .mainrm{font-family:KaTeX_Main;font-style:normal}.katex .vlist-t{border-collapse:collapse;display:inline-table;table-layout:fixed}.katex .vlist-r{display:table-row}.katex .vlist{display:table-cell;position:relative;vertical-align:bottom}.katex .vlist>span{display:block;height:0;position:relative}.katex .vlist>span>span{display:inline-block}.katex .vlist>span>.pstrut{overflow:hidden;width:0}.katex .vlist-t2{margin-right:-2px}.katex .vlist-s{display:table-cell;font-size:1px;min-width:2px;vertical-align:bottom;width:2px}.katex .vbox{-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-box-align:baseline;align-items:baseline;display:-webkit-inline-box;display:inline-flex;flex-direction:column}.katex .hbox{width:100%}.katex .hbox,.katex .thinbox{-webkit-box-orient:horizontal;-webkit-box-direction:normal;display:-webkit-inline-box;display:inline-flex;flex-direction:row}.katex .thinbox{max-width:0;width:0}.katex .msupsub{text-align:left}.katex .mfrac>span>span{text-align:center}.katex .mfrac .frac-line{border-bottom-style:solid;display:inline-block;width:100%}.katex .hdashline,.katex .hline,.katex .mfrac .frac-line,.katex .overline .overline-line,.katex .rule,.katex .underline .underline-line{min-height:1px}.katex .mspace{display:inline-block}.katex .clap,.katex .llap,.katex .rlap{position:relative;width:0}.katex .clap>.inner,.katex .llap>.inner,.katex .rlap>.inner{position:absolute}.katex .clap>.fix,.katex .llap>.fix,.katex .rlap>.fix{display:inline-block}.katex .llap>.inner{right:0}.katex .clap>.inner,.katex .rlap>.inner{left:0}.katex .clap>.inner>span{margin-left:-50%;margin-right:50%}.katex .rule{border:0 solid;display:inline-block;position:relative}.katex .hline,.katex .overline .overline-line,.katex .underline .underline-line{border-bottom-style:solid;display:inline-block;width:100%}.katex .hdashline{border-bottom-style:dashed;display:inline-block;width:100%}.katex .sqrt>.root{margin-left:.27777778em;margin-right:-.55555556em}.katex .fontsize-ensurer.reset-size1.size1,.katex .sizing.reset-size1.size1{font-size:1em}.katex .fontsize-ensurer.reset-size1.size2,.katex .sizing.reset-size1.size2{font-size:1.2em}.katex .fontsize-ensurer.reset-size1.size3,.katex .sizing.reset-size1.size3{font-size:1.4em}.katex .fontsize-ensurer.reset-size1.size4,.katex .sizing.reset-size1.size4{font-size:1.6em}.katex .fontsize-ensurer.reset-size1.size5,.katex .sizing.reset-size1.size5{font-size:1.8em}.katex .fontsize-ensurer.reset-size1.size6,.katex .sizing.reset-size1.size6{font-size:2em}.katex .fontsize-ensurer.reset-size1.size7,.katex .sizing.reset-size1.size7{font-size:2.4em}.katex .fontsize-ensurer.reset-size1.size8,.katex .sizing.reset-size1.size8{font-size:2.88em}.katex .fontsize-ensurer.reset-size1.size9,.katex .sizing.reset-size1.size9{font-size:3.456em}.katex .fontsize-ensurer.reset-size1.size10,.katex .sizing.reset-size1.size10{font-size:4.148em}.katex .fontsize-ensurer.reset-size1.size11,.katex .sizing.reset-size1.size11{font-size:4.976em}.katex .fontsize-ensurer.reset-size2.size1,.katex .sizing.reset-size2.size1{font-size:.83333333em}.katex .fontsize-ensurer.reset-size2.size2,.katex .sizing.reset-size2.size2{font-size:1em}.katex .fontsize-ensurer.reset-size2.size3,.katex .sizing.reset-size2.size3{font-size:1.16666667em}.katex .fontsize-ensurer.reset-size2.size4,.katex .sizing.reset-size2.size4{font-size:1.33333333em}.katex .fontsize-ensurer.reset-size2.size5,.katex .sizing.reset-size2.size5{font-size:1.5em}.katex .fontsize-ensurer.reset-size2.size6,.katex .sizing.reset-size2.size6{font-size:1.66666667em}.katex .fontsize-ensurer.reset-size2.size7,.katex .sizing.reset-size2.size7{font-size:2em}.katex .fontsize-ensurer.reset-size2.size8,.katex .sizing.reset-size2.size8{font-size:2.4em}.katex .fontsize-ensurer.reset-size2.size9,.katex .sizing.reset-size2.size9{font-size:2.88em}.katex .fontsize-ensurer.reset-size2.size10,.katex .sizing.reset-size2.size10{font-size:3.45666667em}.katex .fontsize-ensurer.reset-size2.size11,.katex .sizing.reset-size2.size11{font-size:4.14666667em}.katex .fontsize-ensurer.reset-size3.size1,.katex .sizing.reset-size3.size1{font-size:.71428571em}.katex .fontsize-ensurer.reset-size3.size2,.katex .sizing.reset-size3.size2{font-size:.85714286em}.katex .fontsize-ensurer.reset-size3.size3,.katex .sizing.reset-size3.size3{font-size:1em}.katex .fontsize-ensurer.reset-size3.size4,.katex .sizing.reset-size3.size4{font-size:1.14285714em}.katex .fontsize-ensurer.reset-size3.size5,.katex .sizing.reset-size3.size5{font-size:1.28571429em}.katex .fontsize-ensurer.reset-size3.size6,.katex .sizing.reset-size3.size6{font-size:1.42857143em}.katex .fontsize-ensurer.reset-size3.size7,.katex .sizing.reset-size3.size7{font-size:1.71428571em}.katex .fontsize-ensurer.reset-size3.size8,.katex .sizing.reset-size3.size8{font-size:2.05714286em}.katex .fontsize-ensurer.reset-size3.size9,.katex .sizing.reset-size3.size9{font-size:2.46857143em}.katex .fontsize-ensurer.reset-size3.size10,.katex .sizing.reset-size3.size10{font-size:2.96285714em}.katex .fontsize-ensurer.reset-size3.size11,.katex .sizing.reset-size3.size11{font-size:3.55428571em}.katex .fontsize-ensurer.reset-size4.size1,.katex .sizing.reset-size4.size1{font-size:.625em}.katex .fontsize-ensurer.reset-size4.size2,.katex .sizing.reset-size4.size2{font-size:.75em}.katex .fontsize-ensurer.reset-size4.size3,.katex .sizing.reset-size4.size3{font-size:.875em}.katex .fontsize-ensurer.reset-size4.size4,.katex .sizing.reset-size4.size4{font-size:1em}.katex .fontsize-ensurer.reset-size4.size5,.katex .sizing.reset-size4.size5{font-size:1.125em}.katex .fontsize-ensurer.reset-size4.size6,.katex .sizing.reset-size4.size6{font-size:1.25em}.katex .fontsize-ensurer.reset-size4.size7,.katex .sizing.reset-size4.size7{font-size:1.5em}.katex .fontsize-ensurer.reset-size4.size8,.katex .sizing.reset-size4.size8{font-size:1.8em}.katex .fontsize-ensurer.reset-size4.size9,.katex .sizing.reset-size4.size9{font-size:2.16em}.katex .fontsize-ensurer.reset-size4.size10,.katex .sizing.reset-size4.size10{font-size:2.5925em}.katex .fontsize-ensurer.reset-size4.size11,.katex .sizing.reset-size4.size11{font-size:3.11em}.katex .fontsize-ensurer.reset-size5.size1,.katex .sizing.reset-size5.size1{font-size:.55555556em}.katex .fontsize-ensurer.reset-size5.size2,.katex .sizing.reset-size5.size2{font-size:.66666667em}.katex .fontsize-ensurer.reset-size5.size3,.katex .sizing.reset-size5.size3{font-size:.77777778em}.katex .fontsize-ensurer.reset-size5.size4,.katex .sizing.reset-size5.size4{font-size:.88888889em}.katex .fontsize-ensurer.reset-size5.size5,.katex .sizing.reset-size5.size5{font-size:1em}.katex .fontsize-ensurer.reset-size5.size6,.katex .sizing.reset-size5.size6{font-size:1.11111111em}.katex .fontsize-ensurer.reset-size5.size7,.katex .sizing.reset-size5.size7{font-size:1.33333333em}.katex .fontsize-ensurer.reset-size5.size8,.katex .sizing.reset-size5.size8{font-size:1.6em}.katex .fontsize-ensurer.reset-size5.size9,.katex .sizing.reset-size5.size9{font-size:1.92em}.katex .fontsize-ensurer.reset-size5.size10,.katex .sizing.reset-size5.size10{font-size:2.30444444em}.katex .fontsize-ensurer.reset-size5.size11,.katex .sizing.reset-size5.size11{font-size:2.76444444em}.katex .fontsize-ensurer.reset-size6.size1,.katex .sizing.reset-size6.size1{font-size:.5em}.katex .fontsize-ensurer.reset-size6.size2,.katex .sizing.reset-size6.size2{font-size:.6em}.katex .fontsize-ensurer.reset-size6.size3,.katex .sizing.reset-size6.size3{font-size:.7em}.katex .fontsize-ensurer.reset-size6.size4,.katex .sizing.reset-size6.size4{font-size:.8em}.katex .fontsize-ensurer.reset-size6.size5,.katex .sizing.reset-size6.size5{font-size:.9em}.katex .fontsize-ensurer.reset-size6.size6,.katex .sizing.reset-size6.size6{font-size:1em}.katex .fontsize-ensurer.reset-size6.size7,.katex .sizing.reset-size6.size7{font-size:1.2em}.katex .fontsize-ensurer.reset-size6.size8,.katex .sizing.reset-size6.size8{font-size:1.44em}.katex .fontsize-ensurer.reset-size6.size9,.katex .sizing.reset-size6.size9{font-size:1.728em}.katex .fontsize-ensurer.reset-size6.size10,.katex .sizing.reset-size6.size10{font-size:2.074em}.katex .fontsize-ensurer.reset-size6.size11,.katex .sizing.reset-size6.size11{font-size:2.488em}.katex .fontsize-ensurer.reset-size7.size1,.katex .sizing.reset-size7.size1{font-size:.41666667em}.katex .fontsize-ensurer.reset-size7.size2,.katex .sizing.reset-size7.size2{font-size:.5em}.katex .fontsize-ensurer.reset-size7.size3,.katex .sizing.reset-size7.size3{font-size:.58333333em}.katex .fontsize-ensurer.reset-size7.size4,.katex .sizing.reset-size7.size4{font-size:.66666667em}.katex .fontsize-ensurer.reset-size7.size5,.katex .sizing.reset-size7.size5{font-size:.75em}.katex .fontsize-ensurer.reset-size7.size6,.katex .sizing.reset-size7.size6{font-size:.83333333em}.katex .fontsize-ensurer.reset-size7.size7,.katex .sizing.reset-size7.size7{font-size:1em}.katex .fontsize-ensurer.reset-size7.size8,.katex .sizing.reset-size7.size8{font-size:1.2em}.katex .fontsize-ensurer.reset-size7.size9,.katex .sizing.reset-size7.size9{font-size:1.44em}.katex .fontsize-ensurer.reset-size7.size10,.katex .sizing.reset-size7.size10{font-size:1.72833333em}.katex .fontsize-ensurer.reset-size7.size11,.katex .sizing.reset-size7.size11{font-size:2.07333333em}.katex .fontsize-ensurer.reset-size8.size1,.katex .sizing.reset-size8.size1{font-size:.34722222em}.katex .fontsize-ensurer.reset-size8.size2,.katex .sizing.reset-size8.size2{font-size:.41666667em}.katex .fontsize-ensurer.reset-size8.size3,.katex .sizing.reset-size8.size3{font-size:.48611111em}.katex .fontsize-ensurer.reset-size8.size4,.katex .sizing.reset-size8.size4{font-size:.55555556em}.katex .fontsize-ensurer.reset-size8.size5,.katex .sizing.reset-size8.size5{font-size:.625em}.katex .fontsize-ensurer.reset-size8.size6,.katex .sizing.reset-size8.size6{font-size:.69444444em}.katex .fontsize-ensurer.reset-size8.size7,.katex .sizing.reset-size8.size7{font-size:.83333333em}.katex .fontsize-ensurer.reset-size8.size8,.katex .sizing.reset-size8.size8{font-size:1em}.katex .fontsize-ensurer.reset-size8.size9,.katex .sizing.reset-size8.size9{font-size:1.2em}.katex .fontsize-ensurer.reset-size8.size10,.katex .sizing.reset-size8.size10{font-size:1.44027778em}.katex .fontsize-ensurer.reset-size8.size11,.katex .sizing.reset-size8.size11{font-size:1.72777778em}.katex .fontsize-ensurer.reset-size9.size1,.katex .sizing.reset-size9.size1{font-size:.28935185em}.katex .fontsize-ensurer.reset-size9.size2,.katex .sizing.reset-size9.size2{font-size:.34722222em}.katex .fontsize-ensurer.reset-size9.size3,.katex .sizing.reset-size9.size3{font-size:.40509259em}.katex .fontsize-ensurer.reset-size9.size4,.katex .sizing.reset-size9.size4{font-size:.46296296em}.katex .fontsize-ensurer.reset-size9.size5,.katex .sizing.reset-size9.size5{font-size:.52083333em}.katex .fontsize-ensurer.reset-size9.size6,.katex .sizing.reset-size9.size6{font-size:.5787037em}.katex .fontsize-ensurer.reset-size9.size7,.katex .sizing.reset-size9.size7{font-size:.69444444em}.katex .fontsize-ensurer.reset-size9.size8,.katex .sizing.reset-size9.size8{font-size:.83333333em}.katex .fontsize-ensurer.reset-size9.size9,.katex .sizing.reset-size9.size9{font-size:1em}.katex .fontsize-ensurer.reset-size9.size10,.katex .sizing.reset-size9.size10{font-size:1.20023148em}.katex .fontsize-ensurer.reset-size9.size11,.katex .sizing.reset-size9.size11{font-size:1.43981481em}.katex .fontsize-ensurer.reset-size10.size1,.katex .sizing.reset-size10.size1{font-size:.24108004em}.katex .fontsize-ensurer.reset-size10.size2,.katex .sizing.reset-size10.size2{font-size:.28929605em}.katex .fontsize-ensurer.reset-size10.size3,.katex .sizing.reset-size10.size3{font-size:.33751205em}.katex .fontsize-ensurer.reset-size10.size4,.katex .sizing.reset-size10.size4{font-size:.38572806em}.katex .fontsize-ensurer.reset-size10.size5,.katex .sizing.reset-size10.size5{font-size:.43394407em}.katex .fontsize-ensurer.reset-size10.size6,.katex .sizing.reset-size10.size6{font-size:.48216008em}.katex .fontsize-ensurer.reset-size10.size7,.katex .sizing.reset-size10.size7{font-size:.57859209em}.katex .fontsize-ensurer.reset-size10.size8,.katex .sizing.reset-size10.size8{font-size:.69431051em}.katex .fontsize-ensurer.reset-size10.size9,.katex .sizing.reset-size10.size9{font-size:.83317261em}.katex .fontsize-ensurer.reset-size10.size10,.katex .sizing.reset-size10.size10{font-size:1em}.katex .fontsize-ensurer.reset-size10.size11,.katex .sizing.reset-size10.size11{font-size:1.19961427em}.katex .fontsize-ensurer.reset-size11.size1,.katex .sizing.reset-size11.size1{font-size:.20096463em}.katex .fontsize-ensurer.reset-size11.size2,.katex .sizing.reset-size11.size2{font-size:.24115756em}.katex .fontsize-ensurer.reset-size11.size3,.katex .sizing.reset-size11.size3{font-size:.28135048em}.katex .fontsize-ensurer.reset-size11.size4,.katex .sizing.reset-size11.size4{font-size:.32154341em}.katex .fontsize-ensurer.reset-size11.size5,.katex .sizing.reset-size11.size5{font-size:.36173633em}.katex .fontsize-ensurer.reset-size11.size6,.katex .sizing.reset-size11.size6{font-size:.40192926em}.katex .fontsize-ensurer.reset-size11.size7,.katex .sizing.reset-size11.size7{font-size:.48231511em}.katex .fontsize-ensurer.reset-size11.size8,.katex .sizing.reset-size11.size8{font-size:.57877814em}.katex .fontsize-ensurer.reset-size11.size9,.katex .sizing.reset-size11.size9{font-size:.69453376em}.katex .fontsize-ensurer.reset-size11.size10,.katex .sizing.reset-size11.size10{font-size:.83360129em}.katex .fontsize-ensurer.reset-size11.size11,.katex .sizing.reset-size11.size11{font-size:1em}.katex .delimsizing.size1{font-family:KaTeX_Size1}.katex .delimsizing.size2{font-family:KaTeX_Size2}.katex .delimsizing.size3{font-family:KaTeX_Size3}.katex .delimsizing.size4{font-family:KaTeX_Size4}.katex .delimsizing.mult .delim-size1>span{font-family:KaTeX_Size1}.katex .delimsizing.mult .delim-size4>span{font-family:KaTeX_Size4}.katex .nulldelimiter{display:inline-block;width:.12em}.katex .delimcenter,.katex .op-symbol{position:relative}.katex .op-symbol.small-op{font-family:KaTeX_Size1}.katex .op-symbol.large-op{font-family:KaTeX_Size2}.katex .accent>.vlist-t,.katex .op-limits>.vlist-t{text-align:center}.katex .accent .accent-body{position:relative}.katex .accent .accent-body:not(.accent-full){width:0}.katex .overlay{display:block}.katex .mtable .vertical-separator{display:inline-block;min-width:1px}.katex .mtable .arraycolsep{display:inline-block}.katex .mtable .col-align-c>.vlist-t{text-align:center}.katex .mtable .col-align-l>.vlist-t{text-align:left}.katex .mtable .col-align-r>.vlist-t{text-align:right}.katex .svg-align{text-align:left}.katex svg{fill:currentColor;stroke:currentColor;fill-rule:nonzero;fill-opacity:1;stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;display:block;height:inherit;position:absolute;width:100%}.katex svg path{stroke:none}.katex img{border-style:none;max-height:none;max-width:none;min-height:0;min-width:0}.katex .stretchy{display:block;overflow:hidden;position:relative;width:100%}.katex .stretchy:after,.katex .stretchy:before{content:""}.katex .hide-tail{overflow:hidden;position:relative;width:100%}.katex .halfarrow-left{left:0;overflow:hidden;position:absolute;width:50.2%}.katex .halfarrow-right{overflow:hidden;position:absolute;right:0;width:50.2%}.katex .brace-left{left:0;overflow:hidden;position:absolute;width:25.1%}.katex .brace-center{left:25%;overflow:hidden;position:absolute;width:50%}.katex .brace-right{overflow:hidden;position:absolute;right:0;width:25.1%}.katex .x-arrow-pad{padding:0 .5em}.katex .cd-arrow-pad{padding:0 .55556em 0 .27778em}.katex .mover,.katex .munder,.katex .x-arrow{text-align:center}.katex .boxpad{padding:0 .3em}.katex .fbox,.katex .fcolorbox{border:.04em solid;box-sizing:border-box}.katex .cancel-pad{padding:0 .2em}.katex .cancel-lap{margin-left:-.2em;margin-right:-.2em}.katex .sout{border-bottom-style:solid;border-bottom-width:.08em}.katex .angl{border-right:.049em solid;border-top:.049em solid;box-sizing:border-content;margin-right:.03889em}.katex .anglpad{padding:0 .03889em}.katex .eqn-num:before{content:"(" counter(katexEqnNo) ")";counter-increment:katexEqnNo}.katex .mml-eqn-num:before{content:"(" counter(mmlEqnNo) ")";counter-increment:mmlEqnNo}.katex .mtr-glue{width:50%}.katex .cd-vert-arrow{display:inline-block;position:relative}.katex .cd-label-left{display:inline-block;position:absolute;right:-webkit-calc(50% + .3em);right:calc(50% + .3em);text-align:left}.katex .cd-label-right{display:inline-block;left:-webkit-calc(50% + .3em);left:calc(50% + .3em);position:absolute;text-align:right}.katex-display{display:block;margin:1em 0;text-align:center}.katex-display>.katex{display:block;text-align:center;white-space:nowrap}.katex-display>.katex>.katex-html{display:block;position:relative}.katex-display>.katex>.katex-html>.tag{position:absolute;right:0}.katex-display.leqno>.katex>.katex-html>.tag{left:0;right:auto}.katex-display.fleqn>.katex{padding-left:2em;text-align:left}body{counter-reset:katexEqnNo mmlEqnNo}

@charset "UTF-8";
@font-face {
  font-family: 'compass-icons';
  src: url(/static/files/77dce857bb9399f77ea0f56524dd001e.eot);
  src: url(/static/files/77dce857bb9399f77ea0f56524dd001e.eot#iefix) format('embedded-opentype'),
       url(/static/files/c3b7590c1d7baa74062dceae138254c8.woff2) format('woff2'),
       url(/static/files/aef77893ea603ff2b3e5cf1e25266408.woff) format('woff'),
       url(/static/files/f65421f0c3a26bea7944064f1bd37f7f.ttf) format('truetype'),
       url(/static/files/790499ad5a846a34a1d55fd0a3143e27.svg#compass-icons) format('svg');
  font-weight: normal;
  font-style: normal;
}
/* Chrome hack: SVG is rendered more smooth in Windozze. 100% magic, uncomment if you need it. */
/* Note, that will break hinting! In other OS-es font will be not as sharp as it could be */
/*
@media screen and (-webkit-min-device-pixel-ratio:0) {
  @font-face {
    font-family: 'compass-icons';
    src: url('../font/compass-icons.svg?23701167#compass-icons') format('svg');
  }
}
*/
[class^="icon-"]:before, [class*=" icon-"]:before {
  font-family: "compass-icons";
  font-style: normal;
  font-weight: normal;
  speak: never;

  display: inline-block;
  text-decoration: inherit;
  width: 1em;
  margin-right: .2em;
  text-align: center;
  /* opacity: .8; */

  /* For safety - reset parent styles, that can break glyph codes*/
  font-variant: normal;
  text-transform: none;

  /* fix buttons height, for twitter bootstrap */
  line-height: 1em;

  /* Animation center compensation - margins should be symmetric */
  /* remove if not needed */
  margin-left: .2em;

  /* you can be more comfortable with increased icons size */
  /* font-size: 120%; */

  /* Font smoothing. That was taken from TWBS */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;

  /* Uncomment for 3D effect */
  /* text-shadow: 1px 1px 1px rgba(127, 127, 127, 0.3); */
}

.icon-mattermost:before { content: '\e800'; } /* '' */
.icon-gfycat:before { content: '\e804'; } /* '' */
.icon-globe:before { content: '\e805'; } /* '' */
.icon-iframe-list-outline:before { content: '\e806'; } /* '' */
.icon-oauth:before { content: '\e807'; } /* '' */
.icon-server-outline:before { content: '\e80a'; } /* '' */
.icon-slash-forward-box-outline:before { content: '\e80b'; } /* '' */
.icon-webhook-incoming:before { content: '\e80c'; } /* '' */
.icon-webhook-outgoing:before { content: '\e80d'; } /* '' */
.icon-image-area-outline:before { content: '\e80e'; } /* '' */
.icon-emoticon-plus-outline:before { content: '\e80f'; } /* '' */
.icon-mark-as-unread:before { content: '\e810'; } /* '' */
.icon-arrow-back-ios:before { content: '\e811'; } /* '' */
.icon-arrow-forward-ios:before { content: '\e812'; } /* '' */
.icon-brand-zoom:before { content: '\e813'; } /* '' */
.icon-menu-variant:before { content: '\e814'; } /* '' */
.icon-message-check:before { content: '\e815'; } /* '' */
.icon-airplane-variant:before { content: '\e816'; } /* '' */
.icon-leaf-outline:before { content: '\e818'; } /* '' */
.icon-basketball:before { content: '\e819'; } /* '' */
.icon-emoticon-custom-outline:before { content: '\e81a'; } /* '' */
.icon-message-check-outline:before { content: '\e81b'; } /* '' */
.icon-image-broken-outline:before { content: '\e81c'; } /* '' */
.icon-format-header:before { content: '\e81d'; } /* '' */
.icon-circle-multiple-outline-lock:before { content: '\e81e'; } /* '' */
.icon-server-variant:before { content: '\e81f'; } /* '' */
.icon-server-variant-plus:before { content: '\e820'; } /* '' */
.icon-search-list:before { content: '\e821'; } /* '' */
.icon-brand-one-login:before { content: '\e825'; } /* '' */
.icon-key-variant-circle:before { content: '\e827'; } /* '' */
.icon-file-zip-outline:before { content: '\e828'; } /* '' */
.icon-file-patch-outline:before { content: '\e829'; } /* '' */
.icon-file-image-broken-outline:before { content: '\e82b'; } /* '' */
.icon-product-channels:before { content: '\e82c'; } /* '' */
.icon-product-playbooks:before { content: '\e82d'; } /* '' */
.icon-product-boards:before { content: '\e82e'; } /* '' */
.icon-products:before { content: '\e82f'; } /* '' */
.icon-file-audio-outline:before { content: '\e830'; } /* '' */
.icon-file-pdf-outline:before { content: '\e831'; } /* '' */
.icon-account-multiple-plus-outline:before { content: '\e832'; } /* '' */
.icon-file-gif:before { content: '\e833'; } /* '' */
.icon-file-text-outline-large:before { content: '\e900'; } /* '' */
.icon-file-word-outline-large:before { content: '\e901'; } /* '' */
.icon-file-excel-outline-large:before { content: '\e902'; } /* '' */
.icon-file-powerpoint-outline-large:before { content: '\e903'; } /* '' */
.icon-file-pdf-outline-large:before { content: '\e904'; } /* '' */
.icon-file-image-outline-large:before { content: '\e905'; } /* '' */
.icon-file-video-outline-large:before { content: '\e906'; } /* '' */
.icon-file-audio-outline-large:before { content: '\e907'; } /* '' */
.icon-file-generic-outline-large:before { content: '\e908'; } /* '' */
.icon-file-patch-outline-large:before { content: '\e909'; } /* '' */
.icon-file-zip-outline-large:before { content: '\e90a'; } /* '' */
.icon-file-code-outline-large:before { content: '\e90b'; } /* '' */
.icon-file-image-broken-outline-large:before { content: '\e90c'; } /* '' */
.icon-file-multiple-outline-large:before { content: '\e90d'; } /* '' */
.icon-account-multiple-outline:before { content: '󰀏'; } /* '\f000f' */
.icon-account-outline:before { content: '󰀓'; } /* '\f0013' */
.icon-airplane:before { content: '󰀝'; } /* '\f001d' */
.icon-alert-outline:before { content: '󰀪'; } /* '\f002a' */
.icon-apps:before { content: '󰀻'; } /* '\f003b' */
.icon-arrow-down:before { content: '󰁅'; } /* '\f0045' */
.icon-arrow-down-bold-circle-outline:before { content: '󰁈'; } /* '\f0048' */
.icon-arrow-expand-all:before { content: '󰁌'; } /* '\f004c' */
.icon-arrow-left:before { content: '󰁍'; } /* '\f004d' */
.icon-arrow-right:before { content: '󰁔'; } /* '\f0054' */
.icon-arrow-up:before { content: '󰁝'; } /* '\f005d' */
.icon-arrow-up-bold-circle-outline:before { content: '󰁠'; } /* '\f0060' */
.icon-at:before { content: '󰁥'; } /* '\f0065' */
.icon-flask-outline:before { content: '󰂖'; } /* '\f0096' */
.icon-bell-outline:before { content: '󰂜'; } /* '\f009c' */
.icon-bookmark:before { content: '󰃀'; } /* '\f00c0' */
.icon-bookmark-outline:before { content: '󰃃'; } /* '\f00c3' */
.icon-cellphone:before { content: '󰄜'; } /* '\f011c' */
.icon-chart-bar:before { content: '󰄨'; } /* '\f0128' */
.icon-chart-line:before { content: '󰄪'; } /* '\f012a' */
.icon-check:before { content: '󰄬'; } /* '\f012c' */
.icon-check-all:before { content: '󰄭'; } /* '\f012d' */
.icon-checkbox-blank-outline:before { content: '󰄱'; } /* '\f0131' */
.icon-checkbox-marked:before { content: '󰄲'; } /* '\f0132' */
.icon-chevron-down:before { content: '󰅀'; } /* '\f0140' */
.icon-chevron-left:before { content: '󰅁'; } /* '\f0141' */
.icon-chevron-right:before { content: '󰅂'; } /* '\f0142' */
.icon-chevron-up:before { content: '󰅃'; } /* '\f0143' */
.icon-clock-outline:before { content: '󰅐'; } /* '\f0150' */
.icon-close:before { content: '󰅖'; } /* '\f0156' */
.icon-close-circle:before { content: '󰅙'; } /* '\f0159' */
.icon-close-circle-outline:before { content: '󰅚'; } /* '\f015a' */
.icon-code-brackets:before { content: '󰅪'; } /* '\f016a' */
.icon-code-tags:before { content: '󰅴'; } /* '\f0174' */
.icon-cog-outline:before { content: '󰅽'; } /* '\f017d' */
.icon-console:before { content: '󰆍'; } /* '\f018d' */
.icon-content-copy:before { content: '󰆏'; } /* '\f018f' */
.icon-credit-card-outline:before { content: '󰆛'; } /* '\f019b' */
.icon-currency-usd:before { content: '󰇁'; } /* '\f01c1' */
.icon-dots-horizontal:before { content: '󰇘'; } /* '\f01d8' */
.icon-dots-vertical:before { content: '󰇙'; } /* '\f01d9' */
.icon-drag-vertical:before { content: '󰇝'; } /* '\f01dd' */
.icon-email-outline:before { content: '󰇰'; } /* '\f01f0' */
.icon-emoticon-outline:before { content: '󰇲'; } /* '\f01f2' */
.icon-emoticon-happy-outline:before { content: '󰇵'; } /* '\f01f5' */
.icon-exit-to-app:before { content: '󰈆'; } /* '\f0206' */
.icon-file-generic-outline:before { content: '󰈤'; } /* '\f0224' */
.icon-filter-variant:before { content: '󰈶'; } /* '\f0236' */
.icon-fire:before { content: '󰈸'; } /* '\f0238' */
.icon-flag:before { content: '󰈻'; } /* '\f023b' */
.icon-flag-outline:before { content: '󰈽'; } /* '\f023d' */
.icon-folder-outline:before { content: '󰉖'; } /* '\f0256' */
.icon-format-bold:before { content: '󰉤'; } /* '\f0264' */
.icon-format-clear:before { content: '󰉥'; } /* '\f0265' */
.icon-format-header-1:before { content: '󰉫'; } /* '\f026b' */
.icon-format-header-2:before { content: '󰉬'; } /* '\f026c' */
.icon-format-header-3:before { content: '󰉭'; } /* '\f026d' */
.icon-format-header-4:before { content: '󰉮'; } /* '\f026e' */
.icon-format-header-5:before { content: '󰉯'; } /* '\f026f' */
.icon-format-header-6:before { content: '󰉰'; } /* '\f0270' */
.icon-format-italic:before { content: '󰉷'; } /* '\f0277' */
.icon-format-list-bulleted:before { content: '󰉹'; } /* '\f0279' */
.icon-format-list-numbered:before { content: '󰉻'; } /* '\f027b' */
.icon-format-strikethrough-variant:before { content: '󰊁'; } /* '\f0281' */
.icon-github-circle:before { content: '󰊤'; } /* '\f02a4' */
.icon-glasses:before { content: '󰊪'; } /* '\f02aa' */
.icon-brand-google:before { content: '󰊭'; } /* '\f02ad' */
.icon-heart-outline:before { content: '󰋕'; } /* '\f02d5' */
.icon-help:before { content: '󰋖'; } /* '\f02d6' */
.icon-information-outline:before { content: '󰋽'; } /* '\f02fd' */
.icon-key-variant:before { content: '󰌋'; } /* '\f030b' */
.icon-laptop:before { content: '󰌢'; } /* '\f0322' */
.icon-leaf:before { content: '󰌪'; } /* '\f032a' */
.icon-lightbulb-outline:before { content: '󰌶'; } /* '\f0336' */
.icon-link-variant:before { content: '󰌹'; } /* '\f0339' */
.icon-link-variant-off:before { content: '󰌺'; } /* '\f033a' */
.icon-lock:before { content: '󰌾'; } /* '\f033e' */
.icon-lock-outline:before { content: '󰍁'; } /* '\f0341' */
.icon-magnify:before { content: '󰍉'; } /* '\f0349' */
.icon-magnify-minus:before { content: '󰍊'; } /* '\f034a' */
.icon-magnify-plus:before { content: '󰍋'; } /* '\f034b' */
.icon-menu:before { content: '󰍜'; } /* '\f035c' */
.icon-menu-down:before { content: '󰍝'; } /* '\f035d' */
.icon-menu-left:before { content: '󰍞'; } /* '\f035e' */
.icon-menu-right:before { content: '󰍟'; } /* '\f035f' */
.icon-menu-up:before { content: '󰍠'; } /* '\f0360' */
.icon-message-text-outline:before { content: '󰍪'; } /* '\f036a' */
.icon-microphone:before { content: '󰍬'; } /* '\f036c' */
.icon-microphone-off:before { content: '󰍭'; } /* '\f036d' */
.icon-minus:before { content: '󰍴'; } /* '\f0374' */
.icon-minus-box:before { content: '󰍵'; } /* '\f0375' */
.icon-minus-circle:before { content: '󰍶'; } /* '\f0376' */
.icon-minus-circle-outline:before { content: '󰍷'; } /* '\f0377' */
.icon-monitor:before { content: '󰍹'; } /* '\f0379' */
.icon-brand-office-365:before { content: '󰏆'; } /* '\f03c6' */
.icon-open-in-new:before { content: '󰏌'; } /* '\f03cc' */
.icon-paperclip:before { content: '󰏢'; } /* '\f03e2' */
.icon-pause:before { content: '󰏤'; } /* '\f03e4' */
.icon-phone-hangup:before { content: '󰏵'; } /* '\f03f5' */
.icon-phone-in-talk:before { content: '󰏶'; } /* '\f03f6' */
.icon-pin:before { content: '󰐃'; } /* '\f0403' */
.icon-play:before { content: '󰐊'; } /* '\f040a' */
.icon-plus:before { content: '󰐕'; } /* '\f0415' */
.icon-plus-box:before { content: '󰐖'; } /* '\f0416' */
.icon-pound:before { content: '󰐣'; } /* '\f0423' */
.icon-radiobox-blank:before { content: '󰐽'; } /* '\f043d' */
.icon-radiobox-marked:before { content: '󰐾'; } /* '\f043e' */
.icon-refresh:before { content: '󰑐'; } /* '\f0450' */
.icon-send:before { content: '󰒊'; } /* '\f048a' */
.icon-shield-outline:before { content: '󰒙'; } /* '\f0499' */
.icon-sitemap:before { content: '󰒪'; } /* '\f04aa' */
.icon-soccer:before { content: '󰒸'; } /* '\f04b8' */
.icon-source-pull:before { content: '󰓂'; } /* '\f04c2' */
.icon-star:before { content: '󰓎'; } /* '\f04ce' */
.icon-star-outline:before { content: '󰓒'; } /* '\f04d2' */
.icon-sync:before { content: '󰓦'; } /* '\f04e6' */
.icon-thumbs-up-down:before { content: '󰔕'; } /* '\f0515' */
.icon-beach-umbrella-outline:before { content: '󰕋'; } /* '\f054b' */
.icon-volume-high:before { content: '󰕾'; } /* '\f057e' */
.icon-sort-alphabetical-ascending:before { content: '󰖽'; } /* '\f05bd' */
.icon-playlist-check:before { content: '󰗇'; } /* '\f05c7' */
.icon-alert-circle-outline:before { content: '󰗖'; } /* '\f05d6' */
.icon-check-circle:before { content: '󰗠'; } /* '\f05e0' */
.icon-check-circle-outline:before { content: '󰗡'; } /* '\f05e1' */
.icon-email-variant:before { content: '󰗰'; } /* '\f05f0' */
.icon-food-fork-drink:before { content: '󰗲'; } /* '\f05f2' */
.icon-logout-variant:before { content: '󰗽'; } /* '\f05fd' */
.icon-arrow-collapse:before { content: '󰘕'; } /* '\f0615' */
.icon-arrow-expand:before { content: '󰘖'; } /* '\f0616' */
.icon-help-circle-outline:before { content: '󰘥'; } /* '\f0625' */
.icon-source-branch:before { content: '󰘬'; } /* '\f062c' */
.icon-tune:before { content: '󰘮'; } /* '\f062e' */
.icon-webhook:before { content: '󰘯'; } /* '\f062f' */
.icon-circle-multiple-outline:before { content: '󰚕'; } /* '\f0695' */
.icon-update:before { content: '󰚰'; } /* '\f06b0' */
.icon-eye-outline:before { content: '󰛐'; } /* '\f06d0' */
.icon-eye-off-outline:before { content: '󰛑'; } /* '\f06d1' */
.icon-infinity:before { content: '󰛤'; } /* '\f06e4' */
.icon-plus-box-outline:before { content: '󰜄'; } /* '\f0704' */
.icon-cancel:before { content: '󰜺'; } /* '\f073a' */
.icon-format-quote-open:before { content: '󰝗'; } /* '\f0757' */
.icon-square:before { content: '󰝤'; } /* '\f0764' */
.icon-circle-outline:before { content: '󰝦'; } /* '\f0766' */
.icon-account-plus-outline:before { content: '󰠁'; } /* '\f0801' */
.icon-forum-outline:before { content: '󰠢'; } /* '\f0822' */
.icon-settings-outline:before { content: '󰢻'; } /* '\f08bb' */
.icon-hammer:before { content: '󰣪'; } /* '\f08ea' */
.icon-pin-outline:before { content: '󰤱'; } /* '\f0931' */
.icon-clock:before { content: '󰥔'; } /* '\f0954' */
.icon-image-outline:before { content: '󰥶'; } /* '\f0976' */
.icon-arrow-right-bold-outline:before { content: '󰧂'; } /* '\f09c2' */
.icon-email-plus-outline:before { content: '󰧬'; } /* '\f09ec' */
.icon-file-text-outline:before { content: '󰧮'; } /* '\f09ee' */
.icon-layers-outline:before { content: '󰧾'; } /* '\f09fe' */
.icon-trash-can-outline:before { content: '󰩺'; } /* '\f0a7a' */
.icon-bell-off-outline:before { content: '󰪑'; } /* '\f0a91' */
.icon-account-minus-outline:before { content: '󰫬'; } /* '\f0aec' */
.icon-chevron-down-circle-outline:before { content: '󰬧'; } /* '\f0b27' */
.icon-format-letter-case:before { content: '󰬴'; } /* '\f0b34' */
.icon-calendar-outline:before { content: '󰭧'; } /* '\f0b67' */
.icon-download-outline:before { content: '󰮏'; } /* '\f0b8f' */
.icon-export-variant:before { content: '󰮓'; } /* '\f0b93' */
.icon-folder-plus-outline:before { content: '󰮝'; } /* '\f0b9d' */
.icon-brand-gitlab:before { content: '󰮠'; } /* '\f0ba0' */
.icon-home-variant-outline:before { content: '󰮧'; } /* '\f0ba7' */
.icon-video-outline:before { content: '󰯜'; } /* '\f0bdc' */
.icon-calendar-check-outline:before { content: '󰱄'; } /* '\f0c44' */
.icon-food-apple:before { content: '󰲄'; } /* '\f0c84' */
.icon-pencil-outline:before { content: '󰲶'; } /* '\f0cb6' */
.icon-camera-outline:before { content: '󰵝'; } /* '\f0d5d' */
.icon-phone-outline:before { content: '󰷰'; } /* '\f0df0' */
.icon-palette-outline:before { content: '󰸌'; } /* '\f0e0c' */
.icon-file-video-outline:before { content: '󰸬'; } /* '\f0e2c' */
.icon-hand-right:before { content: '󰹇'; } /* '\f0e47' */
.icon-file-image-outline:before { content: '󰺰'; } /* '\f0eb0' */
.icon-notebook-outline:before { content: '󰺿'; } /* '\f0ebf' */
.icon-shield-alert-outline:before { content: '󰻍'; } /* '\f0ecd' */
.icon-reply-outline:before { content: '󰼠'; } /* '\f0f20' */
.icon-draw:before { content: '󰽉'; } /* '\f0f49' */
.icon-slash-forward:before { content: '󰿟'; } /* '\f0fdf' */
.icon-file-code-outline:before { content: '󱀫'; } /* '\f102b' */
.icon-file-excel-outline:before { content: '󱀭'; } /* '\f102d' */
.icon-file-multiple-outline:before { content: '󱀲'; } /* '\f1032' */
.icon-file-powerpoint-outline:before { content: '󱀵'; } /* '\f1035' */
.icon-file-word-outline:before { content: '󱀾'; } /* '\f103e' */
.icon-dock-left:before { content: '󱂪'; } /* '\f10aa' */
.icon-dock-window:before { content: '󱂬'; } /* '\f10ac' */
.icon-message-plus-outline:before { content: '󱂻'; } /* '\f10bb' */
.icon-send-outline:before { content: '󱅥'; } /* '\f1165' */
.icon-message-minus-outline:before { content: '󱅯'; } /* '\f116f' */
.icon-crown-outline:before { content: '󱇐'; } /* '\f11d0' */
.icon-view-grid-plus-outline:before { content: '󱇚'; } /* '\f11da' */
.icon-archive-outline:before { content: '󱈎'; } /* '\f120e' */
.icon-exclamation-thick:before { content: '󱈸'; } /* '\f1238' */
.icon-folder-move-outline:before { content: '󱉆'; } /* '\f1246' */
.icon-archive-arrow-up-outline:before { content: '󱉜'; } /* '\f125c' */
.icon-power-plug-outline:before { content: '󱐥'; } /* '\f1425' */
.icon-car-outline:before { content: '󱓭'; } /* '\f14ed' */
.icon-share-variant-outline:before { content: '󱔔'; } /* '\f1514' */
.icon-application-cog:before { content: '󱕷'; } /* '\f1577' */
.icon-robot-happy:before { content: '󱜙'; } /* '\f1719' */

.annnouncementBar__purchaseNow{display:block;padding:12px 20px;border:none;margin-top:15px;background:var(--sys-button-bg);border-radius:4px;color:var(--sys-button-color)}.annnouncementBar__purchaseNow span{font-size:14px;font-weight:600;line-height:14px}
.contact-us{display:block;padding:12px 20px;border:1px solid var(--sys-button-bg);margin-top:15px;margin-left:10px;background-color:var(--sys-center-channel-bg);border-radius:4px;color:var(--sys-button-bg)}.contact-us span{font-size:14px;font-weight:600;line-height:14px}

/*# sourceMappingURL=main.fee395d4b8af194f7fd2.css.map*/